	; IntyBASIC compiler v1.2 Aug/19/2015
        ;
        ; Prologue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Spacing adjustment and more comments.
        ; Revision: Apr/01/2014. It now sets the starting screen pos. for PRINT
	; Revision: Aug/26/2014. Added PAL detection code.
	; Revision: Dec/12/2014. Added optimized constant multiplication routines
	;                        by James Pujals.
	; Revision: Jan/25/2015. Added marker for automatic title replacement.
	;                        (option --title of IntyBASIC)
	; Revision: Aug/06/2015. Turns off ECS sound. Seed random generator using
	;                        trash in 16-bit RAM. Solved bugs and optimized
	;                        macro for constant multiplication.
	; 

        ROMW 16
        ORG $5000

        ; This macro will 'eat' SRCFILE directives if the assembler doesn't support the directive.
        IF ( DEFINED __FEATURE.SRCFILE ) = 0
            MACRO SRCFILE x, y
            ; macro must be non-empty, but a comment works fine.
            ENDM
        ENDI

        ;
        ; ROM header
        ;
        BIDECLE _ZERO           ; MOB picture base
        BIDECLE _ZERO           ; Process table
        BIDECLE _MAIN           ; Program start
        BIDECLE _ZERO           ; Background base image
        BIDECLE _ONES           ; GRAM
        BIDECLE _TITLE          ; Cartridge title and date
        DECLE   $03C0           ; No ECS title, jump to code after title,
                                ; ... no clicks
                                
_ZERO:  DECLE   $0000           ; Border control
        DECLE   $0000           ; 0 = color stack, 1 = f/b mode
        
_ONES:  DECLE   $0001, $0001    ; Initial color stack 0 and 1: Blue
        DECLE   $0001, $0001    ; Initial color stack 2 and 3: Blue
        DECLE   $0001           ; Initial border color: Blue

C_WHT:  EQU $0007

CLRSCR: MVII #$200,R4           ; Used also for CLS
        MVII #$F0,R1
FILLZERO:
        CLRR R0
MEMSET:
        MVO@ R0,R4
        DECR R1
        BNE MEMSET
        JR R5

        ;
        ; Title, Intellivision EXEC will jump over it and start
        ; execution directly in _MAIN
        ;
	; Note mark is for automatic replacement by IntyBASIC
_TITLE:
	BYTE 115,'IntyBASIC program',0
        
        ;
        ; Main program
        ;
_MAIN:
        DIS
        MVII #STACK,R6

_MAIN0:
        ;
        ; Clean memory
        ;
        MVII #$00e,R1           ; 14 of sound (ECS)
        MVII #$0f0,R4           ; ECS PSG
        CALL FILLZERO
        MVII #$0fe,R1           ; 240 words of 8 bits plus 14 of sound
        MVII #$100,R4           ; 8-bit scratch RAM
        CALL FILLZERO

	; Seed random generator using 16 bit RAM (not cleared by EXEC)
	CLRR R0
	MVII #$02F0,R4
	MVII #$0110/4,R1        ; Includes phantom memory for extra randomness
_MAIN4:                         ; This loop is courtesy of GroovyBee
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	DECR R1
	BNE _MAIN4
	MVO R0,_rand

        MVII #$058,R1           ; 88 words of 16 bits
        MVII #$308,R4           ; 16-bit scratch RAM
        CALL FILLZERO

        CALL CLRSCR             ; Clean up screen

        MVII #_pal1_vector,R0 ; Points to interrupt vector
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1

        EIS

_MAIN1:	MVI _ntsc,R0
	CMPI #3,R0
	BNE _MAIN1
	CLRR R2
_MAIN2:	INCR R2
	MVI _ntsc,R0
	CMPI #4,R0
	BNE _MAIN2

        ; 387 for PAL in jzintv
        ; 444 for NTSC in jzintv
        CMPI #415,R2
        MVII #1,R0
        BGE _MAIN3
        CLRR R0
_MAIN3: MVO R0,_ntsc

        CALL _wait
	CALL _init_music
        MVII #1,R0
        MVO R0,_mode_select
        MVII #$038,R0
        MVO R0,$01F8            ; Configures sound
        MVO R0,$00F8            ; Configures sound (ECS)
        CALL _wait

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- James Pujals (DZ-Jay), 2014                              *;
;* ======================================================================== *;

; Modified by Oscar Toledo G. (nanochess), Aug/06/2015
; * Tested all multiplications with automated test.
; * Accelerated multiplication by 7,14,15,28,31,60,62,63,112,120,124
; * Solved bug in multiplication by 23,39,46,47,55,71,78,79,87,92,93,94,95,103,110,111,119
; * Improved sequence of instructions to be more interruptible.

;; ======================================================================== ;;
;;  MULT reg, tmp, const                                                    ;;
;;  Multiplies "reg" by constant "const" and using "tmp" for temporary      ;;
;;  calculations.  The result is placed in "reg."  The multiplication is    ;;
;;  performed by an optimal combination of shifts, additions, and           ;;
;;  subtractions.                                                           ;;
;;                                                                          ;;
;;  NOTE:   The resulting contents of the "tmp" are undefined.              ;;
;;                                                                          ;;
;;  ARGUMENTS                                                               ;;
;;      reg         A register containing the multiplicand.                 ;;
;;      tmp         A register for temporary calculations.                  ;;
;;      const       The constant multiplier.                                ;;
;;                                                                          ;;
;;  OUTPUT                                                                  ;;
;;      reg         Output value.                                           ;;
;;      tmp         Trashed.                                                ;;
;;      .ERR.Failed True if operation failed.                               ;;
;; ======================================================================== ;;
MACRO   MULT reg, tmp, const
;
    LISTING "code"

_mul.const      QSET    %const%
_mul.done       QSET    0

        IF (%const% > $7F)
_mul.const      QSET    (_mul.const SHR 1)
                SLL     %reg%,  1
        ENDI

        ; Multiply by $00 (0)
        IF (_mul.const = $00)
_mul.done       QSET    -1
                CLRR    %reg%
        ENDI

        ; Multiply by $01 (1)
        IF (_mul.const = $01)
_mul.done       QSET    -1
                ; Nothing to do
        ENDI

        ; Multiply by $02 (2)
        IF (_mul.const = $02)
_mul.done       QSET    -1
                SLL     %reg%,  1
        ENDI

        ; Multiply by $03 (3)
        IF (_mul.const = $03)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $04 (4)
        IF (_mul.const = $04)
_mul.done       QSET    -1
                SLL     %reg%,  2
        ENDI

        ; Multiply by $05 (5)
        IF (_mul.const = $05)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $06 (6)
        IF (_mul.const = $06)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $07 (7)
        IF (_mul.const = $07)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $08 (8)
        IF (_mul.const = $08)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
        ENDI

        ; Multiply by $09 (9)
        IF (_mul.const = $09)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0A (10)
        IF (_mul.const = $0A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0B (11)
        IF (_mul.const = $0B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0C (12)
        IF (_mul.const = $0C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0D (13)
        IF (_mul.const = $0D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0E (14)
        IF (_mul.const = $0E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0F (15)
        IF (_mul.const = $0F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $10 (16)
        IF (_mul.const = $10)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $11 (17)
        IF (_mul.const = $11)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $12 (18)
        IF (_mul.const = $12)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $13 (19)
        IF (_mul.const = $13)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $14 (20)
        IF (_mul.const = $14)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $15 (21)
        IF (_mul.const = $15)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $16 (22)
        IF (_mul.const = $16)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $17 (23)
        IF (_mul.const = $17)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $18 (24)
        IF (_mul.const = $18)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $19 (25)
        IF (_mul.const = $19)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1A (26)
        IF (_mul.const = $1A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1B (27)
        IF (_mul.const = $1B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1C (28)
        IF (_mul.const = $1C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1D (29)
        IF (_mul.const = $1D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1E (30)
        IF (_mul.const = $1E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1F (31)
        IF (_mul.const = $1F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $20 (32)
        IF (_mul.const = $20)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
        ENDI

        ; Multiply by $21 (33)
        IF (_mul.const = $21)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $22 (34)
        IF (_mul.const = $22)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $23 (35)
        IF (_mul.const = $23)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $24 (36)
        IF (_mul.const = $24)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $25 (37)
        IF (_mul.const = $25)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $26 (38)
        IF (_mul.const = $26)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $27 (39)
        IF (_mul.const = $27)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $28 (40)
        IF (_mul.const = $28)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $29 (41)
        IF (_mul.const = $29)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2A (42)
        IF (_mul.const = $2A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2B (43)
        IF (_mul.const = $2B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2C (44)
        IF (_mul.const = $2C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2D (45)
        IF (_mul.const = $2D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2E (46)
        IF (_mul.const = $2E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $2F (47)
        IF (_mul.const = $2F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $30 (48)
        IF (_mul.const = $30)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $31 (49)
        IF (_mul.const = $31)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $32 (50)
        IF (_mul.const = $32)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $33 (51)
        IF (_mul.const = $33)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $34 (52)
        IF (_mul.const = $34)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $35 (53)
        IF (_mul.const = $35)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $36 (54)
        IF (_mul.const = $36)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $37 (55)
        IF (_mul.const = $37)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
		SLL	%reg%,	1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $38 (56)
        IF (_mul.const = $38)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $39 (57)
        IF (_mul.const = $39)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3A (58)
        IF (_mul.const = $3A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3B (59)
        IF (_mul.const = $3B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3C (60)
        IF (_mul.const = $3C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3D (61)
        IF (_mul.const = $3D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3E (62)
        IF (_mul.const = $3E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3F (63)
        IF (_mul.const = $3F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $40 (64)
        IF (_mul.const = $40)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $41 (65)
        IF (_mul.const = $41)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $42 (66)
        IF (_mul.const = $42)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $43 (67)
        IF (_mul.const = $43)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $44 (68)
        IF (_mul.const = $44)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $45 (69)
        IF (_mul.const = $45)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $46 (70)
        IF (_mul.const = $46)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $47 (71)
        IF (_mul.const = $47)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $48 (72)
        IF (_mul.const = $48)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $49 (73)
        IF (_mul.const = $49)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4A (74)
        IF (_mul.const = $4A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4B (75)
        IF (_mul.const = $4B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4C (76)
        IF (_mul.const = $4C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4D (77)
        IF (_mul.const = $4D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4E (78)
        IF (_mul.const = $4E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $4F (79)
        IF (_mul.const = $4F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $50 (80)
        IF (_mul.const = $50)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $51 (81)
        IF (_mul.const = $51)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $52 (82)
        IF (_mul.const = $52)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $53 (83)
        IF (_mul.const = $53)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $54 (84)
        IF (_mul.const = $54)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $55 (85)
        IF (_mul.const = $55)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $56 (86)
        IF (_mul.const = $56)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $57 (87)
        IF (_mul.const = $57)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR    %reg%,	%tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $58 (88)
        IF (_mul.const = $58)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $59 (89)
        IF (_mul.const = $59)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5A (90)
        IF (_mul.const = $5A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5B (91)
        IF (_mul.const = $5B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5C (92)
        IF (_mul.const = $5C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5D (93)
        IF (_mul.const = $5D)
_mul.done       QSET    -1
		MOVR	%reg%,	%tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5E (94)
        IF (_mul.const = $5E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5F (95)
        IF (_mul.const = $5F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                ADDR	%reg%,	%reg%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $60 (96)
        IF (_mul.const = $60)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $61 (97)
        IF (_mul.const = $61)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $62 (98)
        IF (_mul.const = $62)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $63 (99)
        IF (_mul.const = $63)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $64 (100)
        IF (_mul.const = $64)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $65 (101)
        IF (_mul.const = $65)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $66 (102)
        IF (_mul.const = $66)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $67 (103)
        IF (_mul.const = $67)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $68 (104)
        IF (_mul.const = $68)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $69 (105)
        IF (_mul.const = $69)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6A (106)
        IF (_mul.const = $6A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6B (107)
        IF (_mul.const = $6B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6C (108)
        IF (_mul.const = $6C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6D (109)
        IF (_mul.const = $6D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6E (110)
        IF (_mul.const = $6E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $6F (111)
        IF (_mul.const = $6F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $70 (112)
        IF (_mul.const = $70)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $71 (113)
        IF (_mul.const = $71)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $72 (114)
        IF (_mul.const = $72)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $73 (115)
        IF (_mul.const = $73)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $74 (116)
        IF (_mul.const = $74)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $75 (117)
        IF (_mul.const = $75)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $76 (118)
        IF (_mul.const = $76)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $77 (119)
        IF (_mul.const = $77)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $78 (120)
        IF (_mul.const = $78)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $79 (121)
        IF (_mul.const = $79)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7A (122)
        IF (_mul.const = $7A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7B (123)
        IF (_mul.const = $7B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7C (124)
        IF (_mul.const = $7C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7D (125)
        IF (_mul.const = $7D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7E (126)
        IF (_mul.const = $7E)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SWAP    %reg%,  1
                SLR     %reg%,  1
		ADDR    %tmp%,  %tmp%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7F (127)
        IF (_mul.const = $7F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SWAP    %reg%, 1
                SLR     %reg%, 1
                SUBR    %tmp%,  %reg%
        ENDI

        IF  (_mul.done = 0)
            ERR $("Invalid multiplication constant \'%const%\', must be between 0 and ", $#($7F), ".")
        ENDI

    LISTING "prev"
ENDM

;; ======================================================================== ;;
;;  EOF: pm:mac:lang:mult                                                   ;;
;; ======================================================================== ;;

	;FILE whalehunt_1a.bas
	;[1] 
	SRCFILE "whalehunt_1a.bas",1
	;[2] REM Created: Tue Aug 25 13:04:02 2015 by Robby Hannan (Emerson)
	SRCFILE "whalehunt_1a.bas",2
	;[3] 
	SRCFILE "whalehunt_1a.bas",3
	;[4] REM =====CONSOLE MEMORY ADDRESSES=====
	SRCFILE "whalehunt_1a.bas",4
	;[5] REM $0500-$09F6	
	SRCFILE "whalehunt_1a.bas",5
	;[6] REM	$5000-$6F88
	SRCFILE "whalehunt_1a.bas",6
	;[7] REM	$4820-$4FD0	
	SRCFILE "whalehunt_1a.bas",7
	;[8] REM $2000-2994
	SRCFILE "whalehunt_1a.bas",8
	;[9] REM $8040-$9340
	SRCFILE "whalehunt_1a.bas",9
	;[10] REM	$2995-$2FFF		free
	SRCFILE "whalehunt_1a.bas",10
	;[11] REM	$4000-$47FF		free
	SRCFILE "whalehunt_1a.bas",11
	;[12] REM	$7001-$77FF		free
	SRCFILE "whalehunt_1a.bas",12
	;[13] REM	$9341-$B7FF		free
	SRCFILE "whalehunt_1a.bas",13
	;[14] REM $EA23-$F7FF		free
	SRCFILE "whalehunt_1a.bas",14
	;[15] REM $C040-$EA22		beat_level_music, dim_check, row_throw, sail, upgrade backgrounds data, sounds and music
	SRCFILE "whalehunt_1a.bas",15
	;[16] REM $B800-$BF7F		item upgrade [bitmaps only] 				(rom only memory)
	SRCFILE "whalehunt_1a.bas",16
	;[17] REM	$7800-$7E5B		sprites, map and background	data 			(rom only memory)
	SRCFILE "whalehunt_1a.bas",17
	;[18] REM $F800-$FD93		title_screen, lose_life, beat_level data 	(rom only memory)
	SRCFILE "whalehunt_1a.bas",18
	;[19] 
	SRCFILE "whalehunt_1a.bas",19
	;[20] REM =====ROW THROW GRAM MAP=====
	SRCFILE "whalehunt_1a.bas",20
	;[21] REM 0-52	row_throw_bitmaps
	SRCFILE "whalehunt_1a.bas",21
	;[22] REM 53-55	paddle	'hands = 2
	SRCFILE "whalehunt_1a.bas",22
	;[23] REM 54-55	harpoon	'hands = 1
	SRCFILE "whalehunt_1a.bas",23
	;[24] REM	56		???
	SRCFILE "whalehunt_1a.bas",24
	;[25] REM 57-59	blood
	SRCFILE "whalehunt_1a.bas",25
	;[26] REM 60-62	whale_bitmaps
	SRCFILE "whalehunt_1a.bas",26
	;[27] REM	63		harpoon_3
	SRCFILE "whalehunt_1a.bas",27
	;[28] 
	SRCFILE "whalehunt_1a.bas",28
	;[29] REM =====SAIL GRAM MAP=====
	SRCFILE "whalehunt_1a.bas",29
	;[30] REM 0-56	sail_bitmaps 'hands = 3	
	SRCFILE "whalehunt_1a.bas",30
	;[31] REM	57-59	blood
	SRCFILE "whalehunt_1a.bas",31
	;[32] REM 60-62	whale bitmaps
	SRCFILE "whalehunt_1a.bas",32
	;[33] REM	63		harpoon_3
	SRCFILE "whalehunt_1a.bas",33
	;[34] 	
	SRCFILE "whalehunt_1a.bas",34
	;[35] include "constants.bas"	
	SRCFILE "whalehunt_1a.bas",35
	;FILE /Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas
	;[1] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",1
	;[2] REM HEADER - CONSTANTS.BAS
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",2
	;[3] REM 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",3
	;[4] REM Started by Mark Ball, July 2015
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",4
	;[5] REM
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",5
	;[6] REM Constants for use in IntyBASIC
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",6
	;[7] REM
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",7
	;[8] REM HISTORY
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",8
	;[9] REM -------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",9
	;[10] REM 1.00F 05/07/15 - First version.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",10
	;[11] REM 1.01F 07/07/15 - Added disc directions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",11
	;[12] REM                - Added background modes.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",12
	;[13] REM                - Minor comment changes.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",13
	;[14] REM 1.02F 08/07/15 - Renamed constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",14
	;[15] REM                - Added background access information.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",15
	;[16] REM                - Adjustments to layout.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",16
	;[17] REM 1.03F 08/07/15 - Fixed comment delimiter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",17
	;[18] REM 1.04F 11/07/15 - Added useful functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",18
	;[19] REM	               - Added controller movement mask.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",19
	;[20] REM 1.05F 11/07/15 - Added BACKGROUND constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",20
	;[21] REM 1.06F 11/07/15 - Changed Y, X order to X, Y in DEF FN functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",21
	;[22] REM 1.07F 11/07/15 - Added colour stack advance.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",22
	;[23] REM 1.08F 12/07/15 - Added functions for sprite position handling.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",23
	;[24] REM 1.09F 12/07/15 - Added a function for resetting a sprite.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",24
	;[25] REM 1.10F 13/07/15 - Added keypad constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",25
	;[26] REM 1.11F 13/07/15 - Added side button constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",26
	;[27] REM 1.12F 13/07/15 - Updated sprite functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",27
	;[28] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",28
	;[29] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",29
	;[30] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",30
	;[31] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",31
	;[32] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",32
	;[33] REM Background information.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",33
	;[34] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",34
	;[35] CONST BACKTAB				= $0200		' Start of the background in RAM.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",35
	;[36] CONST BACKGROUND_ROWS		= 12		' Height of the background in cards.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",36
	;[37] CONST BACKGROUND_COLUMNS	= 20		' Width of the background in cards.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",37
	;[38] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",38
	;[39] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",39
	;[40] REM Background GRAM cards.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",40
	;[41] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",41
	;[42] CONST BG00 					= $0800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",42
	;[43] CONST BG01 					= $0808
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",43
	;[44] CONST BG02 					= $0810
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",44
	;[45] CONST BG03 					= $0818
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",45
	;[46] CONST BG04 					= $0820
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",46
	;[47] CONST BG05 					= $0828
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",47
	;[48] CONST BG06 					= $0830
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",48
	;[49] CONST BG07 					= $0838
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",49
	;[50] CONST BG08 					= $0840
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",50
	;[51] CONST BG09 					= $0848
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",51
	;[52] CONST BG10 					= $0850
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",52
	;[53] CONST BG11 					= $0858
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",53
	;[54] CONST BG12 					= $0860
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",54
	;[55] CONST BG13 					= $0868
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",55
	;[56] CONST BG14 					= $0870
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",56
	;[57] CONST BG15 					= $0878
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",57
	;[58] CONST BG16 					= $0880
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",58
	;[59] CONST BG17 					= $0888
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",59
	;[60] CONST BG18 					= $0890
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",60
	;[61] CONST BG19 					= $0898
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",61
	;[62] CONST BG20 					= $08A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",62
	;[63] CONST BG21 					= $08A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",63
	;[64] CONST BG22 					= $08B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",64
	;[65] CONST BG23 					= $08B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",65
	;[66] CONST BG24 					= $08C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",66
	;[67] CONST BG25 					= $08C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",67
	;[68] CONST BG26 					= $08D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",68
	;[69] CONST BG27 					= $08D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",69
	;[70] CONST BG28 					= $08E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",70
	;[71] CONST BG29 					= $08E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",71
	;[72] CONST BG30 					= $08F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",72
	;[73] CONST BG31 					= $08F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",73
	;[74] CONST BG32 					= $0900
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",74
	;[75] CONST BG33 					= $0908
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",75
	;[76] CONST BG34 					= $0910
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",76
	;[77] CONST BG35 					= $0918
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",77
	;[78] CONST BG36 					= $0920
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",78
	;[79] CONST BG37 					= $0928
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",79
	;[80] CONST BG38 					= $0930
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",80
	;[81] CONST BG39 					= $0938
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",81
	;[82] CONST BG40 					= $0940
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",82
	;[83] CONST BG41 					= $0948
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",83
	;[84] CONST BG42 					= $0950
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",84
	;[85] CONST BG43 					= $0958
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",85
	;[86] CONST BG44 					= $0960
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",86
	;[87] CONST BG45 					= $0968
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",87
	;[88] CONST BG46 					= $0970
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",88
	;[89] CONST BG47 					= $0978
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",89
	;[90] CONST BG48 					= $0980
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",90
	;[91] CONST BG49 					= $0988
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",91
	;[92] CONST BG50 					= $0990
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",92
	;[93] CONST BG51 					= $0998
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",93
	;[94] CONST BG52 					= $09A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",94
	;[95] CONST BG53 					= $09A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",95
	;[96] CONST BG54 					= $09B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",96
	;[97] CONST BG55 					= $09B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",97
	;[98] CONST BG56 					= $09C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",98
	;[99] CONST BG57 					= $09C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",99
	;[100] CONST BG58 					= $09D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",100
	;[101] CONST BG59 					= $09D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",101
	;[102] CONST BG60 					= $09E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",102
	;[103] CONST BG61 					= $09E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",103
	;[104] CONST BG62 					= $09F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",104
	;[105] CONST BG63 					= $09F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",105
	;[106] 	
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",106
	;[107] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",107
	;[108] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",108
	;[109] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",109
	;[110] REM GRAM card index numbers.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",110
	;[111] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",111
	;[112] REM Note: For use with the "define" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",112
	;[113] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",113
	;[114] CONST DEF00 				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",114
	;[115] CONST DEF01 				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",115
	;[116] CONST DEF02 				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",116
	;[117] CONST DEF03 				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",117
	;[118] CONST DEF04 				= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",118
	;[119] CONST DEF05 				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",119
	;[120] CONST DEF06 				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",120
	;[121] CONST DEF07 				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",121
	;[122] CONST DEF08 				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",122
	;[123] CONST DEF09 				= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",123
	;[124] CONST DEF10 				= $000A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",124
	;[125] CONST DEF11 				= $000B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",125
	;[126] CONST DEF12 				= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",126
	;[127] CONST DEF13 				= $000D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",127
	;[128] CONST DEF14 				= $000E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",128
	;[129] CONST DEF15 				= $000F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",129
	;[130] CONST DEF16 				= $0010
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",130
	;[131] CONST DEF17 				= $0011
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",131
	;[132] CONST DEF18 				= $0012
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",132
	;[133] CONST DEF19 				= $0013
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",133
	;[134] CONST DEF20 				= $0014
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",134
	;[135] CONST DEF21 				= $0015
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",135
	;[136] CONST DEF22 				= $0016
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",136
	;[137] CONST DEF23 				= $0017
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",137
	;[138] CONST DEF24 				= $0018
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",138
	;[139] CONST DEF25 				= $0019
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",139
	;[140] CONST DEF26 				= $001A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",140
	;[141] CONST DEF27 				= $001B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",141
	;[142] CONST DEF28 				= $001C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",142
	;[143] CONST DEF29 				= $001D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",143
	;[144] CONST DEF30 				= $001E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",144
	;[145] CONST DEF31 				= $001F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",145
	;[146] CONST DEF32 				= $0020
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",146
	;[147] CONST DEF33 				= $0021
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",147
	;[148] CONST DEF34 				= $0022
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",148
	;[149] CONST DEF35 				= $0023
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",149
	;[150] CONST DEF36 				= $0024
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",150
	;[151] CONST DEF37 				= $0025
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",151
	;[152] CONST DEF38 				= $0026
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",152
	;[153] CONST DEF39 				= $0027
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",153
	;[154] CONST DEF40 				= $0028
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",154
	;[155] CONST DEF41 				= $0029
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",155
	;[156] CONST DEF42 				= $002A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",156
	;[157] CONST DEF43 				= $002B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",157
	;[158] CONST DEF44 				= $002C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",158
	;[159] CONST DEF45 				= $002D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",159
	;[160] CONST DEF46 				= $002E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",160
	;[161] CONST DEF47 				= $002F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",161
	;[162] CONST DEF48 				= $0030
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",162
	;[163] CONST DEF49 				= $0031
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",163
	;[164] CONST DEF50 				= $0032
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",164
	;[165] CONST DEF51 				= $0033
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",165
	;[166] CONST DEF52 				= $0034
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",166
	;[167] CONST DEF53 				= $0035
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",167
	;[168] CONST DEF54 				= $0036
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",168
	;[169] CONST DEF55 				= $0037
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",169
	;[170] CONST DEF56 				= $0038
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",170
	;[171] CONST DEF57 				= $0039
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",171
	;[172] CONST DEF58 				= $003A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",172
	;[173] CONST DEF59 				= $003B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",173
	;[174] CONST DEF60 				= $003C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",174
	;[175] CONST DEF61 				= $003D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",175
	;[176] CONST DEF62 				= $003E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",176
	;[177] CONST DEF63 				= $003F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",177
	;[178] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",178
	;[179] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",179
	;[180] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",180
	;[181] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",181
	;[182] REM Screen modes.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",182
	;[183] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",183
	;[184] REM Note: For use with the "mode" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",184
	;[185] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",185
	;[186] CONST SCREEN_COLOR_STACK			= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",186
	;[187] CONST SCREEN_FOREGROUND_BACKGROUND	= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",187
	;[188] REM Abbreviated versions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",188
	;[189] CONST SCREEN_CS						= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",189
	;[190] CONST SCREEN_FB						= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",190
	;[191] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",191
	;[192] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",192
	;[193] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",193
	;[194] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",194
	;[195] REM COLORS - Border.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",195
	;[196] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",196
	;[197] REM Note: For use with the commands "mode 0" and "mode 1".
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",197
	;[198] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",198
	;[199] CONST BORDER_BLACK			= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",199
	;[200] CONST BORDER_BLUE			= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",200
	;[201] CONST BORDER_RED			= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",201
	;[202] CONST BORDER_TAN			= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",202
	;[203] CONST BORDER_DARKGREEN		= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",203
	;[204] CONST BORDER_GREEN			= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",204
	;[205] CONST BORDER_YELLOW			= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",205
	;[206] CONST BORDER_WHITE			= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",206
	;[207] CONST BORDER_GREY			= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",207
	;[208] CONST BORDER_CYAN			= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",208
	;[209] CONST BORDER_ORANGE			= $000A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",209
	;[210] CONST BORDER_BROWN			= $000B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",210
	;[211] CONST BORDER_PINK			= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",211
	;[212] CONST BORDER_LIGHTBLUE		= $000D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",212
	;[213] CONST BORDER_YELLOWGREEN	= $000E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",213
	;[214] CONST BORDER_PURPLE			= $000F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",214
	;[215] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",215
	;[216] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",216
	;[217] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",217
	;[218] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",218
	;[219] REM COLORS - Mode 0 (Color Stack).
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",219
	;[220] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",220
	;[221] REM Stack
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",221
	;[222] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",222
	;[223] REM Note: For use as the last 4 parameters used in the "mode 1" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",223
	;[224] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",224
	;[225] CONST STACK_BLACK			= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",225
	;[226] CONST STACK_BLUE			= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",226
	;[227] CONST STACK_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",227
	;[228] CONST STACK_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",228
	;[229] CONST STACK_DARKGREEN		= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",229
	;[230] CONST STACK_GREEN			= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",230
	;[231] CONST STACK_YELLOW			= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",231
	;[232] CONST STACK_WHITE			= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",232
	;[233] CONST STACK_GREY			= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",233
	;[234] CONST STACK_CYAN			= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",234
	;[235] CONST STACK_ORANGE			= $000A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",235
	;[236] CONST STACK_BROWN			= $000B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",236
	;[237] CONST STACK_PINK			= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",237
	;[238] CONST STACK_LIGHTBLUE		= $000D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",238
	;[239] CONST STACK_YELLOWGREEN		= $000E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",239
	;[240] CONST STACK_PURPLE			= $000F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",240
	;[241] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",241
	;[242] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",242
	;[243] REM Foreground.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",243
	;[244] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",244
	;[245] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",245
	;[246] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",246
	;[247] REM - Only one foreground colour permitted per background card.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",247
	;[248] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",248
	;[249] CONST CS_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",249
	;[250] CONST CS_BLUE				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",250
	;[251] CONST CS_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",251
	;[252] CONST CS_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",252
	;[253] CONST CS_DARKGREEN			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",253
	;[254] CONST CS_GREEN				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",254
	;[255] CONST CS_YELLOW				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",255
	;[256] CONST CS_WHITE				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",256
	;[257] CONST CS_GREY				= $1000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",257
	;[258] CONST CS_CYAN				= $1001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",258
	;[259] CONST CS_ORANGE				= $1002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",259
	;[260] CONST CS_BROWN				= $1003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",260
	;[261] CONST CS_PINK				= $1004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",261
	;[262] CONST CS_LIGHTBLUE			= $1005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",262
	;[263] CONST CS_YELLOWGREEN		= $1006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",263
	;[264] CONST CS_PURPLE				= $1007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",264
	;[265] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",265
	;[266] CONST CS_CARD_DATA_MASK		= $07F8		' Mask to get the background card's data.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",266
	;[267] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",267
	;[268] CONST CS_ADVANCE			= $2000		' Advance the colour stack by one position.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",268
	;[269] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",269
	;[270] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",270
	;[271] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",271
	;[272] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",272
	;[273] REM COLORS - Mode 1 (Foreground Background)
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",273
	;[274] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",274
	;[275] REM Foreground.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",275
	;[276] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",276
	;[277] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",277
	;[278] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",278
	;[279] REM - Only one foreground colour permitted per background card.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",279
	;[280] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",280
	;[281] CONST FG_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",281
	;[282] CONST FG_BLUE				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",282
	;[283] CONST FG_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",283
	;[284] CONST FG_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",284
	;[285] CONST FG_DARKGREEN			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",285
	;[286] CONST FG_GREEN				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",286
	;[287] CONST FG_YELLOW				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",287
	;[288] CONST FG_WHITE				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",288
	;[289] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",289
	;[290] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",290
	;[291] REM Background.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",291
	;[292] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",292
	;[293] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",293
	;[294] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",294
	;[295] REM - Only one background colour permitted per background card.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",295
	;[296] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",296
	;[297] CONST BG_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",297
	;[298] CONST BG_BLUE				= $0200
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",298
	;[299] CONST BG_RED				= $0400
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",299
	;[300] CONST BG_TAN				= $0600
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",300
	;[301] CONST BG_DARKGREEN			= $0800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",301
	;[302] CONST BG_GREEN				= $0A00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",302
	;[303] CONST BG_YELLOW				= $0C00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",303
	;[304] CONST BG_WHITE				= $0E00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",304
	;[305] CONST BG_GREY				= $1000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",305
	;[306] CONST BG_CYAN				= $1200
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",306
	;[307] CONST BG_ORANGE				= $1400
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",307
	;[308] CONST BG_BROWN				= $1600
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",308
	;[309] CONST BG_PINK				= $1800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",309
	;[310] CONST BG_LIGHTBLUE			= $1A00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",310
	;[311] CONST BG_YELLOWGREEN		= $1C00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",311
	;[312] CONST BG_PURPLE				= $1E00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",312
	;[313] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",313
	;[314] CONST FGBG_CARD_DATA_MASK	= $01F8		' Mask to get the background card's data.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",314
	;[315] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",315
	;[316] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",316
	;[317] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",317
	;[318] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",318
	;[319] REM Sprites.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",319
	;[320] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",320
	;[321] REM Note: For use with "sprite" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",321
	;[322] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",322
	;[323] REM X
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",323
	;[324] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",324
	;[325] REM Note: Add these constants to the sprite command's X parameter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",325
	;[326] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",326
	;[327] CONST HIT					= $0100		' Enable the sprite's collision detection.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",327
	;[328] CONST VISIBLE				= $0200		' Make the sprite visible.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",328
	;[329] CONST ZOOMX2				= $0400		' Make the sprite twice the width.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",329
	;[330] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",330
	;[331] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",331
	;[332] REM Y
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",332
	;[333] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",333
	;[334] REM Note: Add these constants to the sprite command's Y parameter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",334
	;[335] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",335
	;[336] CONST DOUBLEY				= $0080		' Make a double height sprite (with 2 GRAM cards).
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",336
	;[337] CONST ZOOMY2				= $0100		' Make the sprite twice (x2) the normal height.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",337
	;[338] CONST ZOOMY4				= $0200		' Make the sprite quadruple (x4) the normal height.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",338
	;[339] CONST ZOOMY8				= $0300		' Make the sprite octuple (x8) the normal height.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",339
	;[340] CONST FLIPX					= $0400		' Flip/mirror the sprite in X.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",340
	;[341] CONST FLIPY					= $0800		' Flip/mirror the sprite in Y.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",341
	;[342] CONST MIRROR				= $0C00		' Flip/mirror the sprite in both X and Y.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",342
	;[343] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",343
	;[344] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",344
	;[345] REM A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",345
	;[346] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",346
	;[347] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",347
	;[348] REM - Combine to create the sprite command's A parameter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",348
	;[349] REM - Only one colour per sprite.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",349
	;[350] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",350
	;[351] CONST GRAM					= $0800		' Sprite's data is located in GRAM.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",351
	;[352] CONST BEHIND				= $2000		' Sprite is behind the background.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",352
	;[353] CONST SPR_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",353
	;[354] CONST SPR_BLUE				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",354
	;[355] CONST SPR_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",355
	;[356] CONST SPR_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",356
	;[357] CONST SPR_DARKGREEN			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",357
	;[358] CONST SPR_GREEN				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",358
	;[359] CONST SPR_YELLOW			= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",359
	;[360] CONST SPR_WHITE				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",360
	;[361] CONST SPR_GREY				= $1000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",361
	;[362] CONST SPR_CYAN				= $1001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",362
	;[363] CONST SPR_ORANGE			= $1002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",363
	;[364] CONST SPR_BROWN				= $1003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",364
	;[365] CONST SPR_PINK				= $1004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",365
	;[366] CONST SPR_LIGHTBLUE			= $1005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",366
	;[367] CONST SPR_YELLOWGREEN		= $1006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",367
	;[368] CONST SPR_PURPLE			= $1007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",368
	;[369] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",369
	;[370] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",370
	;[371] REM GRAM numbers.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",371
	;[372] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",372
	;[373] REM Note: For use in the sprite command's parameter A.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",373
	;[374] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",374
	;[375] CONST SPR00 				= $0800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",375
	;[376] CONST SPR01 				= $0808
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",376
	;[377] CONST SPR02 				= $0810
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",377
	;[378] CONST SPR03 				= $0818
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",378
	;[379] CONST SPR04 				= $0820
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",379
	;[380] CONST SPR05 				= $0828
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",380
	;[381] CONST SPR06 				= $0830
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",381
	;[382] CONST SPR07 				= $0838
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",382
	;[383] CONST SPR08 				= $0840
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",383
	;[384] CONST SPR09 				= $0848
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",384
	;[385] CONST SPR10 				= $0850
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",385
	;[386] CONST SPR11 				= $0858
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",386
	;[387] CONST SPR12 				= $0860
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",387
	;[388] CONST SPR13 				= $0868
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",388
	;[389] CONST SPR14 				= $0870
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",389
	;[390] CONST SPR15 				= $0878
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",390
	;[391] CONST SPR16 				= $0880
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",391
	;[392] CONST SPR17 				= $0888
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",392
	;[393] CONST SPR18 				= $0890
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",393
	;[394] CONST SPR19 				= $0898
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",394
	;[395] CONST SPR20 				= $08A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",395
	;[396] CONST SPR21 				= $08A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",396
	;[397] CONST SPR22 				= $08B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",397
	;[398] CONST SPR23 				= $08B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",398
	;[399] CONST SPR24 				= $08C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",399
	;[400] CONST SPR25 				= $08C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",400
	;[401] CONST SPR26 				= $08D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",401
	;[402] CONST SPR27 				= $08D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",402
	;[403] CONST SPR28 				= $08E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",403
	;[404] CONST SPR29 				= $08E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",404
	;[405] CONST SPR30 				= $08F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",405
	;[406] CONST SPR31 				= $08F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",406
	;[407] CONST SPR32 				= $0900
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",407
	;[408] CONST SPR33 				= $0908
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",408
	;[409] CONST SPR34 				= $0910
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",409
	;[410] CONST SPR35 				= $0918
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",410
	;[411] CONST SPR36 				= $0920
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",411
	;[412] CONST SPR37 				= $0928
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",412
	;[413] CONST SPR38 				= $0930
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",413
	;[414] CONST SPR39 				= $0938
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",414
	;[415] CONST SPR40 				= $0940
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",415
	;[416] CONST SPR41 				= $0948
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",416
	;[417] CONST SPR42 				= $0950
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",417
	;[418] CONST SPR43 				= $0958
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",418
	;[419] CONST SPR44 				= $0960
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",419
	;[420] CONST SPR45 				= $0968
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",420
	;[421] CONST SPR46 				= $0970
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",421
	;[422] CONST SPR47 				= $0978
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",422
	;[423] CONST SPR48 				= $0980
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",423
	;[424] CONST SPR49 				= $0988
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",424
	;[425] CONST SPR50 				= $0990
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",425
	;[426] CONST SPR51 				= $0998
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",426
	;[427] CONST SPR52 				= $09A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",427
	;[428] CONST SPR53 				= $09A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",428
	;[429] CONST SPR54 				= $09B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",429
	;[430] CONST SPR55 				= $09B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",430
	;[431] CONST SPR56 				= $09C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",431
	;[432] CONST SPR57 				= $09C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",432
	;[433] CONST SPR58 				= $09D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",433
	;[434] CONST SPR59 				= $09D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",434
	;[435] CONST SPR60 				= $09E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",435
	;[436] CONST SPR61 				= $09E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",436
	;[437] CONST SPR62 				= $09F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",437
	;[438] CONST SPR63 				= $09F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",438
	;[439] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",439
	;[440] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",440
	;[441] REM Sprite collision.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",441
	;[442] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",442
	;[443] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",443
	;[444] REM - For use with variables COL0, COL1, COL2, COL3, COL4, COL5, COL6 and COL7.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",444
	;[445] REM - More than one collision can occur simultaneously.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",445
	;[446] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",446
	;[447] CONST HIT_SPRITE0			= $0001		' Sprite collided with sprite 0.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",447
	;[448] CONST HIT_SPRITE1			= $0002		' Sprite collided with sprite 1.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",448
	;[449] CONST HIT_SPRITE2			= $0004		' Sprite collided with sprite 2.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",449
	;[450] CONST HIT_SPRITE3			= $0008		' Sprite collided with sprite 3.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",450
	;[451] CONST HIT_SPRITE4			= $0010		' Sprite collided with sprite 4.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",451
	;[452] CONST HIT_SPRITE5			= $0020		' Sprite collided with sprite 5.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",452
	;[453] CONST HIT_SPRITE6			= $0040		' Sprite collided with sprite 6.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",453
	;[454] CONST HIT_SPRITE7			= $0080		' Sprite collided with sprite 7.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",454
	;[455] CONST HIT_BACKGROUND		= $0100		' Sprite collided with a background pixel.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",455
	;[456] CONST HIT_BORDER			= $0200		' Sprite collided with the top/bottom/left/right border.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",456
	;[457] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",457
	;[458] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",458
	;[459] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",459
	;[460] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",460
	;[461] REM DISC - Compass.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",461
	;[462] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",462
	;[463] REM   NW         N         NE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",463
	;[464] REM     \   NNW  |  NNE   /
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",464
	;[465] REM       \      |      /
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",465
	;[466] REM         \    |    /
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",466
	;[467] REM    WNW    \  |  /    ENE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",467
	;[468] REM             \|/
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",468
	;[469] REM  W ----------+---------- E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",469
	;[470] REM             /|\ 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",470
	;[471] REM    WSW    /  |  \    ESE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",471
	;[472] REM         /    |    \
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",472
	;[473] REM       /      |      \
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",473
	;[474] REM     /   SSW  |  SSE   \
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",474
	;[475] REM   SW         S         SE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",475
	;[476] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",476
	;[477] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",477
	;[478] REM - North points upwards on the hand controller.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",478
	;[479] REM - Directions are listed in a clockwise manner.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",479
	;[480] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",480
	;[481] CONST DISC_NORTH			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",481
	;[482] CONST DISC_NORTH_NORTH_EAST = $0014
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",482
	;[483] CONST DISC_NORTH_EAST		= $0016
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",483
	;[484] CONST DISC_EAST_NORTH_EAST	= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",484
	;[485] CONST DISC_EAST				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",485
	;[486] CONST DISC_EAST_SOUTH_EAST	= $0012
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",486
	;[487] CONST DISC_SOUTH_EAST		= $0013
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",487
	;[488] CONST DISC_SOUTH_SOUTH_EAST	= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",488
	;[489] CONST DISC_SOUTH			= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",489
	;[490] CONST DISC_SOUTH_SOUTH_WEST	= $0011
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",490
	;[491] CONST DISC_SOUTH_WEST		= $0025
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",491
	;[492] CONST DISC_WEST_SOUTH_WEST	= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",492
	;[493] CONST DISC_WEST				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",493
	;[494] CONST DISC_WEST_NORTH_WEST	= $0018
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",494
	;[495] CONST DISC_NORTH_WEST		= $001C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",495
	;[496] CONST DISC_NORTH_NORTH_WEST	= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",496
	;[497] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",497
	;[498] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",498
	;[499] REM DISC - Compass abbreviated versions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",499
	;[500] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",500
	;[501] CONST DISC_N				= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",501
	;[502] CONST DISC_NNE 				= $0014
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",502
	;[503] CONST DISC_NE				= $0016
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",503
	;[504] CONST DISC_ENE				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",504
	;[505] CONST DISC_E				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",505
	;[506] CONST DISC_ESE				= $0012
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",506
	;[507] CONST DISC_SE				= $0013
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",507
	;[508] CONST DISC_SSE				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",508
	;[509] CONST DISC_S				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",509
	;[510] CONST DISC_SSW				= $0011
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",510
	;[511] CONST DISC_SW				= $0025
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",511
	;[512] CONST DISC_WSW				= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",512
	;[513] CONST DISC_W				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",513
	;[514] CONST DISC_WNW				= $0018
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",514
	;[515] CONST DISC_NW				= $001C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",515
	;[516] CONST DISC_NNW				= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",516
	;[517] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",517
	;[518] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",518
	;[519] REM DISC - Directions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",519
	;[520] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",520
	;[521] CONST DISC_UP				= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",521
	;[522] CONST DISC_UP_RIGHT			= $0016		' Up and right diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",522
	;[523] CONST DISC_RIGHT			= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",523
	;[524] CONST DISC_DOWN_RIGHT		= $0013		' Down  and right diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",524
	;[525] CONST DISC_DOWN				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",525
	;[526] CONST DISC_DOWN_LEFT		= $0025		' Down and left diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",526
	;[527] CONST DISC_LEFT				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",527
	;[528] CONST DISC_UP_LEFT			= $001C		' Up and left diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",528
	;[529] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",529
	;[530] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",530
	;[531] REM DISK - Mask.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",531
	;[532] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",532
	;[533] CONST DISK_MASK				= $001F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",533
	;[534] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",534
	;[535] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",535
	;[536] REM Controller - Keypad.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",536
	;[537] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",537
	;[538] CONST KEYPAD_0				= 72
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",538
	;[539] CONST KEYPAD_1				= 129
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",539
	;[540] CONST KEYPAD_2				= 65
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",540
	;[541] CONST KEYPAD_3				= 33
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",541
	;[542] CONST KEYPAD_4				= 130
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",542
	;[543] CONST KEYPAD_5				= 66
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",543
	;[544] CONST KEYPAD_6				= 34
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",544
	;[545] CONST KEYPAD_7				= 132
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",545
	;[546] CONST KEYPAD_8				= 68
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",546
	;[547] CONST KEYPAD_9				= 36
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",547
	;[548] CONST KEYPAD_CLEAR			= 136
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",548
	;[549] CONST KEYPAD_ENTER			= 40
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",549
	;[550] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",550
	;[551] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",551
	;[552] REM Controller - Side buttons.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",552
	;[553] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",553
	;[554] CONST BUTTON_TOP_LEFT		= $A0		' Top left and top right are the same button.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",554
	;[555] CONST BUTTON_TOP_RIGHT		= $A0		' Note: Bit 6 is low. 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",555
	;[556] CONST BUTTON_BOTTOM_LEFT	= $60		' Note: Bit 7 is low.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",556
	;[557] CONST BUTTON_BOTTOM_RIGHT	= $C0		' Note: Bit 5 is low
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",557
	;[558] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",558
	;[559] REM Abbreviated versions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",559
	;[560] CONST BUTTON_1				= $A0		' Top left or top right.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",560
	;[561] CONST BUTTON_2				= $60		' Bottom left.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",561
	;[562] CONST BUTTON_3				= $C0		' Bottom right.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",562
	;[563] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",563
	;[564] REM Mask.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",564
	;[565] CONST BUTTON_MASK			= $E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",565
	;[566] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",566
	;[567] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",567
	;[568] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",568
	;[569] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",569
	;[570] REM Useful functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",570
	;[571] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",571
	;[572] DEF FN screenpos(aColumn, aRow)		= (((aRow)*BACKGROUND_COLUMNS)+(aColumn))
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",572
	;[573] DEF FN screenaddr(aColumn, aRow)	= (BACKTAB+(((aRow)*BACKGROUND_COLUMNS)+(aColumn)))
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",573
	;[574] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",574
	;[575] DEF FN setspritex(aSpriteNo,anXPosition)	= #mobshadow(aSpriteNo)=(#mobshadow(aSpriteNo) and $ff00)+anXPosition
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",575
	;[576] DEF FN setspritey(aSpriteNo,aYPosition)		= #mobshadow(aSpriteNo+8)=(#mobshadow(aSpriteNo+8) and $ff80)+aYPosition
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",576
	;[577] DEF FN resetsprite(aSpriteNo)				= sprite aSpriteNo, 0, 0, 0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",577
	;[578] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",578
	;[579] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",579
	;[580] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",580
	;[581] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",581
	;[582] REM END
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",582
	;[583] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.1/constants.bas",583
	;ENDFILE
	;FILE whalehunt_1a.bas
	;[36] 	
	SRCFILE "whalehunt_1a.bas",36
	;[37] reset:
	SRCFILE "whalehunt_1a.bas",37
	; RESET
Q3:	;[38] 	
	SRCFILE "whalehunt_1a.bas",38
	;[39] dim stormx_map(12)
	SRCFILE "whalehunt_1a.bas",39
	;[40] dim stormy_map(12)
	SRCFILE "whalehunt_1a.bas",40
	;[41] #day_cnt = 0
	SRCFILE "whalehunt_1a.bas",41
	CLRR R0
	MVO R0,V1
	;[42] #char_dir = 0
	SRCFILE "whalehunt_1a.bas",42
	MVO R0,V2
	;[43] #enemy_dir = 0
	SRCFILE "whalehunt_1a.bas",43
	NOP
	MVO R0,V3
	;[44] #score = 0
	SRCFILE "whalehunt_1a.bas",44
	MVO R0,V4
	;[45] #new_score = 0
	SRCFILE "whalehunt_1a.bas",45
	NOP
	MVO R0,V5
	;[46] #next_score = 100
	SRCFILE "whalehunt_1a.bas",46
	MVII #100,R0
	MVO R0,V6
	;[47] lives = 3
	SRCFILE "whalehunt_1a.bas",47
	MVII #3,R0
	MVO R0,V7
	;[48] health = 4
	SRCFILE "whalehunt_1a.bas",48
	MVII #4,R0
	MVO R0,V8
	;[49] level = 1
	SRCFILE "whalehunt_1a.bas",49
	MVII #1,R0
	MVO R0,V9
	;[50] timeout_flag = 0
	SRCFILE "whalehunt_1a.bas",50
	CLRR R0
	MVO R0,V10
	;[51] map = 0
	SRCFILE "whalehunt_1a.bas",51
	MVO R0,V11
	;[52] whalex = 22
	SRCFILE "whalehunt_1a.bas",52
	MVII #22,R0
	MVO R0,V12
	;[53] whaley = 81	
	SRCFILE "whalehunt_1a.bas",53
	MVII #81,R0
	MVO R0,V13
	;[54] dir_cnt = 5
	SRCFILE "whalehunt_1a.bas",54
	MVII #5,R0
	MVO R0,V14
	;[55] direction = 1
	SRCFILE "whalehunt_1a.bas",55
	MVII #1,R0
	MVO R0,V15
	;[56] hands = 2
	SRCFILE "whalehunt_1a.bas",56
	MVII #2,R0
	MVO R0,V16
	;[57] offset = 160
	SRCFILE "whalehunt_1a.bas",57
	MVII #160,R0
	MVO R0,V17
	;[58] player_x = 77
	SRCFILE "whalehunt_1a.bas",58
	MVII #77,R0
	MVO R0,V18
	;[59] player_y = 75
	SRCFILE "whalehunt_1a.bas",59
	MVII #75,R0
	MVO R0,V19
	;[60] whalex_map = 77
	SRCFILE "whalehunt_1a.bas",60
	MVII #77,R0
	MVO R0,V20
	;[61] whaley_map = 60
	SRCFILE "whalehunt_1a.bas",61
	MVII #60,R0
	MVO R0,V21
	;[62] row_total = 4
	SRCFILE "whalehunt_1a.bas",62
	MVII #4,R0
	MVO R0,V22
	;[63] row_speed = 4
	SRCFILE "whalehunt_1a.bas",63
	MVO R0,V23
	;[64] row_cnt = 5
	SRCFILE "whalehunt_1a.bas",64
	MVII #5,R0
	MVO R0,V24
	;[65] row = 1
	SRCFILE "whalehunt_1a.bas",65
	MVII #1,R0
	MVO R0,V25
	;[66] kill_qty = 2
	SRCFILE "whalehunt_1a.bas",66
	MVII #2,R0
	MVO R0,V26
	;[67] kill_cnt = 0
	SRCFILE "whalehunt_1a.bas",67
	CLRR R0
	MVO R0,V27
	;[68] hit_cnt = 0
	SRCFILE "whalehunt_1a.bas",68
	MVO R0,V28
	;[69] hit_total = 3
	SRCFILE "whalehunt_1a.bas",69
	MVII #3,R0
	MVO R0,V29
	;[70] harp1 = 0
	SRCFILE "whalehunt_1a.bas",70
	CLRR R0
	MVO R0,V30
	;[71] harp2 = 0
	SRCFILE "whalehunt_1a.bas",71
	MVO R0,V31
	;[72] harp3 = 0
	SRCFILE "whalehunt_1a.bas",72
	NOP
	MVO R0,V32
	;[73] harpoon = 1
	SRCFILE "whalehunt_1a.bas",73
	MVII #1,R0
	MVO R0,V33
	;[74] wind_flute = 0
	SRCFILE "whalehunt_1a.bas",74
	CLRR R0
	MVO R0,V34
	;[75] paddle = 1
	SRCFILE "whalehunt_1a.bas",75
	MVII #1,R0
	MVO R0,V35
	;[76] wind_cnt = 0
	SRCFILE "whalehunt_1a.bas",76
	CLRR R0
	MVO R0,V36
	;[77] 'wind_direction = 7
	SRCFILE "whalehunt_1a.bas",77
	;[78] town_check = 0
	SRCFILE "whalehunt_1a.bas",78
	MVO R0,V37
	;[79] town1_cnt = 0
	SRCFILE "whalehunt_1a.bas",79
	NOP
	MVO R0,V38
	;[80] town2_cnt = 0
	SRCFILE "whalehunt_1a.bas",80
	MVO R0,V39
	;[81] town3_cnt = 0
	SRCFILE "whalehunt_1a.bas",81
	NOP
	MVO R0,V40
	;[82] enemy = 0
	SRCFILE "whalehunt_1a.bas",82
	MVO R0,V41
	;[83] enemy_atk = 0
	SRCFILE "whalehunt_1a.bas",83
	NOP
	MVO R0,V42
	;[84] draw_x = 6
	SRCFILE "whalehunt_1a.bas",84
	MVII #6,R0
	MVO R0,V43
	;[85] draw_y = 5
	SRCFILE "whalehunt_1a.bas",85
	MVII #5,R0
	MVO R0,V44
	;[86] wave_x = 0
	SRCFILE "whalehunt_1a.bas",86
	CLRR R0
	MVO R0,V45
	;[87] wave_y = 0
	SRCFILE "whalehunt_1a.bas",87
	MVO R0,V46
	;[88] daytime = 0
	SRCFILE "whalehunt_1a.bas",88
	NOP
	MVO R0,V47
	;[89] daytime_cnt = 0
	SRCFILE "whalehunt_1a.bas",89
	MVO R0,V48
	;[90] sun_x = 0
	SRCFILE "whalehunt_1a.bas",90
	NOP
	MVO R0,V49
	;[91] storm_cnt = 60
	SRCFILE "whalehunt_1a.bas",91
	MVII #60,R0
	MVO R0,V50
	;[92] storm_cnt_total = 60
	SRCFILE "whalehunt_1a.bas",92
	MVO R0,V51
	;[93] storm_qty = 5
	SRCFILE "whalehunt_1a.bas",93
	MVII #5,R0
	MVO R0,V52
	;[94] storm_roll = 65
	SRCFILE "whalehunt_1a.bas",94
	MVII #65,R0
	MVO R0,V53
	;[95] for cnt = 1 to 12
	SRCFILE "whalehunt_1a.bas",95
	MVII #1,R0
	MVO R0,V54
T1:
	;[96] 	stormx_map(cnt) = 0
	SRCFILE "whalehunt_1a.bas",96
	CLRR R0
	MVII #Q4,R3
	ADD V54,R3
	MVO@ R0,R3
	;[97] 	stormy_map(cnt) = 0
	SRCFILE "whalehunt_1a.bas",97
	MVII #Q5,R3
	ADD V54,R3
	MVO@ R0,R3
	;[98] next cnt
	SRCFILE "whalehunt_1a.bas",98
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #12,R0
	BLE T1
	;[99] wait
	SRCFILE "whalehunt_1a.bas",99
	CALL _wait
	;[100] REM =====edit whale_xy to restore random location=====
	SRCFILE "whalehunt_1a.bas",100
	;[101] 'whalex_map = (rand / 5) * 3
	SRCFILE "whalehunt_1a.bas",101
	;[102] wait
	SRCFILE "whalehunt_1a.bas",102
	CALL _wait
	;[103] 'whaley_map = rand / 3
	SRCFILE "whalehunt_1a.bas",103
	;[104] 
	SRCFILE "whalehunt_1a.bas",104
	;[105] sound 5,0
	SRCFILE "whalehunt_1a.bas",105
	CLRR R0
	MVO R0,240
	SWAP R0
	MVO R0,244
	;[106] 
	SRCFILE "whalehunt_1a.bas",106
	;[107] REM =====INTRO=====
	SRCFILE "whalehunt_1a.bas",107
	;[108] 	REM stub for showing image
	SRCFILE "whalehunt_1a.bas",108
	;[109] 	MODE 1
	SRCFILE "whalehunt_1a.bas",109
	MVII #2,R0
	MVO R0,_mode_select
	;[110] 	WAIT
	SRCFILE "whalehunt_1a.bas",110
	CALL _wait
	;[111] 	DEFINE 0,16,title_screen_bitmaps_0
	SRCFILE "whalehunt_1a.bas",111
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q6,R0
	MVO R0,_gram_bitmap
	;[112] 	WAIT
	SRCFILE "whalehunt_1a.bas",112
	CALL _wait
	;[113] 	DEFINE 16,16,title_screen_bitmaps_1
	SRCFILE "whalehunt_1a.bas",113
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q7,R0
	MVO R0,_gram_bitmap
	;[114] 	WAIT
	SRCFILE "whalehunt_1a.bas",114
	CALL _wait
	;[115] 	DEFINE 32,16,title_screen_bitmaps_2
	SRCFILE "whalehunt_1a.bas",115
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q8,R0
	MVO R0,_gram_bitmap
	;[116] 	WAIT
	SRCFILE "whalehunt_1a.bas",116
	CALL _wait
	;[117] 	DEFINE 48,14,title_screen_bitmaps_3
	SRCFILE "whalehunt_1a.bas",117
	MVII #48,R0
	MVO R0,_gram_target
	MVII #14,R0
	MVO R0,_gram_total
	MVII #Q9,R0
	MVO R0,_gram_bitmap
	;[118] 	define alternate 62,2, title_harpoon
	SRCFILE "whalehunt_1a.bas",118
	MVII #62,R0
	MVO R0,_gram2_target
	MVII #2,R0
	MVO R0,_gram2_total
	MVII #Q10,R0
	MVO R0,_gram2_bitmap
	;[119] 	wait
	SRCFILE "whalehunt_1a.bas",119
	CALL _wait
	;[120] 	play full
	SRCFILE "whalehunt_1a.bas",120
	MVII #2,R3
	MVO R3,_music_mode
	;[121] 	play beat_level_music
	SRCFILE "whalehunt_1a.bas",121
	MVII #Q11,R0
	CALL _play_music
	;[122] 	SCREEN title_screen_cards
	SRCFILE "whalehunt_1a.bas",122
	MVII #Q12,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[123] 	sprite 01,		132 + visible, 6 + zoomy2, spr63 + spr_grey
	SRCFILE "whalehunt_1a.bas",123
	MVII #644,R0
	MVO R0,_mobs+1
	MVII #262,R0
	MVO R0,_mobs+9
	MVII #6648,R0
	MVO R0,_mobs+17
	;[124] 	SPRITE 02,		137 + VISIBLE + zoomx2, 12 + zoomy8, SPR62 + spr_orange
	SRCFILE "whalehunt_1a.bas",124
	MVII #1673,R0
	MVO R0,_mobs+2
	MVII #780,R0
	MVO R0,_mobs+10
	MVII #6642,R0
	MVO R0,_mobs+18
	;[125] 	wait
	SRCFILE "whalehunt_1a.bas",125
	CALL _wait
	;[126] 
	SRCFILE "whalehunt_1a.bas",126
	;[127] 	print at screenpos(1,1) color bg_cyan, "WHALE"
	SRCFILE "whalehunt_1a.bas",127
	MVII #533,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #440,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[128] 	print at screenpos(4,2) color bg_cyan, "HUNT"
	SRCFILE "whalehunt_1a.bas",128
	MVII #556,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #320,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[129] 	wait
	SRCFILE "whalehunt_1a.bas",129
	CALL _wait
	;[130] 
	SRCFILE "whalehunt_1a.bas",130
	;[131] 	gosub cont1wait
	SRCFILE "whalehunt_1a.bas",131
	CALL Q13
	;[132] '	for y = 1 to 8
	SRCFILE "whalehunt_1a.bas",132
	;[133] '	for x = 1 to 57
	SRCFILE "whalehunt_1a.bas",133
	;[134] title_loop:
	SRCFILE "whalehunt_1a.bas",134
	; TITLE_LOOP
Q14:	;[135] 		if cont1.key < 12 then goto clear_title
	SRCFILE "whalehunt_1a.bas",135
	MVI _cnt1_key,R0
	CMPI #12,R0
	BLT Q15
	;[136] 		wait
	SRCFILE "whalehunt_1a.bas",136
	CALL _wait
	;[137] 		goto title_loop
	SRCFILE "whalehunt_1a.bas",137
	B Q14
	;[138] '	next x
	SRCFILE "whalehunt_1a.bas",138
	;[139] '	next y
	SRCFILE "whalehunt_1a.bas",139
	;[140] clear_title:
	SRCFILE "whalehunt_1a.bas",140
	; CLEAR_TITLE
Q15:	;[141] 	play off
	SRCFILE "whalehunt_1a.bas",141
	CLRR R0
	CALL _play_music
	;[142] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",142
	MVII #8192,R0
	MVO R0,_mobs+1
	;[143] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",143
	MVO R0,_mobs+2
	;[144] 	cls
	SRCFILE "whalehunt_1a.bas",144
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[145] 	
	SRCFILE "whalehunt_1a.bas",145
	;[146] 	wind_direction = (rand/32) + 1
	SRCFILE "whalehunt_1a.bas",146
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,1
	INCR R0
	MVO R0,V55
	;[147] 	gosub whale_xy
	SRCFILE "whalehunt_1a.bas",147
	CALL Q17
	;[148] 	gosub kill_quantity
	SRCFILE "whalehunt_1a.bas",148
	CALL Q18
	;[149] '	gosub health_crate
	SRCFILE "whalehunt_1a.bas",149
	;[150] 	
	SRCFILE "whalehunt_1a.bas",150
	;[151] REM ========================GAME START=====================
	SRCFILE "whalehunt_1a.bas",151
	;[152] ' 53 bitmaps
	SRCFILE "whalehunt_1a.bas",152
	;[153] load_images:
	SRCFILE "whalehunt_1a.bas",153
	; LOAD_IMAGES
Q19:	;[154] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",154
	CALL Q20
	;[155] 	cls
	SRCFILE "whalehunt_1a.bas",155
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[156] 	map = 0
	SRCFILE "whalehunt_1a.bas",156
	CLRR R0
	MVO R0,V11
	;[157] 	if daytime = 0 then screen background_dawn
	SRCFILE "whalehunt_1a.bas",157
	MVI V47,R0
	TSTR R0
	BNE T3
	MVII #Q21,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T3:
	;[158] 	if daytime = 1 then screen background
	SRCFILE "whalehunt_1a.bas",158
	MVI V47,R0
	CMPI #1,R0
	BNE T4
	MVII #Q22,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T4:
	;[159] 	if daytime = 2 then screen background_dusk
	SRCFILE "whalehunt_1a.bas",159
	MVI V47,R0
	CMPI #2,R0
	BNE T5
	MVII #Q23,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T5:
	;[160] 	if daytime = 3 then screen background_storm
	SRCFILE "whalehunt_1a.bas",160
	MVI V47,R0
	CMPI #3,R0
	BNE T6
	MVII #Q24,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T6:
	;[161] load_new_level:
	SRCFILE "whalehunt_1a.bas",161
	; LOAD_NEW_LEVEL
Q25:	;[162] 	if level = 11 then
	SRCFILE "whalehunt_1a.bas",162
	MVI V9,R0
	CMPI #11,R0
	BNE T7
	;[163] 	   level = 10
	SRCFILE "whalehunt_1a.bas",163
	MVII #10,R0
	MVO R0,V9
	;[164] 	   goto tally_score
	SRCFILE "whalehunt_1a.bas",164
	B Q26
	;[165] 	end if
	SRCFILE "whalehunt_1a.bas",165
T7:
	;[166] 	whale_cnt = 29
	SRCFILE "whalehunt_1a.bas",166
	MVII #29,R0
	MVO R0,V56
	;[167] 	hands = 2
	SRCFILE "whalehunt_1a.bas",167
	MVII #2,R0
	MVO R0,V16
	;[168] 	gosub score
	SRCFILE "whalehunt_1a.bas",168
	CALL Q27
	;[169] 	gosub load_row_throw
	SRCFILE "whalehunt_1a.bas",169
	CALL Q28
	;[170] 	gosub whale_movement
	SRCFILE "whalehunt_1a.bas",170
	CALL Q29
	;[171] 	gosub cont1wait	
	SRCFILE "whalehunt_1a.bas",171
	CALL Q13
	;[172] 
	SRCFILE "whalehunt_1a.bas",172
	;[173] actionloop:    
	SRCFILE "whalehunt_1a.bas",173
	; ACTIONLOOP
Q30:	;[174] 	gosub whale_movement                   
	SRCFILE "whalehunt_1a.bas",174
	CALL Q29
	;[175] 	if cont1.key = 11 then goto load_map
	SRCFILE "whalehunt_1a.bas",175
	MVI _cnt1_key,R0
	CMPI #11,R0
	BEQ Q31
	;[176] 	if cont1.key = 0 then goto load_map
	SRCFILE "whalehunt_1a.bas",176
	MVI _cnt1_key,R0
	TSTR R0
	BEQ Q31
	;[177] 	if cont1.key = 10 then goto load_map
	SRCFILE "whalehunt_1a.bas",177
	MVI _cnt1_key,R0
	CMPI #10,R0
	BEQ Q31
	;[178] 	if cont1.key = 9 then if storm_flag = 1 then goto lose_life else sail_dir = 3 : gosub sail 'turn right
	SRCFILE "whalehunt_1a.bas",178
	MVI _cnt1_key,R0
	CMPI #9,R0
	BNE T11
	MVI V57,R0
	CMPI #1,R0
	BNE T12
	B Q32
	B T13
T12:
	MVII #3,R0
	MVO R0,V58
	CALL Q33
T13:
T11:
	;[179] 	if cont1.key = 8 then if storm_flag = 1 then goto lose_life else sail_dir = 2 : gosub sail 'straight
	SRCFILE "whalehunt_1a.bas",179
	MVI _cnt1_key,R0
	CMPI #8,R0
	BNE T14
	MVI V57,R0
	CMPI #1,R0
	BNE T15
	B Q32
	B T16
T15:
	MVII #2,R0
	MVO R0,V58
	CALL Q33
T16:
T14:
	;[180] 	if cont1.key = 7 then if storm_flag = 1 then goto lose_life else sail_dir = 1 : gosub sail 'turn left
	SRCFILE "whalehunt_1a.bas",180
	MVI _cnt1_key,R0
	CMPI #7,R0
	BNE T17
	MVI V57,R0
	CMPI #1,R0
	BNE T18
	B Q32
	B T19
T18:
	MVII #1,R0
	MVO R0,V58
	CALL Q33
T19:
T17:
	;[181] 	if cont1.key = 6 then if hands = 3 then hands = 2 : row = 0 : gosub load_row_throw : goto actionloop else dir_cnt = dir_cnt + 1 : if dir_cnt > 11 then direction = direction + 1 : dir_cnt = 1 : whale_cnt = 29 ': if row = 1 then offset = 240 else offset = 160
	SRCFILE "whalehunt_1a.bas",181
	MVI _cnt1_key,R0
	CMPI #6,R0
	BNE T20
	MVI V16,R0
	CMPI #3,R0
	BNE T21
	MVII #2,R0
	MVO R0,V16
	CLRR R0
	MVO R0,V25
	CALL Q28
	B Q30
	B T22
T21:
	MVI V14,R0
	INCR R0
	MVO R0,V14
	MVI V14,R0
	CMPI #11,R0
	BLE T23
	MVI V15,R0
	INCR R0
	MVO R0,V15
	MVII #1,R0
	MVO R0,V14
	MVII #29,R0
	MVO R0,V56
T23:
T22:
T20:
	;[182] 	if cont1.key = 6 then row_cnt = row_cnt + 1 : if row_cnt > row_total then gosub player_row : row_cnt = 0	'row turn right
	SRCFILE "whalehunt_1a.bas",182
	MVI _cnt1_key,R0
	CMPI #6,R0
	BNE T24
	MVI V24,R0
	INCR R0
	MVO R0,V24
	MVI V24,R0
	CMP V22,R0
	BLE T25
	CALL Q34
	CLRR R0
	MVO R0,V24
T25:
T24:
	;[183] 	if cont1.key = 5 then if hands = 3 then hands = 2 : row = 0 : gosub load_row_throw : goto actionloop else row_cnt = row_cnt + 1 : if row_cnt > row_total then gosub player_row : row_cnt = 0	'row straight
	SRCFILE "whalehunt_1a.bas",183
	MVI _cnt1_key,R0
	CMPI #5,R0
	BNE T26
	MVI V16,R0
	CMPI #3,R0
	BNE T27
	MVII #2,R0
	MVO R0,V16
	CLRR R0
	MVO R0,V25
	CALL Q28
	B Q30
	B T28
T27:
	MVI V24,R0
	INCR R0
	MVO R0,V24
	MVI V24,R0
	CMP V22,R0
	BLE T29
	CALL Q34
	CLRR R0
	MVO R0,V24
T29:
T28:
T26:
	;[184] 	if cont1.key = 4 then if hands = 3 then hands = 2 : row = 0 : gosub load_row_throw : goto actionloop else dir_cnt = dir_cnt - 1 : if dir_cnt < 1 then direction = direction - 1 : dir_cnt = 11 : whale_cnt = 29 ': if row = 1 then offset = 240 else offset = 160
	SRCFILE "whalehunt_1a.bas",184
	MVI _cnt1_key,R0
	CMPI #4,R0
	BNE T30
	MVI V16,R0
	CMPI #3,R0
	BNE T31
	MVII #2,R0
	MVO R0,V16
	CLRR R0
	MVO R0,V25
	CALL Q28
	B Q30
	B T32
T31:
	MVI V14,R0
	DECR R0
	MVO R0,V14
	MVI V14,R0
	CMPI #1,R0
	BGE T33
	MVI V15,R0
	DECR R0
	MVO R0,V15
	MVII #11,R0
	MVO R0,V14
	MVII #29,R0
	MVO R0,V56
T33:
T32:
T30:
	;[185] 	if cont1.key = 4 then row_cnt = row_cnt + 1 : if row_cnt > row_total then gosub player_row : row_cnt = 0	'row turn left	
	SRCFILE "whalehunt_1a.bas",185
	MVI _cnt1_key,R0
	CMPI #4,R0
	BNE T34
	MVI V24,R0
	INCR R0
	MVO R0,V24
	MVI V24,R0
	CMP V22,R0
	BLE T35
	CALL Q34
	CLRR R0
	MVO R0,V24
T35:
T34:
	;[186] 	if cont1.key = 1 then if hands = 3 then hands = 1 : gosub hide_sprites : gosub load_row_throw : goto actionloop else arch = 3 : gosub player_throw
	SRCFILE "whalehunt_1a.bas",186
	MVI _cnt1_key,R0
	CMPI #1,R0
	BNE T36
	MVI V16,R0
	CMPI #3,R0
	BNE T37
	MVII #1,R0
	MVO R0,V16
	CALL Q20
	CALL Q28
	B Q30
	B T38
T37:
	MVII #3,R0
	MVO R0,V59
	CALL Q35
T38:
T36:
	;[187] 	if cont1.key = 2 then if hands = 3 then hands = 1 : gosub hide_sprites : gosub load_row_throw : goto actionloop else arch = 2 : gosub player_throw
	SRCFILE "whalehunt_1a.bas",187
	MVI _cnt1_key,R0
	CMPI #2,R0
	BNE T39
	MVI V16,R0
	CMPI #3,R0
	BNE T40
	MVII #1,R0
	MVO R0,V16
	CALL Q20
	CALL Q28
	B Q30
	B T41
T40:
	MVII #2,R0
	MVO R0,V59
	CALL Q35
T41:
T39:
	;[188] 	if cont1.key = 3 then if hands = 3 then hands = 1 : gosub hide_sprites : gosub load_row_throw : goto actionloop else arch = 1 : gosub player_throw
	SRCFILE "whalehunt_1a.bas",188
	MVI _cnt1_key,R0
	CMPI #3,R0
	BNE T42
	MVI V16,R0
	CMPI #3,R0
	BNE T43
	MVII #1,R0
	MVO R0,V16
	CALL Q20
	CALL Q28
	B Q30
	B T44
T43:
	MVII #1,R0
	MVO R0,V59
	CALL Q35
T44:
T42:
	;[189] 	if health = 0 then goto lose_life
	SRCFILE "whalehunt_1a.bas",189
	MVI V8,R0
	TSTR R0
	BEQ Q32
	;[190] 	if cont1.b0 then goto sundial
	SRCFILE "whalehunt_1a.bas",190
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	CMPI #160,R0
	BEQ Q36
	;[191] 	if cont1.b1 then if wind_flute = 1 then wind_direction = direction : play simple : play flute_song
	SRCFILE "whalehunt_1a.bas",191
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	CMPI #96,R0
	BNE T47
	MVI V34,R0
	CMPI #1,R0
	BNE T48
	MVI V15,R0
	MVO R0,V55
	MVII #1,R3
	MVO R3,_music_mode
	MVII #Q37,R0
	CALL _play_music
T48:
T47:
	;[192] 	if cont1.b2 then if wind_flute = 1 then wind_direction = direction : play simple : play flute_song
	SRCFILE "whalehunt_1a.bas",192
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	CMPI #192,R0
	BNE T49
	MVI V34,R0
	CMPI #1,R0
	BNE T50
	MVI V15,R0
	MVO R0,V55
	MVII #1,R3
	MVO R3,_music_mode
	MVII #Q37,R0
	CALL _play_music
T50:
T49:
	;[193] 	gosub timer
	SRCFILE "whalehunt_1a.bas",193
	CALL Q38
	;[194] 	if timeout_flag = 1 then goto lose_life
	SRCFILE "whalehunt_1a.bas",194
	MVI V10,R0
	CMPI #1,R0
	BEQ Q32
	;[195] 	if storm_cnt = storm_cnt_total then 
	SRCFILE "whalehunt_1a.bas",195
	MVI V50,R0
	CMP V51,R0
	BNE T52
	;[196] 		x = rand / 10
	SRCFILE "whalehunt_1a.bas",196
	MVI _rand,R0
	MVII #-1,R4
T53:
	INCR R4
	SUBI #10,R0
	BC T53
	MOVR R4,R0
	MVO R0,V60
	;[197] 		if storm_flag = 1 then if x = 3 then goto lose_life
	SRCFILE "whalehunt_1a.bas",197
	MVI V57,R0
	CMPI #1,R0
	BNE T54
	MVI V60,R0
	CMPI #3,R0
	BEQ Q32
T54:
	;[198] 	end if
	SRCFILE "whalehunt_1a.bas",198
T52:
	;[199] 	gosub wind
	SRCFILE "whalehunt_1a.bas",199
	CALL Q39
	;[200] 	if #score < #new_score then #score = #score + 1 
	SRCFILE "whalehunt_1a.bas",200
	MVI V4,R0
	CMP V5,R0
	BGE T56
	INCR R0
	MVO R0,V4
T56:
	;[201] 	if #score >= #next_score then #next_score = #next_score + 100 : if health < 4 then health = health + 1
	SRCFILE "whalehunt_1a.bas",201
	MVI V4,R0
	CMP V6,R0
	BLT T57
	MVI V6,R0
	ADDI #100,R0
	MVO R0,V6
	MVI V8,R0
	CMPI #4,R0
	BGE T58
	INCR R0
	MVO R0,V8
T58:
T57:
	;[202] 	gosub score
	SRCFILE "whalehunt_1a.bas",202
	CALL Q27
	;[203] 	wait
	SRCFILE "whalehunt_1a.bas",203
	CALL _wait
	;[204] goto actionloop
	SRCFILE "whalehunt_1a.bas",204
	B Q30
	;[205] 
	SRCFILE "whalehunt_1a.bas",205
	;[206] 
	SRCFILE "whalehunt_1a.bas",206
	;[207] 
	SRCFILE "whalehunt_1a.bas",207
	;[208] REM =======================SUBROUTINES=============================
	SRCFILE "whalehunt_1a.bas",208
	;[209] 
	SRCFILE "whalehunt_1a.bas",209
	;[210] timer:	procedure
	SRCFILE "whalehunt_1a.bas",210
	; TIMER
Q38:	PROC
	BEGIN
	;[211] 	#day_cnt = #day_cnt + 1
	SRCFILE "whalehunt_1a.bas",211
	MVI V1,R0
	INCR R0
	MVO R0,V1
	;[212] 	'if #day_cnt >= 570 then
	SRCFILE "whalehunt_1a.bas",212
	;[213] 	if #day_cnt = 250 then
	SRCFILE "whalehunt_1a.bas",213
	CMPI #250,R0
	BNE T59
	;[214] 		daytime_cnt = daytime_cnt + 1
	SRCFILE "whalehunt_1a.bas",214
	MVI V48,R0
	INCR R0
	MVO R0,V48
	;[215] 		if daytime_cnt = 3 then if daytime < 3 then daytime = 1
	SRCFILE "whalehunt_1a.bas",215
	MVI V48,R0
	CMPI #3,R0
	BNE T60
	MVI V47,R0
	CMPI #3,R0
	BGE T61
	MVII #1,R0
	MVO R0,V47
T61:
T60:
	;[216] 		if daytime_cnt = 12 then if daytime < 3 then daytime = 2
	SRCFILE "whalehunt_1a.bas",216
	MVI V48,R0
	CMPI #12,R0
	BNE T62
	MVI V47,R0
	CMPI #3,R0
	BGE T63
	MVII #2,R0
	MVO R0,V47
T63:
T62:
	;[217] 		if daytime_cnt > 14 then timeout_flag = 1 ': goto lose_life
	SRCFILE "whalehunt_1a.bas",217
	MVI V48,R0
	CMPI #14,R0
	BLE T64
	MVII #1,R0
	MVO R0,V10
T64:
	;[218] 		if map = 0 then 
	SRCFILE "whalehunt_1a.bas",218
	MVI V11,R0
	TSTR R0
	BNE T65
	;[219] 		if sun_x = 0 then
	SRCFILE "whalehunt_1a.bas",219
	MVI V49,R0
	TSTR R0
	BNE T66
	;[220] 			draw_y = 1
	SRCFILE "whalehunt_1a.bas",220
	MVII #1,R0
	MVO R0,V44
	;[221] 			draw_x = 0
	SRCFILE "whalehunt_1a.bas",221
	CLRR R0
	MVO R0,V43
	;[222] 			if hands = 1 then
	SRCFILE "whalehunt_1a.bas",222
	MVI V16,R0
	CMPI #1,R0
	BNE T67
	;[223] 				if arch > 0 then offset = 80 else offset = 0
	SRCFILE "whalehunt_1a.bas",223
	MVI V59,R0
	CMPI #0,R0
	BLE T68
	MVII #80,R0
	MVO R0,V17
	B T69
T68:
	CLRR R0
	MVO R0,V17
T69:
	;[224] 				gosub draw_player
	SRCFILE "whalehunt_1a.bas",224
	CALL Q41
	;[225] 			end if
	SRCFILE "whalehunt_1a.bas",225
T67:
	;[226] 			if hands = 2 then 
	SRCFILE "whalehunt_1a.bas",226
	MVI V16,R0
	CMPI #2,R0
	BNE T70
	;[227] 				if row = 1 then offset = 160 else offset = 240
	SRCFILE "whalehunt_1a.bas",227
	MVI V25,R0
	CMPI #1,R0
	BNE T71
	MVII #160,R0
	MVO R0,V17
	B T72
T71:
	MVII #240,R0
	MVO R0,V17
T72:
	;[228] 				gosub draw_player
	SRCFILE "whalehunt_1a.bas",228
	CALL Q41
	;[229] 			end if
	SRCFILE "whalehunt_1a.bas",229
T70:
	;[230] 			if hands = 3 then 
	SRCFILE "whalehunt_1a.bas",230
	MVI V16,R0
	CMPI #3,R0
	BNE T73
	;[231] 				if sail_dir = 1 then offset = 0 : gosub sail_left
	SRCFILE "whalehunt_1a.bas",231
	MVI V58,R0
	CMPI #1,R0
	BNE T74
	CLRR R0
	MVO R0,V17
	CALL Q42
T74:
	;[232] 				if sail_dir = 2 then offset = 80 : gosub sail_straight
	SRCFILE "whalehunt_1a.bas",232
	MVI V58,R0
	CMPI #2,R0
	BNE T75
	MVII #80,R0
	MVO R0,V17
	CALL Q43
T75:
	;[233] 				if sail_dir = 3 then offset = 160 : gosub sail_right
	SRCFILE "whalehunt_1a.bas",233
	MVI V58,R0
	CMPI #3,R0
	BNE T76
	MVII #160,R0
	MVO R0,V17
	CALL Q44
T76:
	;[234] 			end if
	SRCFILE "whalehunt_1a.bas",234
T73:
	;[235] 			draw_y = 5
	SRCFILE "whalehunt_1a.bas",235
	MVII #5,R0
	MVO R0,V44
	;[236] 			draw_x = 6
	SRCFILE "whalehunt_1a.bas",236
	MVII #6,R0
	MVO R0,V43
	;[237] 		end if
	SRCFILE "whalehunt_1a.bas",237
T66:
	;[238] 		end if
	SRCFILE "whalehunt_1a.bas",238
T65:
	;[239] 	#day_cnt = 0 
	SRCFILE "whalehunt_1a.bas",239
	CLRR R0
	MVO R0,V1
	;[240] 	end if
	SRCFILE "whalehunt_1a.bas",240
T59:
	;[241] 	if sun_x = 0 then gosub storm
	SRCFILE "whalehunt_1a.bas",241
	MVI V49,R0
	TSTR R0
	BNE T77
	CALL Q45
T77:
	;[242] 	end
	SRCFILE "whalehunt_1a.bas",242
	RETURN
	ENDP
	;[243] 	
	SRCFILE "whalehunt_1a.bas",243
	;[244] 
	SRCFILE "whalehunt_1a.bas",244
	;[245] 
	SRCFILE "whalehunt_1a.bas",245
	;[246] score:	procedure
	SRCFILE "whalehunt_1a.bas",246
	; SCORE
Q27:	PROC
	BEGIN
	;[247] 	if health = 4 then x = fg_blue
	SRCFILE "whalehunt_1a.bas",247
	MVI V8,R0
	CMPI #4,R0
	BNE T78
	MVII #1,R0
	MVO R0,V60
T78:
	;[248] 	if health = 3 then x = fg_white
	SRCFILE "whalehunt_1a.bas",248
	MVI V8,R0
	CMPI #3,R0
	BNE T79
	MVII #7,R0
	MVO R0,V60
T79:
	;[249] 	if health = 2 then x = fg_yellow
	SRCFILE "whalehunt_1a.bas",249
	MVI V8,R0
	CMPI #2,R0
	BNE T80
	MVII #6,R0
	MVO R0,V60
T80:
	;[250] 	if health = 1 then x = fg_red
	SRCFILE "whalehunt_1a.bas",250
	MVI V8,R0
	CMPI #1,R0
	BNE T81
	MVII #2,R0
	MVO R0,V60
T81:
	;[251] 	print at screenpos(0,0) color x, <2>lives
	SRCFILE "whalehunt_1a.bas",251
	MVII #512,R0
	MVO R0,_screen
	MVI V60,R0
	MVO R0,_color
	MVI V7,R0
	MVII #2,R2
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.z
	MVO R4,_screen
	;[252] 	print at screenpos(16,0) color x, <4>#score
	SRCFILE "whalehunt_1a.bas",252
	MVII #528,R0
	MVO R0,_screen
	MVI V60,R0
	MVO R0,_color
	MVI V4,R0
	MVII #4,R2
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.z
	MVO R4,_screen
	;[253] 	if kill_cnt >= kill_qty then x = fg_yellow else x = fg_green
	SRCFILE "whalehunt_1a.bas",253
	MVI V27,R0
	CMP V26,R0
	BLT T82
	MVII #6,R0
	MVO R0,V60
	B T83
T82:
	MVII #5,R0
	MVO R0,V60
T83:
	;[254] 	if kill_qty - kill_cnt >= 0 then print at screenpos(3,0) color x, <2>kill_qty - kill_cnt else print at screenpos(3,0) color x, "00"
	SRCFILE "whalehunt_1a.bas",254
	MVI V26,R0
	SUB V27,R0
	CMPI #0,R0
	BLT T84
	MVII #515,R0
	MVO R0,_screen
	MVI V60,R0
	MVO R0,_color
	MVI V26,R0
	SUB V27,R0
	MVII #2,R2
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.z
	MVO R4,_screen
	B T85
T84:
	MVII #515,R0
	MVO R0,_screen
	MVI V60,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #128,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T85:
	;[255] 	
	SRCFILE "whalehunt_1a.bas",255
	;[256] 	if wind_direction = 1 then print at screenpos(13,0) color fg_green, " N"
	SRCFILE "whalehunt_1a.bas",256
	MVI V55,R0
	CMPI #1,R0
	BNE T86
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	MVO R4,_screen
T86:
	;[257] 	if wind_direction = 2 then print at screenpos(13,0) color fg_green, "NE"
	SRCFILE "whalehunt_1a.bas",257
	MVI V55,R0
	CMPI #2,R0
	BNE T87
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #368,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	MVO R4,_screen
T87:
	;[258] 	if wind_direction = 3 then print at screenpos(13,0) color fg_green, " E"
	SRCFILE "whalehunt_1a.bas",258
	MVI V55,R0
	CMPI #3,R0
	BNE T88
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO R4,_screen
T88:
	;[259] 	if wind_direction = 4 then print at screenpos(13,0) color fg_green, "SE"
	SRCFILE "whalehunt_1a.bas",259
	MVI V55,R0
	CMPI #4,R0
	BNE T89
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	MVO R4,_screen
T89:
	;[260] 	if wind_direction = 5 then print at screenpos(13,0) color fg_green, " S"
	SRCFILE "whalehunt_1a.bas",260
	MVI V55,R0
	CMPI #5,R0
	BNE T90
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	MVO R4,_screen
T90:
	;[261] 	if wind_direction = 6 then print at screenpos(13,0) color fg_green, "SW"
	SRCFILE "whalehunt_1a.bas",261
	MVI V55,R0
	CMPI #6,R0
	BNE T91
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	MVO R4,_screen
T91:
	;[262] 	if wind_direction = 7 then print at screenpos(13,0) color fg_green, " W"
	SRCFILE "whalehunt_1a.bas",262
	MVI V55,R0
	CMPI #7,R0
	BNE T92
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	MVO R4,_screen
T92:
	;[263] 	if wind_direction = 8 then print at screenpos(13,0) color fg_green, "NW"
	SRCFILE "whalehunt_1a.bas",263
	MVI V55,R0
	CMPI #8,R0
	BNE T93
	MVII #525,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #368,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	MVO R4,_screen
T93:
	;[264] 	if direction > 8 then direction = 1
	SRCFILE "whalehunt_1a.bas",264
	MVI V15,R0
	CMPI #8,R0
	BLE T94
	MVII #1,R0
	MVO R0,V15
T94:
	;[265] 	if direction < 1 then direction = 8
	SRCFILE "whalehunt_1a.bas",265
	MVI V15,R0
	CMPI #1,R0
	BGE T95
	MVII #8,R0
	MVO R0,V15
T95:
	;[266] 	print at screenpos(6,0) color fg_red, "<     >"
	SRCFILE "whalehunt_1a.bas",266
	MVII #518,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #224,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[267] 	print color cs_tan
	SRCFILE "whalehunt_1a.bas",267
	MVII #3,R0
	MVO R0,_color
	;[268] 	if direction = 1 then print at screenpos(7,0), "\37\13 \13\55" : if wind_direction = direction then print at screenpos(9,0) color fg_green, "\46" else print at screenpos(9,0) color fg_red, "\46"	'north
	SRCFILE "whalehunt_1a.bas",268
	MVI V15,R0
	CMPI #1,R0
	BNE T96
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #296,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #464,R0
	MVO@ R0,R4
	MVO R4,_screen
	MVI V55,R0
	CMP V15,R0
	BNE T97
	MVII #521,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #368,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	B T98
T97:
	MVII #521,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #368,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T98:
T96:
	;[269] 	if direction = 2 then print at screenpos(7,0), "\13\37 \46\13"	'northeast
	SRCFILE "whalehunt_1a.bas",269
	MVI V15,R0
	CMPI #2,R0
	BNE T99
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #104,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #280,R0
	MVO@ R0,R4
	MVO R4,_screen
T99:
	;[270] 	if direction = 3 then print at screenpos(7,0), "\51\13 \13\46" : if wind_direction = direction then print at screenpos(9,0) color fg_green, "\37" else print at screenpos(9,0) color fg_red, "\37"	'east
	SRCFILE "whalehunt_1a.bas",270
	MVI V15,R0
	CMPI #3,R0
	BNE T100
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #496,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #280,R0
	MVO@ R0,R4
	MVO R4,_screen
	MVI V55,R0
	CMP V15,R0
	BNE T101
	MVII #521,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #296,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	B T102
T101:
	MVII #521,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #296,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T102:
T100:
	;[271] 	if direction = 4 then print at screenpos(7,0), "\13\51 \37\13"	'southeast
	SRCFILE "whalehunt_1a.bas",271
	MVI V15,R0
	CMPI #4,R0
	BNE T103
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #104,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #496,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	MVO R4,_screen
T103:
	;[272] 	if direction = 5 then print at screenpos(7,0), "\55\13 \13\37" : if wind_direction = direction then print at screenpos(9,0) color fg_green, "\51" else print at screenpos(9,0) color fg_red, "\51" 'south
	SRCFILE "whalehunt_1a.bas",272
	MVI V15,R0
	CMPI #5,R0
	BNE T104
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #440,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #464,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	MVO R4,_screen
	MVI V55,R0
	CMP V15,R0
	BNE T105
	MVII #521,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	B T106
T105:
	MVII #521,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T106:
T104:
	;[273] 	if direction = 6 then print at screenpos(7,0), "\13\55 \51\13"	'southwest
	SRCFILE "whalehunt_1a.bas",273
	MVI V15,R0
	CMPI #6,R0
	BNE T107
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #104,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #464,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #496,R0
	MVO@ R0,R4
	MVO R4,_screen
T107:
	;[274] 	if direction = 7 then print at screenpos(7,0), "\46\13 \13\51" : if wind_direction = direction then print at screenpos(9,0) color fg_green, "\55" else print at screenpos(9,0) color fg_red, "\55" 'west
	SRCFILE "whalehunt_1a.bas",274
	MVI V15,R0
	CMPI #7,R0
	BNE T108
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #368,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #280,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #496,R0
	MVO@ R0,R4
	MVO R4,_screen
	MVI V55,R0
	CMP V15,R0
	BNE T109
	MVII #521,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #440,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	B T110
T109:
	MVII #521,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #440,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T110:
T108:
	;[275] 	if direction = 8 then print at screenpos(7,0), "\13\46 \55\13"	'northwest
	SRCFILE "whalehunt_1a.bas",275
	MVI V15,R0
	CMPI #8,R0
	BNE T111
	MVII #519,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #104,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #280,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #464,R0
	MVO@ R0,R4
	MVO R4,_screen
T111:
	;[276] 	for score_cnt = 2 to 8 step 2
	SRCFILE "whalehunt_1a.bas",276
	MVII #2,R0
	MVO R0,V61
T112:
	;[277] 		if direction = score_cnt then if wind_direction = direction then print at screenpos(9,0) color fg_green, "\13" else print at screenpos(9,0) color fg_red, "\13"	'red/green marker for NE, NW, SE, SW
	SRCFILE "whalehunt_1a.bas",277
	MVI V15,R0
	CMP V61,R0
	BNE T113
	MVI V55,R0
	CMP V15,R0
	BNE T114
	MVII #521,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #104,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	B T115
T114:
	MVII #521,R0
	MVO R0,_screen
	MVII #2,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #104,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T115:
T113:
	;[278] 	next score_cnt
	SRCFILE "whalehunt_1a.bas",278
	MVI V61,R0
	ADDI #2,R0
	MVO R0,V61
	CMPI #8,R0
	BLE T112
	;[279] 	wait
	SRCFILE "whalehunt_1a.bas",279
	CALL _wait
	;[280] 	end
	SRCFILE "whalehunt_1a.bas",280
	RETURN
	ENDP
	;[281] 	
	SRCFILE "whalehunt_1a.bas",281
	;[282] cont1wait:	procedure
	SRCFILE "whalehunt_1a.bas",282
	; CONT1WAIT
Q13:	PROC
	BEGIN
	;[283] cont1wait_loop:
	SRCFILE "whalehunt_1a.bas",283
	; CONT1WAIT_LOOP
Q48:	;[284] 	wait
	SRCFILE "whalehunt_1a.bas",284
	CALL _wait
	;[285] 	if cont1.key < 12 then goto cont1wait_loop
	SRCFILE "whalehunt_1a.bas",285
	MVI _cnt1_key,R0
	CMPI #12,R0
	BLT Q48
	;[286] 	end
	SRCFILE "whalehunt_1a.bas",286
	RETURN
	ENDP
	;[287] 
	SRCFILE "whalehunt_1a.bas",287
	;[288] cont1pause:		procedure
	SRCFILE "whalehunt_1a.bas",288
	; CONT1PAUSE
Q49:	PROC
	BEGIN
	;[289] cont1pause_loop:
	SRCFILE "whalehunt_1a.bas",289
	; CONT1PAUSE_LOOP
Q50:	;[290] 	wait
	SRCFILE "whalehunt_1a.bas",290
	CALL _wait
	;[291] 	if cont1.key = 12 then goto cont1pause_loop
	SRCFILE "whalehunt_1a.bas",291
	MVI _cnt1_key,R0
	CMPI #12,R0
	BEQ Q50
	;[292] 	end
	SRCFILE "whalehunt_1a.bas",292
	RETURN
	ENDP
	;[293] 
	SRCFILE "whalehunt_1a.bas",293
	;[294] load_row_throw:		procedure
	SRCFILE "whalehunt_1a.bas",294
	; LOAD_ROW_THROW
Q28:	PROC
	BEGIN
	;[295] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",295
	MVII #8192,R0
	MVO R0,_mobs+1
	;[296] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",296
	MVO R0,_mobs+2
	;[297] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",297
	NOP
	MVO R0,_mobs+3
	;[298] 	gosub blank_char
	SRCFILE "whalehunt_1a.bas",298
	CALL Q52
	;[299] 	DEFINE 0,16,row_throw_bitmaps_0
	SRCFILE "whalehunt_1a.bas",299
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q53,R0
	MVO R0,_gram_bitmap
	;[300] 	WAIT
	SRCFILE "whalehunt_1a.bas",300
	CALL _wait
	;[301] 	DEFINE 16,16,row_throw_bitmaps_1
	SRCFILE "whalehunt_1a.bas",301
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q54,R0
	MVO R0,_gram_bitmap
	;[302] 	WAIT
	SRCFILE "whalehunt_1a.bas",302
	CALL _wait
	;[303] 	DEFINE 32,16,row_throw_bitmaps_2
	SRCFILE "whalehunt_1a.bas",303
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q55,R0
	MVO R0,_gram_bitmap
	;[304] 	WAIT
	SRCFILE "whalehunt_1a.bas",304
	CALL _wait
	;[305] 	DEFINE 48,5,row_throw_bitmaps_3
	SRCFILE "whalehunt_1a.bas",305
	MVII #48,R0
	MVO R0,_gram_target
	MVII #5,R0
	MVO R0,_gram_total
	MVII #Q56,R0
	MVO R0,_gram_bitmap
	;[306] 'load_row_throw_end:
	SRCFILE "whalehunt_1a.bas",306
	;[307] 	define alternate 57,3,blood_1
	SRCFILE "whalehunt_1a.bas",307
	MVII #57,R0
	MVO R0,_gram2_target
	MVII #3,R0
	MVO R0,_gram2_total
	MVII #Q57,R0
	MVO R0,_gram2_bitmap
	;[308] 	wait
	SRCFILE "whalehunt_1a.bas",308
	CALL _wait
	;[309] 	if hands = 2 then define 53,3,paddle_sprites : wait
	SRCFILE "whalehunt_1a.bas",309
	MVI V16,R0
	CMPI #2,R0
	BNE T118
	MVII #53,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q58,R0
	MVO R0,_gram_bitmap
	CALL _wait
T118:
	;[310] 	gosub player_ready
	SRCFILE "whalehunt_1a.bas",310
	CALL Q59
	;[311] 	end
	SRCFILE "whalehunt_1a.bas",311
	RETURN
	ENDP
	;[312] 
	SRCFILE "whalehunt_1a.bas",312
	;[313] 	
	SRCFILE "whalehunt_1a.bas",313
	;[314] wind:	procedure	
	SRCFILE "whalehunt_1a.bas",314
	; WIND
Q39:	PROC
	BEGIN
	;[315] 	wait
	SRCFILE "whalehunt_1a.bas",315
	CALL _wait
	;[316] 	if wind_cnt = 0 then wind_roll = rand / 128
	SRCFILE "whalehunt_1a.bas",316
	MVI V36,R0
	TSTR R0
	BNE T119
	MVI _rand,R0
	SWAP R0
	ADDR R0,R0
	ADCR R0
	ANDI #511,R0
	MVO R0,V62
T119:
	;[317] 	wait
	SRCFILE "whalehunt_1a.bas",317
	CALL _wait
	;[318] 	if wind_roll = 0 then wind_roll = 1 : wind_direction = (rand/32) + 1
	SRCFILE "whalehunt_1a.bas",318
	MVI V62,R0
	TSTR R0
	BNE T120
	MVII #1,R0
	MVO R0,V62
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,1
	INCR R0
	MVO R0,V55
T120:
	;[319] 	wind_cnt = wind_cnt + 1 
	SRCFILE "whalehunt_1a.bas",319
	MVI V36,R0
	INCR R0
	MVO R0,V36
	;[320] 	if wind_cnt = 100 then wind_cnt = 0
	SRCFILE "whalehunt_1a.bas",320
	MVI V36,R0
	CMPI #100,R0
	BNE T121
	CLRR R0
	MVO R0,V36
T121:
	;[321] 	end
	SRCFILE "whalehunt_1a.bas",321
	RETURN
	ENDP
	;[322] 
	SRCFILE "whalehunt_1a.bas",322
	;[323] player_ready:	procedure
	SRCFILE "whalehunt_1a.bas",323
	; PLAYER_READY
Q59:	PROC
	BEGIN
	;[324] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",324
	MVII #8192,R0
	MVO R0,_mobs+1
	;[325] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",325
	MVO R0,_mobs+2
	;[326] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",326
	NOP
	MVO R0,_mobs+3
	;[327] 	gosub whale_movement
	SRCFILE "whalehunt_1a.bas",327
	CALL Q29
	;[328] 	if hands = 1 then
	SRCFILE "whalehunt_1a.bas",328
	MVI V16,R0
	CMPI #1,R0
	BNE T122
	;[329] 		offset = 0
	SRCFILE "whalehunt_1a.bas",329
	CLRR R0
	MVO R0,V17
	;[330] 		gosub draw_player
	SRCFILE "whalehunt_1a.bas",330
	CALL Q41
	;[331] 		define 54,2,title_harpoon
	SRCFILE "whalehunt_1a.bas",331
	MVII #54,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q10,R0
	MVO R0,_gram_bitmap
	;[332] 		wait
	SRCFILE "whalehunt_1a.bas",332
	CALL _wait
	;[333] 		sprite 01,		138 + visible, 62 + zoomy2, spr55 + spr_grey
	SRCFILE "whalehunt_1a.bas",333
	MVII #650,R0
	MVO R0,_mobs+1
	MVII #318,R0
	MVO R0,_mobs+9
	MVII #6584,R0
	MVO R0,_mobs+17
	;[334] 		SPRITE 02,		143 + VISIBLE + zoomx2, 68 + zoomy8, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",334
	MVII #1679,R0
	MVO R0,_mobs+2
	MVII #836,R0
	MVO R0,_mobs+10
	MVII #6578,R0
	MVO R0,_mobs+18
	;[335] 		goto ready_end
	SRCFILE "whalehunt_1a.bas",335
	B Q62
	;[336] 	end if
	SRCFILE "whalehunt_1a.bas",336
T122:
	;[337] 	if hands = 2 then 
	SRCFILE "whalehunt_1a.bas",337
	MVI V16,R0
	CMPI #2,R0
	BNE T123
	;[338] 		if row = 1 then offset = 160 else offset = 240
	SRCFILE "whalehunt_1a.bas",338
	MVI V25,R0
	CMPI #1,R0
	BNE T124
	MVII #160,R0
	MVO R0,V17
	B T125
T124:
	MVII #240,R0
	MVO R0,V17
T125:
	;[339] 		gosub draw_player
	SRCFILE "whalehunt_1a.bas",339
	CALL Q41
	;[340] 		goto ready_end
	SRCFILE "whalehunt_1a.bas",340
	B Q62
	;[341] 	end if
	SRCFILE "whalehunt_1a.bas",341
T123:
	;[342] 'ready_sail:
	SRCFILE "whalehunt_1a.bas",342
	;[343] 			'if daytime = 0 then screen background_dawn,20,20,20,11
	SRCFILE "whalehunt_1a.bas",343
	;[344] 			'if daytime = 1 then screen background,20,20,20,11
	SRCFILE "whalehunt_1a.bas",344
	;[345] 			'if daytime = 2 then screen background_dusk,20,20,20,11
	SRCFILE "whalehunt_1a.bas",345
	;[346] 			'if daytime = 3 then screen background_storm,20,20,20,11
	SRCFILE "whalehunt_1a.bas",346
	;[347] 	gosub blank_char
	SRCFILE "whalehunt_1a.bas",347
	CALL Q52
	;[348] 	DEFINE 0,16,sail_bitmaps_0
	SRCFILE "whalehunt_1a.bas",348
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q63,R0
	MVO R0,_gram_bitmap
	;[349] 	WAIT
	SRCFILE "whalehunt_1a.bas",349
	CALL _wait
	;[350] 	DEFINE 16,16,sail_bitmaps_1
	SRCFILE "whalehunt_1a.bas",350
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q64,R0
	MVO R0,_gram_bitmap
	;[351] 	WAIT
	SRCFILE "whalehunt_1a.bas",351
	CALL _wait
	;[352] 	DEFINE 32,16,sail_bitmaps_2
	SRCFILE "whalehunt_1a.bas",352
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q65,R0
	MVO R0,_gram_bitmap
	;[353] 	WAIT
	SRCFILE "whalehunt_1a.bas",353
	CALL _wait
	;[354] 	DEFINE 48,7,sail_bitmaps_3
	SRCFILE "whalehunt_1a.bas",354
	MVII #48,R0
	MVO R0,_gram_target
	MVII #7,R0
	MVO R0,_gram_total
	MVII #Q66,R0
	MVO R0,_gram_bitmap
	;[355] 	define alternate 63,1,harpoon_3
	SRCFILE "whalehunt_1a.bas",355
	MVII #63,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q67,R0
	MVO R0,_gram2_bitmap
	;[356] 	wait
	SRCFILE "whalehunt_1a.bas",356
	CALL _wait
	;[357] 'ready_sail_end:
	SRCFILE "whalehunt_1a.bas",357
	;[358] 	if sail_dir = 1 then offset = 0 : gosub sail_left
	SRCFILE "whalehunt_1a.bas",358
	MVI V58,R0
	CMPI #1,R0
	BNE T126
	CLRR R0
	MVO R0,V17
	CALL Q42
T126:
	;[359] 	if sail_dir = 2 then offset = 80 : gosub sail_straight
	SRCFILE "whalehunt_1a.bas",359
	MVI V58,R0
	CMPI #2,R0
	BNE T127
	MVII #80,R0
	MVO R0,V17
	CALL Q43
T127:
	;[360] 	if sail_dir = 3 then offset = 160 : gosub sail_right
	SRCFILE "whalehunt_1a.bas",360
	MVI V58,R0
	CMPI #3,R0
	BNE T128
	MVII #160,R0
	MVO R0,V17
	CALL Q44
T128:
	;[361] ready_end:
	SRCFILE "whalehunt_1a.bas",361
	; READY_END
Q62:	;[362] 	wait
	SRCFILE "whalehunt_1a.bas",362
	CALL _wait
	;[363] 	end
	SRCFILE "whalehunt_1a.bas",363
	RETURN
	ENDP
	;[364] 	
	SRCFILE "whalehunt_1a.bas",364
	;[365] player_throw:	procedure
	SRCFILE "whalehunt_1a.bas",365
	; PLAYER_THROW
Q35:	PROC
	BEGIN
	;[366] 	if hands <> 1 then hands = 1 : if map = 0 then gosub player_ready
	SRCFILE "whalehunt_1a.bas",366
	MVI V16,R0
	CMPI #1,R0
	BEQ T129
	MVII #1,R0
	MVO R0,V16
	MVI V11,R0
	TSTR R0
	BNE T130
	CALL Q59
T130:
T129:
	;[367] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",367
	MVII #8192,R0
	MVO R0,_mobs+1
	;[368] 	sprite 02, behind	
	SRCFILE "whalehunt_1a.bas",368
	MVO R0,_mobs+2
	;[369] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",369
	NOP
	MVO R0,_mobs+3
	;[370] 	offset = 80
	SRCFILE "whalehunt_1a.bas",370
	MVII #80,R0
	MVO R0,V17
	;[371] 	gosub draw_player
	SRCFILE "whalehunt_1a.bas",371
	CALL Q41
	;[372] 	harp1 = 124
	SRCFILE "whalehunt_1a.bas",372
	MVII #124,R0
	MVO R0,V30
	;[373] 	harp2 = harp1 - 8
	SRCFILE "whalehunt_1a.bas",373
	MVI V30,R0
	SUBI #8,R0
	MVO R0,V31
	;[374] 	harp3 = 47
	SRCFILE "whalehunt_1a.bas",374
	MVII #47,R0
	MVO R0,V32
	;[375] 	define 54,2,harpoon_1
	SRCFILE "whalehunt_1a.bas",375
	MVII #54,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q70,R0
	MVO R0,_gram_bitmap
	;[376] 	wait
	SRCFILE "whalehunt_1a.bas",376
	CALL _wait
	;[377] 	for throw_x = harp1 to harp2 step -1
	SRCFILE "whalehunt_1a.bas",377
	MVI V30,R0
	MVO R0,V63
T131:
	;[378] 		harp3 = harp3 - 2
	SRCFILE "whalehunt_1a.bas",378
	MVI V32,R0
	SUBI #2,R0
	MVO R0,V32
	;[379] REM =====sprites 53 and 54 are intentionally reversed here=====
	SRCFILE "whalehunt_1a.bas",379
	;[380] 		sprite 01,		throw_x + visible, harp3, spr54 + spr_grey
	SRCFILE "whalehunt_1a.bas",380
	MVI V63,R0
	ADDI #512,R0
	MVO R0,_mobs+1
	MVI V32,R0
	MVO R0,_mobs+9
	MVII #6576,R0
	MVO R0,_mobs+17
	;[381] 		SPRITE 02,		throw_x + 5 + VISIBLE + zoomx2, harp3 + 4 + zoomy4, SPR55 + spr_orange
	SRCFILE "whalehunt_1a.bas",381
	MVI V63,R0
	ADDI #1541,R0
	MVO R0,_mobs+2
	MVI V32,R0
	ADDI #516,R0
	MVO R0,_mobs+10
	MVII #6586,R0
	MVO R0,_mobs+18
	;[382] 		gosub whale_movement
	SRCFILE "whalehunt_1a.bas",382
	CALL Q29
	;[383] 	next throw_x
	SRCFILE "whalehunt_1a.bas",383
	MVI V63,R0
	DECR R0
	MVO R0,V63
	CMP V31,R0
	BGE T131
	;[384] 	gosub timer
	SRCFILE "whalehunt_1a.bas",384
	CALL Q38
	;[385] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",385
	MVII #8192,R0
	MVO R0,_mobs+1
	;[386] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",386
	MVO R0,_mobs+2
	;[387] 	sprite 03, behind	
	SRCFILE "whalehunt_1a.bas",387
	NOP
	MVO R0,_mobs+3
	;[388] 	define 54,2,harpoon_2
	SRCFILE "whalehunt_1a.bas",388
	MVII #54,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q71,R0
	MVO R0,_gram_bitmap
	;[389] 	wait
	SRCFILE "whalehunt_1a.bas",389
	CALL _wait
	;[390] 	harp1 = throw_x 
	SRCFILE "whalehunt_1a.bas",390
	MVI V63,R0
	MVO R0,V30
	;[391] 	if arch = 3 then harp2 = throw_x - (8*(arch+2)) else harp2 = throw_x - (8*(arch+1))
	SRCFILE "whalehunt_1a.bas",391
	MVI V59,R0
	CMPI #3,R0
	BNE T132
	MVI V63,R0
	MVI V59,R1
	ADDI #2,R1
	SLL R1,2
	ADDR R1,R1
	SUBR R1,R0
	MVO R0,V31
	B T133
T132:
	MVI V63,R0
	MVI V59,R1
	INCR R1
	SLL R1,2
	ADDR R1,R1
	SUBR R1,R0
	MVO R0,V31
T133:
	;[392] 	for throw_x = harp1 to harp2 step -1
	SRCFILE "whalehunt_1a.bas",392
	MVI V30,R0
	MVO R0,V63
T134:
	;[393] 		if throw_x = harp1 - (2*(arch+1)) then harp3 = harp3 - 1
	SRCFILE "whalehunt_1a.bas",393
	MVI V30,R0
	MVI V59,R1
	INCR R1
	SLL R1,1
	SUBR R1,R0
	MVI V63,R1
	CMPR R1,R0
	BNE T135
	MVI V32,R0
	DECR R0
	MVO R0,V32
T135:
	;[394] 		if throw_x = harp1 - (4*(arch+1)) then harp3 = harp3 - 1
	SRCFILE "whalehunt_1a.bas",394
	MVI V30,R0
	MVI V59,R1
	INCR R1
	SLL R1,2
	SUBR R1,R0
	MVI V63,R1
	CMPR R1,R0
	BNE T136
	MVI V32,R0
	DECR R0
	MVO R0,V32
T136:
	;[395] 		if throw_x = harp1 - (6*(arch+1)) then harp3 = harp3 - 1
	SRCFILE "whalehunt_1a.bas",395
	MVI V30,R0
	MVI V59,R1
	INCR R1
	MULT R1,R4,6
	SUBR R1,R0
	MVI V63,R1
	CMPR R1,R0
	BNE T137
	MVI V32,R0
	DECR R0
	MVO R0,V32
T137:
	;[396] 		sprite 01,		throw_x + visible, harp3, spr55 + spr_grey
	SRCFILE "whalehunt_1a.bas",396
	MVI V63,R0
	ADDI #512,R0
	MVO R0,_mobs+1
	MVI V32,R0
	MVO R0,_mobs+9
	MVII #6584,R0
	MVO R0,_mobs+17
	;[397] 		SPRITE 02,		throw_x + 8 + VISIBLE, harp3, SPR54 + spr_orange
	SRCFILE "whalehunt_1a.bas",397
	MVI V63,R0
	ADDI #520,R0
	MVO R0,_mobs+2
	MVI V32,R0
	MVO R0,_mobs+10
	MVII #6578,R0
	MVO R0,_mobs+18
	;[398] 		sprite 03,		throw_x + 12 + visible, harp3 + 1, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",398
	MVI V63,R0
	ADDI #524,R0
	MVO R0,_mobs+3
	MVI V32,R0
	INCR R0
	MVO R0,_mobs+11
	MVII #6578,R0
	MVO R0,_mobs+19
	;[399] 		wait
	SRCFILE "whalehunt_1a.bas",399
	CALL _wait
	;[400] 		wait
	SRCFILE "whalehunt_1a.bas",400
	CALL _wait
	;[401] 	next throw_x
	SRCFILE "whalehunt_1a.bas",401
	MVI V63,R0
	DECR R0
	MVO R0,V63
	CMP V31,R0
	BGE T134
	;[402] 	gosub timer
	SRCFILE "whalehunt_1a.bas",402
	CALL Q38
	;[403] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",403
	MVII #8192,R0
	MVO R0,_mobs+1
	;[404] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",404
	MVO R0,_mobs+2
	;[405] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",405
	NOP
	MVO R0,_mobs+3
	;[406] 	define 54,2,harpoon_3
	SRCFILE "whalehunt_1a.bas",406
	MVII #54,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q67,R0
	MVO R0,_gram_bitmap
	;[407] 	wait
	SRCFILE "whalehunt_1a.bas",407
	CALL _wait
	;[408] 	harp1 = throw_x 
	SRCFILE "whalehunt_1a.bas",408
	MVI V63,R0
	MVO R0,V30
	;[409] 	if arch > 1 then harp2 = throw_x - (8*(arch+2)) else harp2 = throw_x - (8*(arch+1))
	SRCFILE "whalehunt_1a.bas",409
	MVI V59,R0
	CMPI #1,R0
	BLE T138
	MVI V63,R0
	MVI V59,R1
	ADDI #2,R1
	SLL R1,2
	ADDR R1,R1
	SUBR R1,R0
	MVO R0,V31
	B T139
T138:
	MVI V63,R0
	MVI V59,R1
	INCR R1
	SLL R1,2
	ADDR R1,R1
	SUBR R1,R0
	MVO R0,V31
T139:
	;[410] 	for throw_x = harp1 to harp2 step -1
	SRCFILE "whalehunt_1a.bas",410
	MVI V30,R0
	MVO R0,V63
T140:
	;[411] 		if throw_x = harp1 - (2*(arch+1)) then harp3 = harp3 + 1
	SRCFILE "whalehunt_1a.bas",411
	MVI V30,R0
	MVI V59,R1
	INCR R1
	SLL R1,1
	SUBR R1,R0
	MVI V63,R1
	CMPR R1,R0
	BNE T141
	MVI V32,R0
	INCR R0
	MVO R0,V32
T141:
	;[412] 		if throw_x = harp1 - (4*(arch+1)) then harp3 = harp3 + 1
	SRCFILE "whalehunt_1a.bas",412
	MVI V30,R0
	MVI V59,R1
	INCR R1
	SLL R1,2
	SUBR R1,R0
	MVI V63,R1
	CMPR R1,R0
	BNE T142
	MVI V32,R0
	INCR R0
	MVO R0,V32
T142:
	;[413] 		if throw_x = harp1 - (6*(arch+1)) then harp3 = harp3 + 1
	SRCFILE "whalehunt_1a.bas",413
	MVI V30,R0
	MVI V59,R1
	INCR R1
	MULT R1,R4,6
	SUBR R1,R0
	MVI V63,R1
	CMPR R1,R0
	BNE T143
	MVI V32,R0
	INCR R0
	MVO R0,V32
T143:
	;[414] 		sprite 01,		throw_x + visible, harp3, spr55 + spr_grey
	SRCFILE "whalehunt_1a.bas",414
	MVI V63,R0
	ADDI #512,R0
	MVO R0,_mobs+1
	MVI V32,R0
	MVO R0,_mobs+9
	MVII #6584,R0
	MVO R0,_mobs+17
	;[415] 		SPRITE 02,		throw_x + 7 + VISIBLE, harp3, SPR54 + spr_orange
	SRCFILE "whalehunt_1a.bas",415
	MVI V63,R0
	ADDI #519,R0
	MVO R0,_mobs+2
	MVI V32,R0
	MVO R0,_mobs+10
	MVII #6578,R0
	MVO R0,_mobs+18
	;[416] 		sprite 03,		throw_x + 11 + visible, harp3 - 1, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",416
	MVI V63,R0
	ADDI #523,R0
	MVO R0,_mobs+3
	MVI V32,R0
	DECR R0
	MVO R0,_mobs+11
	MVII #6578,R0
	MVO R0,_mobs+19
	;[417] 		wait
	SRCFILE "whalehunt_1a.bas",417
	CALL _wait
	;[418] 		wait
	SRCFILE "whalehunt_1a.bas",418
	CALL _wait
	;[419] 	next throw_x
	SRCFILE "whalehunt_1a.bas",419
	MVI V63,R0
	DECR R0
	MVO R0,V63
	CMP V31,R0
	BGE T140
	;[420] 	gosub timer
	SRCFILE "whalehunt_1a.bas",420
	CALL Q38
	;[421] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",421
	MVII #8192,R0
	MVO R0,_mobs+1
	;[422] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",422
	MVO R0,_mobs+2
	;[423] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",423
	NOP
	MVO R0,_mobs+3
	;[424] 	define 54,2,harpoon_4
	SRCFILE "whalehunt_1a.bas",424
	MVII #54,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q72,R0
	MVO R0,_gram_bitmap
	;[425] 	wait
	SRCFILE "whalehunt_1a.bas",425
	CALL _wait
	;[426] 	harp1 = throw_x + 2
	SRCFILE "whalehunt_1a.bas",426
	MVI V63,R0
	ADDI #2,R0
	MVO R0,V30
	;[427] 	harp2 = harp1 - (8*(arch+1))
	SRCFILE "whalehunt_1a.bas",427
	MVI V30,R0
	MVI V59,R1
	INCR R1
	SLL R1,2
	ADDR R1,R1
	SUBR R1,R0
	MVO R0,V31
	;[428] 	harp3 = harp3 + 8
	SRCFILE "whalehunt_1a.bas",428
	MVI V32,R0
	ADDI #8,R0
	MVO R0,V32
	;[429] 	for throw_x = harp1 to harp2 step -1
	SRCFILE "whalehunt_1a.bas",429
	MVI V30,R0
	MVO R0,V63
T144:
	;[430] '		if throw_x = harp1 - (2*(arch+1)) then harp3 = harp3 + 3
	SRCFILE "whalehunt_1a.bas",430
	;[431] '		if throw_x = harp1 - (4*(arch+1)) then harp3 = harp3 + 3
	SRCFILE "whalehunt_1a.bas",431
	;[432] '		if throw_x = harp1 - (6*(arch+1)) then harp3 = harp3 + 3
	SRCFILE "whalehunt_1a.bas",432
	;[433] 		harp3 = harp3 + 2
	SRCFILE "whalehunt_1a.bas",433
	MVI V32,R0
	ADDI #2,R0
	MVO R0,V32
	;[434] 		sprite 01,		throw_x + visible, harp3, spr55 + spr_grey
	SRCFILE "whalehunt_1a.bas",434
	MVI V63,R0
	ADDI #512,R0
	MVO R0,_mobs+1
	MVI V32,R0
	MVO R0,_mobs+9
	MVII #6584,R0
	MVO R0,_mobs+17
	;[435] 		SPRITE 02,		throw_x + VISIBLE, harp3 - 4, SPR54 + spr_orange
	SRCFILE "whalehunt_1a.bas",435
	MVI V63,R0
	ADDI #512,R0
	MVO R0,_mobs+2
	MVI V32,R0
	SUBI #4,R0
	MVO R0,_mobs+10
	MVII #6578,R0
	MVO R0,_mobs+18
	;[436] 		sprite 03,		throw_x + 4 + visible, harp3 - 8, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",436
	MVI V63,R0
	ADDI #516,R0
	MVO R0,_mobs+3
	MVI V32,R0
	SUBI #8,R0
	MVO R0,_mobs+11
	MVII #6578,R0
	MVO R0,_mobs+19
	;[437] 		gosub whale_movement
	SRCFILE "whalehunt_1a.bas",437
	CALL Q29
	;[438] 		wait
	SRCFILE "whalehunt_1a.bas",438
	CALL _wait
	;[439] 		gosub whale_movement
	SRCFILE "whalehunt_1a.bas",439
	CALL Q29
	;[440] 		wait
	SRCFILE "whalehunt_1a.bas",440
	CALL _wait
	;[441] 		wait
	SRCFILE "whalehunt_1a.bas",441
	CALL _wait
	;[442] 		if harp3 > 70 then goto drop_harpoon
	SRCFILE "whalehunt_1a.bas",442
	MVI V32,R0
	CMPI #70,R0
	BGT Q73
	;[443] 	next throw_x
	SRCFILE "whalehunt_1a.bas",443
	MVI V63,R0
	DECR R0
	MVO R0,V63
	CMP V31,R0
	BGE T144
	;[444] 	gosub timer
	SRCFILE "whalehunt_1a.bas",444
	CALL Q38
	;[445] 	
	SRCFILE "whalehunt_1a.bas",445
	;[446] drop_harpoon:
	SRCFILE "whalehunt_1a.bas",446
	; DROP_HARPOON
Q73:	;[447] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",447
	MVII #8192,R0
	MVO R0,_mobs+1
	;[448] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",448
	MVO R0,_mobs+2
	;[449] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",449
	NOP
	MVO R0,_mobs+3
	;[450] 	throw_x = throw_x + 2
	SRCFILE "whalehunt_1a.bas",450
	MVI V63,R0
	ADDI #2,R0
	MVO R0,V63
	;[451] 	harp3 = harp3 + 2
	SRCFILE "whalehunt_1a.bas",451
	MVI V32,R0
	ADDI #2,R0
	MVO R0,V32
	;[452] 	harp1 = harp3
	SRCFILE "whalehunt_1a.bas",452
	MVI V32,R0
	MVO R0,V30
	;[453] 	define 54,2,harpoon_5
	SRCFILE "whalehunt_1a.bas",453
	MVII #54,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q75,R0
	MVO R0,_gram_bitmap
	;[454] 	wait
	SRCFILE "whalehunt_1a.bas",454
	CALL _wait
	;[455] 	for harp3 = harp1 to harp1 + 17
	SRCFILE "whalehunt_1a.bas",455
	MVI V30,R0
	MVO R0,V32
T146:
	;[456] 		sprite 01,		throw_x + hit + visible, harp3, spr55 + spr_grey
	SRCFILE "whalehunt_1a.bas",456
	MVI V63,R0
	ADDI #768,R0
	MVO R0,_mobs+1
	MVI V32,R0
	MVO R0,_mobs+9
	MVII #6584,R0
	MVO R0,_mobs+17
	;[457] 		SPRITE 02,		throw_x + hit + VISIBLE, harp3 - 4, SPR54 + spr_orange
	SRCFILE "whalehunt_1a.bas",457
	MVI V63,R0
	ADDI #768,R0
	MVO R0,_mobs+2
	MVI V32,R0
	SUBI #4,R0
	MVO R0,_mobs+10
	MVII #6578,R0
	MVO R0,_mobs+18
	;[458] 		sprite 03,		throw_x+1 + hit + visible, harp3 - 8, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",458
	MVI V63,R0
	ADDI #769,R0
	MVO R0,_mobs+3
	MVI V32,R0
	SUBI #8,R0
	MVO R0,_mobs+11
	MVII #6578,R0
	MVO R0,_mobs+19
	;[459] 		if col1 and hit_sprite4+hit_sprite6+hit_sprite7 then goto hit_throw
	SRCFILE "whalehunt_1a.bas",459
	MVI _col1,R0
	ANDI #208,R0
	BNE Q76
	;[460] 		for cnt = 1 to 3
	SRCFILE "whalehunt_1a.bas",460
	MVII #1,R0
	MVO R0,V54
T148:
	;[461] 			wait
	SRCFILE "whalehunt_1a.bas",461
	CALL _wait
	;[462] 		next cnt
	SRCFILE "whalehunt_1a.bas",462
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #3,R0
	BLE T148
	;[463] 	next harp3
	SRCFILE "whalehunt_1a.bas",463
	MVI V32,R0
	INCR R0
	MVO R0,V32
	MVI V30,R1
	ADDI #17,R1
	CMPR R1,R0
	BLE T146
	;[464] 	gosub timer
	SRCFILE "whalehunt_1a.bas",464
	CALL Q38
	;[465] 	wait
	SRCFILE "whalehunt_1a.bas",465
	CALL _wait
	;[466] 	play simple
	SRCFILE "whalehunt_1a.bas",466
	MVII #1,R3
	MVO R3,_music_mode
	;[467] 	play spear_miss
	SRCFILE "whalehunt_1a.bas",467
	MVII #Q77,R0
	CALL _play_music
	;[468] 	sprite 01, throw_x - 1 + visible, harp3, spr59 + spr_cyan
	SRCFILE "whalehunt_1a.bas",468
	MVI V63,R0
	ADDI #511,R0
	MVO R0,_mobs+1
	MVI V32,R0
	MVO R0,_mobs+9
	MVII #6617,R0
	MVO R0,_mobs+17
	;[469] 	SPRITE 02, throw_x + VISIBLE, harp3, SPR54 + spr_orange
	SRCFILE "whalehunt_1a.bas",469
	MVI V63,R0
	ADDI #512,R0
	MVO R0,_mobs+2
	MVI V32,R0
	MVO R0,_mobs+10
	MVII #6578,R0
	MVO R0,_mobs+18
	;[470] 	sprite 03, throw_x + 1 + visible, harp3 - 4, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",470
	MVI V63,R0
	ADDI #513,R0
	MVO R0,_mobs+3
	MVI V32,R0
	SUBI #4,R0
	MVO R0,_mobs+11
	MVII #6578,R0
	MVO R0,_mobs+19
	;[471] 	goto exit_throw
	SRCFILE "whalehunt_1a.bas",471
	B Q78
	;[472] 	
	SRCFILE "whalehunt_1a.bas",472
	;[473] hit_throw:
	SRCFILE "whalehunt_1a.bas",473
	; HIT_THROW
Q76:	;[474] 	play simple
	SRCFILE "whalehunt_1a.bas",474
	MVII #1,R3
	MVO R3,_music_mode
	;[475] 	play spear_hit
	SRCFILE "whalehunt_1a.bas",475
	MVII #Q80,R0
	CALL _play_music
	;[476] 	if enemy = 0 then #new_score = #score + 5
	SRCFILE "whalehunt_1a.bas",476
	MVI V41,R0
	TSTR R0
	BNE T149
	MVI V4,R0
	ADDI #5,R0
	MVO R0,V5
T149:
	;[477] 	if enemy = 1 then #new_score = #score + 3
	SRCFILE "whalehunt_1a.bas",477
	MVI V41,R0
	CMPI #1,R0
	BNE T150
	MVI V4,R0
	ADDI #3,R0
	MVO R0,V5
T150:
	;[478] 	if enemy = 2 then #new_score = #score + 7
	SRCFILE "whalehunt_1a.bas",478
	MVI V41,R0
	CMPI #2,R0
	BNE T151
	MVI V4,R0
	ADDI #7,R0
	MVO R0,V5
T151:
	;[479] 	if enemy = 3 then #new_score = #score + 10
	SRCFILE "whalehunt_1a.bas",479
	MVI V41,R0
	CMPI #3,R0
	BNE T152
	MVI V4,R0
	ADDI #10,R0
	MVO R0,V5
T152:
	;[480] 	sprite 01, throw_x - 1 + visible, harp3 - 3, spr59 + spr_red
	SRCFILE "whalehunt_1a.bas",480
	MVI V63,R0
	ADDI #511,R0
	MVO R0,_mobs+1
	MVI V32,R0
	SUBI #3,R0
	MVO R0,_mobs+9
	MVII #2522,R0
	MVO R0,_mobs+17
	;[481] 	SPRITE 02, throw_x + VISIBLE, harp3 - 3, SPR54 + spr_orange
	SRCFILE "whalehunt_1a.bas",481
	MVI V63,R0
	ADDI #512,R0
	MVO R0,_mobs+2
	MVI V32,R0
	SUBI #3,R0
	MVO R0,_mobs+10
	MVII #6578,R0
	MVO R0,_mobs+18
	;[482] 	sprite 03, throw_x + 1 + visible, harp3 - 7, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",482
	MVI V63,R0
	ADDI #513,R0
	MVO R0,_mobs+3
	MVI V32,R0
	SUBI #7,R0
	MVO R0,_mobs+11
	MVII #6578,R0
	MVO R0,_mobs+19
	;[483] 	hit_cnt = hit_cnt + harpoon
	SRCFILE "whalehunt_1a.bas",483
	MVI V28,R0
	ADD V33,R0
	MVO R0,V28
	;[484] 	for cnt = 1 to 10
	SRCFILE "whalehunt_1a.bas",484
	MVII #1,R0
	MVO R0,V54
T153:
	;[485] 		wait
	SRCFILE "whalehunt_1a.bas",485
	CALL _wait
	;[486] 	next cnt
	SRCFILE "whalehunt_1a.bas",486
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #10,R0
	BLE T153
	;[487] 	if hit_cnt >= hit_total then 
	SRCFILE "whalehunt_1a.bas",487
	MVI V28,R0
	CMP V29,R0
	BLT T154
	;[488] 		sprite 01, behind
	SRCFILE "whalehunt_1a.bas",488
	MVII #8192,R0
	MVO R0,_mobs+1
	;[489] 		sprite 02, behind
	SRCFILE "whalehunt_1a.bas",489
	MVO R0,_mobs+2
	;[490] 		sprite 03, behind
	SRCFILE "whalehunt_1a.bas",490
	NOP
	MVO R0,_mobs+3
	;[491] 		gosub enemy_attack
	SRCFILE "whalehunt_1a.bas",491
	CALL Q81
	;[492] 		gosub change_enemy
	SRCFILE "whalehunt_1a.bas",492
	CALL Q82
	;[493] 	end if
	SRCFILE "whalehunt_1a.bas",493
T154:
	;[494] exit_throw:
	SRCFILE "whalehunt_1a.bas",494
	; EXIT_THROW
Q78:	;[495] 	arch = 0
	SRCFILE "whalehunt_1a.bas",495
	CLRR R0
	MVO R0,V59
	;[496] 	if hit_cnt >= hit_total then hit_cnt = 0 : gosub hide_sprites else sprite 01, behind : sprite 02, behind : sprite 03, behind
	SRCFILE "whalehunt_1a.bas",496
	MVI V28,R0
	CMP V29,R0
	BLT T155
	CLRR R0
	MVO R0,V28
	CALL Q20
	B T156
T155:
	MVII #8192,R0
	MVO R0,_mobs+1
	MVO R0,_mobs+2
	NOP
	MVO R0,_mobs+3
T156:
	;[497] 	if #new_score > #score then if hit_cnt > 0 then gosub enemy_attack
	SRCFILE "whalehunt_1a.bas",497
	MVI V5,R0
	CMP V4,R0
	BLE T157
	MVI V28,R0
	CMPI #0,R0
	BLE T158
	CALL Q81
T158:
T157:
	;[498] 	gosub player_ready
	SRCFILE "whalehunt_1a.bas",498
	CALL Q59
	;[499] 	end
	SRCFILE "whalehunt_1a.bas",499
	RETURN
	ENDP
	;[500] 
	SRCFILE "whalehunt_1a.bas",500
	;[501] change_enemy:	procedure
	SRCFILE "whalehunt_1a.bas",501
	; CHANGE_ENEMY
Q82:	PROC
	BEGIN
	;[502] 	hit_cnt = 0
	SRCFILE "whalehunt_1a.bas",502
	CLRR R0
	MVO R0,V28
	;[503] 	if enemy = 0 then #new_score = #score + 30 : kill_cnt = kill_cnt + 1
	SRCFILE "whalehunt_1a.bas",503
	MVI V41,R0
	TSTR R0
	BNE T159
	MVI V4,R0
	ADDI #30,R0
	MVO R0,V5
	MVI V27,R0
	INCR R0
	MVO R0,V27
T159:
	;[504] 	if enemy = 1 then #new_score = #score + 25
	SRCFILE "whalehunt_1a.bas",504
	MVI V41,R0
	CMPI #1,R0
	BNE T160
	MVI V4,R0
	ADDI #25,R0
	MVO R0,V5
T160:
	;[505] 	if enemy = 2 then #new_score = #score + 35
	SRCFILE "whalehunt_1a.bas",505
	MVI V41,R0
	CMPI #2,R0
	BNE T161
	MVI V4,R0
	ADDI #35,R0
	MVO R0,V5
T161:
	;[506] 	if enemy = 3 then #new_score = #score + 40
	SRCFILE "whalehunt_1a.bas",506
	MVI V41,R0
	CMPI #3,R0
	BNE T162
	MVI V4,R0
	ADDI #40,R0
	MVO R0,V5
T162:
	;[507] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",507
	CALL Q20
	;[508] 	gosub whale_xy
	SRCFILE "whalehunt_1a.bas",508
	CALL Q17
	;[509] 	gosub whale_movement
	SRCFILE "whalehunt_1a.bas",509
	CALL Q29
	;[510] 	wait
	SRCFILE "whalehunt_1a.bas",510
	CALL _wait
	;[511] 	enemy = (rand / 64)
	SRCFILE "whalehunt_1a.bas",511
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	NOP
	MVO R0,V41
	;[512] 	if enemy >= 2 then wait : enemy = (rand / 64) else enemy = 0
	SRCFILE "whalehunt_1a.bas",512
	MVI V41,R0
	CMPI #2,R0
	BLT T163
	CALL _wait
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	NOP
	MVO R0,V41
	B T164
T163:
	CLRR R0
	MVO R0,V41
T164:
	;[513] 	if enemy = 0 then hit_total = 3
	SRCFILE "whalehunt_1a.bas",513
	MVI V41,R0
	TSTR R0
	BNE T165
	MVII #3,R0
	MVO R0,V29
T165:
	;[514] 	if enemy = 1 then hit_total = 3
	SRCFILE "whalehunt_1a.bas",514
	MVI V41,R0
	CMPI #1,R0
	BNE T166
	MVII #3,R0
	MVO R0,V29
T166:
	;[515] 	if enemy = 2 then hit_total = 2
	SRCFILE "whalehunt_1a.bas",515
	MVI V41,R0
	CMPI #2,R0
	BNE T167
	MVII #2,R0
	MVO R0,V29
T167:
	;[516] 	if enemy = 3 then hit_total = 4
	SRCFILE "whalehunt_1a.bas",516
	MVI V41,R0
	CMPI #3,R0
	BNE T168
	MVII #4,R0
	MVO R0,V29
T168:
	;[517] 	end
	SRCFILE "whalehunt_1a.bas",517
	RETURN
	ENDP
	;[518] 	
	SRCFILE "whalehunt_1a.bas",518
	;[519] 	
	SRCFILE "whalehunt_1a.bas",519
	;[520] player_row:		procedure
	SRCFILE "whalehunt_1a.bas",520
	; PLAYER_ROW
Q34:	PROC
	BEGIN
	;[521] 	if hands <> 2 then 
	SRCFILE "whalehunt_1a.bas",521
	MVI V16,R0
	CMPI #2,R0
	BEQ T169
	;[522] 		hands = 2
	SRCFILE "whalehunt_1a.bas",522
	MVII #2,R0
	MVO R0,V16
	;[523] 		if map = 0 then 
	SRCFILE "whalehunt_1a.bas",523
	MVI V11,R0
	TSTR R0
	BNE T170
	;[524] 			offset = 160
	SRCFILE "whalehunt_1a.bas",524
	MVII #160,R0
	MVO R0,V17
	;[525] 			gosub draw_player 
	SRCFILE "whalehunt_1a.bas",525
	CALL Q41
	;[526] 			row = 1
	SRCFILE "whalehunt_1a.bas",526
	MVII #1,R0
	MVO R0,V25
	;[527] 		end if
	SRCFILE "whalehunt_1a.bas",527
T170:
	;[528] 	end if
	SRCFILE "whalehunt_1a.bas",528
T169:
	;[529] 
	SRCFILE "whalehunt_1a.bas",529
	;[530] 	if map = 0 then 
	SRCFILE "whalehunt_1a.bas",530
	MVI V11,R0
	TSTR R0
	BNE T171
	;[531] 	if row = 1 then 
	SRCFILE "whalehunt_1a.bas",531
	MVI V25,R0
	CMPI #1,R0
	BNE T172
	;[532] 		offset = 160 
	SRCFILE "whalehunt_1a.bas",532
	MVII #160,R0
	MVO R0,V17
	;[533] 		gosub draw_player
	SRCFILE "whalehunt_1a.bas",533
	CALL Q41
	;[534] 		row = 0 
	SRCFILE "whalehunt_1a.bas",534
	CLRR R0
	MVO R0,V25
	;[535] 	else 
	SRCFILE "whalehunt_1a.bas",535
	B T173
T172:
	;[536] 		offset = 240 
	SRCFILE "whalehunt_1a.bas",536
	MVII #240,R0
	MVO R0,V17
	;[537] 		gosub draw_player 
	SRCFILE "whalehunt_1a.bas",537
	CALL Q41
	;[538] 		row = 1
	SRCFILE "whalehunt_1a.bas",538
	MVII #1,R0
	MVO R0,V25
	;[539] 	end if
	SRCFILE "whalehunt_1a.bas",539
T173:
	;[540] 	end if
	SRCFILE "whalehunt_1a.bas",540
T171:
	;[541] 	gosub whale_pos_calc
	SRCFILE "whalehunt_1a.bas",541
	CALL Q86
	;[542] 	if whalex_map > player_x - 9 then if whalex_map < player_x + 8 then if whaley_map > player_y - 5 then if whaley_map < player_y + 5 then goto check_row_position else goto check_row_end
	SRCFILE "whalehunt_1a.bas",542
	MVI V20,R0
	MVI V18,R1
	SUBI #9,R1
	CMPR R1,R0
	BLE T174
	MVI V18,R1
	ADDI #8,R1
	CMPR R1,R0
	BGE T175
	MVI V21,R0
	MVI V19,R1
	SUBI #5,R1
	CMPR R1,R0
	BLE T176
	MVI V19,R1
	ADDI #5,R1
	CMPR R1,R0
	BGE T177
	B Q87
	B T178
T177:
	B Q88
T178:
T176:
T175:
T174:
	;[543] 	goto check_row_end
	SRCFILE "whalehunt_1a.bas",543
	B Q88
	;[544] check_row_position:
	SRCFILE "whalehunt_1a.bas",544
	; CHECK_ROW_POSITION
Q87:	;[545] 	if whale_position = direction then goto player_row_end
	SRCFILE "whalehunt_1a.bas",545
	MVI V64,R0
	CMP V15,R0
	BEQ Q90
	;[546] 	if whale_up = direction then goto player_row_end
	SRCFILE "whalehunt_1a.bas",546
	MVI V65,R0
	CMP V15,R0
	BEQ Q90
	;[547] 	if whale_down = direction then goto player_row_end
	SRCFILE "whalehunt_1a.bas",547
	MVI V66,R0
	CMP V15,R0
	BEQ Q90
	;[548] check_row_end:
	SRCFILE "whalehunt_1a.bas",548
	; CHECK_ROW_END
Q88:	;[549] 	if direction = 1 then if row_cnt > row_total then player_y = player_y - paddle								'north
	SRCFILE "whalehunt_1a.bas",549
	MVI V15,R0
	CMPI #1,R0
	BNE T182
	MVI V24,R0
	CMP V22,R0
	BLE T183
	MVI V19,R0
	SUB V35,R0
	MVO R0,V19
T183:
T182:
	;[550] 	if direction = 2 then if row_cnt > row_total then player_y = player_y - paddle : player_x = player_x + paddle		'northeast
	SRCFILE "whalehunt_1a.bas",550
	MVI V15,R0
	CMPI #2,R0
	BNE T184
	MVI V24,R0
	CMP V22,R0
	BLE T185
	MVI V19,R0
	SUB V35,R0
	MVO R0,V19
	MVI V18,R0
	ADD V35,R0
	MVO R0,V18
T185:
T184:
	;[551] 	if direction = 3 then if row_cnt > row_total then player_x = player_x + paddle								'east
	SRCFILE "whalehunt_1a.bas",551
	MVI V15,R0
	CMPI #3,R0
	BNE T186
	MVI V24,R0
	CMP V22,R0
	BLE T187
	MVI V18,R0
	ADD V35,R0
	MVO R0,V18
T187:
T186:
	;[552] 	if direction = 4 then if row_cnt > row_total then player_y = player_y + paddle : player_x = player_x + paddle		'southeast
	SRCFILE "whalehunt_1a.bas",552
	MVI V15,R0
	CMPI #4,R0
	BNE T188
	MVI V24,R0
	CMP V22,R0
	BLE T189
	MVI V19,R0
	ADD V35,R0
	MVO R0,V19
	MVI V18,R0
	ADD V35,R0
	MVO R0,V18
T189:
T188:
	;[553] 	if direction = 5 then if row_cnt > row_total then player_y = player_y + paddle								'south
	SRCFILE "whalehunt_1a.bas",553
	MVI V15,R0
	CMPI #5,R0
	BNE T190
	MVI V24,R0
	CMP V22,R0
	BLE T191
	MVI V19,R0
	ADD V35,R0
	MVO R0,V19
T191:
T190:
	;[554] 	if direction = 6 then if row_cnt > row_total then player_y = player_y + paddle : player_x = player_x - paddle		'southwest
	SRCFILE "whalehunt_1a.bas",554
	MVI V15,R0
	CMPI #6,R0
	BNE T192
	MVI V24,R0
	CMP V22,R0
	BLE T193
	MVI V19,R0
	ADD V35,R0
	MVO R0,V19
	MVI V18,R0
	SUB V35,R0
	MVO R0,V18
T193:
T192:
	;[555] 	if direction = 7 then if row_cnt > row_total then player_x = player_x - paddle								'west
	SRCFILE "whalehunt_1a.bas",555
	MVI V15,R0
	CMPI #7,R0
	BNE T194
	MVI V24,R0
	CMP V22,R0
	BLE T195
	MVI V18,R0
	SUB V35,R0
	MVO R0,V18
T195:
T194:
	;[556] 	if direction = 8 then if row_cnt > row_total then player_y = player_y - paddle : player_x = player_x - paddle		'northwest
	SRCFILE "whalehunt_1a.bas",556
	MVI V15,R0
	CMPI #8,R0
	BNE T196
	MVI V24,R0
	CMP V22,R0
	BLE T197
	MVI V19,R0
	SUB V35,R0
	MVO R0,V19
	MVI V18,R0
	SUB V35,R0
	MVO R0,V18
T197:
T196:
	;[557] 	gosub dim_check
	SRCFILE "whalehunt_1a.bas",557
	CALL Q92
	;[558] 	gosub score
	SRCFILE "whalehunt_1a.bas",558
	CALL Q27
	;[559] 'check_health:
	SRCFILE "whalehunt_1a.bas",559
	;[560] '	print at 20, <3>player_x, " ", <3>player_y , " ", <3>crate_x, " ", <1>health
	SRCFILE "whalehunt_1a.bas",560
	;[561] '	if player_y >= 70 then if player_y <= 73 then if player_x > crate_x - 5 then if player_x < crate_x + 9 then goto use_health
	SRCFILE "whalehunt_1a.bas",561
	;[562] '	goto player_row_end
	SRCFILE "whalehunt_1a.bas",562
	;[563] 'use_health:
	SRCFILE "whalehunt_1a.bas",563
	;[564] '		'play simple
	SRCFILE "whalehunt_1a.bas",564
	;[565] '		'play health_sound
	SRCFILE "whalehunt_1a.bas",565
	;[566] '		if health < 5 then health = health + 1
	SRCFILE "whalehunt_1a.bas",566
	;[567] '		gosub health_crate
	SRCFILE "whalehunt_1a.bas",567
	;[568] player_row_end:
	SRCFILE "whalehunt_1a.bas",568
	; PLAYER_ROW_END
Q90:	;[569] 	if storm_flag = 0 then row_total = row_speed
	SRCFILE "whalehunt_1a.bas",569
	MVI V57,R0
	TSTR R0
	BNE T198
	MVI V23,R0
	MVO R0,V22
T198:
	;[570] 	end	
	SRCFILE "whalehunt_1a.bas",570
	RETURN
	ENDP
	;[571] 		
	SRCFILE "whalehunt_1a.bas",571
	;[572] draw_player:		procedure
	SRCFILE "whalehunt_1a.bas",572
	; DRAW_PLAYER
Q41:	PROC
	BEGIN
	;[573] 	for y = draw_y TO 11
	SRCFILE "whalehunt_1a.bas",573
	MVI V44,R0
	MVO R0,V67
T199:
	;[574] 	for x = draw_x TO 19
	SRCFILE "whalehunt_1a.bas",574
	MVI V43,R0
	MVO R0,V60
T200:
	;[575] 		if hands = 3 then
	SRCFILE "whalehunt_1a.bas",575
	MVI V16,R0
	CMPI #3,R0
	BNE T201
	;[576] 			PRINT AT y * 20 + x,sail_cards(y * 240 + x + (20*daytime) + offset)
	SRCFILE "whalehunt_1a.bas",576
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVI V67,R1
	MVII #240,R5
	CLRR R4
	CLRC
	RRC R1,1
	BEQ T203
T202:
	BNC $+3
	ADDR R5,R4
	ADDR R5,R5
	SARC R1,1
	BNE T202
T203:
	BNC $+3
	ADDR R5,R4
	MOVR R4,R1
	ADD V60,R1
	MVI V47,R2
	MULT R2,R4,20
	ADDR R2,R1
	ADD V17,R1
	MVII #Q95,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[577] 		else
	SRCFILE "whalehunt_1a.bas",577
	B T204
T201:
	;[578] 			PRINT AT y * 20 + x,row_throw_cards(y * 320 + x + (20*daytime) + offset)
	SRCFILE "whalehunt_1a.bas",578
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVI V67,R1
	MVII #320,R5
	CLRR R4
	CLRC
	RRC R1,1
	BEQ T206
T205:
	BNC $+3
	ADDR R5,R4
	ADDR R5,R5
	SARC R1,1
	BNE T205
T206:
	BNC $+3
	ADDR R5,R4
	MOVR R4,R1
	ADD V60,R1
	MVI V47,R2
	MULT R2,R4,20
	ADDR R2,R1
	ADD V17,R1
	MVII #Q96,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[579] 		end if
	SRCFILE "whalehunt_1a.bas",579
T204:
	;[580] 	next x
	SRCFILE "whalehunt_1a.bas",580
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMPI #19,R0
	BLE T200
	;[581] 	next y
	SRCFILE "whalehunt_1a.bas",581
	MVI V67,R0
	INCR R0
	MVO R0,V67
	CMPI #11,R0
	BLE T199
	;[582] 	if map = 0 then
	SRCFILE "whalehunt_1a.bas",582
	MVI V11,R0
	TSTR R0
	BNE T207
	;[583] 	if hands < 3 then
	SRCFILE "whalehunt_1a.bas",583
	MVI V16,R0
	CMPI #3,R0
	BGE T208
	;[584] 	if offset = 160 then
	SRCFILE "whalehunt_1a.bas",584
	MVI V17,R0
	CMPI #160,R0
	BNE T209
	;[585] 		define 53,3,paddle_sprites
	SRCFILE "whalehunt_1a.bas",585
	MVII #53,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q58,R0
	MVO R0,_gram_bitmap
	;[586] 		wait
	SRCFILE "whalehunt_1a.bas",586
	CALL _wait
	;[587] 		sprite 01, 56 + visible, 80 + zoomy2, spr53 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",587
	MVII #568,R0
	MVO R0,_mobs+1
	MVII #336,R0
	MVO R0,_mobs+9
	MVII #2476,R0
	MVO R0,_mobs+17
	;[588] 		sprite 02, 64 + visible, 80 + zoomy2, spr54 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",588
	MVII #576,R0
	MVO R0,_mobs+2
	MVII #336,R0
	MVO R0,_mobs+10
	MVII #2484,R0
	MVO R0,_mobs+18
	;[589] 		sprite 03, 72 + visible, 80 + zoomy2, spr55 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",589
	MVII #584,R0
	MVO R0,_mobs+3
	MVII #336,R0
	MVO R0,_mobs+11
	MVII #2492,R0
	MVO R0,_mobs+19
	;[590] 	end if
	SRCFILE "whalehunt_1a.bas",590
T209:
	;[591] 	if offset = 240 then 
	SRCFILE "whalehunt_1a.bas",591
	MVI V17,R0
	CMPI #240,R0
	BNE T210
	;[592] 		sprite 01, behind 
	SRCFILE "whalehunt_1a.bas",592
	MVII #8192,R0
	MVO R0,_mobs+1
	;[593] 		sprite 02, behind 
	SRCFILE "whalehunt_1a.bas",593
	MVO R0,_mobs+2
	;[594] 		sprite 03, behind
	SRCFILE "whalehunt_1a.bas",594
	NOP
	MVO R0,_mobs+3
	;[595] 	end if
	SRCFILE "whalehunt_1a.bas",595
T210:
	;[596] 	end if
	SRCFILE "whalehunt_1a.bas",596
T208:
	;[597] 	end if
	SRCFILE "whalehunt_1a.bas",597
T207:
	;[598] 	end
	SRCFILE "whalehunt_1a.bas",598
	RETURN
	ENDP
	;[599] 
	SRCFILE "whalehunt_1a.bas",599
	;[600] 
	SRCFILE "whalehunt_1a.bas",600
	;[601] sail:	procedure
	SRCFILE "whalehunt_1a.bas",601
	; SAIL
Q33:	PROC
	BEGIN
	;[602] 	play off
	SRCFILE "whalehunt_1a.bas",602
	CLRR R0
	CALL _play_music
	;[603] 	if map = 0 then if hands <> 3 then hands = 3 : sprite 01, behind : sprite 02, behind : sprite 03, behind : gosub player_ready
	SRCFILE "whalehunt_1a.bas",603
	MVI V11,R0
	TSTR R0
	BNE T211
	MVI V16,R0
	CMPI #3,R0
	BEQ T212
	MVII #3,R0
	MVO R0,V16
	MVII #8192,R0
	MVO R0,_mobs+1
	MVO R0,_mobs+2
	NOP
	MVO R0,_mobs+3
	CALL Q59
T212:
T211:
	;[604] 	if map = 1 then hands = 3
	SRCFILE "whalehunt_1a.bas",604
	MVI V11,R0
	CMPI #1,R0
	BNE T213
	MVII #3,R0
	MVO R0,V16
T213:
	;[605] 	gosub wind
	SRCFILE "whalehunt_1a.bas",605
	CALL Q39
	;[606] 	if direction = wind_direction then wind_bonus = 2 else wind_bonus = 0
	SRCFILE "whalehunt_1a.bas",606
	MVI V15,R0
	CMP V55,R0
	BNE T214
	MVII #2,R0
	MVO R0,V68
	B T215
T214:
	CLRR R0
	MVO R0,V68
T215:
	;[607] 	if cont1.key = 9 then if map = 0 then offset = 160 : gosub sail_right 
	SRCFILE "whalehunt_1a.bas",607
	MVI _cnt1_key,R0
	CMPI #9,R0
	BNE T216
	MVI V11,R0
	TSTR R0
	BNE T217
	MVII #160,R0
	MVO R0,V17
	CALL Q44
T217:
T216:
	;[608] 	if cont1.key = 9 then wind_offset = wind_direction + 1 : if wind_offset > 8 then wind_offset = 1
	SRCFILE "whalehunt_1a.bas",608
	MVI _cnt1_key,R0
	CMPI #9,R0
	BNE T218
	MVI V55,R0
	INCR R0
	MVO R0,V69
	MVI V69,R0
	CMPI #8,R0
	BLE T219
	MVII #1,R0
	MVO R0,V69
T219:
T218:
	;[609] 	if cont1.key = 7 then if map = 0 then offset = 0 : gosub sail_left
	SRCFILE "whalehunt_1a.bas",609
	MVI _cnt1_key,R0
	CMPI #7,R0
	BNE T220
	MVI V11,R0
	TSTR R0
	BNE T221
	MVO R0,V17
	CALL Q42
T221:
T220:
	;[610] 	if cont1.key = 7 then wind_offset = wind_direction - 1 : if wind_offset < 1 then wind_offset = 8
	SRCFILE "whalehunt_1a.bas",610
	MVI _cnt1_key,R0
	CMPI #7,R0
	BNE T222
	MVI V55,R0
	DECR R0
	MVO R0,V69
	MVI V69,R0
	CMPI #1,R0
	BGE T223
	MVII #8,R0
	MVO R0,V69
T223:
T222:
	;[611] 	if cont1.key = 8 then if map = 0 then offset = 80 : gosub sail_straight
	SRCFILE "whalehunt_1a.bas",611
	MVI _cnt1_key,R0
	CMPI #8,R0
	BNE T224
	MVI V11,R0
	TSTR R0
	BNE T225
	MVII #80,R0
	MVO R0,V17
	CALL Q43
T225:
T224:
	;[612] 	if cont1.key = 8 then wind_offset = wind_direction
	SRCFILE "whalehunt_1a.bas",612
	MVI _cnt1_key,R0
	CMPI #8,R0
	BNE T226
	MVI V55,R0
	MVO R0,V69
T226:
	;[613] 'sail_map:
	SRCFILE "whalehunt_1a.bas",613
	;[614] '	if whalex_map > player_x - 5 then if whaley_map < player_y + 5 then if whalex_map < player_x + 5 then if whaley_map > player_y - 5 then if whale_position = direction then goto sail_end
	SRCFILE "whalehunt_1a.bas",614
	;[615] '	if whalex_map > player_x - 5 then if whaley_map < player_y + 5 then if whalex_map < player_x + 5 then if whaley_map > player_y - 5 then if whale_up = direction then goto sail_end
	SRCFILE "whalehunt_1a.bas",615
	;[616] '	if whalex_map > player_x - 5 then if whaley_map < player_y + 5 then if whalex_map < player_x + 5 then if whaley_map > player_y - 5 then if whale_down = direction then goto sail_end
	SRCFILE "whalehunt_1a.bas",616
	;[617] 	gosub whale_pos_calc
	SRCFILE "whalehunt_1a.bas",617
	CALL Q86
	;[618] 		if whalex_map > player_x - 9 then if whalex_map < player_x + 8 then if whaley_map > player_y - 5 then if whaley_map < player_y + 5 then goto check_sail_end
	SRCFILE "whalehunt_1a.bas",618
	MVI V20,R0
	MVI V18,R1
	SUBI #9,R1
	CMPR R1,R0
	BLE T227
	MVI V18,R1
	ADDI #8,R1
	CMPR R1,R0
	BGE T228
	MVI V21,R0
	MVI V19,R1
	SUBI #5,R1
	CMPR R1,R0
	BLE T229
	MVI V19,R1
	ADDI #5,R1
	CMPR R1,R0
	BLT Q98
T229:
T228:
T227:
	;[619] 'check_sail_position:
	SRCFILE "whalehunt_1a.bas",619
	;[620] 	if wind_offset = 1 then player_y = player_y - wind_bonus								'north
	SRCFILE "whalehunt_1a.bas",620
	MVI V69,R0
	CMPI #1,R0
	BNE T231
	MVI V19,R0
	SUB V68,R0
	MVO R0,V19
T231:
	;[621] 	if wind_offset = 2 then player_y = player_y - wind_bonus : player_x = player_x + wind_bonus		'northeast
	SRCFILE "whalehunt_1a.bas",621
	MVI V69,R0
	CMPI #2,R0
	BNE T232
	MVI V19,R0
	SUB V68,R0
	MVO R0,V19
	MVI V18,R0
	ADD V68,R0
	MVO R0,V18
T232:
	;[622] 	if wind_offset = 3 then player_x = player_x + wind_bonus								'east
	SRCFILE "whalehunt_1a.bas",622
	MVI V69,R0
	CMPI #3,R0
	BNE T233
	MVI V18,R0
	ADD V68,R0
	MVO R0,V18
T233:
	;[623] 	if wind_offset = 4 then player_y = player_y + wind_bonus : player_x = player_x + wind_bonus		'southeast
	SRCFILE "whalehunt_1a.bas",623
	MVI V69,R0
	CMPI #4,R0
	BNE T234
	MVI V19,R0
	ADD V68,R0
	MVO R0,V19
	MVI V18,R0
	ADD V68,R0
	MVO R0,V18
T234:
	;[624] 	if wind_offset = 5 then player_y = player_y + wind_bonus								'south
	SRCFILE "whalehunt_1a.bas",624
	MVI V69,R0
	CMPI #5,R0
	BNE T235
	MVI V19,R0
	ADD V68,R0
	MVO R0,V19
T235:
	;[625] 	if wind_offset = 6 then player_y = player_y + wind_bonus : player_x = player_x - wind_bonus		'southwest
	SRCFILE "whalehunt_1a.bas",625
	MVI V69,R0
	CMPI #6,R0
	BNE T236
	MVI V19,R0
	ADD V68,R0
	MVO R0,V19
	MVI V18,R0
	SUB V68,R0
	MVO R0,V18
T236:
	;[626] 	if wind_offset = 7 then player_x = player_x - wind_bonus								'west
	SRCFILE "whalehunt_1a.bas",626
	MVI V69,R0
	CMPI #7,R0
	BNE T237
	MVI V18,R0
	SUB V68,R0
	MVO R0,V18
T237:
	;[627] 	if wind_offset = 8 then player_y = player_y - wind_bonus : player_x = player_x - wind_bonus		'northwest
	SRCFILE "whalehunt_1a.bas",627
	MVI V69,R0
	CMPI #8,R0
	BNE T238
	MVI V19,R0
	SUB V68,R0
	MVO R0,V19
	MVI V18,R0
	SUB V68,R0
	MVO R0,V18
T238:
	;[628] 	gosub dim_check
	SRCFILE "whalehunt_1a.bas",628
	CALL Q92
	;[629] 	check_sail_end:
	SRCFILE "whalehunt_1a.bas",629
	; CHECK_SAIL_END
Q98:	;[630] 	gosub whale_movement
	SRCFILE "whalehunt_1a.bas",630
	CALL Q29
	;[631] 	gosub score
	SRCFILE "whalehunt_1a.bas",631
	CALL Q27
	;[632] 	wait
	SRCFILE "whalehunt_1a.bas",632
	CALL _wait
	;[633] 	wait
	SRCFILE "whalehunt_1a.bas",633
	CALL _wait
	;[634] 	end
	SRCFILE "whalehunt_1a.bas",634
	RETURN
	ENDP
	;[635] 
	SRCFILE "whalehunt_1a.bas",635
	;[636] sail_left:		procedure
	SRCFILE "whalehunt_1a.bas",636
	; SAIL_LEFT
Q42:	PROC
	BEGIN
	;[637] 	'gosub draw_player
	SRCFILE "whalehunt_1a.bas",637
	;[638] 	sprite 01, 120 + visible, 51 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",638
	MVII #632,R0
	MVO R0,_mobs+1
	MVII #563,R0
	MVO R0,_mobs+9
	MVII #2556,R0
	MVO R0,_mobs+17
	;[639] 	sprite 02, 80 + visible, 81 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",639
	MVII #592,R0
	MVO R0,_mobs+2
	MVII #593,R0
	MVO R0,_mobs+10
	MVII #2556,R0
	MVO R0,_mobs+18
	;[640] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",640
	MVII #8192,R0
	MVO R0,_mobs+3
	;[641] 	gosub draw_player
	SRCFILE "whalehunt_1a.bas",641
	CALL Q41
	;[642] 	end
	SRCFILE "whalehunt_1a.bas",642
	RETURN
	ENDP
	;[643] sail_straight:		procedure
	SRCFILE "whalehunt_1a.bas",643
	; SAIL_STRAIGHT
Q43:	PROC
	BEGIN
	;[644] 	'gosub draw_player
	SRCFILE "whalehunt_1a.bas",644
	;[645] 	sprite 01, 120 + zoomx2 + visible, 51 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",645
	MVII #1656,R0
	MVO R0,_mobs+1
	MVII #563,R0
	MVO R0,_mobs+9
	MVII #2556,R0
	MVO R0,_mobs+17
	;[646] 	sprite 02, 88 + visible, 73 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",646
	MVII #600,R0
	MVO R0,_mobs+2
	MVII #585,R0
	MVO R0,_mobs+10
	MVII #2556,R0
	MVO R0,_mobs+18
	;[647] 	sprite 03, 152 + visible, 73 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",647
	MVII #664,R0
	MVO R0,_mobs+3
	MVII #585,R0
	MVO R0,_mobs+11
	MVII #2556,R0
	MVO R0,_mobs+19
	;[648] 	gosub draw_player
	SRCFILE "whalehunt_1a.bas",648
	CALL Q41
	;[649] 	end
	SRCFILE "whalehunt_1a.bas",649
	RETURN
	ENDP
	;[650] sail_right:		procedure
	SRCFILE "whalehunt_1a.bas",650
	; SAIL_RIGHT
Q44:	PROC
	BEGIN
	;[651] 	'gosub draw_player
	SRCFILE "whalehunt_1a.bas",651
	;[652] 	sprite 01, 128 + zoomx2 + visible, 51 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",652
	MVII #1664,R0
	MVO R0,_mobs+1
	MVII #563,R0
	MVO R0,_mobs+9
	MVII #2556,R0
	MVO R0,_mobs+17
	;[653] 	sprite 02, 96 + visible, 65 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",653
	MVII #608,R0
	MVO R0,_mobs+2
	MVII #577,R0
	MVO R0,_mobs+10
	MVII #2556,R0
	MVO R0,_mobs+18
	;[654] 	sprite 03, 151 + zoomx2 + visible, 63 + zoomy4, spr63 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",654
	MVII #1687,R0
	MVO R0,_mobs+3
	MVII #575,R0
	MVO R0,_mobs+11
	MVII #2556,R0
	MVO R0,_mobs+19
	;[655] 	gosub draw_player
	SRCFILE "whalehunt_1a.bas",655
	CALL Q41
	;[656] 	end
	SRCFILE "whalehunt_1a.bas",656
	RETURN
	ENDP
	;[657] 
	SRCFILE "whalehunt_1a.bas",657
	;[658] whale_xy:	procedure
	SRCFILE "whalehunt_1a.bas",658
	; WHALE_XY
Q17:	PROC
	BEGIN
	;[659] whale_xy_loop:
	SRCFILE "whalehunt_1a.bas",659
	; WHALE_XY_LOOP
Q104:	;[660] 	wait
	SRCFILE "whalehunt_1a.bas",660
	CALL _wait
	;[661] 	whalex_map = (rand / 5) * 3
	SRCFILE "whalehunt_1a.bas",661
	MVI _rand,R0
	MVII #-1,R4
T239:
	INCR R4
	SUBI #5,R0
	BC T239
	MOVR R4,R0
	MULT R0,R4,3
	MVO R0,V20
	;[662] 	wait
	SRCFILE "whalehunt_1a.bas",662
	CALL _wait
	;[663] 	whaley_map = rand / 3
	SRCFILE "whalehunt_1a.bas",663
	MVI _rand,R0
	MVII #-1,R4
T240:
	INCR R4
	SUBI #3,R0
	BC T240
	MOVR R4,R0
	MVO R0,V21
	;[664] 	gosub dim_check
	SRCFILE "whalehunt_1a.bas",664
	CALL Q92
	;[665] 	if whalex_map > player_x - 6 then if whalex_map < player_x + 6 then if whaley_map > player_y - 6 then if whaley_map < player_y + 6 then goto whale_xy_loop
	SRCFILE "whalehunt_1a.bas",665
	MVI V20,R0
	MVI V18,R1
	SUBI #6,R1
	CMPR R1,R0
	BLE T241
	MVI V18,R1
	ADDI #6,R1
	CMPR R1,R0
	BGE T242
	MVI V21,R0
	MVI V19,R1
	SUBI #6,R1
	CMPR R1,R0
	BLE T243
	MVI V19,R1
	ADDI #6,R1
	CMPR R1,R0
	BLT Q104
T243:
T242:
T241:
	;[666] 	for cnt = 1 to storm_qty
	SRCFILE "whalehunt_1a.bas",666
	MVII #1,R0
	MVO R0,V54
T245:
	;[667] 		if whalex_map > stormx_map(cnt) - 1 then if whalex_map < stormx_map(cnt) + 1 then if whaley_map > stormy_map(cnt) - 1 then if whaley_map < stormy_map(cnt) + 1 then goto whale_xy_loop
	SRCFILE "whalehunt_1a.bas",667
	MVI V20,R0
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R1
	DECR R1
	CMPR R1,R0
	BLE T246
	MVI@ R3,R1
	INCR R1
	CMPR R1,R0
	BGE T247
	MVI V21,R0
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	DECR R1
	CMPR R1,R0
	BLE T248
	MVI@ R3,R1
	INCR R1
	CMPR R1,R0
	BLT Q104
T248:
T247:
T246:
	;[668] 	next cnt
	SRCFILE "whalehunt_1a.bas",668
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMP V52,R0
	BLE T245
	;[669] 	end
	SRCFILE "whalehunt_1a.bas",669
	RETURN
	ENDP
	;[670] 	
	SRCFILE "whalehunt_1a.bas",670
	;[671] whale_movement:		procedure
	SRCFILE "whalehunt_1a.bas",671
	; WHALE_MOVEMENT
Q29:	PROC
	BEGIN
	;[672] whale_cnt = whale_cnt + 1
	SRCFILE "whalehunt_1a.bas",672
	MVI V56,R0
	INCR R0
	MVO R0,V56
	;[673] if whale_cnt < 30 then goto whale_move_end
	SRCFILE "whalehunt_1a.bas",673
	MVI V56,R0
	CMPI #30,R0
	BLT Q106
	;[674] if whale_cnt > 30 then whale_cnt = 0 : goto whale_move_end
	SRCFILE "whalehunt_1a.bas",674
	MVI V56,R0
	CMPI #30,R0
	BLE T251
	CLRR R0
	MVO R0,V56
	B Q106
T251:
	;[675] gosub whale_pos_calc
	SRCFILE "whalehunt_1a.bas",675
	CALL Q86
	;[676] if storm_flag = 1 then goto whale_move_map
	SRCFILE "whalehunt_1a.bas",676
	MVI V57,R0
	CMPI #1,R0
	BEQ Q107
	;[677] if map = 1 then goto whale_move_map
	SRCFILE "whalehunt_1a.bas",677
	MVI V11,R0
	CMPI #1,R0
	BEQ Q107
	;[678] if whale_position <> direction then goto whale_move_map
	SRCFILE "whalehunt_1a.bas",678
	MVI V64,R0
	CMP V15,R0
	BNE Q107
	;[679] whalex = dir_cnt * 4
	SRCFILE "whalehunt_1a.bas",679
	MVI V14,R0
	SLL R0,2
	MVO R0,V12
	;[680] move_dir = rand / 64
	SRCFILE "whalehunt_1a.bas",680
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,2
	NOP
	MVO R0,V70
	;[681] if move_dir = 0 then whalex = whalex - 5
	SRCFILE "whalehunt_1a.bas",681
	MVI V70,R0
	TSTR R0
	BNE T255
	MVI V12,R0
	SUBI #5,R0
	MVO R0,V12
T255:
	;[682] if move_dir = 2 then whalex = whalex + 5
	SRCFILE "whalehunt_1a.bas",682
	MVI V70,R0
	CMPI #2,R0
	BNE T256
	MVI V12,R0
	ADDI #5,R0
	MVO R0,V12
T256:
	;[683] if whalex > 44 then whalex = 44
	SRCFILE "whalehunt_1a.bas",683
	MVI V12,R0
	CMPI #44,R0
	BLE T257
	MVII #44,R0
	MVO R0,V12
T257:
	;[684] if whalex > 245 then whalex = 1
	SRCFILE "whalehunt_1a.bas",684
	MVI V12,R0
	CMPI #245,R0
	BLE T258
	MVII #1,R0
	MVO R0,V12
T258:
	;[685] 'if whalex > 44 then whalex = 1 : direction = direction + 1 : if direction > 8 then direction = 1 : whalex_map = whalex_map + 16 : gosub whale_pos_calc
	SRCFILE "whalehunt_1a.bas",685
	;[686] 'if whalex > 245 then whalex = 38 : direction = direction - 1 : if direction < 1 then direction = 8 : whalex_map = whalex_map - 16 : gosub whale_pos_calc
	SRCFILE "whalehunt_1a.bas",686
	;[687] 
	SRCFILE "whalehunt_1a.bas",687
	;[688] if map = 0 then goto enemy_images
	SRCFILE "whalehunt_1a.bas",688
	MVI V11,R0
	TSTR R0
	BEQ Q108
	;[689] goto whale_move_map
	SRCFILE "whalehunt_1a.bas",689
	B Q107
	;[690] 
	SRCFILE "whalehunt_1a.bas",690
	;[691] enemy_images:
	SRCFILE "whalehunt_1a.bas",691
	; ENEMY_IMAGES
Q108:	;[692] if whalex_map > player_x - 10 then if whaley_map < player_y + 10 then if whalex_map < player_x + 10 then if whaley_map > player_y - 10 then gosub draw_enemy_big : goto whale_move_map
	SRCFILE "whalehunt_1a.bas",692
	MVI V20,R0
	MVI V18,R1
	SUBI #10,R1
	CMPR R1,R0
	BLE T260
	MVI V21,R0
	MVI V19,R1
	ADDI #10,R1
	CMPR R1,R0
	BGE T261
	MVI V20,R0
	MVI V18,R1
	ADDI #10,R1
	CMPR R1,R0
	BGE T262
	MVI V21,R0
	MVI V19,R1
	SUBI #10,R1
	CMPR R1,R0
	BLE T263
	CALL Q110
	B Q107
T263:
T262:
T261:
T260:
	;[693] if whalex_map > player_x - 20 then if whaley_map < player_y + 20 then if whalex_map < player_x + 20 then if whaley_map > player_y - 20 then goto draw_enemy_med
	SRCFILE "whalehunt_1a.bas",693
	MVI V20,R0
	MVI V18,R1
	SUBI #20,R1
	CMPR R1,R0
	BLE T264
	MVI V21,R0
	MVI V19,R1
	ADDI #20,R1
	CMPR R1,R0
	BGE T265
	MVI V20,R0
	MVI V18,R1
	ADDI #20,R1
	CMPR R1,R0
	BGE T266
	MVI V21,R0
	MVI V19,R1
	SUBI #20,R1
	CMPR R1,R0
	BGT Q111
T266:
T265:
T264:
	;[694] if whalex_map > player_x - 30 then if whaley_map < player_y + 30 then if whalex_map < player_x + 30 then if whaley_map > player_y - 30 then goto draw_enemy_small
	SRCFILE "whalehunt_1a.bas",694
	MVI V20,R0
	MVI V18,R1
	SUBI #30,R1
	CMPR R1,R0
	BLE T268
	MVI V21,R0
	MVI V19,R1
	ADDI #30,R1
	CMPR R1,R0
	BGE T269
	MVI V20,R0
	MVI V18,R1
	ADDI #30,R1
	CMPR R1,R0
	BGE T270
	MVI V21,R0
	MVI V19,R1
	SUBI #30,R1
	CMPR R1,R0
	BGT Q112
T270:
T269:
T268:
	;[695] goto whale_move_map
	SRCFILE "whalehunt_1a.bas",695
	B Q107
	;[696] 
	SRCFILE "whalehunt_1a.bas",696
	;[697] draw_enemy_small:
	SRCFILE "whalehunt_1a.bas",697
	; DRAW_ENEMY_SMALL
Q112:	;[698] 	if enemy = 0 then goto draw_whale_small
	SRCFILE "whalehunt_1a.bas",698
	MVI V41,R0
	TSTR R0
	BEQ Q114
	;[699] 	if enemy = 1 then goto draw_serpant_small
	SRCFILE "whalehunt_1a.bas",699
	MVI V41,R0
	CMPI #1,R0
	BEQ Q115
	;[700] 	if enemy = 2 then goto draw_squid_small
	SRCFILE "whalehunt_1a.bas",700
	MVI V41,R0
	CMPI #2,R0
	BEQ Q116
	;[701] 	if enemy = 3 then goto draw_crab_small
	SRCFILE "whalehunt_1a.bas",701
	MVI V41,R0
	CMPI #3,R0
	BEQ Q117
	;[702] 	
	SRCFILE "whalehunt_1a.bas",702
	;[703] 	
	SRCFILE "whalehunt_1a.bas",703
	;[704] draw_whale_small:
	SRCFILE "whalehunt_1a.bas",704
	; DRAW_WHALE_SMALL
Q114:	;[705] 	sprite 00,behind
	SRCFILE "whalehunt_1a.bas",705
	MVII #8192,R0
	MVO R0,_mobs
	;[706] 	define 60,2,small_whale
	SRCFILE "whalehunt_1a.bas",706
	MVII #60,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q119,R0
	MVO R0,_gram_bitmap
	;[707] 	wait
	SRCFILE "whalehunt_1a.bas",707
	CALL _wait
	;[708] 	sprite 05, whalex + visible, whaley + 3, spr60 + spr_white
	SRCFILE "whalehunt_1a.bas",708
	MVI V12,R0
	ADDI #512,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+13
	MVII #2535,R0
	MVO R0,_mobs+21
	;[709] 	sprite 06, whalex + 8 + visible, whaley + 3, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",709
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+14
	MVII #2543,R0
	MVO R0,_mobs+22
	;[710] 	sprite 07, behind
	SRCFILE "whalehunt_1a.bas",710
	MVII #8192,R0
	MVO R0,_mobs+7
	;[711] 	goto whale_move_map
	SRCFILE "whalehunt_1a.bas",711
	B Q107
	;[712] 	
	SRCFILE "whalehunt_1a.bas",712
	;[713] draw_serpant_small:	
	SRCFILE "whalehunt_1a.bas",713
	; DRAW_SERPANT_SMALL
Q115:	;[714] 	sprite 00,behind
	SRCFILE "whalehunt_1a.bas",714
	MVII #8192,R0
	MVO R0,_mobs
	;[715] 	sprite 06, behind
	SRCFILE "whalehunt_1a.bas",715
	MVO R0,_mobs+6
	;[716] 	sprite 07, behind
	SRCFILE "whalehunt_1a.bas",716
	NOP
	MVO R0,_mobs+7
	;[717] 	define 60,1,small_serpant
	SRCFILE "whalehunt_1a.bas",717
	MVII #60,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q121,R0
	MVO R0,_gram_bitmap
	;[718] 	wait
	SRCFILE "whalehunt_1a.bas",718
	CALL _wait
	;[719] 	sprite 05, whalex + visible + zoomx2, whaley + 3, spr60 + spr_green
	SRCFILE "whalehunt_1a.bas",719
	MVI V12,R0
	ADDI #1536,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+13
	MVII #2533,R0
	MVO R0,_mobs+21
	;[720] 	goto whale_move_map
	SRCFILE "whalehunt_1a.bas",720
	B Q107
	;[721] 	
	SRCFILE "whalehunt_1a.bas",721
	;[722] draw_squid_small:
	SRCFILE "whalehunt_1a.bas",722
	; DRAW_SQUID_SMALL
Q116:	;[723] 	sprite 00,behind
	SRCFILE "whalehunt_1a.bas",723
	MVII #8192,R0
	MVO R0,_mobs
	;[724] 	sprite 06, behind
	SRCFILE "whalehunt_1a.bas",724
	MVO R0,_mobs+6
	;[725] 	sprite 07, behind
	SRCFILE "whalehunt_1a.bas",725
	NOP
	MVO R0,_mobs+7
	;[726] 	define 60,1,squid_map
	SRCFILE "whalehunt_1a.bas",726
	MVII #60,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q123,R0
	MVO R0,_gram_bitmap
	;[727] 	wait
	SRCFILE "whalehunt_1a.bas",727
	CALL _wait
	;[728] 	sprite 05, whalex + visible, whaley + 3, spr60 + spr_purple
	SRCFILE "whalehunt_1a.bas",728
	MVI V12,R0
	ADDI #512,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+13
	MVII #6631,R0
	MVO R0,_mobs+21
	;[729] 	goto whale_move_map
	SRCFILE "whalehunt_1a.bas",729
	B Q107
	;[730] 	
	SRCFILE "whalehunt_1a.bas",730
	;[731] draw_crab_small:
	SRCFILE "whalehunt_1a.bas",731
	; DRAW_CRAB_SMALL
Q117:	;[732] 	sprite 00,behind
	SRCFILE "whalehunt_1a.bas",732
	MVII #8192,R0
	MVO R0,_mobs
	;[733] 	sprite 07, behind
	SRCFILE "whalehunt_1a.bas",733
	MVO R0,_mobs+7
	;[734] 	define 60,2,small_crab
	SRCFILE "whalehunt_1a.bas",734
	MVII #60,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q125,R0
	MVO R0,_gram_bitmap
	;[735] 	wait
	SRCFILE "whalehunt_1a.bas",735
	CALL _wait
	;[736] 	sprite 05, whalex + visible, whaley + 4, spr61 + spr_red
	SRCFILE "whalehunt_1a.bas",736
	MVI V12,R0
	ADDI #512,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #4,R0
	MVO R0,_mobs+13
	MVII #2538,R0
	MVO R0,_mobs+21
	;[737] 	sprite 06, whalex + visible, whaley + 3, spr60 + spr_white
	SRCFILE "whalehunt_1a.bas",737
	MVI V12,R0
	ADDI #512,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+14
	MVII #2535,R0
	MVO R0,_mobs+22
	;[738] 	goto whale_move_map
	SRCFILE "whalehunt_1a.bas",738
	B Q107
	;[739] 	
	SRCFILE "whalehunt_1a.bas",739
	;[740] draw_enemy_med:
	SRCFILE "whalehunt_1a.bas",740
	; DRAW_ENEMY_MED
Q111:	;[741] 	if enemy = 0 then goto draw_whale_med
	SRCFILE "whalehunt_1a.bas",741
	MVI V41,R0
	TSTR R0
	BEQ Q127
	;[742] 	if enemy = 1 then goto draw_serpant_med
	SRCFILE "whalehunt_1a.bas",742
	MVI V41,R0
	CMPI #1,R0
	BEQ Q128
	;[743] 	if enemy = 2 then goto draw_squid_med
	SRCFILE "whalehunt_1a.bas",743
	MVI V41,R0
	CMPI #2,R0
	BEQ Q129
	;[744] 	if enemy = 3 then goto draw_crab_med
	SRCFILE "whalehunt_1a.bas",744
	MVI V41,R0
	CMPI #3,R0
	BEQ Q130
	;[745] 	
	SRCFILE "whalehunt_1a.bas",745
	;[746] draw_whale_med:	
	SRCFILE "whalehunt_1a.bas",746
	; DRAW_WHALE_MED
Q127:	;[747] 	sprite 00,behind
	SRCFILE "whalehunt_1a.bas",747
	MVII #8192,R0
	MVO R0,_mobs
	;[748] 	sprite 04, behind
	SRCFILE "whalehunt_1a.bas",748
	MVO R0,_mobs+4
	;[749] 	define 60,2,med_whale
	SRCFILE "whalehunt_1a.bas",749
	MVII #60,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q132,R0
	MVO R0,_gram_bitmap
	;[750] 	wait
	SRCFILE "whalehunt_1a.bas",750
	CALL _wait
	;[751] 	sprite 05, whalex + visible, whaley + 3, spr60 + spr_white
	SRCFILE "whalehunt_1a.bas",751
	MVI V12,R0
	ADDI #512,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+13
	MVII #2535,R0
	MVO R0,_mobs+21
	;[752] 	sprite 06, whalex + 8 + visible, whaley + 3, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",752
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+14
	MVII #2543,R0
	MVO R0,_mobs+22
	;[753] 	sprite 07, whalex + 16 + visible, whaley + 3 + flipx, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",753
	MVI V12,R0
	ADDI #528,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #1027,R0
	MVO R0,_mobs+15
	MVII #2543,R0
	MVO R0,_mobs+23
	;[754] 	goto whale_move_map
	SRCFILE "whalehunt_1a.bas",754
	B Q107
	;[755] 
	SRCFILE "whalehunt_1a.bas",755
	;[756] draw_serpant_med:		
	SRCFILE "whalehunt_1a.bas",756
	; DRAW_SERPANT_MED
Q128:	;[757] 	sprite 00,behind
	SRCFILE "whalehunt_1a.bas",757
	MVII #8192,R0
	MVO R0,_mobs
	;[758] 	sprite 04, behind
	SRCFILE "whalehunt_1a.bas",758
	MVO R0,_mobs+4
	;[759] 	define 60,3,med_serpant
	SRCFILE "whalehunt_1a.bas",759
	MVII #60,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q134,R0
	MVO R0,_gram_bitmap
	;[760] 	wait
	SRCFILE "whalehunt_1a.bas",760
	CALL _wait
	;[761] 	sprite 06, whalex + visible, whaley - 1 + zoomy2, spr60 + spr_green
	SRCFILE "whalehunt_1a.bas",761
	MVI V12,R0
	ADDI #512,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+14
	MVII #2533,R0
	MVO R0,_mobs+22
	;[762] 	sprite 07, whalex + 8 + visible, whaley - 1 + zoomy2, spr61 + spr_green
	SRCFILE "whalehunt_1a.bas",762
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+15
	MVII #2541,R0
	MVO R0,_mobs+23
	;[763] 	sprite 05, whalex + 8 + visible, whaley + 1, spr62 + spr_white
	SRCFILE "whalehunt_1a.bas",763
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs+5
	MVI V13,R0
	INCR R0
	MVO R0,_mobs+13
	MVII #2551,R0
	MVO R0,_mobs+21
	;[764] 	goto whale_move_map
	SRCFILE "whalehunt_1a.bas",764
	B Q107
	;[765] 	
	SRCFILE "whalehunt_1a.bas",765
	;[766] draw_squid_med:		
	SRCFILE "whalehunt_1a.bas",766
	; DRAW_SQUID_MED
Q129:	;[767] 	sprite 00,behind
	SRCFILE "whalehunt_1a.bas",767
	MVII #8192,R0
	MVO R0,_mobs
	;[768] 	sprite 04, behind
	SRCFILE "whalehunt_1a.bas",768
	MVO R0,_mobs+4
	;[769] 	define 60,2,med_squid
	SRCFILE "whalehunt_1a.bas",769
	MVII #60,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q136,R0
	MVO R0,_gram_bitmap
	;[770] 	wait
	SRCFILE "whalehunt_1a.bas",770
	CALL _wait
	;[771] 	sprite 05, whalex + 8 + visible, whaley - 1 + zoomy2, spr60 + spr_purple
	SRCFILE "whalehunt_1a.bas",771
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+13
	MVII #6631,R0
	MVO R0,_mobs+21
	;[772] 	sprite 06, whalex + 1 + visible, whaley + 3, spr61 + spr_purple
	SRCFILE "whalehunt_1a.bas",772
	MVI V12,R0
	ADDI #513,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+14
	MVII #6639,R0
	MVO R0,_mobs+22
	;[773] 	sprite 07, whalex + 15 + visible, whaley + 3 + flipx, spr61 + spr_purple
	SRCFILE "whalehunt_1a.bas",773
	MVI V12,R0
	ADDI #527,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #1027,R0
	MVO R0,_mobs+15
	MVII #6639,R0
	MVO R0,_mobs+23
	;[774] 	goto whale_move_map
	SRCFILE "whalehunt_1a.bas",774
	B Q107
	;[775] 	
	SRCFILE "whalehunt_1a.bas",775
	;[776] draw_crab_med:		
	SRCFILE "whalehunt_1a.bas",776
	; DRAW_CRAB_MED
Q130:	;[777] 	sprite 00, behind
	SRCFILE "whalehunt_1a.bas",777
	MVII #8192,R0
	MVO R0,_mobs
	;[778] 	sprite 04, behind
	SRCFILE "whalehunt_1a.bas",778
	MVO R0,_mobs+4
	;[779] 	define 60,3,med_crab
	SRCFILE "whalehunt_1a.bas",779
	MVII #60,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q138,R0
	MVO R0,_gram_bitmap
	;[780] 	wait
	SRCFILE "whalehunt_1a.bas",780
	CALL _wait
	;[781] 	sprite 05, whalex + visible, whaley - 1 + zoomy2, spr60 + spr_white
	SRCFILE "whalehunt_1a.bas",781
	MVI V12,R0
	ADDI #512,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+13
	MVII #2535,R0
	MVO R0,_mobs+21
	;[782] 	sprite 07, whalex + 8 + visible, whaley + zoomy2, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",782
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #256,R0
	MVO R0,_mobs+15
	MVII #2543,R0
	MVO R0,_mobs+23
	;[783] 	sprite 06, whalex + 8 + visible, whaley + 1 + zoomy2, spr62 + spr_red
	SRCFILE "whalehunt_1a.bas",783
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #257,R0
	MVO R0,_mobs+14
	MVII #2546,R0
	MVO R0,_mobs+22
	;[784] 	'goto whale_move_map
	SRCFILE "whalehunt_1a.bas",784
	;[785] 	
	SRCFILE "whalehunt_1a.bas",785
	;[786] 	
	SRCFILE "whalehunt_1a.bas",786
	;[787] whale_move_map:
	SRCFILE "whalehunt_1a.bas",787
	; WHALE_MOVE_MAP
Q107:	;[788] 	wait
	SRCFILE "whalehunt_1a.bas",788
	CALL _wait
	;[789] 	whale_dir = (rand / 32) + 1
	SRCFILE "whalehunt_1a.bas",789
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	SLR R0,1
	INCR R0
	MVO R0,V71
	;[790] 	if whalex_map > player_x - 5 then if whaley_map < player_y + 5 then if whalex_map < player_x + 5 then if whaley_map > player_y - 5 then goto whale_move_end
	SRCFILE "whalehunt_1a.bas",790
	MVI V20,R0
	MVI V18,R1
	SUBI #5,R1
	CMPR R1,R0
	BLE T280
	MVI V21,R0
	MVI V19,R1
	ADDI #5,R1
	CMPR R1,R0
	BGE T281
	MVI V20,R0
	MVI V18,R1
	ADDI #5,R1
	CMPR R1,R0
	BGE T282
	MVI V21,R0
	MVI V19,R1
	SUBI #5,R1
	CMPR R1,R0
	BGT Q106
T282:
T281:
T280:
	;[791] 	if whale_dir = 1 then whaley_map = whaley_map - 1									'north
	SRCFILE "whalehunt_1a.bas",791
	MVI V71,R0
	CMPI #1,R0
	BNE T284
	MVI V21,R0
	DECR R0
	MVO R0,V21
T284:
	;[792] 	if whale_dir = 2 then whalex_map = whalex_map + 1 : whaley_map = whaley_map - 1		'northeast
	SRCFILE "whalehunt_1a.bas",792
	MVI V71,R0
	CMPI #2,R0
	BNE T285
	MVI V20,R0
	INCR R0
	MVO R0,V20
	MVI V21,R0
	DECR R0
	MVO R0,V21
T285:
	;[793] 	if whale_dir = 3 then whalex_map = whalex_map + 1									'east
	SRCFILE "whalehunt_1a.bas",793
	MVI V71,R0
	CMPI #3,R0
	BNE T286
	MVI V20,R0
	INCR R0
	MVO R0,V20
T286:
	;[794] 	if whale_dir = 4 then whalex_map = whalex_map + 1 : whaley_map = whaley_map + 1		'southeast
	SRCFILE "whalehunt_1a.bas",794
	MVI V71,R0
	CMPI #4,R0
	BNE T287
	MVI V20,R0
	INCR R0
	MVO R0,V20
	MVI V21,R0
	INCR R0
	MVO R0,V21
T287:
	;[795] 	if whale_dir = 5 then whaley_map = whaley_map + 1									'south
	SRCFILE "whalehunt_1a.bas",795
	MVI V71,R0
	CMPI #5,R0
	BNE T288
	MVI V21,R0
	INCR R0
	MVO R0,V21
T288:
	;[796] 	if whale_dir = 6 then whalex_map = whalex_map - 1 : whaley_map = whaley_map + 1		'southwest
	SRCFILE "whalehunt_1a.bas",796
	MVI V71,R0
	CMPI #6,R0
	BNE T289
	MVI V20,R0
	DECR R0
	MVO R0,V20
	MVI V21,R0
	INCR R0
	MVO R0,V21
T289:
	;[797] 	if whale_dir = 7 then whalex_map = whalex_map - 1									'west
	SRCFILE "whalehunt_1a.bas",797
	MVI V71,R0
	CMPI #7,R0
	BNE T290
	MVI V20,R0
	DECR R0
	MVO R0,V20
T290:
	;[798] 	if whale_dir = 8 then whalex_map = whalex_map - 1 : whaley_map = whaley_map - 1		'northwest
	SRCFILE "whalehunt_1a.bas",798
	MVI V71,R0
	CMPI #8,R0
	BNE T291
	MVI V20,R0
	DECR R0
	MVO R0,V20
	MVI V21,R0
	DECR R0
	MVO R0,V21
T291:
	;[799] 	gosub dim_check
	SRCFILE "whalehunt_1a.bas",799
	CALL Q92
	;[800] whale_move_end:
	SRCFILE "whalehunt_1a.bas",800
	; WHALE_MOVE_END
Q106:	;[801] 	wait
	SRCFILE "whalehunt_1a.bas",801
	CALL _wait
	;[802] 	end
	SRCFILE "whalehunt_1a.bas",802
	RETURN
	ENDP
	;[803] 	
	SRCFILE "whalehunt_1a.bas",803
	;[804] whale_pos_calc:		procedure
	SRCFILE "whalehunt_1a.bas",804
	; WHALE_POS_CALC
Q86:	PROC
	BEGIN
	;[805] REM =====1-north=====2-northeast=====3-east=====4-southeast=====5-south=====6-southwest=====7-west=====8-northwest=====
	SRCFILE "whalehunt_1a.bas",805
	;[806] 	whale_position  = 0
	SRCFILE "whalehunt_1a.bas",806
	CLRR R0
	MVO R0,V64
	;[807] 'north
	SRCFILE "whalehunt_1a.bas",807
	;[808] 	if whalex_map > player_x - 7 then if whalex_map < player_x + 6 then if whaley_map < player_y then whale_position = 1 : whale_up = 2 : whale_down = 8 
	SRCFILE "whalehunt_1a.bas",808
	MVI V20,R0
	MVI V18,R1
	SUBI #7,R1
	CMPR R1,R0
	BLE T292
	MVI V18,R1
	ADDI #6,R1
	CMPR R1,R0
	BGE T293
	MVI V21,R0
	CMP V19,R0
	BGE T294
	MVII #1,R0
	MVO R0,V64
	MVII #2,R0
	MVO R0,V65
	MVII #8,R0
	MVO R0,V66
T294:
T293:
T292:
	;[809] 'south	
	SRCFILE "whalehunt_1a.bas",809
	;[810] 	if whale_position = 0 then if whalex_map > player_x - 7 then if whalex_map < player_x + 6 then if whaley_map > player_y then whale_position = 5 : whale_up = 6 : whale_down = 4
	SRCFILE "whalehunt_1a.bas",810
	MVI V64,R0
	TSTR R0
	BNE T295
	MVI V20,R0
	MVI V18,R1
	SUBI #7,R1
	CMPR R1,R0
	BLE T296
	MVI V18,R1
	ADDI #6,R1
	CMPR R1,R0
	BGE T297
	MVI V21,R0
	CMP V19,R0
	BLE T298
	MVII #5,R0
	MVO R0,V64
	MVII #6,R0
	MVO R0,V65
	MVII #4,R0
	MVO R0,V66
T298:
T297:
T296:
T295:
	;[811] 'east	
	SRCFILE "whalehunt_1a.bas",811
	;[812] 	if whale_position = 0 then if whaley_map > player_y - 3 then if whaley_map < player_y + 3 then if whalex_map > player_x then whale_position = 3 : whale_up = 4 : whale_down = 2
	SRCFILE "whalehunt_1a.bas",812
	MVI V64,R0
	TSTR R0
	BNE T299
	MVI V21,R0
	MVI V19,R1
	SUBI #3,R1
	CMPR R1,R0
	BLE T300
	MVI V19,R1
	ADDI #3,R1
	CMPR R1,R0
	BGE T301
	MVI V20,R0
	CMP V18,R0
	BLE T302
	MVII #3,R0
	MVO R0,V64
	MVII #4,R0
	MVO R0,V65
	MVII #2,R0
	MVO R0,V66
T302:
T301:
T300:
T299:
	;[813] 'west
	SRCFILE "whalehunt_1a.bas",813
	;[814] 	if whale_position = 0 then if whaley_map > player_y - 3 then if whaley_map < player_y + 3 then if whalex_map < player_x then whale_position = 7 : whale_up = 8 : whale_down = 6 
	SRCFILE "whalehunt_1a.bas",814
	MVI V64,R0
	TSTR R0
	BNE T303
	MVI V21,R0
	MVI V19,R1
	SUBI #3,R1
	CMPR R1,R0
	BLE T304
	MVI V19,R1
	ADDI #3,R1
	CMPR R1,R0
	BGE T305
	MVI V20,R0
	CMP V18,R0
	BGE T306
	MVII #7,R0
	MVO R0,V64
	MVII #8,R0
	MVO R0,V65
	MVII #6,R0
	MVO R0,V66
T306:
T305:
T304:
T303:
	;[815] 'northwest
	SRCFILE "whalehunt_1a.bas",815
	;[816] 	if whale_position = 0 then if whalex_map <= player_x - 7 then if whaley_map <= player_y - 3 then whale_position = 8 : whale_up = 1 : whale_down = 7
	SRCFILE "whalehunt_1a.bas",816
	MVI V64,R0
	TSTR R0
	BNE T307
	MVI V20,R0
	MVI V18,R1
	SUBI #7,R1
	CMPR R1,R0
	BGT T308
	MVI V21,R0
	MVI V19,R1
	SUBI #3,R1
	CMPR R1,R0
	BGT T309
	MVII #8,R0
	MVO R0,V64
	MVII #1,R0
	MVO R0,V65
	MVII #7,R0
	MVO R0,V66
T309:
T308:
T307:
	;[817] 'northeast
	SRCFILE "whalehunt_1a.bas",817
	;[818] 	if whale_position = 0 then if whalex_map >= player_x + 6 then if whaley_map <= player_y - 3 then whale_position = 2 : whale_up = 3 : whale_down = 1
	SRCFILE "whalehunt_1a.bas",818
	MVI V64,R0
	TSTR R0
	BNE T310
	MVI V20,R0
	MVI V18,R1
	ADDI #6,R1
	CMPR R1,R0
	BLT T311
	MVI V21,R0
	MVI V19,R1
	SUBI #3,R1
	CMPR R1,R0
	BGT T312
	MVII #2,R0
	MVO R0,V64
	MVII #3,R0
	MVO R0,V65
	MVII #1,R0
	MVO R0,V66
T312:
T311:
T310:
	;[819] 'southwest
	SRCFILE "whalehunt_1a.bas",819
	;[820] 	if whale_position = 0 then if whalex_map <= player_x - 7 then if whaley_map >= player_y + 3 then whale_position = 6 : whale_up = 7 : whale_down = 5
	SRCFILE "whalehunt_1a.bas",820
	MVI V64,R0
	TSTR R0
	BNE T313
	MVI V20,R0
	MVI V18,R1
	SUBI #7,R1
	CMPR R1,R0
	BGT T314
	MVI V21,R0
	MVI V19,R1
	ADDI #3,R1
	CMPR R1,R0
	BLT T315
	MVII #6,R0
	MVO R0,V64
	MVII #7,R0
	MVO R0,V65
	MVII #5,R0
	MVO R0,V66
T315:
T314:
T313:
	;[821] 'southeast
	SRCFILE "whalehunt_1a.bas",821
	;[822] 	if whale_position = 0 then if whalex_map >= player_x + 6 then if whaley_map >= player_y + 3 then whale_position = 4 : whale_up = 5 : whale_down = 3
	SRCFILE "whalehunt_1a.bas",822
	MVI V64,R0
	TSTR R0
	BNE T316
	MVI V20,R0
	MVI V18,R1
	ADDI #6,R1
	CMPR R1,R0
	BLT T317
	MVI V21,R0
	MVI V19,R1
	ADDI #3,R1
	CMPR R1,R0
	BLT T318
	MVII #4,R0
	MVO R0,V64
	MVII #5,R0
	MVO R0,V65
	MVII #3,R0
	MVO R0,V66
T318:
T317:
T316:
	;[823] 
	SRCFILE "whalehunt_1a.bas",823
	;[824] 	if whale_position <> direction then if map = 0 then sprite 00, behind : sprite 04, behind : sprite 05, behind : sprite 06, behind : sprite 07, behind
	SRCFILE "whalehunt_1a.bas",824
	MVI V64,R0
	CMP V15,R0
	BEQ T319
	MVI V11,R0
	TSTR R0
	BNE T320
	MVII #8192,R0
	MVO R0,_mobs
	MVO R0,_mobs+4
	NOP
	MVO R0,_mobs+5
	MVO R0,_mobs+6
	NOP
	MVO R0,_mobs+7
T320:
T319:
	;[825] 
	SRCFILE "whalehunt_1a.bas",825
	;[826] 	end
	SRCFILE "whalehunt_1a.bas",826
	RETURN
	ENDP
	;[827] 	
	SRCFILE "whalehunt_1a.bas",827
	;[828] load_map:	
	SRCFILE "whalehunt_1a.bas",828
	; LOAD_MAP
Q31:	;[829] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",829
	CALL Q20
	;[830] 	cls
	SRCFILE "whalehunt_1a.bas",830
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[831] 	DEFINE 0,16,map_bitmaps_0
	SRCFILE "whalehunt_1a.bas",831
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q143,R0
	MVO R0,_gram_bitmap
	;[832] 	WAIT
	SRCFILE "whalehunt_1a.bas",832
	CALL _wait
	;[833] 	DEFINE 16,4,map_bitmaps_1
	SRCFILE "whalehunt_1a.bas",833
	MVII #16,R0
	MVO R0,_gram_target
	MVII #4,R0
	MVO R0,_gram_total
	MVII #Q144,R0
	MVO R0,_gram_bitmap
	;[834] 	define alternate 20,9,buildings
	SRCFILE "whalehunt_1a.bas",834
	MVII #20,R0
	MVO R0,_gram2_target
	MVII #9,R0
	MVO R0,_gram2_total
	MVII #Q145,R0
	MVO R0,_gram2_bitmap
	;[835] 	wait
	SRCFILE "whalehunt_1a.bas",835
	CALL _wait
	;[836] 	define 36,11,map_sprites
	SRCFILE "whalehunt_1a.bas",836
	MVII #36,R0
	MVO R0,_gram_target
	MVII #11,R0
	MVO R0,_gram_total
	MVII #Q146,R0
	MVO R0,_gram_bitmap
	;[837] 	wait
	SRCFILE "whalehunt_1a.bas",837
	CALL _wait
	;[838] 	SCREEN map_cards
	SRCFILE "whalehunt_1a.bas",838
	MVII #Q147,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[839] 	sprite 05, 24 + hit + visible, 80 + zoomy2, spr41 + spr_orange	'left dock
	SRCFILE "whalehunt_1a.bas",839
	MVII #792,R0
	MVO R0,_mobs+5
	MVII #336,R0
	MVO R0,_mobs+13
	MVII #6474,R0
	MVO R0,_mobs+21
	;[840] 	sprite 06, 77 + hit + visible, 80 + zoomy2, spr41 + spr_orange	'middle dock
	SRCFILE "whalehunt_1a.bas",840
	MVII #845,R0
	MVO R0,_mobs+6
	MVII #336,R0
	MVO R0,_mobs+14
	MVII #6474,R0
	MVO R0,_mobs+22
	;[841] 	sprite 07, 147 + hit + visible, 79 + zoomy2, spr41 + spr_orange	'right dock
	SRCFILE "whalehunt_1a.bas",841
	MVII #915,R0
	MVO R0,_mobs+7
	MVII #335,R0
	MVO R0,_mobs+15
	MVII #6474,R0
	MVO R0,_mobs+23
	;[842] '	print at 160 + crate_map color bg_blue, "\010"
	SRCFILE "whalehunt_1a.bas",842
	;[843] 	gosub cont1wait
	SRCFILE "whalehunt_1a.bas",843
	CALL Q13
	;[844] map_loop:	
	SRCFILE "whalehunt_1a.bas",844
	; MAP_LOOP
Q148:	;[845] 	map = 1
	SRCFILE "whalehunt_1a.bas",845
	MVII #1,R0
	MVO R0,V11
	;[846] 	gosub whale_movement
	SRCFILE "whalehunt_1a.bas",846
	CALL Q29
	;[847] 	gosub wind
	SRCFILE "whalehunt_1a.bas",847
	CALL Q39
	;[848] 	if #score < #new_score then #score = #score + 1
	SRCFILE "whalehunt_1a.bas",848
	MVI V4,R0
	CMP V5,R0
	BGE T321
	INCR R0
	MVO R0,V4
T321:
	;[849] 	if #score >= #next_score then #next_score = #next_score + 100 : if health < 4 then health = health + 1
	SRCFILE "whalehunt_1a.bas",849
	MVI V4,R0
	CMP V6,R0
	BLT T322
	MVI V6,R0
	ADDI #100,R0
	MVO R0,V6
	MVI V8,R0
	CMPI #4,R0
	BGE T323
	INCR R0
	MVO R0,V8
T323:
T322:
	;[850] 	gosub score
	SRCFILE "whalehunt_1a.bas",850
	CALL Q27
	;[851] 	if direction < 5 then #char_dir = flipx : x = 1 else #char_dir = 0 : x = 0
	SRCFILE "whalehunt_1a.bas",851
	MVI V15,R0
	CMPI #5,R0
	BGE T324
	MVII #1024,R0
	MVO R0,V2
	MVII #1,R0
	MVO R0,V60
	B T325
T324:
	CLRR R0
	MVO R0,V2
	MVO R0,V60
T325:
	;[852] 	sprite 00, player_x + x + visible, player_y + #char_dir, spr38 + cs_red	'player
	SRCFILE "whalehunt_1a.bas",852
	MVI V18,R0
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_mobs
	MVI V19,R0
	ADD V2,R0
	MVO R0,_mobs+8
	MVII #2354,R0
	MVO R0,_mobs+16
	;[853] 	sprite 01, player_x + x + visible, player_y + #char_dir, spr39 + cs_white
	SRCFILE "whalehunt_1a.bas",853
	MVI V18,R0
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_mobs+1
	MVI V19,R0
	ADD V2,R0
	MVO R0,_mobs+9
	MVII #2367,R0
	MVO R0,_mobs+17
	;[854] 	sprite 02, player_x + x + hit + visible, player_y + #char_dir, spr40 + cs_orange	'player
	SRCFILE "whalehunt_1a.bas",854
	MVI V18,R0
	ADD V60,R0
	ADDI #768,R0
	MVO R0,_mobs+2
	MVI V19,R0
	ADD V2,R0
	MVO R0,_mobs+10
	MVII #6466,R0
	MVO R0,_mobs+18
	;[855] 	if whale_dir > 5 then #enemy_dir = flipx else #enemy_dir = 0
	SRCFILE "whalehunt_1a.bas",855
	MVI V71,R0
	CMPI #5,R0
	BLE T326
	MVII #1024,R0
	MVO R0,V3
	B T327
T326:
	CLRR R0
	MVO R0,V3
T327:
	;[856] 	if enemy = 0 then sprite 03, whalex_map + visible, whaley_map + #enemy_dir, spr36 + cs_white	'whale	
	SRCFILE "whalehunt_1a.bas",856
	MVI V41,R0
	TSTR R0
	BNE T328
	MVI V20,R0
	ADDI #512,R0
	MVO R0,_mobs+3
	MVI V21,R0
	ADD V3,R0
	MVO R0,_mobs+11
	MVII #2343,R0
	MVO R0,_mobs+19
T328:
	;[857] 	if enemy = 0 then sprite 04, whalex_map + visible, whaley_map - 1 + #enemy_dir, spr37 + cs_cyan
	SRCFILE "whalehunt_1a.bas",857
	MVI V41,R0
	TSTR R0
	BNE T329
	MVI V20,R0
	ADDI #512,R0
	MVO R0,_mobs+4
	MVI V21,R0
	DECR R0
	ADD V3,R0
	MVO R0,_mobs+12
	MVII #6441,R0
	MVO R0,_mobs+20
T329:
	;[858] 	if enemy = 1 then sprite 03, whalex_map + visible, whaley_map + #enemy_dir, spr43 + cs_white	'serpant
	SRCFILE "whalehunt_1a.bas",858
	MVI V41,R0
	CMPI #1,R0
	BNE T330
	MVI V20,R0
	ADDI #512,R0
	MVO R0,_mobs+3
	MVI V21,R0
	ADD V3,R0
	MVO R0,_mobs+11
	MVII #2399,R0
	MVO R0,_mobs+19
T330:
	;[859] 	if enemy = 1 then sprite 04, whalex_map + visible, whaley_map + #enemy_dir, spr42 + cs_green
	SRCFILE "whalehunt_1a.bas",859
	MVI V41,R0
	CMPI #1,R0
	BNE T331
	MVI V20,R0
	ADDI #512,R0
	MVO R0,_mobs+4
	MVI V21,R0
	ADD V3,R0
	MVO R0,_mobs+12
	MVII #2389,R0
	MVO R0,_mobs+20
T331:
	;[860] 	if enemy = 2 then sprite 03, whalex_map + visible, whaley_map, spr44 + spr_purple	'squid
	SRCFILE "whalehunt_1a.bas",860
	MVI V41,R0
	CMPI #2,R0
	BNE T332
	MVI V20,R0
	ADDI #512,R0
	MVO R0,_mobs+3
	MVI V21,R0
	MVO R0,_mobs+11
	MVII #6503,R0
	MVO R0,_mobs+19
T332:
	;[861] 	if enemy = 3 then sprite 04, whalex_map + visible, whaley_map + #enemy_dir, spr45 + cs_white	    'crab	
	SRCFILE "whalehunt_1a.bas",861
	MVI V41,R0
	CMPI #3,R0
	BNE T333
	MVI V20,R0
	ADDI #512,R0
	MVO R0,_mobs+4
	MVI V21,R0
	ADD V3,R0
	MVO R0,_mobs+12
	MVII #2415,R0
	MVO R0,_mobs+20
T333:
	;[862] 	if enemy = 3 then sprite 03, whalex_map + visible, whaley_map + #enemy_dir, spr46 + cs_red	
	SRCFILE "whalehunt_1a.bas",862
	MVI V41,R0
	CMPI #3,R0
	BNE T334
	MVI V20,R0
	ADDI #512,R0
	MVO R0,_mobs+3
	MVI V21,R0
	ADD V3,R0
	MVO R0,_mobs+11
	MVII #2418,R0
	MVO R0,_mobs+19
T334:
	;[863] 	wait
	SRCFILE "whalehunt_1a.bas",863
	CALL _wait
	;[864] 	gosub draw_towns
	SRCFILE "whalehunt_1a.bas",864
	CALL Q149
	;[865] 	if col2 and hit_sprite5 then gosub town1_check : if town_check = 1 then player_x = 24 : player_y = 75 : town_check = 0 : goto load_new_level
	SRCFILE "whalehunt_1a.bas",865
	MVI _col2,R0
	ANDI #32,R0
	BEQ T335
	CALL Q150
	MVI V37,R0
	CMPI #1,R0
	BNE T336
	MVII #24,R0
	MVO R0,V18
	MVII #75,R0
	MVO R0,V19
	CLRR R0
	MVO R0,V37
	B Q25
T336:
T335:
	;[866] 	if col2 and hit_sprite6 then gosub town2_check : if town_check = 1 then player_x = 77 : player_y = 75 : town_check = 0 : goto load_new_level
	SRCFILE "whalehunt_1a.bas",866
	MVI _col2,R0
	ANDI #64,R0
	BEQ T337
	CALL Q151
	MVI V37,R0
	CMPI #1,R0
	BNE T338
	MVII #77,R0
	MVO R0,V18
	MVII #75,R0
	MVO R0,V19
	CLRR R0
	MVO R0,V37
	B Q25
T338:
T337:
	;[867] 	if col2 and hit_sprite7 then gosub town3_check : if town_check = 1 then player_x = 147 : player_y = 74 : town_check = 0 : goto load_new_level
	SRCFILE "whalehunt_1a.bas",867
	MVI _col2,R0
	ANDI #128,R0
	BEQ T339
	CALL Q152
	MVI V37,R0
	CMPI #1,R0
	BNE T340
	MVII #147,R0
	MVO R0,V18
	MVII #74,R0
	MVO R0,V19
	CLRR R0
	MVO R0,V37
	B Q25
T340:
T339:
	;[868] 	if cont1.key = 0 then goto exit_map
	SRCFILE "whalehunt_1a.bas",868
	MVI _cnt1_key,R0
	TSTR R0
	BEQ Q153
	;[869] 	if cont1.key = 10 then goto exit_map
	SRCFILE "whalehunt_1a.bas",869
	MVI _cnt1_key,R0
	CMPI #10,R0
	BEQ Q153
	;[870] 	if cont1.key = 11 then goto exit_map
	SRCFILE "whalehunt_1a.bas",870
	MVI _cnt1_key,R0
	CMPI #11,R0
	BEQ Q153
	;[871] 	if cont1.key = 9 then if storm_flag = 1 then goto lose_life else gosub sail 'turn right
	SRCFILE "whalehunt_1a.bas",871
	MVI _cnt1_key,R0
	CMPI #9,R0
	BNE T344
	MVI V57,R0
	CMPI #1,R0
	BNE T345
	B Q32
	B T346
T345:
	CALL Q33
T346:
T344:
	;[872] 	if cont1.key = 8 then if storm_flag = 1 then goto lose_life else gosub sail 'straight
	SRCFILE "whalehunt_1a.bas",872
	MVI _cnt1_key,R0
	CMPI #8,R0
	BNE T347
	MVI V57,R0
	CMPI #1,R0
	BNE T348
	B Q32
	B T349
T348:
	CALL Q33
T349:
T347:
	;[873] 	if cont1.key = 7 then if storm_flag = 1 then goto lose_life else gosub sail 'turn left
	SRCFILE "whalehunt_1a.bas",873
	MVI _cnt1_key,R0
	CMPI #7,R0
	BNE T350
	MVI V57,R0
	CMPI #1,R0
	BNE T351
	B Q32
	B T352
T351:
	CALL Q33
T352:
T350:
	;[874] 	if cont1.key = 6 then row_cnt = row_cnt + 1 : if row_cnt > row_total then gosub player_row : row_cnt = 0'row turn right
	SRCFILE "whalehunt_1a.bas",874
	MVI _cnt1_key,R0
	CMPI #6,R0
	BNE T353
	MVI V24,R0
	INCR R0
	MVO R0,V24
	MVI V24,R0
	CMP V22,R0
	BLE T354
	CALL Q34
	CLRR R0
	MVO R0,V24
T354:
T353:
	;[875] 	if cont1.key = 5 then row_cnt = row_cnt + 1 : if row_cnt > row_total then gosub player_row : row_cnt = 0'row straight
	SRCFILE "whalehunt_1a.bas",875
	MVI _cnt1_key,R0
	CMPI #5,R0
	BNE T355
	MVI V24,R0
	INCR R0
	MVO R0,V24
	MVI V24,R0
	CMP V22,R0
	BLE T356
	CALL Q34
	CLRR R0
	MVO R0,V24
T356:
T355:
	;[876] 	if cont1.key = 4 then row_cnt = row_cnt + 1 : if row_cnt > row_total then gosub player_row : row_cnt = 0'row turn left	
	SRCFILE "whalehunt_1a.bas",876
	MVI _cnt1_key,R0
	CMPI #4,R0
	BNE T357
	MVI V24,R0
	INCR R0
	MVO R0,V24
	MVI V24,R0
	CMP V22,R0
	BLE T358
	CALL Q34
	CLRR R0
	MVO R0,V24
T358:
T357:
	;[877] 	if cont1.key = 6 then dir_cnt = dir_cnt + 1 : if dir_cnt > 11 then direction = direction + 1 : dir_cnt = 1 : whale_cnt = 29
	SRCFILE "whalehunt_1a.bas",877
	MVI _cnt1_key,R0
	CMPI #6,R0
	BNE T359
	MVI V14,R0
	INCR R0
	MVO R0,V14
	MVI V14,R0
	CMPI #11,R0
	BLE T360
	MVI V15,R0
	INCR R0
	MVO R0,V15
	MVII #1,R0
	MVO R0,V14
	MVII #29,R0
	MVO R0,V56
T360:
T359:
	;[878] 	if cont1.key = 4 then dir_cnt = dir_cnt - 1 : if dir_cnt < 1 then direction = direction - 1 : dir_cnt = 11 : whale_cnt = 29
	SRCFILE "whalehunt_1a.bas",878
	MVI _cnt1_key,R0
	CMPI #4,R0
	BNE T361
	MVI V14,R0
	DECR R0
	MVO R0,V14
	MVI V14,R0
	CMPI #1,R0
	BGE T362
	MVI V15,R0
	DECR R0
	MVO R0,V15
	MVII #11,R0
	MVO R0,V14
	MVII #29,R0
	MVO R0,V56
T362:
T361:
	;[879] 	if cont1.b0 then goto sundial
	SRCFILE "whalehunt_1a.bas",879
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	CMPI #160,R0
	BEQ Q36
	;[880] 	if cont1.b1 then if wind_flute = 1 then wind_direction = direction : play simple : play flute_song
	SRCFILE "whalehunt_1a.bas",880
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	CMPI #96,R0
	BNE T364
	MVI V34,R0
	CMPI #1,R0
	BNE T365
	MVI V15,R0
	MVO R0,V55
	MVII #1,R3
	MVO R3,_music_mode
	MVII #Q37,R0
	CALL _play_music
T365:
T364:
	;[881] 	if cont1.b2 then if wind_flute = 1 then wind_direction = direction : play simple : play flute_song
	SRCFILE "whalehunt_1a.bas",881
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	CMPI #192,R0
	BNE T366
	MVI V34,R0
	CMPI #1,R0
	BNE T367
	MVI V15,R0
	MVO R0,V55
	MVII #1,R3
	MVO R3,_music_mode
	MVII #Q37,R0
	CALL _play_music
T367:
T366:
	;[882] 	gosub timer
	SRCFILE "whalehunt_1a.bas",882
	CALL Q38
	;[883] 	if timeout_flag = 1 then goto lose_life
	SRCFILE "whalehunt_1a.bas",883
	MVI V10,R0
	CMPI #1,R0
	BEQ Q32
	;[884] 	if storm_cnt = storm_cnt_total then 
	SRCFILE "whalehunt_1a.bas",884
	MVI V50,R0
	CMP V51,R0
	BNE T369
	;[885] 		x = rand / 10
	SRCFILE "whalehunt_1a.bas",885
	MVI _rand,R0
	MVII #-1,R4
T370:
	INCR R4
	SUBI #10,R0
	BC T370
	MOVR R4,R0
	MVO R0,V60
	;[886] 		if storm_flag = 1 then if x = 3 then goto lose_life
	SRCFILE "whalehunt_1a.bas",886
	MVI V57,R0
	CMPI #1,R0
	BNE T371
	MVI V60,R0
	CMPI #3,R0
	BEQ Q32
T371:
	;[887] 	end if
	SRCFILE "whalehunt_1a.bas",887
T369:
	;[888] 	goto map_loop
	SRCFILE "whalehunt_1a.bas",888
	B Q148
	;[889] exit_map:
	SRCFILE "whalehunt_1a.bas",889
	; EXIT_MAP
Q153:	;[890] 	goto load_images
	SRCFILE "whalehunt_1a.bas",890
	B Q19
	;[891] 	
	SRCFILE "whalehunt_1a.bas",891
	;[892] 	
	SRCFILE "whalehunt_1a.bas",892
	;[893] draw_towns:		procedure
	SRCFILE "whalehunt_1a.bas",893
	; DRAW_TOWNS
Q149:	PROC
	BEGIN
	;[894] 	if town1_cnt >= 1 then print at screenpos(2,10) color cs_green, "\277"
	SRCFILE "whalehunt_1a.bas",894
	MVI V38,R0
	CMPI #1,R0
	BLT T373
	MVII #714,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2216,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T373:
	;[895] 	if town1_cnt = 2 then print at screenpos(1,10) color cs_green, "\276"
	SRCFILE "whalehunt_1a.bas",895
	MVI V38,R0
	CMPI #2,R0
	BNE T374
	MVII #713,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2208,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T374:
	;[896] 
	SRCFILE "whalehunt_1a.bas",896
	;[897] 	if town2_cnt >= 1 then print at screenpos(9,10) color cs_green, "\280"	
	SRCFILE "whalehunt_1a.bas",897
	MVI V39,R0
	CMPI #1,R0
	BLT T375
	MVII #721,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2240,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T375:
	;[898] 	if town2_cnt >= 2 then print at screenpos(8,10) color cs_green, "\279"
	SRCFILE "whalehunt_1a.bas",898
	MVI V39,R0
	CMPI #2,R0
	BLT T376
	MVII #720,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2232,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T376:
	;[899] 	if town2_cnt >= 3 then print at screenpos(7,10) color cs_green, "\278"
	SRCFILE "whalehunt_1a.bas",899
	MVI V39,R0
	CMPI #3,R0
	BLT T377
	MVII #719,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2224,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T377:
	;[900] 	if town2_cnt >= 4 then print at screenpos(10,10) color cs_green, "\281"
	SRCFILE "whalehunt_1a.bas",900
	MVI V39,R0
	CMPI #4,R0
	BLT T378
	MVII #722,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2248,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T378:
	;[901] 
	SRCFILE "whalehunt_1a.bas",901
	;[902] 	if town3_cnt >= 2 then print at screenpos(17,10) color cs_green, "\283"
	SRCFILE "whalehunt_1a.bas",902
	MVI V40,R0
	CMPI #2,R0
	BLT T379
	MVII #729,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2264,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T379:
	;[903] 	if town3_cnt >= 1 then print at screenpos(16,10) color cs_green, "\282"
	SRCFILE "whalehunt_1a.bas",903
	MVI V40,R0
	CMPI #1,R0
	BLT T380
	MVII #728,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2256,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T380:
	;[904] 	if town3_cnt = 3 then print at screenpos(18,10) color cs_green, "\284"
	SRCFILE "whalehunt_1a.bas",904
	MVI V40,R0
	CMPI #3,R0
	BNE T381
	MVII #730,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #2272,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T381:
	;[905] 	end
	SRCFILE "whalehunt_1a.bas",905
	RETURN
	ENDP
	;[906] 
	SRCFILE "whalehunt_1a.bas",906
	;[907] town1_check:	procedure
	SRCFILE "whalehunt_1a.bas",907
	; TOWN1_CHECK
Q150:	PROC
	BEGIN
	;[908] 	if kill_cnt < kill_qty then goto town1_end
	SRCFILE "whalehunt_1a.bas",908
	MVI V27,R0
	CMP V26,R0
	BLT Q157
	;[909] 	kill_cnt = 0
	SRCFILE "whalehunt_1a.bas",909
	CLRR R0
	MVO R0,V27
	;[910] 	gosub beat_level
	SRCFILE "whalehunt_1a.bas",910
	CALL Q158
	;[911] 	town_check = 1
	SRCFILE "whalehunt_1a.bas",911
	MVII #1,R0
	MVO R0,V37
	;[912] 	if town1_cnt = 2 then goto town1_end
	SRCFILE "whalehunt_1a.bas",912
	MVI V38,R0
	CMPI #2,R0
	BEQ Q157
	;[913] 	town1_cnt = town1_cnt + 1
	SRCFILE "whalehunt_1a.bas",913
	MVI V38,R0
	INCR R0
	MVO R0,V38
	;[914] 	if town1_cnt = 2 then row_total = 2 : row_speed = 2 : cls : gosub pad_upgrade
	SRCFILE "whalehunt_1a.bas",914
	MVI V38,R0
	CMPI #2,R0
	BNE T384
	MVII #2,R0
	MVO R0,V22
	MVO R0,V23
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	CALL Q159
T384:
	;[915] town1_end:
	SRCFILE "whalehunt_1a.bas",915
	; TOWN1_END
Q157:	;[916] 	if town_check = 1 then gosub win_check
	SRCFILE "whalehunt_1a.bas",916
	MVI V37,R0
	CMPI #1,R0
	BNE T385
	CALL Q161
T385:
	;[917] 	end
	SRCFILE "whalehunt_1a.bas",917
	RETURN
	ENDP
	;[918] 	
	SRCFILE "whalehunt_1a.bas",918
	;[919] town2_check:	procedure
	SRCFILE "whalehunt_1a.bas",919
	; TOWN2_CHECK
Q151:	PROC
	BEGIN
	;[920] 	if kill_cnt < kill_qty then goto town2_end
	SRCFILE "whalehunt_1a.bas",920
	MVI V27,R0
	CMP V26,R0
	BLT Q163
	;[921] 	kill_cnt = 0
	SRCFILE "whalehunt_1a.bas",921
	CLRR R0
	MVO R0,V27
	;[922] 	gosub beat_level
	SRCFILE "whalehunt_1a.bas",922
	CALL Q158
	;[923] 	town_check = 1
	SRCFILE "whalehunt_1a.bas",923
	MVII #1,R0
	MVO R0,V37
	;[924] 	if town2_cnt = 4 then goto town2_end
	SRCFILE "whalehunt_1a.bas",924
	MVI V39,R0
	CMPI #4,R0
	BEQ Q163
	;[925] 	town2_cnt = town2_cnt + 1
	SRCFILE "whalehunt_1a.bas",925
	MVI V39,R0
	INCR R0
	MVO R0,V39
	;[926] 	if town2_cnt = 2 then harpoon = 2 : cls : gosub harpoon_upgrade
	SRCFILE "whalehunt_1a.bas",926
	MVI V39,R0
	CMPI #2,R0
	BNE T388
	MVII #2,R0
	MVO R0,V33
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	CALL Q164
T388:
	;[927] 	if town2_cnt = 4 then harpoon = 3 : cls : gosub harpoon_upgrade
	SRCFILE "whalehunt_1a.bas",927
	MVI V39,R0
	CMPI #4,R0
	BNE T389
	MVII #3,R0
	MVO R0,V33
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	CALL Q164
T389:
	;[928] town2_end:
	SRCFILE "whalehunt_1a.bas",928
	; TOWN2_END
Q163:	;[929] 	if town_check = 1 then gosub win_check
	SRCFILE "whalehunt_1a.bas",929
	MVI V37,R0
	CMPI #1,R0
	BNE T390
	CALL Q161
T390:
	;[930] 	end
	SRCFILE "whalehunt_1a.bas",930
	RETURN
	ENDP
	;[931] 	
	SRCFILE "whalehunt_1a.bas",931
	;[932] town3_check:	procedure
	SRCFILE "whalehunt_1a.bas",932
	; TOWN3_CHECK
Q152:	PROC
	BEGIN
	;[933] 	if kill_cnt < kill_qty then goto town3_end
	SRCFILE "whalehunt_1a.bas",933
	MVI V27,R0
	CMP V26,R0
	BLT Q167
	;[934] 	kill_cnt = 0
	SRCFILE "whalehunt_1a.bas",934
	CLRR R0
	MVO R0,V27
	;[935] 	gosub beat_level
	SRCFILE "whalehunt_1a.bas",935
	CALL Q158
	;[936] 	if town3_cnt < 3 then town3_cnt = town3_cnt + 1
	SRCFILE "whalehunt_1a.bas",936
	MVI V40,R0
	CMPI #3,R0
	BGE T392
	INCR R0
	MVO R0,V40
T392:
	;[937] 	if wind_flute = 0 then 
	SRCFILE "whalehunt_1a.bas",937
	MVI V34,R0
	TSTR R0
	BNE T393
	;[938] 		if 7 <= town1_cnt + town2_cnt + town3_cnt then 
	SRCFILE "whalehunt_1a.bas",938
	MVII #7,R0
	MVI V38,R1
	ADD V39,R1
	ADD V40,R1
	CMPR R1,R0
	BGT T394
	;[939] 			wind_flute = 1 
	SRCFILE "whalehunt_1a.bas",939
	MVII #1,R0
	MVO R0,V34
	;[940] 			gosub flute_upgrade
	SRCFILE "whalehunt_1a.bas",940
	CALL Q168
	;[941] 		else
	SRCFILE "whalehunt_1a.bas",941
	B T395
T394:
	;[942] 			gosub come_back
	SRCFILE "whalehunt_1a.bas",942
	CALL Q169
	;[943] 			gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",943
	CALL Q170
	;[944] 		end if
	SRCFILE "whalehunt_1a.bas",944
T395:
	;[945] 	end if
	SRCFILE "whalehunt_1a.bas",945
T393:
	;[946] 	'gosub cont1wait
	SRCFILE "whalehunt_1a.bas",946
	;[947] 	town_check = 1
	SRCFILE "whalehunt_1a.bas",947
	MVII #1,R0
	MVO R0,V37
	;[948] town3_end:
	SRCFILE "whalehunt_1a.bas",948
	; TOWN3_END
Q167:	;[949] 	if town_check = 1 then gosub win_check
	SRCFILE "whalehunt_1a.bas",949
	MVI V37,R0
	CMPI #1,R0
	BNE T396
	CALL Q161
T396:
	;[950] 	end
	SRCFILE "whalehunt_1a.bas",950
	RETURN
	ENDP
	;[951] 
	SRCFILE "whalehunt_1a.bas",951
	;[952] come_back:		procedure
	SRCFILE "whalehunt_1a.bas",952
	; COME_BACK
Q169:	PROC
	BEGIN
	;[953] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",953
	CALL Q20
	;[954] 	cls
	SRCFILE "whalehunt_1a.bas",954
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[955] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",955
	CALL Q173
	;[956] 	print at 81 color bg_cyan, "RETURN WHEN SEVEN"
	SRCFILE "whalehunt_1a.bas",956
	MVII #593,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #400,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[957] 	print at 102, "TOWNS ARE BUILT"
	SRCFILE "whalehunt_1a.bas",957
	MVII #614,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #416,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #272,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[958] 	end
	SRCFILE "whalehunt_1a.bas",958
	RETURN
	ENDP
	;[959] 
	SRCFILE "whalehunt_1a.bas",959
	;[960] win_check:	procedure
	SRCFILE "whalehunt_1a.bas",960
	; WIN_CHECK
Q161:	PROC
	BEGIN
	;[961] 	if level = 10 then level = level + 1 : goto win_check_end
	SRCFILE "whalehunt_1a.bas",961
	MVI V9,R0
	CMPI #10,R0
	BNE T397
	INCR R0
	MVO R0,V9
	B Q175
T397:
	;[962] '	for cnt = 1 to 30
	SRCFILE "whalehunt_1a.bas",962
	;[963] '		wait
	SRCFILE "whalehunt_1a.bas",963
	;[964] '	next cnt
	SRCFILE "whalehunt_1a.bas",964
	;[965] '	win_check_end:
	SRCFILE "whalehunt_1a.bas",965
	;[966] 	'gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",966
	;[967] 	gosub new_level_stats
	SRCFILE "whalehunt_1a.bas",967
	CALL Q176
	;[968] 	gosub kill_quantity
	SRCFILE "whalehunt_1a.bas",968
	CALL Q18
	;[969] 	gosub transition_out
	SRCFILE "whalehunt_1a.bas",969
	CALL Q177
	;[970] win_check_end:
	SRCFILE "whalehunt_1a.bas",970
	; WIN_CHECK_END
Q175:	;[971]  	end
	SRCFILE "whalehunt_1a.bas",971
	RETURN
	ENDP
	;[972] 	
	SRCFILE "whalehunt_1a.bas",972
	;[973] hide_sprites:	procedure
	SRCFILE "whalehunt_1a.bas",973
	; HIDE_SPRITES
Q20:	PROC
	BEGIN
	;[974] 	sprite 00, behind
	SRCFILE "whalehunt_1a.bas",974
	MVII #8192,R0
	MVO R0,_mobs
	;[975] 	sprite 01, behind
	SRCFILE "whalehunt_1a.bas",975
	MVO R0,_mobs+1
	;[976] 	sprite 02, behind
	SRCFILE "whalehunt_1a.bas",976
	NOP
	MVO R0,_mobs+2
	;[977] 	sprite 03, behind
	SRCFILE "whalehunt_1a.bas",977
	MVO R0,_mobs+3
	;[978] 	sprite 04, behind
	SRCFILE "whalehunt_1a.bas",978
	NOP
	MVO R0,_mobs+4
	;[979] 	sprite 05, behind
	SRCFILE "whalehunt_1a.bas",979
	MVO R0,_mobs+5
	;[980] 	sprite 06, behind
	SRCFILE "whalehunt_1a.bas",980
	NOP
	MVO R0,_mobs+6
	;[981] 	sprite 07, behind
	SRCFILE "whalehunt_1a.bas",981
	MVO R0,_mobs+7
	;[982] 	wait
	SRCFILE "whalehunt_1a.bas",982
	CALL _wait
	;[983] 	end
	SRCFILE "whalehunt_1a.bas",983
	RETURN
	ENDP
	;[984] 
	SRCFILE "whalehunt_1a.bas",984
	;[985] 
	SRCFILE "whalehunt_1a.bas",985
	;[986] REM =============================SUNDIAL CODE========================================
	SRCFILE "whalehunt_1a.bas",986
	;[987] 
	SRCFILE "whalehunt_1a.bas",987
	;[988] asm org $4820
	SRCFILE "whalehunt_1a.bas",988
 org $4820
	;[989] 	
	SRCFILE "whalehunt_1a.bas",989
	;[990] kill_quantity:		procedure
	SRCFILE "whalehunt_1a.bas",990
	; KILL_QUANTITY
Q18:	PROC
	BEGIN
	;[991] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",991
	CALL Q20
	;[992] 	cls
	SRCFILE "whalehunt_1a.bas",992
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[993] 	gosub score	
	SRCFILE "whalehunt_1a.bas",993
	CALL Q27
	;[994] 	define 57,3,blood_1
	SRCFILE "whalehunt_1a.bas",994
	MVII #57,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q57,R0
	MVO R0,_gram_bitmap
	;[995] 	wait
	SRCFILE "whalehunt_1a.bas",995
	CALL _wait
	;[996] 	define 60,2,big_whale 
	SRCFILE "whalehunt_1a.bas",996
	MVII #60,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q181,R0
	MVO R0,_gram_bitmap
	;[997] 	define alternate 62,1,whale_face_dead 
	SRCFILE "whalehunt_1a.bas",997
	MVII #62,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q182,R0
	MVO R0,_gram2_bitmap
	;[998] 	wait
	SRCFILE "whalehunt_1a.bas",998
	CALL _wait
	;[999] 	sprite 05, 47 + visible, 55 + zoomy2, spr60 + spr_white
	SRCFILE "whalehunt_1a.bas",999
	MVII #559,R0
	MVO R0,_mobs+5
	MVII #311,R0
	MVO R0,_mobs+13
	MVII #2535,R0
	MVO R0,_mobs+21
	;[1000] 	sprite 06, 55 + visible + zoomx2, 55 + zoomy2, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",1000
	MVII #1591,R0
	MVO R0,_mobs+6
	MVII #311,R0
	MVO R0,_mobs+14
	MVII #2543,R0
	MVO R0,_mobs+22
	;[1001] 	sprite 07, 71 + visible, 55 + zoomy2 + flipx, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",1001
	MVII #583,R0
	MVO R0,_mobs+7
	MVII #1335,R0
	MVO R0,_mobs+15
	MVII #2543,R0
	MVO R0,_mobs+23
	;[1002] 	sprite 04, 72 + visible, 58, spr62 + spr_black
	SRCFILE "whalehunt_1a.bas",1002
	MVII #584,R0
	MVO R0,_mobs+4
	MVII #58,R0
	MVO R0,_mobs+12
	MVII #2544,R0
	MVO R0,_mobs+20
	;[1003] 	sprite 00, 65 + visible, 53, spr58 + spr_red
	SRCFILE "whalehunt_1a.bas",1003
	MVII #577,R0
	MVO R0,_mobs
	MVII #53,R0
	MVO R0,_mobs+8
	MVII #2514,R0
	MVO R0,_mobs+16
	;[1004] 	sprite 03, 73, 46, spr54 + spr_orange
	SRCFILE "whalehunt_1a.bas",1004
	MVII #73,R0
	MVO R0,_mobs+3
	MVII #46,R0
	MVO R0,_mobs+11
	MVII #6578,R0
	MVO R0,_mobs+19
	;[1005] 	print at 66 color fg_yellow, "LEVEL ", <2>level
	SRCFILE "whalehunt_1a.bas",1005
	MVII #578,R0
	MVO R0,_screen
	MVII #6,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #352,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #352,R0
	MVO@ R0,R4
	MVO R4,_screen
	MVI V9,R0
	MVII #2,R2
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.z
	MVO R4,_screen
	;[1006] 	print at 130 color fg_green, "X"
	SRCFILE "whalehunt_1a.bas",1006
	MVII #642,R0
	MVO R0,_screen
	MVII #5,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #448,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1007] 	print at 132, <2>kill_qty
	SRCFILE "whalehunt_1a.bas",1007
	MVII #644,R0
	MVO R0,_screen
	MVI V26,R0
	MVII #2,R2
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.z
	MVO R4,_screen
	;[1008] 	gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",1008
	CALL Q170
	;[1009] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1009
	CALL Q20
	;[1010] 	end
	SRCFILE "whalehunt_1a.bas",1010
	RETURN
	ENDP
	;[1011] 
	SRCFILE "whalehunt_1a.bas",1011
	;[1012] sundial:
	SRCFILE "whalehunt_1a.bas",1012
	; SUNDIAL
Q36:	;[1013] 	'z = map
	SRCFILE "whalehunt_1a.bas",1013
	;[1014] 	'map = 1
	SRCFILE "whalehunt_1a.bas",1014
	;[1015] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1015
	CALL Q20
	;[1016] 	cls
	SRCFILE "whalehunt_1a.bas",1016
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1017] 	wait
	SRCFILE "whalehunt_1a.bas",1017
	CALL _wait
	;[1018] 	DEFINE 0,16,sundial_bitmaps_0
	SRCFILE "whalehunt_1a.bas",1018
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q184,R0
	MVO R0,_gram_bitmap
	;[1019] 	WAIT
	SRCFILE "whalehunt_1a.bas",1019
	CALL _wait
	;[1020] 	DEFINE 16,16,sundial_bitmaps_1
	SRCFILE "whalehunt_1a.bas",1020
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q185,R0
	MVO R0,_gram_bitmap
	;[1021] 	WAIT
	SRCFILE "whalehunt_1a.bas",1021
	CALL _wait
	;[1022] 	DEFINE 32,16,sundial_bitmaps_2
	SRCFILE "whalehunt_1a.bas",1022
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q186,R0
	MVO R0,_gram_bitmap
	;[1023] 	WAIT
	SRCFILE "whalehunt_1a.bas",1023
	CALL _wait
	;[1024] 	DEFINE 48,4,sundial_bitmaps_3
	SRCFILE "whalehunt_1a.bas",1024
	MVII #48,R0
	MVO R0,_gram_target
	MVII #4,R0
	MVO R0,_gram_total
	MVII #Q187,R0
	MVO R0,_gram_bitmap
	;[1025] 	define alternate 57,1,sundial_sprites
	SRCFILE "whalehunt_1a.bas",1025
	MVII #57,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q188,R0
	MVO R0,_gram2_bitmap
	;[1026] 	WAIT
	SRCFILE "whalehunt_1a.bas",1026
	CALL _wait
	;[1027] 	define 58,1,shadow_1
	SRCFILE "whalehunt_1a.bas",1027
	MVII #58,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q189,R0
	MVO R0,_gram_bitmap
	;[1028] 	define alternate 59,1,shadow_2
	SRCFILE "whalehunt_1a.bas",1028
	MVII #59,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q190,R0
	MVO R0,_gram2_bitmap
	;[1029] 	wait
	SRCFILE "whalehunt_1a.bas",1029
	CALL _wait
	;[1030] 	define 60,1,shadow_3
	SRCFILE "whalehunt_1a.bas",1030
	MVII #60,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q191,R0
	MVO R0,_gram_bitmap
	;[1031] 	define alternate 61,1,shadow_4	
	SRCFILE "whalehunt_1a.bas",1031
	MVII #61,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q192,R0
	MVO R0,_gram2_bitmap
	;[1032] 	gosub cont1wait
	SRCFILE "whalehunt_1a.bas",1032
	CALL Q13
	;[1033] 	if daytime = 0 then screen sundial_dawn_cards
	SRCFILE "whalehunt_1a.bas",1033
	MVI V47,R0
	TSTR R0
	BNE T398
	MVII #Q193,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T398:
	;[1034] 	if daytime = 1 then screen sundial_cards
	SRCFILE "whalehunt_1a.bas",1034
	MVI V47,R0
	CMPI #1,R0
	BNE T399
	MVII #Q194,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T399:
	;[1035] 	if daytime = 2 then screen sundial_dusk_cards
	SRCFILE "whalehunt_1a.bas",1035
	MVI V47,R0
	CMPI #2,R0
	BNE T400
	MVII #Q195,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T400:
	;[1036] 	if daytime = 3 then screen sundial_storm_cards
	SRCFILE "whalehunt_1a.bas",1036
	MVI V47,R0
	CMPI #3,R0
	BNE T401
	MVII #Q196,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
T401:
	;[1037] 	
	SRCFILE "whalehunt_1a.bas",1037
	;[1038] sundial_loop:
	SRCFILE "whalehunt_1a.bas",1038
	; SUNDIAL_LOOP
Q197:	;[1039] 	if daytime = 3 then sun_x = 1 : goto sundial_skip
	SRCFILE "whalehunt_1a.bas",1039
	MVI V47,R0
	CMPI #3,R0
	BNE T402
	MVII #1,R0
	MVO R0,V49
	B Q198
T402:
	;[1040] 	if daytime_cnt = 0 then	sun_x = 20 : sprite 04, 91 + visible + zoomx2, 53 + zoomy2 + flipx + flipy, spr61 + spr_red			'5am
	SRCFILE "whalehunt_1a.bas",1040
	MVI V48,R0
	TSTR R0
	BNE T403
	MVII #20,R0
	MVO R0,V49
	MVII #1627,R0
	MVO R0,_mobs+4
	MVII #3381,R0
	MVO R0,_mobs+12
	MVII #2538,R0
	MVO R0,_mobs+20
T403:
	;[1041] 	if daytime_cnt = 1 then	sun_x = 28 : sprite 04, 89 + visible + zoomx2, 58 + zoomy2 + flipx + flipy, spr61 + spr_red			'6am
	SRCFILE "whalehunt_1a.bas",1041
	MVI V48,R0
	CMPI #1,R0
	BNE T404
	MVII #28,R0
	MVO R0,V49
	MVII #1625,R0
	MVO R0,_mobs+4
	MVII #3386,R0
	MVO R0,_mobs+12
	MVII #2538,R0
	MVO R0,_mobs+20
T404:
	;[1042] 	if daytime_cnt = 2 then	sun_x = 36 : sprite 04, 88 + visible + zoomx2, 64 + zoomy2 + flipx, spr60 + spr_red	'7am
	SRCFILE "whalehunt_1a.bas",1042
	MVI V48,R0
	CMPI #2,R0
	BNE T405
	MVII #36,R0
	MVO R0,V49
	MVII #1624,R0
	MVO R0,_mobs+4
	MVII #1344,R0
	MVO R0,_mobs+12
	MVII #2530,R0
	MVO R0,_mobs+20
T405:
	;[1043] 	if daytime_cnt = 3 then	
	SRCFILE "whalehunt_1a.bas",1043
	MVI V48,R0
	CMPI #3,R0
	BNE T406
	;[1044] 		daytime = 1
	SRCFILE "whalehunt_1a.bas",1044
	MVII #1,R0
	MVO R0,V47
	;[1045] 		gosub sundial_sky
	SRCFILE "whalehunt_1a.bas",1045
	CALL Q199
	;[1046] 		sun_x = 44
	SRCFILE "whalehunt_1a.bas",1046
	MVII #44,R0
	MVO R0,V49
	;[1047] 		sprite 04, 86 + visible + zoomx2, 68 + zoomy2 + flipx, spr60 + spr_red	'8
	SRCFILE "whalehunt_1a.bas",1047
	MVII #1622,R0
	MVO R0,_mobs+4
	MVII #1348,R0
	MVO R0,_mobs+12
	MVII #2530,R0
	MVO R0,_mobs+20
	;[1048] 	end if
	SRCFILE "whalehunt_1a.bas",1048
T406:
	;[1049] 	if daytime_cnt = 4 then	sun_x = 52 : sprite 04, 90 + visible, 73 + zoomy2 + flipx, spr60 + spr_red	'9
	SRCFILE "whalehunt_1a.bas",1049
	MVI V48,R0
	CMPI #4,R0
	BNE T407
	MVII #52,R0
	MVO R0,V49
	MVII #602,R0
	MVO R0,_mobs+4
	MVII #1353,R0
	MVO R0,_mobs+12
	MVII #2530,R0
	MVO R0,_mobs+20
T407:
	;[1050] 	if daytime_cnt = 5 then	sun_x = 60 : sprite 04, 86 + visible, 78 + zoomy2 + flipx, spr59 + spr_red	'10
	SRCFILE "whalehunt_1a.bas",1050
	MVI V48,R0
	CMPI #5,R0
	BNE T408
	MVII #60,R0
	MVO R0,V49
	MVII #598,R0
	MVO R0,_mobs+4
	MVII #1358,R0
	MVO R0,_mobs+12
	MVII #2522,R0
	MVO R0,_mobs+20
T408:
	;[1051] 	if daytime_cnt = 6 then	sun_x = 68 : sprite 04, 85 + visible, 80 + zoomy2 + flipx, spr58 + spr_red	'11
	SRCFILE "whalehunt_1a.bas",1051
	MVI V48,R0
	CMPI #6,R0
	BNE T409
	MVII #68,R0
	MVO R0,V49
	MVII #597,R0
	MVO R0,_mobs+4
	MVII #1360,R0
	MVO R0,_mobs+12
	MVII #2514,R0
	MVO R0,_mobs+20
T409:
	;[1052] 	if daytime_cnt = 7 then	sun_x = 76 : sprite 04, 79 + visible, 82 + zoomy2 + flipx, spr58 + spr_red	'12
	SRCFILE "whalehunt_1a.bas",1052
	MVI V48,R0
	CMPI #7,R0
	BNE T410
	MVII #76,R0
	MVO R0,V49
	MVII #591,R0
	MVO R0,_mobs+4
	MVII #1362,R0
	MVO R0,_mobs+12
	MVII #2514,R0
	MVO R0,_mobs+20
T410:
	;[1053] 	if daytime_cnt = 8 then	sun_x = 84 : sprite 04, 76 + visible, 80 + zoomy2, spr58 + spr_red			'1
	SRCFILE "whalehunt_1a.bas",1053
	MVI V48,R0
	CMPI #8,R0
	BNE T411
	MVII #84,R0
	MVO R0,V49
	MVII #588,R0
	MVO R0,_mobs+4
	MVII #336,R0
	MVO R0,_mobs+12
	MVII #2514,R0
	MVO R0,_mobs+20
T411:
	;[1054] 	if daytime_cnt = 9 then	sun_x = 92 : sprite 04, 74 + visible, 78 + zoomy2, spr59 + spr_red			'2
	SRCFILE "whalehunt_1a.bas",1054
	MVI V48,R0
	CMPI #9,R0
	BNE T412
	MVII #92,R0
	MVO R0,V49
	MVII #586,R0
	MVO R0,_mobs+4
	MVII #334,R0
	MVO R0,_mobs+12
	MVII #2522,R0
	MVO R0,_mobs+20
T412:
	;[1055] 	if daytime_cnt = 10 then sun_x = 100 : sprite 04, 70 + visible, 73 + zoomy2, spr60 + spr_red			'3
	SRCFILE "whalehunt_1a.bas",1055
	MVI V48,R0
	CMPI #10,R0
	BNE T413
	MVII #100,R0
	MVO R0,V49
	MVII #582,R0
	MVO R0,_mobs+4
	MVII #329,R0
	MVO R0,_mobs+12
	MVII #2530,R0
	MVO R0,_mobs+20
T413:
	;[1056] 	if daytime_cnt = 11 then sun_x = 108 : sprite 04, 64 + visible + zoomx2, 68 + zoomy2, spr60 + spr_red			'4
	SRCFILE "whalehunt_1a.bas",1056
	MVI V48,R0
	CMPI #11,R0
	BNE T414
	MVII #108,R0
	MVO R0,V49
	MVII #1600,R0
	MVO R0,_mobs+4
	MVII #324,R0
	MVO R0,_mobs+12
	MVII #2530,R0
	MVO R0,_mobs+20
T414:
	;[1057] 	if daytime_cnt = 12 then 
	SRCFILE "whalehunt_1a.bas",1057
	MVI V48,R0
	CMPI #12,R0
	BNE T415
	;[1058] 		daytime = 2 
	SRCFILE "whalehunt_1a.bas",1058
	MVII #2,R0
	MVO R0,V47
	;[1059] 		gosub sundial_sky 
	SRCFILE "whalehunt_1a.bas",1059
	CALL Q199
	;[1060] 		sun_x = 116 
	SRCFILE "whalehunt_1a.bas",1060
	MVII #116,R0
	MVO R0,V49
	;[1061] 		sprite 04, 62 + visible + zoomx2, 64 + zoomy2, spr60 + spr_red			'5pm
	SRCFILE "whalehunt_1a.bas",1061
	MVII #1598,R0
	MVO R0,_mobs+4
	MVII #320,R0
	MVO R0,_mobs+12
	MVII #2530,R0
	MVO R0,_mobs+20
	;[1062] 	end if
	SRCFILE "whalehunt_1a.bas",1062
T415:
	;[1063] 	if daytime_cnt = 13 then sun_x = 124 : sprite 04, 62 + visible + zoomx2, 58 + zoomy2 + flipy, spr61 + spr_red	'6pm
	SRCFILE "whalehunt_1a.bas",1063
	MVI V48,R0
	CMPI #13,R0
	BNE T416
	MVII #124,R0
	MVO R0,V49
	MVII #1598,R0
	MVO R0,_mobs+4
	MVII #2362,R0
	MVO R0,_mobs+12
	MVII #2538,R0
	MVO R0,_mobs+20
T416:
	;[1064] 	if daytime_cnt = 14 then sun_x = 132 : sprite 04, 61 + visible + zoomx2, 53 + zoomy2 + flipy, spr61 + spr_red	'7pm
	SRCFILE "whalehunt_1a.bas",1064
	MVI V48,R0
	CMPI #14,R0
	BNE T417
	MVII #132,R0
	MVO R0,V49
	MVII #1597,R0
	MVO R0,_mobs+4
	MVII #2357,R0
	MVO R0,_mobs+12
	MVII #2538,R0
	MVO R0,_mobs+20
T417:
	;[1065] 	sprite 00, sun_x + visible, 8 + zoomy2, spr57 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1065
	MVI V49,R0
	ADDI #512,R0
	MVO R0,_mobs
	MVII #264,R0
	MVO R0,_mobs+8
	MVII #2510,R0
	MVO R0,_mobs+16
	;[1066] 	sprite 01, sun_x + 8 + visible, 8 + zoomy2 + flipx, spr57 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1066
	MVI V49,R0
	ADDI #520,R0
	MVO R0,_mobs+1
	MVII #1288,R0
	MVO R0,_mobs+9
	MVII #2510,R0
	MVO R0,_mobs+17
	;[1067] 	sprite 02, sun_x + visible, 16 + zoomy2 + flipy, spr57 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1067
	MVI V49,R0
	ADDI #512,R0
	MVO R0,_mobs+2
	MVII #2320,R0
	MVO R0,_mobs+10
	MVII #2510,R0
	MVO R0,_mobs+18
	;[1068] 	sprite 03, sun_x + 8 + visible, 16 + zoomy2 + mirror, spr57 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1068
	MVI V49,R0
	ADDI #520,R0
	MVO R0,_mobs+3
	MVII #3344,R0
	MVO R0,_mobs+11
	MVII #2510,R0
	MVO R0,_mobs+19
	;[1069] sundial_skip:
	SRCFILE "whalehunt_1a.bas",1069
	; SUNDIAL_SKIP
Q198:	;[1070] 	for cnt = 1 to 60
	SRCFILE "whalehunt_1a.bas",1070
	MVII #1,R0
	MVO R0,V54
T418:
	;[1071] 		wait
	SRCFILE "whalehunt_1a.bas",1071
	CALL _wait
	;[1072] 		gosub timer
	SRCFILE "whalehunt_1a.bas",1072
	CALL Q38
	;[1073] 		if #day_cnt = 0 then goto sundial_loop
	SRCFILE "whalehunt_1a.bas",1073
	MVI V1,R0
	TSTR R0
	BEQ Q197
	;[1074] 		if cont1.button then goto sundial_end
	SRCFILE "whalehunt_1a.bas",1074
	MVI 511,R0
	COMR R0
	ANDI #224,R0
	BNE Q201
	;[1075] 		if cont1.key < 12 then goto sundial_end
	SRCFILE "whalehunt_1a.bas",1075
	MVI _cnt1_key,R0
	CMPI #12,R0
	BLT Q201
	;[1076] 	next cnt
	SRCFILE "whalehunt_1a.bas",1076
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #60,R0
	BLE T418
	;[1077] 	GOTO sundial_loop
	SRCFILE "whalehunt_1a.bas",1077
	B Q197
	;[1078] 	
	SRCFILE "whalehunt_1a.bas",1078
	;[1079] sundial_end:
	SRCFILE "whalehunt_1a.bas",1079
	; SUNDIAL_END
Q201:	;[1080] 	if cont1.key < 12 then goto sundial_end
	SRCFILE "whalehunt_1a.bas",1080
	MVI _cnt1_key,R0
	CMPI #12,R0
	BLT Q201
	;[1081] 	sun_x = 0
	SRCFILE "whalehunt_1a.bas",1081
	CLRR R0
	MVO R0,V49
	;[1082] 	if map = 0 then goto load_images
	SRCFILE "whalehunt_1a.bas",1082
	MVI V11,R0
	TSTR R0
	BEQ Q19
	;[1083] 	if map = 1 then goto load_map
	SRCFILE "whalehunt_1a.bas",1083
	MVI V11,R0
	CMPI #1,R0
	BEQ Q31
	;[1084] 
	SRCFILE "whalehunt_1a.bas",1084
	;[1085] 
	SRCFILE "whalehunt_1a.bas",1085
	;[1086] 	
	SRCFILE "whalehunt_1a.bas",1086
	;[1087] sundial_sky:		procedure
	SRCFILE "whalehunt_1a.bas",1087
	; SUNDIAL_SKY
Q199:	PROC
	BEGIN
	;[1088] 		FOR y = 0 TO 1
	SRCFILE "whalehunt_1a.bas",1088
	CLRR R0
	MVO R0,V67
T425:
	;[1089] 		FOR x = 0 TO 19
	SRCFILE "whalehunt_1a.bas",1089
	CLRR R0
	MVO R0,V60
T426:
	;[1090] 			if daytime = 0 then PRINT AT y * 20 + x,sundial_dawn_cards(y * 20 + x)
	SRCFILE "whalehunt_1a.bas",1090
	MVI V47,R0
	TSTR R0
	BNE T427
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q193,R1
	MVI V67,R2
	MULT R2,R4,20
	ADD V60,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T427:
	;[1091] 			if daytime = 1 then PRINT AT y * 20 + x,sundial_cards(y * 20 + x)
	SRCFILE "whalehunt_1a.bas",1091
	MVI V47,R0
	CMPI #1,R0
	BNE T428
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q194,R1
	MVI V67,R2
	MULT R2,R4,20
	ADD V60,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T428:
	;[1092] 			if daytime = 2 then PRINT AT y * 20 + x,sundial_dusk_cards(y * 20 + x)
	SRCFILE "whalehunt_1a.bas",1092
	MVI V47,R0
	CMPI #2,R0
	BNE T429
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q195,R1
	MVI V67,R2
	MULT R2,R4,20
	ADD V60,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T429:
	;[1093] 		NEXT x
	SRCFILE "whalehunt_1a.bas",1093
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMPI #19,R0
	BLE T426
	;[1094] 		NEXT y
	SRCFILE "whalehunt_1a.bas",1094
	MVI V67,R0
	INCR R0
	MVO R0,V67
	CMPI #1,R0
	BLE T425
	;[1095] 	'sky_end:
	SRCFILE "whalehunt_1a.bas",1095
	;[1096] 		wait
	SRCFILE "whalehunt_1a.bas",1096
	CALL _wait
	;[1097] 		end
	SRCFILE "whalehunt_1a.bas",1097
	RETURN
	ENDP
	;[1098] 
	SRCFILE "whalehunt_1a.bas",1098
	;[1099] storm:		procedure
	SRCFILE "whalehunt_1a.bas",1099
	; STORM
Q45:	PROC
	BEGIN
	;[1100] 	storm_flag = 0
	SRCFILE "whalehunt_1a.bas",1100
	CLRR R0
	MVO R0,V57
	;[1101] 	for cnt = 1 to storm_qty
	SRCFILE "whalehunt_1a.bas",1101
	MVII #1,R0
	MVO R0,V54
T430:
	;[1102] 		if stormx_map(cnt) > 0 then 
	SRCFILE "whalehunt_1a.bas",1102
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R0
	CMPI #0,R0
	BLE T431
	;[1103] 			if map = 1 then print at screenpos(stormx_map(cnt), stormy_map(cnt)) color bg_blue, "@" 
	SRCFILE "whalehunt_1a.bas",1103
	MVI V11,R0
	CMPI #1,R0
	BNE T432
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R0
	MULT R0,R4,20
	MVII #Q4,R3
	ADD V54,R3
	ADD@ R3,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #512,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #256,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
T432:
	;[1104] 			if daytime < 3 then 
	SRCFILE "whalehunt_1a.bas",1104
	MVI V47,R0
	CMPI #3,R0
	BGE T433
	;[1105] 				if player_x > (stormx_map(cnt)*8) then if player_x < (stormx_map(cnt)*8) + 15 then if player_y > (stormy_map(cnt)*8) + 3 then if player_y < (stormy_map(cnt)*8) + 16 then gosub in_storm
	SRCFILE "whalehunt_1a.bas",1105
	MVI V18,R0
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	CMPR R1,R0
	BLE T434
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #15,R1
	CMPR R1,R0
	BGE T435
	MVI V19,R0
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #3,R1
	CMPR R1,R0
	BLE T436
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #16,R1
	CMPR R1,R0
	BGE T437
	CALL Q205
T437:
T436:
T435:
T434:
	;[1106] 			end if
	SRCFILE "whalehunt_1a.bas",1106
T433:
	;[1107] 			if daytime = 3 then
	SRCFILE "whalehunt_1a.bas",1107
	MVI V47,R0
	CMPI #3,R0
	BNE T438
	;[1108] 				if player_x > (stormx_map(cnt)*8) then if player_x < (stormx_map(cnt)*8) + 15 then if player_y > (stormy_map(cnt)*8) + 3 then if player_y < (stormy_map(cnt)*8) + 16 then storm_flag = 1
	SRCFILE "whalehunt_1a.bas",1108
	MVI V18,R0
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	CMPR R1,R0
	BLE T439
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #15,R1
	CMPR R1,R0
	BGE T440
	MVI V19,R0
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #3,R1
	CMPR R1,R0
	BLE T441
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #16,R1
	CMPR R1,R0
	BGE T442
	MVII #1,R0
	MVO R0,V57
T442:
T441:
T440:
T439:
	;[1109] 			end if
	SRCFILE "whalehunt_1a.bas",1109
T438:
	;[1110] 		end if
	SRCFILE "whalehunt_1a.bas",1110
T431:
	;[1111] 		if storm_cnt = storm_cnt_total then
	SRCFILE "whalehunt_1a.bas",1111
	MVI V50,R0
	CMP V51,R0
	BNE T443
	;[1112] 		if stormx_map(cnt) = 0 then
	SRCFILE "whalehunt_1a.bas",1112
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R0
	TSTR R0
	BNE T444
	;[1113] 			wait
	SRCFILE "whalehunt_1a.bas",1113
	CALL _wait
	;[1114] 			x = (rand/storm_roll) + 1
	SRCFILE "whalehunt_1a.bas",1114
	MVI _rand,R0
	MVI V53,R4
	MOVR R0,R5
	TSTR R4
	BEQ T445
	MVII #-1,R0
T446:
	INCR R0
	SUBR R4,R5
	BC T446
T445:
	INCR R0
	MVO R0,V60
	;[1115] 			if x = 1 then	
	SRCFILE "whalehunt_1a.bas",1115
	MVI V60,R0
	CMPI #1,R0
	BNE T447
	;[1116] storm_reroll:
	SRCFILE "whalehunt_1a.bas",1116
	; STORM_REROLL
Q206:	;[1117] 				wait
	SRCFILE "whalehunt_1a.bas",1117
	CALL _wait
	;[1118] 				stormx_map(cnt) = (rand/16) + 2
	SRCFILE "whalehunt_1a.bas",1118
	MVI _rand,R0
	SLR R0,2
	SLR R0,2
	ADDI #2,R0
	MVII #Q4,R3
	ADD V54,R3
	MVO@ R0,R3
	;[1119] 				wait
	SRCFILE "whalehunt_1a.bas",1119
	CALL _wait
	;[1120] 				stormy_map(cnt) = (rand/48) + 2	
	SRCFILE "whalehunt_1a.bas",1120
	MVI _rand,R0
	MVII #-1,R4
T448:
	INCR R4
	SUBI #48,R0
	BC T448
	MOVR R4,R0
	ADDI #2,R0
	MVII #Q5,R3
	ADD V54,R3
	MVO@ R0,R3
	;[1121] 				if player_x > (stormx_map(cnt)*8) then if player_x < (stormx_map(cnt)*8) + 15 then if player_y > (stormy_map(cnt)*8) + 3 then if player_y < (stormy_map(cnt)*8) + 16 then goto storm_reroll
	SRCFILE "whalehunt_1a.bas",1121
	MVI V18,R0
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	CMPR R1,R0
	BLE T449
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #15,R1
	CMPR R1,R0
	BGE T450
	MVI V19,R0
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #3,R1
	CMPR R1,R0
	BLE T451
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #16,R1
	CMPR R1,R0
	BLT Q206
T451:
T450:
T449:
	;[1122] 				if whalex_map > (stormx_map(cnt)*8) then if whalex_map < (stormx_map(cnt)*8) + 15 then if whaley_map > (stormy_map(cnt)*8) + 3 then if whaley_map < (stormy_map(cnt)*8) + 16 then goto storm_reroll
	SRCFILE "whalehunt_1a.bas",1122
	MVI V20,R0
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	CMPR R1,R0
	BLE T453
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #15,R1
	CMPR R1,R0
	BGE T454
	MVI V21,R0
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #3,R1
	CMPR R1,R0
	BLE T455
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #16,R1
	CMPR R1,R0
	BLT Q206
T455:
T454:
T453:
	;[1123] 			end if
	SRCFILE "whalehunt_1a.bas",1123
T447:
	;[1124] 		else
	SRCFILE "whalehunt_1a.bas",1124
	B T457
T444:
	;[1125] 			if x = 1 then 
	SRCFILE "whalehunt_1a.bas",1125
	MVI V60,R0
	CMPI #1,R0
	BNE T458
	;[1126] 				if map = 1 then print at stormy_map(cnt) * 20 + stormx_map(cnt), map_cards(stormy_map(cnt) * 20 + stormx_map(cnt))
	SRCFILE "whalehunt_1a.bas",1126
	MVI V11,R0
	CMPI #1,R0
	BNE T459
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R0
	MULT R0,R4,20
	MVII #Q4,R3
	ADD V54,R3
	ADD@ R3,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	MULT R1,R4,20
	MVII #Q4,R3
	ADD V54,R3
	ADD@ R3,R1
	MVII #Q147,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T459:
	;[1127] 				stormx_map(cnt) = 0
	SRCFILE "whalehunt_1a.bas",1127
	CLRR R0
	MVII #Q4,R3
	ADD V54,R3
	MVO@ R0,R3
	;[1128] 			if player_x > (stormx_map(cnt)*8) then if player_x < (stormx_map(cnt)*8) + 15 then if player_y > (stormy_map(cnt)*8) + 3 then if player_y < (stormy_map(cnt)*8) + 16 then gosub out_storm
	SRCFILE "whalehunt_1a.bas",1128
	MVI V18,R0
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	CMPR R1,R0
	BLE T460
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #15,R1
	CMPR R1,R0
	BGE T461
	MVI V19,R0
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #3,R1
	CMPR R1,R0
	BLE T462
	MVI@ R3,R1
	SLL R1,2
	ADDR R1,R1
	ADDI #16,R1
	CMPR R1,R0
	BGE T463
	CALL Q207
T463:
T462:
T461:
T460:
	;[1129] 			end if				
	SRCFILE "whalehunt_1a.bas",1129
T458:
	;[1130] 		end if
	SRCFILE "whalehunt_1a.bas",1130
T457:
	;[1131] 		end if	
	SRCFILE "whalehunt_1a.bas",1131
T443:
	;[1132] 	next cnt
	SRCFILE "whalehunt_1a.bas",1132
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMP V52,R0
	BLE T430
	;[1133] 	storm_cnt = storm_cnt + 1
	SRCFILE "whalehunt_1a.bas",1133
	MVI V50,R0
	INCR R0
	MVO R0,V50
	;[1134] 	if storm_cnt > storm_cnt_total then storm_cnt = 1
	SRCFILE "whalehunt_1a.bas",1134
	MVI V50,R0
	CMP V51,R0
	BLE T464
	MVII #1,R0
	MVO R0,V50
T464:
	;[1135] 	if storm_flag = 0 then if daytime = 3 then gosub out_storm
	SRCFILE "whalehunt_1a.bas",1135
	MVI V57,R0
	TSTR R0
	BNE T465
	MVI V47,R0
	CMPI #3,R0
	BNE T466
	CALL Q207
T466:
T465:
	;[1136] 	if storm_flag = 1 then
	SRCFILE "whalehunt_1a.bas",1136
	MVI V57,R0
	CMPI #1,R0
	BNE T467
	;[1137] 	wait
	SRCFILE "whalehunt_1a.bas",1137
	CALL _wait
	;[1138] 	if map = 0 then
	SRCFILE "whalehunt_1a.bas",1138
	MVI V11,R0
	TSTR R0
	BNE T468
	;[1139] 		for cnt = 1 to 2
	SRCFILE "whalehunt_1a.bas",1139
	MVII #1,R0
	MVO R0,V54
T469:
	;[1140] 			if storm_cnt = 30 then gosub lightning
	SRCFILE "whalehunt_1a.bas",1140
	MVI V50,R0
	CMPI #30,R0
	BNE T470
	CALL Q208
T470:
	;[1141] 			if storm_cnt = 1 then gosub lightning
	SRCFILE "whalehunt_1a.bas",1141
	MVI V50,R0
	CMPI #1,R0
	BNE T471
	CALL Q208
T471:
	;[1142] 		next cnt
	SRCFILE "whalehunt_1a.bas",1142
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #2,R0
	BLE T469
	;[1143] 	end if
	SRCFILE "whalehunt_1a.bas",1143
T468:
	;[1144] 	end if
	SRCFILE "whalehunt_1a.bas",1144
T467:
	;[1145] 	end
	SRCFILE "whalehunt_1a.bas",1145
	RETURN
	ENDP
	;[1146] 
	SRCFILE "whalehunt_1a.bas",1146
	;[1147] in_storm:	procedure
	SRCFILE "whalehunt_1a.bas",1147
	; IN_STORM
Q205:	PROC
	BEGIN
	;[1148] 	if hands = 3 then goto lose_life
	SRCFILE "whalehunt_1a.bas",1148
	MVI V16,R0
	CMPI #3,R0
	BEQ Q32
	;[1149] 	daytime = 3
	SRCFILE "whalehunt_1a.bas",1149
	MVII #3,R0
	MVO R0,V47
	;[1150] 	if map = 1 then gosub tornado
	SRCFILE "whalehunt_1a.bas",1150
	MVI V11,R0
	CMPI #1,R0
	BNE T473
	CALL Q210
T473:
	;[1151] 	if map = 0 then 
	SRCFILE "whalehunt_1a.bas",1151
	MVI V11,R0
	TSTR R0
	BNE T474
	;[1152] 		screen background_storm,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1152
	MVII #20,R0
	ADDI #Q24,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
	;[1153] 		gosub draw_player
	SRCFILE "whalehunt_1a.bas",1153
	CALL Q41
	;[1154] 		gosub lightning
	SRCFILE "whalehunt_1a.bas",1154
	CALL Q208
	;[1155] 	end if
	SRCFILE "whalehunt_1a.bas",1155
T474:
	;[1156] 	player_x = stormx_map(cnt)*8 + 8
	SRCFILE "whalehunt_1a.bas",1156
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #8,R0
	MVO R0,V18
	;[1157] 	player_y = stormy_map(cnt)*8 + 9
	SRCFILE "whalehunt_1a.bas",1157
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #9,R0
	MVO R0,V19
	;[1158] 	if storm_flag = 0 then 
	SRCFILE "whalehunt_1a.bas",1158
	MVI V57,R0
	TSTR R0
	BNE T475
	;[1159] 		row_total = row_speed * 4
	SRCFILE "whalehunt_1a.bas",1159
	MVI V23,R0
	SLL R0,2
	MVO R0,V22
	;[1160] '		row_speed = row_total
	SRCFILE "whalehunt_1a.bas",1160
	;[1161] 	end if
	SRCFILE "whalehunt_1a.bas",1161
T475:
	;[1162] 	storm_flag = 1
	SRCFILE "whalehunt_1a.bas",1162
	MVII #1,R0
	MVO R0,V57
	;[1163] 	end
	SRCFILE "whalehunt_1a.bas",1163
	RETURN
	ENDP
	;[1164] 
	SRCFILE "whalehunt_1a.bas",1164
	;[1165] out_storm:		procedure
	SRCFILE "whalehunt_1a.bas",1165
	; OUT_STORM
Q207:	PROC
	BEGIN
	;[1166] 	if map = 0 then
	SRCFILE "whalehunt_1a.bas",1166
	MVI V11,R0
	TSTR R0
	BNE T476
	;[1167] 		sprite 04, behind
	SRCFILE "whalehunt_1a.bas",1167
	MVII #8192,R0
	MVO R0,_mobs+4
	;[1168] 		sprite 05, behind
	SRCFILE "whalehunt_1a.bas",1168
	MVO R0,_mobs+5
	;[1169] 		sprite 06, behind
	SRCFILE "whalehunt_1a.bas",1169
	NOP
	MVO R0,_mobs+6
	;[1170] 		sprite 07, behind
	SRCFILE "whalehunt_1a.bas",1170
	MVO R0,_mobs+7
	;[1171] 	end if
	SRCFILE "whalehunt_1a.bas",1171
T476:
	;[1172] 	if map = 1 then print at stormy_map(cnt) * 20 + stormx_map(cnt), map_cards(stormy_map(cnt) * 20 + stormx_map(cnt))	
	SRCFILE "whalehunt_1a.bas",1172
	MVI V11,R0
	CMPI #1,R0
	BNE T477
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R0
	MULT R0,R4,20
	MVII #Q4,R3
	ADD V54,R3
	ADD@ R3,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R1
	MULT R1,R4,20
	MVII #Q4,R3
	ADD V54,R3
	ADD@ R3,R1
	MVII #Q147,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T477:
	;[1173] 	if daytime_cnt > 2 then daytime = 1 else daytime = 0
	SRCFILE "whalehunt_1a.bas",1173
	MVI V48,R0
	CMPI #2,R0
	BLE T478
	MVII #1,R0
	MVO R0,V47
	B T479
T478:
	CLRR R0
	MVO R0,V47
T479:
	;[1174] 	if daytime_cnt > 11 then daytime = 2
	SRCFILE "whalehunt_1a.bas",1174
	MVI V48,R0
	CMPI #11,R0
	BLE T480
	MVII #2,R0
	MVO R0,V47
T480:
	;[1175] 	if map = 0 then
	SRCFILE "whalehunt_1a.bas",1175
	MVI V11,R0
	TSTR R0
	BNE T481
	;[1176] 		if daytime = 0 then screen background_dawn,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1176
	MVI V47,R0
	TSTR R0
	BNE T482
	MVII #20,R0
	ADDI #Q21,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
T482:
	;[1177] 		if daytime = 1 then screen background,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1177
	MVI V47,R0
	CMPI #1,R0
	BNE T483
	MVII #20,R0
	ADDI #Q22,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
T483:
	;[1178] 		if daytime = 2 then screen background_dusk,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1178
	MVI V47,R0
	CMPI #2,R0
	BNE T484
	MVII #20,R0
	ADDI #Q23,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
T484:
	;[1179] 		gosub draw_player
	SRCFILE "whalehunt_1a.bas",1179
	CALL Q41
	;[1180] 	end if 
	SRCFILE "whalehunt_1a.bas",1180
T481:
	;[1181] 	row_total = row_speed
	SRCFILE "whalehunt_1a.bas",1181
	MVI V23,R0
	MVO R0,V22
	;[1182] 	storm_flag = 0
	SRCFILE "whalehunt_1a.bas",1182
	CLRR R0
	MVO R0,V57
	;[1183] 	end
	SRCFILE "whalehunt_1a.bas",1183
	RETURN
	ENDP
	;[1184] 	
	SRCFILE "whalehunt_1a.bas",1184
	;[1185] draw_player_map_sprites:	procedure
	SRCFILE "whalehunt_1a.bas",1185
	; DRAW_PLAYER_MAP_SPRITES
Q212:	PROC
	BEGIN
	;[1186] 	sprite 00, player_x + visible, player_y + #char_dir, spr38 + cs_red	'player
	SRCFILE "whalehunt_1a.bas",1186
	MVI V18,R0
	ADDI #512,R0
	MVO R0,_mobs
	MVI V19,R0
	ADD V2,R0
	MVO R0,_mobs+8
	MVII #2354,R0
	MVO R0,_mobs+16
	;[1187] 	sprite 01, player_x + visible, player_y + #char_dir, spr39 + cs_white
	SRCFILE "whalehunt_1a.bas",1187
	MVI V18,R0
	ADDI #512,R0
	MVO R0,_mobs+1
	MVI V19,R0
	ADD V2,R0
	MVO R0,_mobs+9
	MVII #2367,R0
	MVO R0,_mobs+17
	;[1188] 	sprite 02, player_x + hit + visible, player_y + #char_dir, spr40 + cs_orange	'player
	SRCFILE "whalehunt_1a.bas",1188
	MVI V18,R0
	ADDI #768,R0
	MVO R0,_mobs+2
	MVI V19,R0
	ADD V2,R0
	MVO R0,_mobs+10
	MVII #6466,R0
	MVO R0,_mobs+18
	;[1189] 	wait
	SRCFILE "whalehunt_1a.bas",1189
	CALL _wait
	;[1190] 	end
	SRCFILE "whalehunt_1a.bas",1190
	RETURN
	ENDP
	;[1191] 	
	SRCFILE "whalehunt_1a.bas",1191
	;[1192] tornado:		procedure
	SRCFILE "whalehunt_1a.bas",1192
	; TORNADO
Q210:	PROC
	BEGIN
	;[1193] if storm_flag = 0 then
	SRCFILE "whalehunt_1a.bas",1193
	MVI V57,R0
	TSTR R0
	BNE T485
	;[1194] 	player_x = stormx_map(cnt)*8 + 11
	SRCFILE "whalehunt_1a.bas",1194
	MVII #Q4,R3
	ADD V54,R3
	MVI@ R3,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #11,R0
	MVO R0,V18
	;[1195] 	player_y = stormy_map(cnt)*8 + 11
	SRCFILE "whalehunt_1a.bas",1195
	MVII #Q5,R3
	ADD V54,R3
	MVI@ R3,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #11,R0
	MVO R0,V19
	;[1196] 	gosub draw_player_map_sprites
	SRCFILE "whalehunt_1a.bas",1196
	CALL Q212
	;[1197] 	for x = 1 to 7
	SRCFILE "whalehunt_1a.bas",1197
	MVII #1,R0
	MVO R0,V60
T486:
	;[1198] 		player_x = player_x - 1
	SRCFILE "whalehunt_1a.bas",1198
	MVI V18,R0
	DECR R0
	MVO R0,V18
	;[1199] 		gosub draw_player_map_sprites
	SRCFILE "whalehunt_1a.bas",1199
	CALL Q212
	;[1200] 	next x
	SRCFILE "whalehunt_1a.bas",1200
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMPI #7,R0
	BLE T486
	;[1201] 	for y = 1 to 5
	SRCFILE "whalehunt_1a.bas",1201
	MVII #1,R0
	MVO R0,V67
T487:
	;[1202] 		player_y = player_y - 1
	SRCFILE "whalehunt_1a.bas",1202
	MVI V19,R0
	DECR R0
	MVO R0,V19
	;[1203] 		gosub draw_player_map_sprites
	SRCFILE "whalehunt_1a.bas",1203
	CALL Q212
	;[1204] 	next y
	SRCFILE "whalehunt_1a.bas",1204
	MVI V67,R0
	INCR R0
	MVO R0,V67
	CMPI #5,R0
	BLE T487
	;[1205] 	for x = 1 to 7
	SRCFILE "whalehunt_1a.bas",1205
	MVII #1,R0
	MVO R0,V60
T488:
	;[1206] 		player_x = player_x + 1
	SRCFILE "whalehunt_1a.bas",1206
	MVI V18,R0
	INCR R0
	MVO R0,V18
	;[1207] 		gosub draw_player_map_sprites
	SRCFILE "whalehunt_1a.bas",1207
	CALL Q212
	;[1208] 	next x
	SRCFILE "whalehunt_1a.bas",1208
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMPI #7,R0
	BLE T488
	;[1209] 	for y = 1 to 3
	SRCFILE "whalehunt_1a.bas",1209
	MVII #1,R0
	MVO R0,V67
T489:
	;[1210] 		player_y = player_y + 1
	SRCFILE "whalehunt_1a.bas",1210
	MVI V19,R0
	INCR R0
	MVO R0,V19
	;[1211] 		gosub draw_player_map_sprites
	SRCFILE "whalehunt_1a.bas",1211
	CALL Q212
	;[1212] 	next y
	SRCFILE "whalehunt_1a.bas",1212
	MVI V67,R0
	INCR R0
	MVO R0,V67
	CMPI #3,R0
	BLE T489
	;[1213] 	for x = 1 to 3
	SRCFILE "whalehunt_1a.bas",1213
	MVII #1,R0
	MVO R0,V60
T490:
	;[1214] 		player_x = player_x - 1
	SRCFILE "whalehunt_1a.bas",1214
	MVI V18,R0
	DECR R0
	MVO R0,V18
	;[1215] 		gosub draw_player_map_sprites
	SRCFILE "whalehunt_1a.bas",1215
	CALL Q212
	;[1216] 	next x
	SRCFILE "whalehunt_1a.bas",1216
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMPI #3,R0
	BLE T490
	;[1217] end if	
	SRCFILE "whalehunt_1a.bas",1217
T485:
	;[1218] end
	SRCFILE "whalehunt_1a.bas",1218
	RETURN
	ENDP
	;[1219] 	
	SRCFILE "whalehunt_1a.bas",1219
	;[1220] 	
	SRCFILE "whalehunt_1a.bas",1220
	;[1221] 
	SRCFILE "whalehunt_1a.bas",1221
	;[1222] REM ===============================BEAT LEVEL========================================
	SRCFILE "whalehunt_1a.bas",1222
	;[1223] asm org $0500
	SRCFILE "whalehunt_1a.bas",1223
 org $0500
	;[1224] lose_life:
	SRCFILE "whalehunt_1a.bas",1224
	; LOSE_LIFE
Q32:	;[1225] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1225
	CALL Q20
	;[1226] 	cls
	SRCFILE "whalehunt_1a.bas",1226
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1227] 	if storm_flag = 1 then
	SRCFILE "whalehunt_1a.bas",1227
	MVI V57,R0
	CMPI #1,R0
	BNE T491
	;[1228] 		gosub lightning
	SRCFILE "whalehunt_1a.bas",1228
	CALL Q208
	;[1229] 		gosub lightning
	SRCFILE "whalehunt_1a.bas",1229
	CALL Q208
	;[1230] 	end if
	SRCFILE "whalehunt_1a.bas",1230
T491:
	;[1231] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",1231
	CALL Q173
	;[1232] 	DEFINE 0,16,lose_life_bitmaps_0
	SRCFILE "whalehunt_1a.bas",1232
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q215,R0
	MVO R0,_gram_bitmap
	;[1233] 	WAIT
	SRCFILE "whalehunt_1a.bas",1233
	CALL _wait
	;[1234] 	DEFINE 16,16,lose_life_bitmaps_1
	SRCFILE "whalehunt_1a.bas",1234
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q216,R0
	MVO R0,_gram_bitmap
	;[1235] 	WAIT
	SRCFILE "whalehunt_1a.bas",1235
	CALL _wait
	;[1236] 	DEFINE 32,16,lose_life_bitmaps_2
	SRCFILE "whalehunt_1a.bas",1236
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q217,R0
	MVO R0,_gram_bitmap
	;[1237] 	WAIT
	SRCFILE "whalehunt_1a.bas",1237
	CALL _wait
	;[1238] 	DEFINE 48,6,lose_life_bitmaps_3
	SRCFILE "whalehunt_1a.bas",1238
	MVII #48,R0
	MVO R0,_gram_target
	MVII #6,R0
	MVO R0,_gram_total
	MVII #Q218,R0
	MVO R0,_gram_bitmap
	;[1239] 	define alternate 56,5,lose_life_sprites
	SRCFILE "whalehunt_1a.bas",1239
	MVII #56,R0
	MVO R0,_gram2_target
	MVII #5,R0
	MVO R0,_gram2_total
	MVII #Q219,R0
	MVO R0,_gram2_bitmap
	;[1240] 	wait
	SRCFILE "whalehunt_1a.bas",1240
	CALL _wait
	;[1241] 	define 55,1,harpoon_4
	SRCFILE "whalehunt_1a.bas",1241
	MVII #55,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q72,R0
	MVO R0,_gram_bitmap
	;[1242] 	define alternate 62,2,title_harpoon
	SRCFILE "whalehunt_1a.bas",1242
	MVII #62,R0
	MVO R0,_gram2_target
	MVII #2,R0
	MVO R0,_gram2_total
	MVII #Q10,R0
	MVO R0,_gram2_bitmap
	;[1243] 	wait
	SRCFILE "whalehunt_1a.bas",1243
	CALL _wait
	;[1244] 	play simple
	SRCFILE "whalehunt_1a.bas",1244
	MVII #1,R3
	MVO R3,_music_mode
	;[1245] 	play game_over_song
	SRCFILE "whalehunt_1a.bas",1245
	MVII #Q220,R0
	CALL _play_music
	;[1246] 	SCREEN lose_life_cards
	SRCFILE "whalehunt_1a.bas",1246
	MVII #Q221,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1247] 	wait
	SRCFILE "whalehunt_1a.bas",1247
	CALL _wait
	;[1248] 	lives = lives - 1
	SRCFILE "whalehunt_1a.bas",1248
	MVI V7,R0
	DECR R0
	MVO R0,V7
	;[1249] 	if lives > 0 then
	SRCFILE "whalehunt_1a.bas",1249
	MVI V7,R0
	CMPI #0,R0
	BLE T492
	;[1250] 		print at 42 color bg_cyan, "YOU LOST A LIFE!"
	SRCFILE "whalehunt_1a.bas",1250
	MVII #554,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #456,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	XORI #352,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #352,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1251] 	else
	SRCFILE "whalehunt_1a.bas",1251
	B T493
T492:
	;[1252] 		print at 45 color bg_cyan, "GAME OVER!"
	SRCFILE "whalehunt_1a.bas",1252
	MVII #557,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #312,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #376,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1253] 	end if
	SRCFILE "whalehunt_1a.bas",1253
T493:
	;[1254] 	sprite 00, 28 + visible, 75, spr56 + spr_black
	SRCFILE "whalehunt_1a.bas",1254
	MVII #540,R0
	MVO R0,_mobs
	MVII #75,R0
	MVO R0,_mobs+8
	MVII #2496,R0
	MVO R0,_mobs+16
	;[1255] 	sprite 01, 28 + visible, 75, spr57 + spr_white
	SRCFILE "whalehunt_1a.bas",1255
	MVII #540,R0
	MVO R0,_mobs+1
	MVII #75,R0
	MVO R0,_mobs+9
	MVII #2511,R0
	MVO R0,_mobs+17
	;[1256] 	sprite 07, 22 + visible + zoomx2, 73 + zoomy4, spr55 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",1256
	MVII #1558,R0
	MVO R0,_mobs+7
	MVII #585,R0
	MVO R0,_mobs+15
	MVII #2492,R0
	MVO R0,_mobs+23
	;[1257] 	
	SRCFILE "whalehunt_1a.bas",1257
	;[1258] 	sprite 02, 13 + visible, 83 + zoomy2, spr58 + spr_orange
	SRCFILE "whalehunt_1a.bas",1258
	MVII #525,R0
	MVO R0,_mobs+2
	MVII #339,R0
	MVO R0,_mobs+10
	MVII #6610,R0
	MVO R0,_mobs+18
	;[1259] 	sprite 03, 64 + visible, 80 + zoomy2, spr59 + spr_cyan
	SRCFILE "whalehunt_1a.bas",1259
	MVII #576,R0
	MVO R0,_mobs+3
	MVII #336,R0
	MVO R0,_mobs+11
	MVII #6617,R0
	MVO R0,_mobs+19
	;[1260] 	sprite 04, 64 + visible, 72 + zoomy2, spr60 + spr_black
	SRCFILE "whalehunt_1a.bas",1260
	MVII #576,R0
	MVO R0,_mobs+4
	MVII #328,R0
	MVO R0,_mobs+12
	MVII #2528,R0
	MVO R0,_mobs+20
	;[1261] 	sprite 05, 118 + visible, 80 + zoomy2 + mirror, spr63 + spr_grey
	SRCFILE "whalehunt_1a.bas",1261
	MVII #630,R0
	MVO R0,_mobs+5
	MVII #3408,R0
	MVO R0,_mobs+13
	MVII #6648,R0
	MVO R0,_mobs+21
	;[1262] 	sprite 06, 105 + visible + zoomx2, 49 + zoomy8 + mirror, spr62 + spr_orange
	SRCFILE "whalehunt_1a.bas",1262
	MVII #1641,R0
	MVO R0,_mobs+6
	MVII #3889,R0
	MVO R0,_mobs+14
	MVII #6642,R0
	MVO R0,_mobs+22
	;[1263] 	gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",1263
	CALL Q170
	;[1264] 	play off
	SRCFILE "whalehunt_1a.bas",1264
	CLRR R0
	CALL _play_music
	;[1265] 	if lives > 0 then 
	SRCFILE "whalehunt_1a.bas",1265
	MVI V7,R0
	CMPI #0,R0
	BLE T494
	;[1266] 		gosub new_level_stats
	SRCFILE "whalehunt_1a.bas",1266
	CALL Q176
	;[1267] 		gosub kill_quantity
	SRCFILE "whalehunt_1a.bas",1267
	CALL Q18
	;[1268] 		player_x = 77
	SRCFILE "whalehunt_1a.bas",1268
	MVII #77,R0
	MVO R0,V18
	;[1269] 		player_y = 75
	SRCFILE "whalehunt_1a.bas",1269
	MVII #75,R0
	MVO R0,V19
	;[1270] 		hit_cnt = 0
	SRCFILE "whalehunt_1a.bas",1270
	CLRR R0
	MVO R0,V28
	;[1271] 		timeout_flag = 0
	SRCFILE "whalehunt_1a.bas",1271
	MVO R0,V10
	;[1272] 		goto load_images
	SRCFILE "whalehunt_1a.bas",1272
	B Q19
	;[1273] 	end if
	SRCFILE "whalehunt_1a.bas",1273
T494:
	;[1274] 	goto tally_score
	SRCFILE "whalehunt_1a.bas",1274
	B Q26
	;[1275] 	
	SRCFILE "whalehunt_1a.bas",1275
	;[1276] beat_level:		procedure
	SRCFILE "whalehunt_1a.bas",1276
	; BEAT_LEVEL
Q158:	PROC
	BEGIN
	;[1277] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1277
	CALL Q20
	;[1278] 	cls
	SRCFILE "whalehunt_1a.bas",1278
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1279] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",1279
	CALL Q173
	;[1280] 	
	SRCFILE "whalehunt_1a.bas",1280
	;[1281] 	DEFINE 0,16,beat_level_bitmaps_0
	SRCFILE "whalehunt_1a.bas",1281
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q223,R0
	MVO R0,_gram_bitmap
	;[1282] 	WAIT
	SRCFILE "whalehunt_1a.bas",1282
	CALL _wait
	;[1283] 	DEFINE 16,16,beat_level_bitmaps_1
	SRCFILE "whalehunt_1a.bas",1283
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q224,R0
	MVO R0,_gram_bitmap
	;[1284] 	WAIT
	SRCFILE "whalehunt_1a.bas",1284
	CALL _wait
	;[1285] 	DEFINE 32,16,beat_level_bitmaps_2
	SRCFILE "whalehunt_1a.bas",1285
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q225,R0
	MVO R0,_gram_bitmap
	;[1286] 	WAIT
	SRCFILE "whalehunt_1a.bas",1286
	CALL _wait
	;[1287] 	DEFINE 48,13,beat_level_bitmaps_3
	SRCFILE "whalehunt_1a.bas",1287
	MVII #48,R0
	MVO R0,_gram_target
	MVII #13,R0
	MVO R0,_gram_total
	MVII #Q226,R0
	MVO R0,_gram_bitmap
	;[1288] 	define alternate 61,1,beat_level_sprites
	SRCFILE "whalehunt_1a.bas",1288
	MVII #61,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q227,R0
	MVO R0,_gram2_bitmap
	;[1289] 	WAIT
	SRCFILE "whalehunt_1a.bas",1289
	CALL _wait
	;[1290] 	define 62,1,blood_2
	SRCFILE "whalehunt_1a.bas",1290
	MVII #62,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q228,R0
	MVO R0,_gram_bitmap
	;[1291] 	define alternate 63,1,beat_level_harpoon
	SRCFILE "whalehunt_1a.bas",1291
	MVII #63,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q229,R0
	MVO R0,_gram2_bitmap
	;[1292] 	wait
	SRCFILE "whalehunt_1a.bas",1292
	CALL _wait
	;[1293] 	play full
	SRCFILE "whalehunt_1a.bas",1293
	MVII #2,R3
	MVO R3,_music_mode
	;[1294] 	play beat_level_music
	SRCFILE "whalehunt_1a.bas",1294
	MVII #Q11,R0
	CALL _play_music
	;[1295] 	SCREEN beat_level_cards
	SRCFILE "whalehunt_1a.bas",1295
	MVII #Q230,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1296] 	
	SRCFILE "whalehunt_1a.bas",1296
	;[1297] 	sprite 00, 80 + visible, 70 + zoomy2, spr61 + spr_black
	SRCFILE "whalehunt_1a.bas",1297
	MVII #592,R0
	MVO R0,_mobs
	MVII #326,R0
	MVO R0,_mobs+8
	MVII #2536,R0
	MVO R0,_mobs+16
	;[1298] 	sprite 01, 96 + visible + zoomx2, 48 + zoomy8, spr63 + spr_orange
	SRCFILE "whalehunt_1a.bas",1298
	MVII #1632,R0
	MVO R0,_mobs+1
	MVII #816,R0
	MVO R0,_mobs+9
	MVII #6650,R0
	MVO R0,_mobs+17
	;[1299] 	sprite 02, 102 + visible + zoomx2, 75 + zoomy2 + flipy, spr62 + spr_red
	SRCFILE "whalehunt_1a.bas",1299
	MVII #1638,R0
	MVO R0,_mobs+2
	MVII #2379,R0
	MVO R0,_mobs+10
	MVII #2546,R0
	MVO R0,_mobs+18
	;[1300] 	sprite 03, 134 + visible + zoomx2, 58 + zoomy8, spr63 + spr_orange
	SRCFILE "whalehunt_1a.bas",1300
	MVII #1670,R0
	MVO R0,_mobs+3
	MVII #826,R0
	MVO R0,_mobs+11
	MVII #6650,R0
	MVO R0,_mobs+19
	;[1301] 	sprite 04, 140 + visible + zoomx2, 85 + zoomy2 + flipy, spr62 + spr_red
	SRCFILE "whalehunt_1a.bas",1301
	MVII #1676,R0
	MVO R0,_mobs+4
	MVII #2389,R0
	MVO R0,_mobs+12
	MVII #2546,R0
	MVO R0,_mobs+20
	;[1302] 	sprite 05, 128 + visible + zoomx2, 66 + zoomy8 + flipx , spr63 + spr_orange
	SRCFILE "whalehunt_1a.bas",1302
	MVII #1664,R0
	MVO R0,_mobs+5
	MVII #1858,R0
	MVO R0,_mobs+13
	MVII #6650,R0
	MVO R0,_mobs+21
	;[1303] 	sprite 06, 120 + visible + zoomx2, 93 + zoomy2 + flipy, spr62 + spr_red
	SRCFILE "whalehunt_1a.bas",1303
	MVII #1656,R0
	MVO R0,_mobs+6
	MVII #2397,R0
	MVO R0,_mobs+14
	MVII #2546,R0
	MVO R0,_mobs+22
	;[1304] 	
	SRCFILE "whalehunt_1a.bas",1304
	;[1305] 	REM	sprite 07, x + visible + zoomx2, 69 + zoomy2 + flipy, spr62 + spr_red
	SRCFILE "whalehunt_1a.bas",1305
	;[1306] 
	SRCFILE "whalehunt_1a.bas",1306
	;[1307] 	print at 102 color bg_cyan, "YOU BEAT"
	SRCFILE "whalehunt_1a.bas",1307
	MVII #614,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #456,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	XORI #272,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1308] 	print at 122, "LEVEL ", <>level, "!"
	SRCFILE "whalehunt_1a.bas",1308
	MVII #634,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #352,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #352,R0
	MVO@ R0,R4
	MVO R4,_screen
	MVI V9,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	MVI _screen,R4
	MVII #8,R0
	XOR _color,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1309] 	
	SRCFILE "whalehunt_1a.bas",1309
	;[1310] 	gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",1310
	CALL Q170
	;[1311] 	
	SRCFILE "whalehunt_1a.bas",1311
	;[1312] 	play off
	SRCFILE "whalehunt_1a.bas",1312
	CLRR R0
	CALL _play_music
	;[1313] 	
	SRCFILE "whalehunt_1a.bas",1313
	;[1314] 	if col2 and hit_sprite5 then
	SRCFILE "whalehunt_1a.bas",1314
	MVI _col2,R0
	ANDI #32,R0
	BEQ T495
	;[1315] 		player_x = 24
	SRCFILE "whalehunt_1a.bas",1315
	MVII #24,R0
	MVO R0,V18
	;[1316] 		player_y = 75
	SRCFILE "whalehunt_1a.bas",1316
	MVII #75,R0
	MVO R0,V19
	;[1317] 	end if
	SRCFILE "whalehunt_1a.bas",1317
T495:
	;[1318] 	if col2 and hit_sprite6 then
	SRCFILE "whalehunt_1a.bas",1318
	MVI _col2,R0
	ANDI #64,R0
	BEQ T496
	;[1319] 		player_x = 77
	SRCFILE "whalehunt_1a.bas",1319
	MVII #77,R0
	MVO R0,V18
	;[1320] 		player_y = 75
	SRCFILE "whalehunt_1a.bas",1320
	MVII #75,R0
	MVO R0,V19
	;[1321] 	end if
	SRCFILE "whalehunt_1a.bas",1321
T496:
	;[1322] 	if col2 and hit_sprite7 then
	SRCFILE "whalehunt_1a.bas",1322
	MVI _col2,R0
	ANDI #128,R0
	BEQ T497
	;[1323] 		player_x = 147
	SRCFILE "whalehunt_1a.bas",1323
	MVII #147,R0
	MVO R0,V18
	;[1324] 		player_y = 74
	SRCFILE "whalehunt_1a.bas",1324
	MVII #74,R0
	MVO R0,V19
	;[1325] 	end if
	SRCFILE "whalehunt_1a.bas",1325
T497:
	;[1326] 	end
	SRCFILE "whalehunt_1a.bas",1326
	RETURN
	ENDP
	;[1327] 
	SRCFILE "whalehunt_1a.bas",1327
	;[1328] new_level_stats:	procedure
	SRCFILE "whalehunt_1a.bas",1328
	; NEW_LEVEL_STATS
Q176:	PROC
	BEGIN
	;[1329] 	map = 0
	SRCFILE "whalehunt_1a.bas",1329
	CLRR R0
	MVO R0,V11
	;[1330] 	daytime = 0
	SRCFILE "whalehunt_1a.bas",1330
	MVO R0,V47
	;[1331] 	daytime_cnt = 0
	SRCFILE "whalehunt_1a.bas",1331
	NOP
	MVO R0,V48
	;[1332] 	direction = 1
	SRCFILE "whalehunt_1a.bas",1332
	MVII #1,R0
	MVO R0,V15
	;[1333] 	storm_flag = 0
	SRCFILE "whalehunt_1a.bas",1333
	CLRR R0
	MVO R0,V57
	;[1334] 	health = 4
	SRCFILE "whalehunt_1a.bas",1334
	MVII #4,R0
	MVO R0,V8
	;[1335] 	if level = 5 then storm_qty = 8 : storm_cnt_total = 45 : storm_roll = 45
	SRCFILE "whalehunt_1a.bas",1335
	MVI V9,R0
	CMPI #5,R0
	BNE T498
	MVII #8,R0
	MVO R0,V52
	MVII #45,R0
	MVO R0,V51
	MVO R0,V53
T498:
	;[1336] 	if wind_flute = 1 then storm_qty = 12 : storm_cnt_total = 30 : storm_roll = 25
	SRCFILE "whalehunt_1a.bas",1336
	MVI V34,R0
	CMPI #1,R0
	BNE T499
	MVII #12,R0
	MVO R0,V52
	MVII #30,R0
	MVO R0,V51
	MVII #25,R0
	MVO R0,V53
T499:
	;[1337] 	row = 0
	SRCFILE "whalehunt_1a.bas",1337
	CLRR R0
	MVO R0,V25
	;[1338] 	if town_check = 1 then level = level + 1
	SRCFILE "whalehunt_1a.bas",1338
	MVI V37,R0
	CMPI #1,R0
	BNE T500
	MVI V9,R0
	INCR R0
	MVO R0,V9
T500:
	;[1339] 	end
	SRCFILE "whalehunt_1a.bas",1339
	RETURN
	ENDP
	;[1340] 	
	SRCFILE "whalehunt_1a.bas",1340
	;[1341] blank_char:		procedure
	SRCFILE "whalehunt_1a.bas",1341
	; BLANK_CHAR
Q52:	PROC
	BEGIN
	;[1342] 	if daytime = 0 then screen background_dawn,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1342
	MVI V47,R0
	TSTR R0
	BNE T501
	MVII #20,R0
	ADDI #Q21,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
T501:
	;[1343] 	if daytime = 1 then screen background,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1343
	MVI V47,R0
	CMPI #1,R0
	BNE T502
	MVII #20,R0
	ADDI #Q22,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
T502:
	;[1344] 	if daytime = 2 then screen background_dusk,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1344
	MVI V47,R0
	CMPI #2,R0
	BNE T503
	MVII #20,R0
	ADDI #Q23,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
T503:
	;[1345] 	if daytime = 3 then screen background_storm,20,20,20,11
	SRCFILE "whalehunt_1a.bas",1345
	MVI V47,R0
	CMPI #3,R0
	BNE T504
	MVII #20,R0
	ADDI #Q24,R0
	PSHR R0
	MVII #20,R0
	ADDI #512,R0
	PSHR R0
	MVII #20,R0
	PSHR R0
	MVII #11,R0
	PULR R1
	PULR R2
	PULR R3
	CALL CPYBLK
T504:
	;[1346] 	end
	SRCFILE "whalehunt_1a.bas",1346
	RETURN
	ENDP
	;[1347] 
	SRCFILE "whalehunt_1a.bas",1347
	;[1348] lightning:		procedure
	SRCFILE "whalehunt_1a.bas",1348
	; LIGHTNING
Q208:	PROC
	BEGIN
	;[1349] 	gosub hide_sprites 
	SRCFILE "whalehunt_1a.bas",1349
	CALL Q20
	;[1350] 	define 60,3,lightning_images
	SRCFILE "whalehunt_1a.bas",1350
	MVII #60,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q234,R0
	MVO R0,_gram_bitmap
	;[1351] 	wait
	SRCFILE "whalehunt_1a.bas",1351
	CALL _wait
	;[1352] 	play simple
	SRCFILE "whalehunt_1a.bas",1352
	MVII #1,R3
	MVO R3,_music_mode
	;[1353] 	play storm_sound
	SRCFILE "whalehunt_1a.bas",1353
	MVII #Q235,R0
	CALL _play_music
	;[1354] if storm_cnt = 30 then
	SRCFILE "whalehunt_1a.bas",1354
	MVI V50,R0
	CMPI #30,R0
	BNE T505
	;[1355] 	sprite 04, 85 + visible + zoomx2, 25 + zoomy2, spr62 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1355
	MVII #1621,R0
	MVO R0,_mobs+4
	MVII #281,R0
	MVO R0,_mobs+12
	MVII #2550,R0
	MVO R0,_mobs+20
	;[1356] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1356
	CALL Q236
	;[1357] 	sprite 04, 85 + visible + zoomx2, 25 + zoomy4, spr62 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1357
	MVII #1621,R0
	MVO R0,_mobs+4
	MVII #537,R0
	MVO R0,_mobs+12
	MVII #2550,R0
	MVO R0,_mobs+20
	;[1358] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1358
	CALL Q236
	;[1359] 	sprite 04, 85 + visible + zoomx2, 25 + zoomy8, spr62 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1359
	MVII #1621,R0
	MVO R0,_mobs+4
	MVII #793,R0
	MVO R0,_mobs+12
	MVII #2550,R0
	MVO R0,_mobs+20
	;[1360] 	'sprite 05, 40 + visible + zoomx2, 35 + zoomy2 + flipx, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1360
	;[1361] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1361
	CALL Q236
	;[1362] 	sprite 04, 85 + visible + zoomx2, 25 + zoomy4, spr62 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1362
	MVII #1621,R0
	MVO R0,_mobs+4
	MVII #537,R0
	MVO R0,_mobs+12
	MVII #2550,R0
	MVO R0,_mobs+20
	;[1363] 	'sprite 05, 40 + visible + zoomx2, 35 + zoomy4 + flipx, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1363
	;[1364] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1364
	CALL Q236
	;[1365] 	sprite 04, 85 + visible + zoomx2, 25 + zoomy8, spr62 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1365
	MVII #1621,R0
	MVO R0,_mobs+4
	MVII #793,R0
	MVO R0,_mobs+12
	MVII #2550,R0
	MVO R0,_mobs+20
	;[1366] 	sprite 05, 20 + visible + zoomx2, 35 + zoomy2 + flipx, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1366
	MVII #1556,R0
	MVO R0,_mobs+5
	MVII #1315,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1367] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1367
	CALL Q236
	;[1368] 	sprite 04, 85 + visible + zoomx2, 25 + zoomy4, spr62 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1368
	MVII #1621,R0
	MVO R0,_mobs+4
	MVII #537,R0
	MVO R0,_mobs+12
	MVII #2550,R0
	MVO R0,_mobs+20
	;[1369] 	sprite 05, 20 + visible + zoomx2, 35 + zoomy4 + flipx, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1369
	MVII #1556,R0
	MVO R0,_mobs+5
	MVII #1571,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1370] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1370
	CALL Q236
	;[1371] 	sprite 04, 85 + visible + zoomx2, 25 + zoomy2, spr62 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1371
	MVII #1621,R0
	MVO R0,_mobs+4
	MVII #281,R0
	MVO R0,_mobs+12
	MVII #2550,R0
	MVO R0,_mobs+20
	;[1372] 	sprite 05, 20 + visible + zoomx2, 35 + zoomy8 + flipx, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1372
	MVII #1556,R0
	MVO R0,_mobs+5
	MVII #1827,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1373] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1373
	CALL Q236
	;[1374] 	sprite 05, 20 + visible + zoomx2, 25 + zoomy4, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1374
	MVII #1556,R0
	MVO R0,_mobs+5
	MVII #537,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1375] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1375
	CALL Q236
	;[1376] 	sprite 05, 20 + visible + zoomx2, 35 + zoomy8 + flipx, spr61 + spr_yellow	
	SRCFILE "whalehunt_1a.bas",1376
	MVII #1556,R0
	MVO R0,_mobs+5
	MVII #1827,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1377] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1377
	CALL Q236
	;[1378] 	sprite 05, 20 + visible + zoomx2, 25 + zoomy4, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1378
	MVII #1556,R0
	MVO R0,_mobs+5
	MVII #537,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1379] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1379
	CALL Q236
	;[1380] 	sprite 05, 20 + visible + zoomx2, 35 + zoomy2 + flipx, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1380
	MVII #1556,R0
	MVO R0,_mobs+5
	MVII #1315,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1381] else
	SRCFILE "whalehunt_1a.bas",1381
	B T506
T505:
	;[1382] 	sprite 04, 40 + visible + zoomx2, 45 + zoomy2, spr60 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1382
	MVII #1576,R0
	MVO R0,_mobs+4
	MVII #301,R0
	MVO R0,_mobs+12
	MVII #2534,R0
	MVO R0,_mobs+20
	;[1383] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1383
	CALL Q236
	;[1384] 	sprite 04, 40 + visible + zoomx2, 45 + zoomy4, spr60 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1384
	MVII #1576,R0
	MVO R0,_mobs+4
	MVII #557,R0
	MVO R0,_mobs+12
	MVII #2534,R0
	MVO R0,_mobs+20
	;[1385] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1385
	CALL Q236
	;[1386] 	sprite 04, 40 + visible + zoomx2, 45 + zoomy8, spr60 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1386
	MVII #1576,R0
	MVO R0,_mobs+4
	MVII #813,R0
	MVO R0,_mobs+12
	MVII #2534,R0
	MVO R0,_mobs+20
	;[1387] 	sprite 05, 120 + visible + zoomx2, 20 + zoomy2, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1387
	MVII #1656,R0
	MVO R0,_mobs+5
	MVII #276,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1388] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1388
	CALL Q236
	;[1389] 	sprite 04, 40 + visible + zoomx2, 45 + zoomy4, spr60 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1389
	MVII #1576,R0
	MVO R0,_mobs+4
	MVII #557,R0
	MVO R0,_mobs+12
	MVII #2534,R0
	MVO R0,_mobs+20
	;[1390] 	sprite 05, 120 + visible + zoomx2, 20 + zoomy4, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1390
	MVII #1656,R0
	MVO R0,_mobs+5
	MVII #532,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1391] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1391
	CALL Q236
	;[1392] 	sprite 04, 40 + visible + zoomx2, 45 + zoomy8, spr60 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1392
	MVII #1576,R0
	MVO R0,_mobs+4
	MVII #813,R0
	MVO R0,_mobs+12
	MVII #2534,R0
	MVO R0,_mobs+20
	;[1393] 	sprite 05, 120 + visible + zoomx2, 20 + zoomy8, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1393
	MVII #1656,R0
	MVO R0,_mobs+5
	MVII #788,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1394] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1394
	CALL Q236
	;[1395] 	sprite 04, 40 + visible + zoomx2, 45 + zoomy4, spr60 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1395
	MVII #1576,R0
	MVO R0,_mobs+4
	MVII #557,R0
	MVO R0,_mobs+12
	MVII #2534,R0
	MVO R0,_mobs+20
	;[1396] 	sprite 05, 120 + visible + zoomx2, 20 + zoomy4, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1396
	MVII #1656,R0
	MVO R0,_mobs+5
	MVII #532,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1397] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1397
	CALL Q236
	;[1398] 	sprite 04, 40 + visible + zoomx2, 45 + zoomy2, spr60 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1398
	MVII #1576,R0
	MVO R0,_mobs+4
	MVII #301,R0
	MVO R0,_mobs+12
	MVII #2534,R0
	MVO R0,_mobs+20
	;[1399] 	sprite 05, 120 + visible + zoomx2, 20 + zoomy8, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1399
	MVII #1656,R0
	MVO R0,_mobs+5
	MVII #788,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1400] 	wait
	SRCFILE "whalehunt_1a.bas",1400
	CALL _wait
	;[1401] 	sprite 05, 120 + visible + zoomx2, 20 + zoomy4, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1401
	MVII #1656,R0
	MVO R0,_mobs+5
	MVII #532,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1402] 	gosub lightning_wait
	SRCFILE "whalehunt_1a.bas",1402
	CALL Q236
	;[1403] 	sprite 05, 120 + visible + zoomx2, 20 + zoomy2, spr61 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1403
	MVII #1656,R0
	MVO R0,_mobs+5
	MVII #276,R0
	MVO R0,_mobs+13
	MVII #2542,R0
	MVO R0,_mobs+21
	;[1404] end if
	SRCFILE "whalehunt_1a.bas",1404
T506:
	;[1405] 	wait
	SRCFILE "whalehunt_1a.bas",1405
	CALL _wait
	;[1406] 	sprite 04, behind
	SRCFILE "whalehunt_1a.bas",1406
	MVII #8192,R0
	MVO R0,_mobs+4
	;[1407] 	sprite 05, behind
	SRCFILE "whalehunt_1a.bas",1407
	MVO R0,_mobs+5
	;[1408] 	play off
	SRCFILE "whalehunt_1a.bas",1408
	CLRR R0
	CALL _play_music
	;[1409] 	end
	SRCFILE "whalehunt_1a.bas",1409
	RETURN
	ENDP
	;[1410] 
	SRCFILE "whalehunt_1a.bas",1410
	;[1411] lightning_wait:		procedure
	SRCFILE "whalehunt_1a.bas",1411
	; LIGHTNING_WAIT
Q236:	PROC
	BEGIN
	;[1412] 	for x = 1 to 3
	SRCFILE "whalehunt_1a.bas",1412
	MVII #1,R0
	MVO R0,V60
T507:
	;[1413] 		wait
	SRCFILE "whalehunt_1a.bas",1413
	CALL _wait
	;[1414] 	next x
	SRCFILE "whalehunt_1a.bas",1414
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMPI #3,R0
	BLE T507
	;[1415] 	end
	SRCFILE "whalehunt_1a.bas",1415
	RETURN
	ENDP
	;[1416] 
	SRCFILE "whalehunt_1a.bas",1416
	;[1417] 
	SRCFILE "whalehunt_1a.bas",1417
	;[1418] REM =============================WIN SCREEN & TALLY SCORE================================
	SRCFILE "whalehunt_1a.bas",1418
	;[1419] asm org $8040
	SRCFILE "whalehunt_1a.bas",1419
 org $8040
	;[1420] 
	SRCFILE "whalehunt_1a.bas",1420
	;[1421] draw_enemy_big:		procedure
	SRCFILE "whalehunt_1a.bas",1421
	; DRAW_ENEMY_BIG
Q110:	PROC
	BEGIN
	;[1422] 	if enemy = 0 then goto draw_whale_big
	SRCFILE "whalehunt_1a.bas",1422
	MVI V41,R0
	TSTR R0
	BEQ Q239
	;[1423] 	if enemy = 1 then goto draw_serpant_big
	SRCFILE "whalehunt_1a.bas",1423
	MVI V41,R0
	CMPI #1,R0
	BEQ Q240
	;[1424] 	if enemy = 2 then goto draw_squid_big
	SRCFILE "whalehunt_1a.bas",1424
	MVI V41,R0
	CMPI #2,R0
	BEQ Q241
	;[1425] 	if enemy = 3 then goto draw_crab_big
	SRCFILE "whalehunt_1a.bas",1425
	MVI V41,R0
	CMPI #3,R0
	BEQ Q242
	;[1426] 	goto draw_enemy_big_end
	SRCFILE "whalehunt_1a.bas",1426
	B Q243
	;[1427] 	
	SRCFILE "whalehunt_1a.bas",1427
	;[1428] draw_whale_big:	
	SRCFILE "whalehunt_1a.bas",1428
	; DRAW_WHALE_BIG
Q239:	;[1429] 	define 57,3,blood_1
	SRCFILE "whalehunt_1a.bas",1429
	MVII #57,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q57,R0
	MVO R0,_gram_bitmap
	;[1430] 	wait
	SRCFILE "whalehunt_1a.bas",1430
	CALL _wait
	;[1431] 	define 60,2,big_whale 
	SRCFILE "whalehunt_1a.bas",1431
	MVII #60,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q181,R0
	MVO R0,_gram_bitmap
	;[1432] 	if hit_cnt >= hit_total then define alternate 62,1,whale_face_dead else define alternate 62,1,whale_face 
	SRCFILE "whalehunt_1a.bas",1432
	MVI V28,R0
	CMP V29,R0
	BLT T512
	MVII #62,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q182,R0
	MVO R0,_gram2_bitmap
	B T513
T512:
	MVII #62,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q245,R0
	MVO R0,_gram2_bitmap
T513:
	;[1433] 	wait
	SRCFILE "whalehunt_1a.bas",1433
	CALL _wait
	;[1434] 	if hit_cnt = 1 then if enemy = 0 then sprite 00, whalex + 18 + visible, whaley - 3, spr57 + spr_red
	SRCFILE "whalehunt_1a.bas",1434
	MVI V28,R0
	CMPI #1,R0
	BNE T514
	MVI V41,R0
	TSTR R0
	BNE T515
	MVI V12,R0
	ADDI #530,R0
	MVO R0,_mobs
	MVI V13,R0
	SUBI #3,R0
	MVO R0,_mobs+8
	MVII #2506,R0
	MVO R0,_mobs+16
T515:
T514:
	;[1435] 	if hit_cnt >= 2 then if enemy = 0 then sprite 00, whalex + 18 + visible, whaley - 3, spr58 + spr_red
	SRCFILE "whalehunt_1a.bas",1435
	MVI V28,R0
	CMPI #2,R0
	BLT T516
	MVI V41,R0
	TSTR R0
	BNE T517
	MVI V12,R0
	ADDI #530,R0
	MVO R0,_mobs
	MVI V13,R0
	SUBI #3,R0
	MVO R0,_mobs+8
	MVII #2514,R0
	MVO R0,_mobs+16
T517:
T516:
	;[1436] 	sprite 05, whalex + hit + visible, whaley - 1 + zoomy2, spr60 + spr_white
	SRCFILE "whalehunt_1a.bas",1436
	MVI V12,R0
	ADDI #768,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+13
	MVII #2535,R0
	MVO R0,_mobs+21
	;[1437] 	sprite 06, whalex + 8 + hit + visible + zoomx2, whaley - 1 + zoomy2, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",1437
	MVI V12,R0
	ADDI #1800,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+14
	MVII #2543,R0
	MVO R0,_mobs+22
	;[1438] 	sprite 07, whalex + 24 + hit + visible, whaley - 1 + zoomy2 + flipx, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",1438
	MVI V12,R0
	ADDI #792,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #1279,R0
	MVO R0,_mobs+15
	MVII #2543,R0
	MVO R0,_mobs+23
	;[1439] 	sprite 04, whalex + 25 + hit + visible, whaley + 3, spr62 + spr_black
	SRCFILE "whalehunt_1a.bas",1439
	MVI V12,R0
	ADDI #793,R0
	MVO R0,_mobs+4
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+12
	MVII #2544,R0
	MVO R0,_mobs+20
	;[1440] 	if hit_cnt = 1 then sprite 00, whalex + 18 + visible, whaley - 3, spr57 + spr_red
	SRCFILE "whalehunt_1a.bas",1440
	MVI V28,R0
	CMPI #1,R0
	BNE T518
	MVI V12,R0
	ADDI #530,R0
	MVO R0,_mobs
	MVI V13,R0
	SUBI #3,R0
	MVO R0,_mobs+8
	MVII #2506,R0
	MVO R0,_mobs+16
T518:
	;[1441] 	if hit_cnt = 2 then sprite 00, whalex + 18 + visible, whaley - 3, spr58 + spr_red
	SRCFILE "whalehunt_1a.bas",1441
	MVI V28,R0
	CMPI #2,R0
	BNE T519
	MVI V12,R0
	ADDI #530,R0
	MVO R0,_mobs
	MVI V13,R0
	SUBI #3,R0
	MVO R0,_mobs+8
	MVII #2514,R0
	MVO R0,_mobs+16
T519:
	;[1442] 	'goto whale_move_map
	SRCFILE "whalehunt_1a.bas",1442
	;[1443] 	goto draw_enemy_big_end
	SRCFILE "whalehunt_1a.bas",1443
	B Q243
	;[1444] 
	SRCFILE "whalehunt_1a.bas",1444
	;[1445] draw_serpant_big:
	SRCFILE "whalehunt_1a.bas",1445
	; DRAW_SERPANT_BIG
Q240:	;[1446] 	define 57,1,serpant_horn
	SRCFILE "whalehunt_1a.bas",1446
	MVII #57,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q247,R0
	MVO R0,_gram_bitmap
	;[1447] 	define alternate 60,2,big_serpant
	SRCFILE "whalehunt_1a.bas",1447
	MVII #60,R0
	MVO R0,_gram2_target
	MVII #2,R0
	MVO R0,_gram2_total
	MVII #Q248,R0
	MVO R0,_gram2_bitmap
	;[1448] 	wait
	SRCFILE "whalehunt_1a.bas",1448
	CALL _wait
	;[1449] 	if hit_cnt >= hit_total then sprite 04, behind : define 62,1,whale_face_dead else define 62,1,serpant_eye 
	SRCFILE "whalehunt_1a.bas",1449
	MVI V28,R0
	CMP V29,R0
	BLT T520
	MVII #8192,R0
	MVO R0,_mobs+4
	MVII #62,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q182,R0
	MVO R0,_gram_bitmap
	B T521
T520:
	MVII #62,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q249,R0
	MVO R0,_gram_bitmap
T521:
	;[1450] 	wait
	SRCFILE "whalehunt_1a.bas",1450
	CALL _wait
	;[1451] 	sprite 06, whalex + hit + visible + zoomx2, whaley - 1 + zoomy2, spr60 + spr_green
	SRCFILE "whalehunt_1a.bas",1451
	MVI V12,R0
	ADDI #1792,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+14
	MVII #2533,R0
	MVO R0,_mobs+22
	;[1452] 	sprite 07, whalex + 16 + hit + visible, whaley - 1 + zoomy2, spr61 + spr_green
	SRCFILE "whalehunt_1a.bas",1452
	MVI V12,R0
	ADDI #784,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+15
	MVII #2541,R0
	MVO R0,_mobs+23
	;[1453] 	if hit_cnt >= hit_total then 
	SRCFILE "whalehunt_1a.bas",1453
	MVI V28,R0
	CMP V29,R0
	BLT T522
	;[1454] 		sprite 04, whalex + 18 + visible, whaley - 1 + flipy, spr62 + spr_black
	SRCFILE "whalehunt_1a.bas",1454
	MVI V12,R0
	ADDI #530,R0
	MVO R0,_mobs+4
	MVI V13,R0
	ADDI #2047,R0
	MVO R0,_mobs+12
	MVII #2544,R0
	MVO R0,_mobs+20
	;[1455] 	else
	SRCFILE "whalehunt_1a.bas",1455
	B T523
T522:
	;[1456] 		sprite 04, whalex + 17 + hit + visible, whaley - 1 + zoomy2, spr62 + spr_black
	SRCFILE "whalehunt_1a.bas",1456
	MVI V12,R0
	ADDI #785,R0
	MVO R0,_mobs+4
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+12
	MVII #2544,R0
	MVO R0,_mobs+20
	;[1457] 	end if
	SRCFILE "whalehunt_1a.bas",1457
T523:
	;[1458] 	sprite 05, whalex + 16 + visible, whaley - 3 + zoomy2, spr57 + spr_white
	SRCFILE "whalehunt_1a.bas",1458
	MVI V12,R0
	ADDI #528,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #253,R0
	MVO R0,_mobs+13
	MVII #2511,R0
	MVO R0,_mobs+21
	;[1459] 	'goto whale_move_map
	SRCFILE "whalehunt_1a.bas",1459
	;[1460] 	goto draw_enemy_big_end
	SRCFILE "whalehunt_1a.bas",1460
	B Q243
	;[1461] 	
	SRCFILE "whalehunt_1a.bas",1461
	;[1462] draw_squid_big:		
	SRCFILE "whalehunt_1a.bas",1462
	; DRAW_SQUID_BIG
Q241:	;[1463] 	define 57,1,squid_tentacle
	SRCFILE "whalehunt_1a.bas",1463
	MVII #57,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q251,R0
	MVO R0,_gram_bitmap
	;[1464] 	define alternate 60,2,big_squid 
	SRCFILE "whalehunt_1a.bas",1464
	MVII #60,R0
	MVO R0,_gram2_target
	MVII #2,R0
	MVO R0,_gram2_total
	MVII #Q252,R0
	MVO R0,_gram2_bitmap
	;[1465] 	wait
	SRCFILE "whalehunt_1a.bas",1465
	CALL _wait
	;[1466] 	if hit_cnt >= hit_total then sprite 00, behind : define 62,1,squid_face_dead else define 62,1,squid_eye 
	SRCFILE "whalehunt_1a.bas",1466
	MVI V28,R0
	CMP V29,R0
	BLT T524
	MVII #8192,R0
	MVO R0,_mobs
	MVII #62,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q253,R0
	MVO R0,_gram_bitmap
	B T525
T524:
	MVII #62,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q254,R0
	MVO R0,_gram_bitmap
T525:
	;[1467] 	wait
	SRCFILE "whalehunt_1a.bas",1467
	CALL _wait
	;[1468] 	sprite 04, whalex + hit + visible, whaley - 1 + zoomy2 + flipx, spr57 + spr_purple
	SRCFILE "whalehunt_1a.bas",1468
	MVI V12,R0
	ADDI #768,R0
	MVO R0,_mobs+4
	MVI V13,R0
	ADDI #1279,R0
	MVO R0,_mobs+12
	MVII #6607,R0
	MVO R0,_mobs+20
	;[1469] 	sprite 05, whalex + 8 + hit + visible, whaley - 1 + zoomy2, spr61 + spr_purple
	SRCFILE "whalehunt_1a.bas",1469
	MVI V12,R0
	ADDI #776,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+13
	MVII #6639,R0
	MVO R0,_mobs+21
	;[1470] 	sprite 07, whalex + 9 + hit + visible, whaley - 9 + zoomy2 + flipx, spr60 + spr_purple
	SRCFILE "whalehunt_1a.bas",1470
	MVI V12,R0
	ADDI #777,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #1271,R0
	MVO R0,_mobs+15
	MVII #6631,R0
	MVO R0,_mobs+23
	;[1471] 	sprite 06, whalex + 17 + hit + visible, whaley - 1 + zoomy2, spr57 + spr_purple
	SRCFILE "whalehunt_1a.bas",1471
	MVI V12,R0
	ADDI #785,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+14
	MVII #6607,R0
	MVO R0,_mobs+22
	;[1472] 	if hit_cnt >= hit_total then
	SRCFILE "whalehunt_1a.bas",1472
	MVI V28,R0
	CMP V29,R0
	BLT T526
	;[1473] 		sprite 00, whalex + 8 + visible, whaley + 3, spr62 + spr_black
	SRCFILE "whalehunt_1a.bas",1473
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs
	MVI V13,R0
	ADDI #3,R0
	MVO R0,_mobs+8
	MVII #2544,R0
	MVO R0,_mobs+16
	;[1474] 	else
	SRCFILE "whalehunt_1a.bas",1474
	B T527
T526:
	;[1475] 		sprite 00, whalex + 8 + visible, whaley - 2 + zoomy2, spr62 + spr_black
	SRCFILE "whalehunt_1a.bas",1475
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs
	MVI V13,R0
	ADDI #254,R0
	MVO R0,_mobs+8
	MVII #2544,R0
	MVO R0,_mobs+16
	;[1476] 	end if
	SRCFILE "whalehunt_1a.bas",1476
T527:
	;[1477] 	'goto whale_move_map
	SRCFILE "whalehunt_1a.bas",1477
	;[1478] 	goto draw_enemy_big_end
	SRCFILE "whalehunt_1a.bas",1478
	B Q243
	;[1479] 	
	SRCFILE "whalehunt_1a.bas",1479
	;[1480] draw_crab_big:
	SRCFILE "whalehunt_1a.bas",1480
	; DRAW_CRAB_BIG
Q242:	;[1481] 	if hit_cnt >= hit_total then 
	SRCFILE "whalehunt_1a.bas",1481
	MVI V28,R0
	CMP V29,R0
	BLT T528
	;[1482] 		define 57,2,crab_border
	SRCFILE "whalehunt_1a.bas",1482
	MVII #57,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q256,R0
	MVO R0,_gram_bitmap
	;[1483] 		define alternate 57,1, crab_face_dead 
	SRCFILE "whalehunt_1a.bas",1483
	MVII #57,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q257,R0
	MVO R0,_gram2_bitmap
	;[1484] 		wait
	SRCFILE "whalehunt_1a.bas",1484
	CALL _wait
	;[1485] 	else	
	SRCFILE "whalehunt_1a.bas",1485
	B T529
T528:
	;[1486] 		define 57,2,crab_border	'and crab_face
	SRCFILE "whalehunt_1a.bas",1486
	MVII #57,R0
	MVO R0,_gram_target
	MVII #2,R0
	MVO R0,_gram_total
	MVII #Q256,R0
	MVO R0,_gram_bitmap
	;[1487] 	end if
	SRCFILE "whalehunt_1a.bas",1487
T529:
	;[1488] 	define alternate 60,3,big_crab 
	SRCFILE "whalehunt_1a.bas",1488
	MVII #60,R0
	MVO R0,_gram2_target
	MVII #3,R0
	MVO R0,_gram2_total
	MVII #Q258,R0
	MVO R0,_gram2_bitmap
	;[1489] 	wait
	SRCFILE "whalehunt_1a.bas",1489
	CALL _wait
	;[1490] 	sprite 04, whalex + hit + visible, whaley - 8 + zoomy2, spr62 + spr_white
	SRCFILE "whalehunt_1a.bas",1490
	MVI V12,R0
	ADDI #768,R0
	MVO R0,_mobs+4
	MVI V13,R0
	ADDI #248,R0
	MVO R0,_mobs+12
	MVII #2551,R0
	MVO R0,_mobs+20
	;[1491] 	sprite 06, whalex + 8 + hit + visible, whaley - 1 + zoomy2, spr61 + spr_white
	SRCFILE "whalehunt_1a.bas",1491
	MVI V12,R0
	ADDI #776,R0
	MVO R0,_mobs+6
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+14
	MVII #2543,R0
	MVO R0,_mobs+22
	;[1492] 	sprite 07, whalex + hit + visible, whaley - 1 + zoomy2, spr60 + spr_white
	SRCFILE "whalehunt_1a.bas",1492
	MVI V12,R0
	ADDI #768,R0
	MVO R0,_mobs+7
	MVI V13,R0
	ADDI #255,R0
	MVO R0,_mobs+15
	MVII #2535,R0
	MVO R0,_mobs+23
	;[1493] 	sprite 05, whalex + 9 + visible, whaley + 1 + zoomy2, spr58 + spr_red
	SRCFILE "whalehunt_1a.bas",1493
	MVI V12,R0
	ADDI #521,R0
	MVO R0,_mobs+5
	MVI V13,R0
	ADDI #257,R0
	MVO R0,_mobs+13
	MVII #2514,R0
	MVO R0,_mobs+21
	;[1494] 	sprite 00, whalex + 8 + visible, whaley + zoomy2, spr57 + spr_black	
	SRCFILE "whalehunt_1a.bas",1494
	MVI V12,R0
	ADDI #520,R0
	MVO R0,_mobs
	MVI V13,R0
	ADDI #256,R0
	MVO R0,_mobs+8
	MVII #2504,R0
	MVO R0,_mobs+16
	;[1495] draw_enemy_big_end:
	SRCFILE "whalehunt_1a.bas",1495
	; DRAW_ENEMY_BIG_END
Q243:	;[1496] end
	SRCFILE "whalehunt_1a.bas",1496
	RETURN
	ENDP
	;[1497] 
	SRCFILE "whalehunt_1a.bas",1497
	;[1498] win_screen:
	SRCFILE "whalehunt_1a.bas",1498
	; WIN_SCREEN
Q260:	;[1499] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1499
	CALL Q20
	;[1500] 	cls
	SRCFILE "whalehunt_1a.bas",1500
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1501] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",1501
	CALL Q173
	;[1502] 	DEFINE 0,16,game_win_bitmaps_0
	SRCFILE "whalehunt_1a.bas",1502
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q261,R0
	MVO R0,_gram_bitmap
	;[1503] 	WAIT
	SRCFILE "whalehunt_1a.bas",1503
	CALL _wait
	;[1504] 	DEFINE 16,16,game_win_bitmaps_1
	SRCFILE "whalehunt_1a.bas",1504
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q262,R0
	MVO R0,_gram_bitmap
	;[1505] 	WAIT
	SRCFILE "whalehunt_1a.bas",1505
	CALL _wait
	;[1506] 	DEFINE 32,16,game_win_bitmaps_2
	SRCFILE "whalehunt_1a.bas",1506
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q263,R0
	MVO R0,_gram_bitmap
	;[1507] 	WAIT
	SRCFILE "whalehunt_1a.bas",1507
	CALL _wait
	;[1508] 	DEFINE 48,1,game_win_bitmaps_3
	SRCFILE "whalehunt_1a.bas",1508
	MVII #48,R0
	MVO R0,_gram_target
	MVII #1,R0
	MVO R0,_gram_total
	MVII #Q264,R0
	MVO R0,_gram_bitmap
	;[1509] 	wait
	SRCFILE "whalehunt_1a.bas",1509
	CALL _wait
	;[1510] 	define 50,3,tally_sprites
	SRCFILE "whalehunt_1a.bas",1510
	MVII #50,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q265,R0
	MVO R0,_gram_bitmap
	;[1511] 	define alternate 53,4,game_win_sprites
	SRCFILE "whalehunt_1a.bas",1511
	MVII #53,R0
	MVO R0,_gram2_target
	MVII #4,R0
	MVO R0,_gram2_total
	MVII #Q266,R0
	MVO R0,_gram2_bitmap
	;[1512] 	wait
	SRCFILE "whalehunt_1a.bas",1512
	CALL _wait
	;[1513] 	play simple
	SRCFILE "whalehunt_1a.bas",1513
	MVII #1,R3
	MVO R3,_music_mode
	;[1514] 	play win_song
	SRCFILE "whalehunt_1a.bas",1514
	MVII #Q267,R0
	CALL _play_music
	;[1515] 	screen game_win_cards
	SRCFILE "whalehunt_1a.bas",1515
	MVII #Q268,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1516] 	sprite 00, 101 + visible + zoomx2, 53 + zoomy2, spr50 + spr_yellow
	SRCFILE "whalehunt_1a.bas",1516
	MVII #1637,R0
	MVO R0,_mobs
	MVII #309,R0
	MVO R0,_mobs+8
	MVII #2454,R0
	MVO R0,_mobs+16
	;[1517] 	sprite 01, 99 + visible, 76, spr51 + spr_black
	SRCFILE "whalehunt_1a.bas",1517
	MVII #611,R0
	MVO R0,_mobs+1
	MVII #76,R0
	MVO R0,_mobs+9
	MVII #2456,R0
	MVO R0,_mobs+17
	;[1518] 	sprite 02, 109 + visible, 76 + flipx, spr51 + spr_black
	SRCFILE "whalehunt_1a.bas",1518
	MVII #621,R0
	MVO R0,_mobs+2
	MVII #1100,R0
	MVO R0,_mobs+10
	MVII #2456,R0
	MVO R0,_mobs+18
	;[1519] 	sprite 03, 104 + visible, 59 + flipx, spr52 + spr_orange
	SRCFILE "whalehunt_1a.bas",1519
	MVII #616,R0
	MVO R0,_mobs+3
	MVII #1083,R0
	MVO R0,_mobs+11
	MVII #6562,R0
	MVO R0,_mobs+19
	;[1520] 	sprite 04, 56 + visible, 52 + zoomy2, spr53 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",1520
	MVII #568,R0
	MVO R0,_mobs+4
	MVII #308,R0
	MVO R0,_mobs+12
	MVII #2476,R0
	MVO R0,_mobs+20
	;[1521] 	sprite 05, 96 + visible + zoomx2, 53 + zoomy2, spr54 + spr_darkgreen
	SRCFILE "whalehunt_1a.bas",1521
	MVII #1632,R0
	MVO R0,_mobs+5
	MVII #309,R0
	MVO R0,_mobs+13
	MVII #2484,R0
	MVO R0,_mobs+21
	;[1522] 	sprite 06, 91 + visible, 84, spr55 + spr_cyan
	SRCFILE "whalehunt_1a.bas",1522
	MVII #603,R0
	MVO R0,_mobs+6
	MVII #84,R0
	MVO R0,_mobs+14
	MVII #6585,R0
	MVO R0,_mobs+22
	;[1523] 	sprite 07, 150 + visible, 83 + zoomy2, spr56 + spr_orange
	SRCFILE "whalehunt_1a.bas",1523
	MVII #662,R0
	MVO R0,_mobs+7
	MVII #339,R0
	MVO R0,_mobs+15
	MVII #6594,R0
	MVO R0,_mobs+23
	;[1524] 
	SRCFILE "whalehunt_1a.bas",1524
	;[1525] 	PRINT AT 220 COLOR BG_BLUE, "    EMERSON 2015    "
	SRCFILE "whalehunt_1a.bas",1525
	MVII #732,R0
	MVO R0,_screen
	MVII #512,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
	;[1526] 	FOR Y = 1 TO 50
	SRCFILE "whalehunt_1a.bas",1526
	MVII #1,R0
	MVO R0,V67
T530:
	;[1527] 	   WAIT
	SRCFILE "whalehunt_1a.bas",1527
	CALL _wait
	;[1528] 	NEXT Y
	SRCFILE "whalehunt_1a.bas",1528
	MVI V67,R0
	INCR R0
	MVO R0,V67
	CMPI #50,R0
	BLE T530
	;[1529] 	PRINT COLOR BG_CYAN
	SRCFILE "whalehunt_1a.bas",1529
	MVII #4608,R0
	MVO R0,_color
	;[1530] 	FOR #new_score = 1000 TO 40 STEP - 20
	SRCFILE "whalehunt_1a.bas",1530
	MVII #1000,R0
	MVO R0,V5
T531:
	;[1531] 		X = #new_score - 900
	SRCFILE "whalehunt_1a.bas",1531
	MVI V5,R0
	SUBI #900,R0
	MVO R0,V60
	;[1532] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " ALAS! YOU HAVE"
	SRCFILE "whalehunt_1a.bas",1532
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T532
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #400,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	MVO R4,_screen
T532:
	;[1533] 		X = #new_score - 880
	SRCFILE "whalehunt_1a.bas",1533
	MVI V5,R0
	SUBI #880,R0
	MVO R0,V60
	;[1534] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " SUCCESSFULLY  "
	SRCFILE "whalehunt_1a.bas",1534
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T533
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T533:
	;[1535] 		X = #new_score - 860
	SRCFILE "whalehunt_1a.bas",1535
	MVI V5,R0
	SUBI #860,R0
	MVO R0,V60
	;[1536] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " HARVESTED AND "
	SRCFILE "whalehunt_1a.bas",1536
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T534
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	MVO R4,_screen
T534:
	;[1537] 		X = #new_score - 840
	SRCFILE "whalehunt_1a.bas",1537
	MVI V5,R0
	SUBI #840,R0
	MVO R0,V60
	;[1538] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " REFINED ENOUGH" 
	SRCFILE "whalehunt_1a.bas",1538
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T535
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #400,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	MVO R4,_screen
T535:
	;[1539] 		X = #new_score - 820
	SRCFILE "whalehunt_1a.bas",1539
	MVI V5,R0
	SUBI #820,R0
	MVO R0,V60
	;[1540] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " WHALES TO     "
	SRCFILE "whalehunt_1a.bas",1540
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T536
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #376,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO R4,_screen
T536:
	;[1541] 		X = #new_score - 800
	SRCFILE "whalehunt_1a.bas",1541
	MVI V5,R0
	SUBI #800,R0
	MVO R0,V60
	;[1542] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " SUSTAIN THE   "
	SRCFILE "whalehunt_1a.bas",1542
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T537
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T537:
	;[1543] 		X = #new_score - 780
	SRCFILE "whalehunt_1a.bas",1543
	MVI V5,R0
	SUBI #780,R0
	MVO R0,V60
	;[1544] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " DEVELOPMENT   "
	SRCFILE "whalehunt_1a.bas",1544
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T538
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T538:
	;[1545] 		X = #new_score - 760
	SRCFILE "whalehunt_1a.bas",1545
	MVI V5,R0
	SUBI #760,R0
	MVO R0,V60
	;[1546] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " OF MODERN     "
	SRCFILE "whalehunt_1a.bas",1546
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T539
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #376,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #304,R0
	MVO@ R0,R4
	XORI #360,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO R4,_screen
T539:
	;[1547] 		X = #new_score - 740
	SRCFILE "whalehunt_1a.bas",1547
	MVI V5,R0
	SUBI #740,R0
	MVO R0,V60
	;[1548] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " INDUSTRY IN   "
	SRCFILE "whalehunt_1a.bas",1548
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T540
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T540:
	;[1549] 		X = #new_score - 720
	SRCFILE "whalehunt_1a.bas",1549
	MVI V5,R0
	SUBI #720,R0
	MVO R0,V60
	;[1550] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " THE NEW WORLD!"
	SRCFILE "whalehunt_1a.bas",1550
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T541
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO R4,_screen
T541:
	;[1551] 		IF #new_score = 760 THEN PRINT at 60, "               "
	SRCFILE "whalehunt_1a.bas",1551
	MVI V5,R0
	CMPI #760,R0
	BNE T542
	MVII #572,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T542:
	;[1552] 		IF #new_score = 740 THEN PRINT at 40, "               "
	SRCFILE "whalehunt_1a.bas",1552
	MVI V5,R0
	CMPI #740,R0
	BNE T543
	MVII #552,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T543:
	;[1553] 		IF #new_score = 720 THEN PRINT at 20, "               "
	SRCFILE "whalehunt_1a.bas",1553
	MVI V5,R0
	CMPI #720,R0
	BNE T544
	MVII #532,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T544:
	;[1554] 		
	SRCFILE "whalehunt_1a.bas",1554
	;[1555] 		X = #new_score - 640
	SRCFILE "whalehunt_1a.bas",1555
	MVI V5,R0
	SUBI #640,R0
	MVO R0,V60
	;[1556] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " THE NOW       "
	SRCFILE "whalehunt_1a.bas",1556
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T545
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T545:
	;[1557] 		X = #new_score - 620
	SRCFILE "whalehunt_1a.bas",1557
	MVI V5,R0
	SUBI #620,R0
	MVO R0,V60
	;[1558] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " INDUSTRIOUS   "
	SRCFILE "whalehunt_1a.bas",1558
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T546
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T546:
	;[1559] 		X = #new_score - 600
	SRCFILE "whalehunt_1a.bas",1559
	MVI V5,R0
	SUBI #600,R0
	MVO R0,V60
	;[1560] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " COASTLINE IS  "
	SRCFILE "whalehunt_1a.bas",1560
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T547
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #280,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #112,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T547:
	;[1561] 		X = #new_score - 580
	SRCFILE "whalehunt_1a.bas",1561
	MVI V5,R0
	SUBI #580,R0
	MVO R0,V60
	;[1562] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " EQUIPPED WITH "
	SRCFILE "whalehunt_1a.bas",1562
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T548
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #160,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	MVO R4,_screen
T548:
	;[1563] 		X = #new_score - 560
	SRCFILE "whalehunt_1a.bas",1563
	MVI V5,R0
	SUBI #560,R0
	MVO R0,V60
	;[1564] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " THE LATEST IN "
	SRCFILE "whalehunt_1a.bas",1564
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T549
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #352,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	MVO R4,_screen
T549:
	;[1565] 		X = #new_score - 540
	SRCFILE "whalehunt_1a.bas",1565
	MVI V5,R0
	SUBI #540,R0
	MVO R0,V60
	;[1566] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " MANUFACTURING "
	SRCFILE "whalehunt_1a.bas",1566
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T550
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #360,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #312,R0
	MVO@ R0,R4
	MVO R4,_screen
T550:
	;[1567] 		X = #new_score - 520
	SRCFILE "whalehunt_1a.bas",1567
	MVI V5,R0
	SUBI #520,R0
	MVO R0,V60
	;[1568] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " TECHNOLOGIES, "
	SRCFILE "whalehunt_1a.bas",1568
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T551
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #112,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #504,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	MVO R4,_screen
T551:
	;[1569] 		X = #new_score - 500
	SRCFILE "whalehunt_1a.bas",1569
	MVI V5,R0
	SUBI #500,R0
	MVO R0,V60
	;[1570] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " POWERED BY THE"
	SRCFILE "whalehunt_1a.bas",1570
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T552
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #384,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #272,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	MVO R4,_screen
T552:
	;[1571] 		X = #new_score - 480
	SRCFILE "whalehunt_1a.bas",1571
	MVI V5,R0
	SUBI #480,R0
	MVO R0,V60
	;[1572] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " FUEL OF YOUR  "
	SRCFILE "whalehunt_1a.bas",1572
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T553
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #304,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #352,R0
	MVO@ R0,R4
	XORI #376,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #304,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #400,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T553:
	;[1573] 		X = #new_score - 460
	SRCFILE "whalehunt_1a.bas",1573
	MVI V5,R0
	SUBI #460,R0
	MVO R0,V60
	;[1574] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, "VALIENT EFFORT!"
	SRCFILE "whalehunt_1a.bas",1574
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T554
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #432,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	MVO R4,_screen
T554:
	;[1575] 		IF #new_score = 500 THEN PRINT at 60, "               "
	SRCFILE "whalehunt_1a.bas",1575
	MVI V5,R0
	CMPI #500,R0
	BNE T555
	MVII #572,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T555:
	;[1576] 		IF #new_score = 480 THEN PRINT at 40, "               "
	SRCFILE "whalehunt_1a.bas",1576
	MVI V5,R0
	CMPI #480,R0
	BNE T556
	MVII #552,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T556:
	;[1577] 		IF #new_score = 460 THEN PRINT at 20, "               "
	SRCFILE "whalehunt_1a.bas",1577
	MVI V5,R0
	CMPI #460,R0
	BNE T557
	MVII #532,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T557:
	;[1578] 		
	SRCFILE "whalehunt_1a.bas",1578
	;[1579] 		
	SRCFILE "whalehunt_1a.bas",1579
	;[1580] 		X = #new_score - 380
	SRCFILE "whalehunt_1a.bas",1580
	MVI V5,R0
	SUBI #380,R0
	MVO R0,V60
	;[1581] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " YOUR COURAGE  "
	SRCFILE "whalehunt_1a.bas",1581
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T558
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #400,R0
	MVO@ R0,R4
	XORI #280,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T558:
	;[1582] 		X = #new_score - 360
	SRCFILE "whalehunt_1a.bas",1582
	MVI V5,R0
	SUBI #360,R0
	MVO R0,V60
	;[1583] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " AND BRAVERY   "
	SRCFILE "whalehunt_1a.bas",1583
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T559
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #272,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T559:
	;[1584] 		X = #new_score - 340
	SRCFILE "whalehunt_1a.bas",1584
	MVI V5,R0
	SUBI #340,R0
	MVO R0,V60
	;[1585] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " HAS LEFT ITS  "
	SRCFILE "whalehunt_1a.bas",1585
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T560
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #352,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T560:
	;[1586] 		X = #new_score - 320
	SRCFILE "whalehunt_1a.bas",1586
	MVI V5,R0
	SUBI #320,R0
	MVO R0,V60
	;[1587] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " IMPACT IN THE "
	SRCFILE "whalehunt_1a.bas",1587
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T561
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO R4,_screen
T561:
	;[1588] 		X = #new_score - 300
	SRCFILE "whalehunt_1a.bas",1588
	MVI V5,R0
	SUBI #300,R0
	MVO R0,V60
	;[1589] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " HEART OF THE  "
	SRCFILE "whalehunt_1a.bas",1589
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T562
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #376,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #304,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T562:
	;[1590] 		X = #new_score - 280
	SRCFILE "whalehunt_1a.bas",1590
	MVI V5,R0
	SUBI #280,R0
	MVO R0,V60
	;[1591] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " DEVELOPING    "
	SRCFILE "whalehunt_1a.bas",1591
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T563
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #312,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T563:
	;[1592] 		X = #new_score - 260
	SRCFILE "whalehunt_1a.bas",1592
	MVI V5,R0
	SUBI #260,R0
	MVO R0,V60
	;[1593] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " WORLD, AND    "
	SRCFILE "whalehunt_1a.bas",1593
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T564
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T564:
	;[1594] 		X = #new_score - 240
	SRCFILE "whalehunt_1a.bas",1594
	MVI V5,R0
	SUBI #240,R0
	MVO R0,V60
	;[1595] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " THE NAME WYATT"
	SRCFILE "whalehunt_1a.bas",1595
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T565
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #112,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T565:
	;[1596] 		X = #new_score - 220
	SRCFILE "whalehunt_1a.bas",1596
	MVI V5,R0
	SUBI #220,R0
	MVO R0,V60
	;[1597] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, "KILLGALLIN WILL"
	SRCFILE "whalehunt_1a.bas",1597
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T566
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #344,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T566:
	;[1598] 		X = #new_score - 200
	SRCFILE "whalehunt_1a.bas",1598
	MVI V5,R0
	SUBI #200,R0
	MVO R0,V60
	;[1599] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " BE KNOWN IN   "
	SRCFILE "whalehunt_1a.bas",1599
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T567
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #272,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #344,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #328,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T567:
	;[1600] 		X = #new_score - 180
	SRCFILE "whalehunt_1a.bas",1600
	MVI V5,R0
	SUBI #180,R0
	MVO R0,V60
	;[1601] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " EVERY PORT AND"
	SRCFILE "whalehunt_1a.bas",1601
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T568
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #384,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	MVO R4,_screen
T568:
	;[1602] 		X = #new_score - 160
	SRCFILE "whalehunt_1a.bas",1602
	MVI V5,R0
	SUBI #160,R0
	MVO R0,V60
	;[1603] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " TAVERN...     "
	SRCFILE "whalehunt_1a.bas",1603
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T569
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #256,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #112,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO R4,_screen
T569:
	;[1604] 		IF #new_score = 200 THEN PRINT at 60, "               "
	SRCFILE "whalehunt_1a.bas",1604
	MVI V5,R0
	CMPI #200,R0
	BNE T570
	MVII #572,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T570:
	;[1605] 		IF #new_score = 180 THEN PRINT at 40, "               "
	SRCFILE "whalehunt_1a.bas",1605
	MVI V5,R0
	CMPI #180,R0
	BNE T571
	MVII #552,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T571:
	;[1606] 		IF #new_score = 160 THEN PRINT at 20, "               "
	SRCFILE "whalehunt_1a.bas",1606
	MVI V5,R0
	CMPI #160,R0
	BNE T572
	MVII #532,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T572:
	;[1607] 		
	SRCFILE "whalehunt_1a.bas",1607
	;[1608] 		X = #new_score - 80
	SRCFILE "whalehunt_1a.bas",1608
	MVI V5,R0
	SUBI #80,R0
	MVO R0,V60
	;[1609] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, "  FOR YOU ARE  "
	SRCFILE "whalehunt_1a.bas",1609
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T573
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #304,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #400,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T573:
	;[1610] 		X = #new_score - 60
	SRCFILE "whalehunt_1a.bas",1610
	MVI V5,R0
	SUBI #60,R0
	MVO R0,V60
	;[1611] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, "    A TRUE     "
	SRCFILE "whalehunt_1a.bas",1611
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T574
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #416,R0
	MVO@ R0,R4
	XORI #48,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #128,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO R4,_screen
T574:
	;[1612] 		X = #new_score - 40
	SRCFILE "whalehunt_1a.bas",1612
	MVI V5,R0
	SUBI #40,R0
	MVO R0,V60
	;[1613] 		IF x = 20 OR x = 40 OR x = 60 THEN PRINT AT X, " WHALE HUNTER! "	
	SRCFILE "whalehunt_1a.bas",1613
	MVI V60,R0
	CMPI #20,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V60,R1
	CMPI #40,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	MVI V60,R1
	CMPI #60,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	COMR R1
	ANDR R1,R0
	COMR R1
	XORR R1,R0
	BEQ T575
	MVI V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	XORI #440,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #320,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	MVO R4,_screen
T575:
	;[1614] 		IF #new_score = 80 THEN PRINT at 60, "               "
	SRCFILE "whalehunt_1a.bas",1614
	MVI V5,R0
	CMPI #80,R0
	BNE T576
	MVII #572,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T576:
	;[1615] 		IF #new_score = 60 THEN PRINT at 40, "               "
	SRCFILE "whalehunt_1a.bas",1615
	MVI V5,R0
	CMPI #60,R0
	BNE T577
	MVII #552,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T577:
	;[1616] 		IF #new_score = 40 THEN PRINT at 20, "               "
	SRCFILE "whalehunt_1a.bas",1616
	MVI V5,R0
	CMPI #40,R0
	BNE T578
	MVII #532,R0
	MVO R0,_screen
	MOVR R0,R4
	MVI _color,R0
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO@ R0,R4
	MVO@ R0,R4
	MVO@ R0,R4
	NOP
	MVO R4,_screen
T578:
	;[1617] 		IF x = 60 THEN cnt = 250 else cnt = 50
	SRCFILE "whalehunt_1a.bas",1617
	MVI V60,R0
	CMPI #60,R0
	BNE T579
	MVII #250,R0
	MVO R0,V54
	B T580
T579:
	MVII #50,R0
	MVO R0,V54
T580:
	;[1618] 		FOR X = 1 TO cnt
	SRCFILE "whalehunt_1a.bas",1618
	MVII #1,R0
	MVO R0,V60
T581:
	;[1619] 		   WAIT
	SRCFILE "whalehunt_1a.bas",1619
	CALL _wait
	;[1620] 		NEXT X
	SRCFILE "whalehunt_1a.bas",1620
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMP V54,R0
	BLE T581
	;[1621] 	NEXT #NEW_SCORE	
	SRCFILE "whalehunt_1a.bas",1621
	MVI V5,R0
	SUBI #20,R0
	MVO R0,V5
	CMPI #40,R0
	BGE T531
	;[1622] 	for cnt = 0 to 25
	SRCFILE "whalehunt_1a.bas",1622
	CLRR R0
	MVO R0,V54
T582:
	;[1623] 	   wait
	SRCFILE "whalehunt_1a.bas",1623
	CALL _wait
	;[1624] 	next cnt
	SRCFILE "whalehunt_1a.bas",1624
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #25,R0
	BLE T582
	;[1625] 	print at 45, "THE END"
	SRCFILE "whalehunt_1a.bas",1625
	MVII #557,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #416,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #296,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[1626] 	gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",1626
	CALL Q170
	;[1627] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1627
	CALL Q20
	;[1628] 	cls
	SRCFILE "whalehunt_1a.bas",1628
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1629] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",1629
	CALL Q173
	;[1630] 	goto reset
	SRCFILE "whalehunt_1a.bas",1630
	B Q3
	;[1631] 	
	SRCFILE "whalehunt_1a.bas",1631
	;[1632] game_win_sprites:
	SRCFILE "whalehunt_1a.bas",1632
	; GAME_WIN_SPRITES
Q266:	;[1633] 'whale ropes
	SRCFILE "whalehunt_1a.bas",1633
	;[1634] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1634
	;[1635] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1635
	DECLE 0
	;[1636] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",1636
	;[1637] 	bitmap "###....."
	SRCFILE "whalehunt_1a.bas",1637
	DECLE 57375
	;[1638] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1638
	;[1639] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1639
	DECLE 0
	;[1640] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1640
	;[1641] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1641
	DECLE 255
	;[1642] 'hand ropes
	SRCFILE "whalehunt_1a.bas",1642
	;[1643] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1643
	;[1644] 	bitmap "##......"
	SRCFILE "whalehunt_1a.bas",1644
	DECLE 49152
	;[1645] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",1645
	;[1646] 	bitmap "....##.."
	SRCFILE "whalehunt_1a.bas",1646
	DECLE 3120
	;[1647] 	bitmap "......#."
	SRCFILE "whalehunt_1a.bas",1647
	;[1648] 	bitmap ".......#"
	SRCFILE "whalehunt_1a.bas",1648
	DECLE 258
	;[1649] 	bitmap "###....."
	SRCFILE "whalehunt_1a.bas",1649
	;[1650] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1650
	DECLE 224
	;[1651] 'front boat sky
	SRCFILE "whalehunt_1a.bas",1651
	;[1652] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1652
	;[1653] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1653
	DECLE 0
	;[1654] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1654
	;[1655] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1655
	DECLE 0
	;[1656] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",1656
	;[1657] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",1657
	DECLE 1028
	;[1658] 	bitmap ".....##."
	SRCFILE "whalehunt_1a.bas",1658
	;[1659] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",1659
	DECLE 1798
	;[1660] 'back boat
	SRCFILE "whalehunt_1a.bas",1660
	;[1661] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",1661
	;[1662] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",1662
	DECLE 64764
	;[1663] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",1663
	;[1664] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",1664
	DECLE 63736
	;[1665] 	bitmap "####...."
	SRCFILE "whalehunt_1a.bas",1665
	;[1666] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1666
	DECLE 240
	;[1667] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1667
	;[1668] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1668
	DECLE 0
	;[1669] 
	SRCFILE "whalehunt_1a.bas",1669
	;[1670] 	' 49 bitmaps
	SRCFILE "whalehunt_1a.bas",1670
	;[1671] game_win_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",1671
	; GAME_WIN_BITMAPS_0
Q261:	;[1672] 	DATA $7F80,$BF3F,$BFBF,$A0A0
	SRCFILE "whalehunt_1a.bas",1672
	DECLE 32640
	DECLE 48959
	DECLE 49087
	DECLE 41120
	;[1673] 	DATA $FE01,$E5E4,$E5E5,$0505
	SRCFILE "whalehunt_1a.bas",1673
	DECLE 65025
	DECLE 58852
	DECLE 58853
	DECLE 1285
	;[1674] 	DATA $BFBF,$60A7,$6060,$BFA7
	SRCFILE "whalehunt_1a.bas",1674
	DECLE 49087
	DECLE 24743
	DECLE 24672
	DECLE 49063
	;[1675] 	DATA $FDFD,$06E5,$0606,$FDE5
	SRCFILE "whalehunt_1a.bas",1675
	DECLE 65021
	DECLE 1765
	DECLE 1542
	DECLE 64997
	;[1676] 	DATA $0000,$0000,$0000,$0703
	SRCFILE "whalehunt_1a.bas",1676
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1795
	;[1677] 	DATA $0000,$0000,$FF00,$FFFF
	SRCFILE "whalehunt_1a.bas",1677
	DECLE 0
	DECLE 0
	DECLE 65280
	DECLE 65535
	;[1678] 	DATA $0000,$0000,$E000,$FFFE
	SRCFILE "whalehunt_1a.bas",1678
	DECLE 0
	DECLE 0
	DECLE 57344
	DECLE 65534
	;[1679] 	DATA $0000,$0000,$3F00,$00C0
	SRCFILE "whalehunt_1a.bas",1679
	DECLE 0
	DECLE 0
	DECLE 16128
	DECLE 192
	;[1680] 	DATA $0000,$0000,$F00F,$0000
	SRCFILE "whalehunt_1a.bas",1680
	DECLE 0
	DECLE 0
	DECLE 61455
	DECLE 0
	;[1681] 	DATA $0000,$0000,$00FF,$0000
	SRCFILE "whalehunt_1a.bas",1681
	DECLE 0
	DECLE 0
	DECLE 255
	DECLE 0
	;[1682] 	DATA $0000,$0000,$FF00,$0000
	SRCFILE "whalehunt_1a.bas",1682
	DECLE 0
	DECLE 0
	DECLE 65280
	DECLE 0
	;[1683] 	DATA $A0B0,$A7A7,$30A0,$807F
	SRCFILE "whalehunt_1a.bas",1683
	DECLE 41136
	DECLE 42919
	DECLE 12448
	DECLE 32895
	;[1684] 	DATA $050D,$E5E5,$0C05,$01FE
	SRCFILE "whalehunt_1a.bas",1684
	DECLE 1293
	DECLE 58853
	DECLE 3077
	DECLE 510
	;[1685] 	DATA $0000,$0000,$0100,$0303
	SRCFILE "whalehunt_1a.bas",1685
	DECLE 0
	DECLE 0
	DECLE 256
	DECLE 771
	;[1686] 	DATA $1F0F,$7F3F,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",1686
	DECLE 7951
	DECLE 32575
	DECLE 65535
	DECLE 65535
	;[1687] 	DATA $0000,$0000,$0E01,$4030
	SRCFILE "whalehunt_1a.bas",1687
	DECLE 0
	DECLE 0
	DECLE 3585
	DECLE 16432
	;[1688] game_win_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",1688
	; GAME_WIN_BITMAPS_1
Q262:	;[1689] 	DATA $0000,$0300,$00FC,$0000
	SRCFILE "whalehunt_1a.bas",1689
	DECLE 0
	DECLE 768
	DECLE 252
	DECLE 0
	;[1690] 	DATA $0000,$F807,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1690
	DECLE 0
	DECLE 63495
	DECLE 0
	DECLE 0
	;[1691] 	DATA $E0C0,$F800,$FCFC,$FEFE
	SRCFILE "whalehunt_1a.bas",1691
	DECLE 57536
	DECLE 63488
	DECLE 64764
	DECLE 65278
	;[1692] 	DATA $FF00,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1692
	DECLE 65280
	DECLE 0
	DECLE 0
	DECLE 0
	;[1693] 	DATA $00FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1693
	DECLE 255
	DECLE 0
	DECLE 0
	DECLE 0
	;[1694] 	DATA $0FF0,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1694
	DECLE 4080
	DECLE 0
	DECLE 0
	DECLE 0
	;[1695] 	DATA $F800,$0007,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1695
	DECLE 63488
	DECLE 7
	DECLE 0
	DECLE 0
	;[1696] 	DATA $0000,$0000,$0C08,$0E0C
	SRCFILE "whalehunt_1a.bas",1696
	DECLE 0
	DECLE 0
	DECLE 3080
	DECLE 3596
	;[1697] 	DATA $0000,$7C00,$7C7C,$7C7C
	SRCFILE "whalehunt_1a.bas",1697
	DECLE 0
	DECLE 31744
	DECLE 31868
	DECLE 31868
	;[1698] 	DATA $0000,$0000,$E040,$6060
	SRCFILE "whalehunt_1a.bas",1698
	DECLE 0
	DECLE 0
	DECLE 57408
	DECLE 24672
	;[1699] 	DATA $0703,$0707,$0F0F,$0F0F
	SRCFILE "whalehunt_1a.bas",1699
	DECLE 1795
	DECLE 1799
	DECLE 3855
	DECLE 3855
	;[1700] 	DATA $FEFE,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",1700
	DECLE 65278
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[1701] 	DATA $0000,$0000,$0000,$0707
	SRCFILE "whalehunt_1a.bas",1701
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1799
	;[1702] 	DATA $0000,$0000,$0100,$8303
	SRCFILE "whalehunt_1a.bas",1702
	DECLE 0
	DECLE 0
	DECLE 256
	DECLE 33539
	;[1703] 	DATA $0000,$0000,$0000,$8080
	SRCFILE "whalehunt_1a.bas",1703
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 32896
	;[1704] 	DATA $0307,$0001,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1704
	DECLE 775
	DECLE 1
	DECLE 0
	DECLE 0
	;[1705] game_win_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",1705
	; GAME_WIN_BITMAPS_2
Q263:	;[1706] 	DATA $FF3C,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",1706
	DECLE 65340
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[1707] 	DATA $C0E0,$0080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1707
	DECLE 49376
	DECLE 128
	DECLE 0
	DECLE 0
	;[1708] 	DATA $0F0F,$0F0F,$0F0F,$070F
	SRCFILE "whalehunt_1a.bas",1708
	DECLE 3855
	DECLE 3855
	DECLE 3855
	DECLE 1807
	;[1709] 	DATA $0103,$0001,$0000,$8000
	SRCFILE "whalehunt_1a.bas",1709
	DECLE 259
	DECLE 1
	DECLE 0
	DECLE 32768
	;[1710] 	DATA $E7C3,$F7E7,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",1710
	DECLE 59331
	DECLE 63463
	DECLE 65535
	DECLE 65535
	;[1711] 	DATA $8080,$C0C0,$C0C0,$80C0
	SRCFILE "whalehunt_1a.bas",1711
	DECLE 32896
	DECLE 49344
	DECLE 49344
	DECLE 32960
	;[1712] 	DATA $0000,$0100,$0001,$0000
	SRCFILE "whalehunt_1a.bas",1712
	DECLE 0
	DECLE 256
	DECLE 1
	DECLE 0
	;[1713] 	DATA $FFFF,$E7E7,$C3C3,$00C3
	SRCFILE "whalehunt_1a.bas",1713
	DECLE 65535
	DECLE 59367
	DECLE 50115
	DECLE 195
	;[1714] 	DATA $0000,$8000,$0080,$0000
	SRCFILE "whalehunt_1a.bas",1714
	DECLE 0
	DECLE 32768
	DECLE 128
	DECLE 0
	;[1715] 	DATA $0707,$0303,$0001,$0000
	SRCFILE "whalehunt_1a.bas",1715
	DECLE 1799
	DECLE 771
	DECLE 1
	DECLE 0
	;[1716] 	DATA $FFFF,$FFFF,$FFFF,$1F7F
	SRCFILE "whalehunt_1a.bas",1716
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 8063
	;[1717] 	DATA $C181,$E7C3,$FFEF,$FFFF
	SRCFILE "whalehunt_1a.bas",1717
	DECLE 49537
	DECLE 59331
	DECLE 65519
	DECLE 65535
	;[1718] 	DATA $FFFF,$FFFF,$FEFF,$F8FC
	SRCFILE "whalehunt_1a.bas",1718
	DECLE 65535
	DECLE 65535
	DECLE 65279
	DECLE 63740
	;[1719] 	DATA $8080,$0080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1719
	DECLE 32896
	DECLE 128
	DECLE 0
	DECLE 0
	;[1720] 	DATA $0301,$0001,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1720
	DECLE 769
	DECLE 1
	DECLE 0
	DECLE 0
	;[1721] 	DATA $FFFF,$00FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1721
	DECLE 65535
	DECLE 255
	DECLE 0
	DECLE 0
	;[1722] game_win_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",1722
	; GAME_WIN_BITMAPS_3
Q264:	;[1723] 	DATA $FCF8,$00F8,$0000,$0000
	SRCFILE "whalehunt_1a.bas",1723
	DECLE 64760
	DECLE 248
	DECLE 0
	DECLE 0
	;[1724] 
	SRCFILE "whalehunt_1a.bas",1724
	;[1725] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",1725
	;[1726] game_win_cards:
	SRCFILE "whalehunt_1a.bas",1726
	; GAME_WIN_CARDS
Q268:	;[1727] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1727
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[1728] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[1729] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1729
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[1730] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$0804,$080C,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1730
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 2052
	DECLE 2060
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[1731] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$0814,$081C,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1731
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 2068
	DECLE 2076
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[1732] 	DATA $1200,$1200,$1A27,$1A2F,$1A2F,$1A37,$1200,$1A3C,$1A44,$1A4C,$1A54,$1200,$1200,$1200,$1200,$085C,$0864,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1732
	DECLE 4608
	DECLE 4608
	DECLE 6695
	DECLE 6703
	DECLE 6703
	DECLE 6711
	DECLE 4608
	DECLE 6716
	DECLE 6724
	DECLE 6732
	DECLE 6740
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 2140
	DECLE 2148
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[1733] 	DATA $1200,$1A6F,$1A77,$2E7C,$2E84,$2E8C,$1A97,$1A9C,$1AA4,$1AAC,$1AB4,$1ABA,$1AC6,$1ACA,$0804,$080C,$0804,$080C,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1733
	DECLE 4608
	DECLE 6767
	DECLE 6775
	DECLE 11900
	DECLE 11908
	DECLE 11916
	DECLE 6807
	DECLE 6812
	DECLE 6820
	DECLE 6828
	DECLE 6836
	DECLE 6842
	DECLE 6854
	DECLE 6858
	DECLE 2052
	DECLE 2060
	DECLE 2052
	DECLE 2060
	DECLE 4608
	DECLE 4608
	;[1734] 	DATA $1200,$1AD7,$2600,$2600,$2600,$2600,$1ADF,$1AE7,$1AEF,$1AF7,$1200,$1AFA,$1B02,$1B0A,$0814,$081C,$0814,$081C,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1734
	DECLE 4608
	DECLE 6871
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 6879
	DECLE 6887
	DECLE 6895
	DECLE 6903
	DECLE 4608
	DECLE 6906
	DECLE 6914
	DECLE 6922
	DECLE 2068
	DECLE 2076
	DECLE 2068
	DECLE 2076
	DECLE 4608
	DECLE 4608
	;[1735] 	DATA $1200,$1B17,$2600,$2600,$2600,$2600,$2600,$1B1F,$1B27,$1B2F,$1200,$1B37,$1B3F,$1B47,$085C,$0864,$085C,$0864,$1200,$1200
	SRCFILE "whalehunt_1a.bas",1735
	DECLE 4608
	DECLE 6935
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 6943
	DECLE 6951
	DECLE 6959
	DECLE 4608
	DECLE 6967
	DECLE 6975
	DECLE 6983
	DECLE 2140
	DECLE 2148
	DECLE 2140
	DECLE 2148
	DECLE 4608
	DECLE 4608
	;[1736] 	DATA $1200,$1B4F,$1B57,$2600,$2600,$2600,$2600,$1B5F,$1B67,$1B6F,$1B70,$1D78,$1D78,$1D78,$1D78,$1D78,$1D78,$1D78,$1B80,$1200
	SRCFILE "whalehunt_1a.bas",1736
	DECLE 4608
	DECLE 6991
	DECLE 6999
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7007
	DECLE 7015
	DECLE 7023
	DECLE 7024
	DECLE 7544
	DECLE 7544
	DECLE 7544
	DECLE 7544
	DECLE 7544
	DECLE 7544
	DECLE 7544
	DECLE 7040
	DECLE 4608
	;[1737] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",1737
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[1738] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",1738
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[1739] 
	SRCFILE "whalehunt_1a.bas",1739
	;[1740] enemy_attack:	procedure
	SRCFILE "whalehunt_1a.bas",1740
	; ENEMY_ATTACK
Q81:	PROC
	BEGIN
	;[1741] 	define 53,3,wave_sprites
	SRCFILE "whalehunt_1a.bas",1741
	MVII #53,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q276,R0
	MVO R0,_gram_bitmap
	;[1742] 	wait
	SRCFILE "whalehunt_1a.bas",1742
	CALL _wait
	;[1743] '	enemy_atk = rand / 63
	SRCFILE "whalehunt_1a.bas",1743
	;[1744] '	for x = 1 to enemy_atk
	SRCFILE "whalehunt_1a.bas",1744
	;[1745] 		for cnt = 1 to 7
	SRCFILE "whalehunt_1a.bas",1745
	MVII #1,R0
	MVO R0,V54
T583:
	;[1746] 			if #score < #new_score then #score = #score + 1 : gosub score
	SRCFILE "whalehunt_1a.bas",1746
	MVI V4,R0
	CMP V5,R0
	BGE T584
	INCR R0
	MVO R0,V4
	CALL Q27
T584:
	;[1747] 			if #score >= #next_score then #next_score = #next_score + 100 : if health < 4 then health = health + 1
	SRCFILE "whalehunt_1a.bas",1747
	MVI V4,R0
	CMP V6,R0
	BLT T585
	MVI V6,R0
	ADDI #100,R0
	MVO R0,V6
	MVI V8,R0
	CMPI #4,R0
	BGE T586
	INCR R0
	MVO R0,V8
T586:
T585:
	;[1748] 			whaley = whaley - 1
	SRCFILE "whalehunt_1a.bas",1748
	MVI V13,R0
	DECR R0
	MVO R0,V13
	;[1749] 			gosub draw_enemy_big
	SRCFILE "whalehunt_1a.bas",1749
	CALL Q110
	;[1750] 			if enemy > 0 then wait
	SRCFILE "whalehunt_1a.bas",1750
	MVI V41,R0
	CMPI #0,R0
	BLE T587
	CALL _wait
T587:
	;[1751] 		next cnt
	SRCFILE "whalehunt_1a.bas",1751
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #7,R0
	BLE T583
	;[1752] 		for cnt = 1 to 7
	SRCFILE "whalehunt_1a.bas",1752
	MVII #1,R0
	MVO R0,V54
T588:
	;[1753] 			if #score < #new_score then #score = #score + 1 : gosub score
	SRCFILE "whalehunt_1a.bas",1753
	MVI V4,R0
	CMP V5,R0
	BGE T589
	INCR R0
	MVO R0,V4
	CALL Q27
T589:
	;[1754] 			if #score >= #next_score then #next_score = #next_score + 100 : if health < 4 then health = health + 1
	SRCFILE "whalehunt_1a.bas",1754
	MVI V4,R0
	CMP V6,R0
	BLT T590
	MVI V6,R0
	ADDI #100,R0
	MVO R0,V6
	MVI V8,R0
	CMPI #4,R0
	BGE T591
	INCR R0
	MVO R0,V8
T591:
T590:
	;[1755] 			whaley = whaley + 1
	SRCFILE "whalehunt_1a.bas",1755
	MVI V13,R0
	INCR R0
	MVO R0,V13
	;[1756] 			gosub draw_enemy_big
	SRCFILE "whalehunt_1a.bas",1756
	CALL Q110
	;[1757] 			if enemy > 0 then wait
	SRCFILE "whalehunt_1a.bas",1757
	MVI V41,R0
	CMPI #0,R0
	BLE T592
	CALL _wait
T592:
	;[1758] 		next cnt
	SRCFILE "whalehunt_1a.bas",1758
	MVI V54,R0
	INCR R0
	MVO R0,V54
	CMPI #7,R0
	BLE T588
	;[1759] '		play simple
	SRCFILE "whalehunt_1a.bas",1759
	;[1760] '		play enemy_splash
	SRCFILE "whalehunt_1a.bas",1760
	;[1761] '		for cnt = 1 to 5
	SRCFILE "whalehunt_1a.bas",1761
	;[1762] '			wait
	SRCFILE "whalehunt_1a.bas",1762
	;[1763] '		next cnt
	SRCFILE "whalehunt_1a.bas",1763
	;[1764] '		play off
	SRCFILE "whalehunt_1a.bas",1764
	;[1765] '	next x
	SRCFILE "whalehunt_1a.bas",1765
	;[1766] 	
	SRCFILE "whalehunt_1a.bas",1766
	;[1767] 	wave_y = whaley + 4
	SRCFILE "whalehunt_1a.bas",1767
	MVI V13,R0
	ADDI #4,R0
	MVO R0,V46
	;[1768] 	for wave_x = whalex to 100
	SRCFILE "whalehunt_1a.bas",1768
	MVI V12,R0
	MVO R0,V45
T593:
	;[1769] 		if wave_x < 65 then
	SRCFILE "whalehunt_1a.bas",1769
	MVI V45,R0
	CMPI #65,R0
	BGE T594
	;[1770] 			sprite 02, wave_x +	13 + visible + zoomx2, wave_y, spr53 + spr_blue
	SRCFILE "whalehunt_1a.bas",1770
	ADDI #1549,R0
	MVO R0,_mobs+2
	MVI V46,R0
	MVO R0,_mobs+10
	MVII #2473,R0
	MVO R0,_mobs+18
	;[1771] 			sprite 03, wave_x + 15 + visible + zoomx2, wave_y - 4, spr54 + spr_blue
	SRCFILE "whalehunt_1a.bas",1771
	MVI V45,R0
	ADDI #1551,R0
	MVO R0,_mobs+3
	MVI V46,R0
	SUBI #4,R0
	MVO R0,_mobs+11
	MVII #2481,R0
	MVO R0,_mobs+19
	;[1772] 			sprite 01, wave_x + 15 + visible + zoomx2, wave_y - 2, spr55 + spr_white
	SRCFILE "whalehunt_1a.bas",1772
	MVI V45,R0
	ADDI #1551,R0
	MVO R0,_mobs+1
	MVI V46,R0
	SUBI #2,R0
	MVO R0,_mobs+9
	MVII #2495,R0
	MVO R0,_mobs+17
	;[1773] 		end if		
	SRCFILE "whalehunt_1a.bas",1773
T594:
	;[1774] 		if wave_x >= 70 then
	SRCFILE "whalehunt_1a.bas",1774
	MVI V45,R0
	CMPI #70,R0
	BLT T595
	;[1775] 			sprite 02, wave_x +	13 + visible + zoomx2, wave_y - 3 + zoomy2, spr53 + spr_blue
	SRCFILE "whalehunt_1a.bas",1775
	ADDI #1549,R0
	MVO R0,_mobs+2
	MVI V46,R0
	ADDI #253,R0
	MVO R0,_mobs+10
	MVII #2473,R0
	MVO R0,_mobs+18
	;[1776] 			sprite 03, wave_x + 15 + visible + zoomx2, wave_y - 11 + zoomy2, spr54 + spr_blue
	SRCFILE "whalehunt_1a.bas",1776
	MVI V45,R0
	ADDI #1551,R0
	MVO R0,_mobs+3
	MVI V46,R0
	ADDI #245,R0
	MVO R0,_mobs+11
	MVII #2481,R0
	MVO R0,_mobs+19
	;[1777] 			sprite 01, wave_x + 15 + visible + zoomx2, wave_y - 7 + zoomy2, spr55 + spr_white	
	SRCFILE "whalehunt_1a.bas",1777
	MVI V45,R0
	ADDI #1551,R0
	MVO R0,_mobs+1
	MVI V46,R0
	ADDI #249,R0
	MVO R0,_mobs+9
	MVII #2495,R0
	MVO R0,_mobs+17
	;[1778] 		end if
	SRCFILE "whalehunt_1a.bas",1778
T595:
	;[1779] 		wait
	SRCFILE "whalehunt_1a.bas",1779
	CALL _wait
	;[1780] 		play simple
	SRCFILE "whalehunt_1a.bas",1780
	MVII #1,R3
	MVO R3,_music_mode
	;[1781] 		play enemy_splash
	SRCFILE "whalehunt_1a.bas",1781
	MVII #Q277,R0
	CALL _play_music
	;[1782] 	next wave_x
	SRCFILE "whalehunt_1a.bas",1782
	MVI V45,R0
	INCR R0
	MVO R0,V45
	CMPI #100,R0
	BLE T593
	;[1783] 	play off
	SRCFILE "whalehunt_1a.bas",1783
	CLRR R0
	CALL _play_music
	;[1784] 	if enemy_atk = 4 then
	SRCFILE "whalehunt_1a.bas",1784
	MVI V42,R0
	CMPI #4,R0
	BNE T596
	;[1785] 		play simple
	SRCFILE "whalehunt_1a.bas",1785
	MVII #1,R3
	MVO R3,_music_mode
	;[1786] 		play enemy_hit
	SRCFILE "whalehunt_1a.bas",1786
	MVII #Q278,R0
	CALL _play_music
	;[1787] 		health = health - 1
	SRCFILE "whalehunt_1a.bas",1787
	MVI V8,R0
	DECR R0
	MVO R0,V8
	;[1788] 		goto enemy_attack_end
	SRCFILE "whalehunt_1a.bas",1788
	B Q279
	;[1789] 	end if
	SRCFILE "whalehunt_1a.bas",1789
T596:
	;[1790] 	if enemy_atk = 3 then 
	SRCFILE "whalehunt_1a.bas",1790
	MVI V42,R0
	CMPI #3,R0
	BNE T597
	;[1791] 		enemy_atk = rand / 127
	SRCFILE "whalehunt_1a.bas",1791
	MVI _rand,R0
	MVII #-1,R4
T598:
	INCR R4
	SUBI #127,R0
	BC T598
	MOVR R4,R0
	MVO R0,V42
	;[1792] 		if enemy_atk > 0 then 
	SRCFILE "whalehunt_1a.bas",1792
	MVI V42,R0
	CMPI #0,R0
	BLE T599
	;[1793] 			play simple
	SRCFILE "whalehunt_1a.bas",1793
	MVII #1,R3
	MVO R3,_music_mode
	;[1794] 			play enemy_hit
	SRCFILE "whalehunt_1a.bas",1794
	MVII #Q278,R0
	CALL _play_music
	;[1795] 			health = health - 1
	SRCFILE "whalehunt_1a.bas",1795
	MVI V8,R0
	DECR R0
	MVO R0,V8
	;[1796] 			goto enemy_attack_end
	SRCFILE "whalehunt_1a.bas",1796
	B Q279
	;[1797] 		end if
	SRCFILE "whalehunt_1a.bas",1797
T599:
	;[1798] 	end if
	SRCFILE "whalehunt_1a.bas",1798
T597:
	;[1799] 	enemy_atk = rand / 85
	SRCFILE "whalehunt_1a.bas",1799
	MVI _rand,R0
	MVII #-1,R4
T600:
	INCR R4
	SUBI #85,R0
	BC T600
	MOVR R4,R0
	MVO R0,V42
	;[1800] 	if enemy_atk = 1 then
	SRCFILE "whalehunt_1a.bas",1800
	MVI V42,R0
	CMPI #1,R0
	BNE T601
	;[1801] 		play simple
	SRCFILE "whalehunt_1a.bas",1801
	MVII #1,R3
	MVO R3,_music_mode
	;[1802] 		play enemy_hit
	SRCFILE "whalehunt_1a.bas",1802
	MVII #Q278,R0
	CALL _play_music
	;[1803] 		health = health - 1
	SRCFILE "whalehunt_1a.bas",1803
	MVI V8,R0
	DECR R0
	MVO R0,V8
	;[1804] 		goto enemy_attack_end
	SRCFILE "whalehunt_1a.bas",1804
	B Q279
	;[1805] 	end if
	SRCFILE "whalehunt_1a.bas",1805
T601:
	;[1806] 	play simple
	SRCFILE "whalehunt_1a.bas",1806
	MVII #1,R3
	MVO R3,_music_mode
	;[1807] 	play enemy_miss
	SRCFILE "whalehunt_1a.bas",1807
	MVII #Q280,R0
	CALL _play_music
	;[1808] enemy_attack_end:
	SRCFILE "whalehunt_1a.bas",1808
	; ENEMY_ATTACK_END
Q279:	;[1809] gosub score
	SRCFILE "whalehunt_1a.bas",1809
	CALL Q27
	;[1810] end	
	SRCFILE "whalehunt_1a.bas",1810
	RETURN
	ENDP
	;[1811] 
	SRCFILE "whalehunt_1a.bas",1811
	;[1812] wave_sprites:
	SRCFILE "whalehunt_1a.bas",1812
	; WAVE_SPRITES
Q276:	;[1813] 
	SRCFILE "whalehunt_1a.bas",1813
	;[1814] 	bitmap ".#####.."
	SRCFILE "whalehunt_1a.bas",1814
	;[1815] 	bitmap ".#####.."
	SRCFILE "whalehunt_1a.bas",1815
	DECLE 31868
	;[1816] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",1816
	;[1817] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",1817
	DECLE 65278
	;[1818] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1818
	;[1819] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1819
	DECLE 65535
	;[1820] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1820
	;[1821] 	bitmap "........"	
	SRCFILE "whalehunt_1a.bas",1821
	DECLE 0
	;[1822] 	
	SRCFILE "whalehunt_1a.bas",1822
	;[1823] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1823
	;[1824] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1824
	DECLE 0
	;[1825] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1825
	;[1826] 	bitmap "..#####."
	SRCFILE "whalehunt_1a.bas",1826
	DECLE 15872
	;[1827] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",1827
	;[1828] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",1828
	DECLE 32639
	;[1829] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",1829
	;[1830] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",1830
	DECLE 63736
	;[1831] 
	SRCFILE "whalehunt_1a.bas",1831
	;[1832] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1832
	;[1833] 	bitmap "...##.##"
	SRCFILE "whalehunt_1a.bas",1833
	DECLE 6912
	;[1834] 	bitmap "..#.###."
	SRCFILE "whalehunt_1a.bas",1834
	;[1835] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",1835
	DECLE 8238
	;[1836] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",1836
	;[1837] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",1837
	DECLE 16448
	;[1838] 	bitmap "........"		
	SRCFILE "whalehunt_1a.bas",1838
	;[1839] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1839
	DECLE 0
	;[1840] 	
	SRCFILE "whalehunt_1a.bas",1840
	;[1841] 'health_crate:		procedure
	SRCFILE "whalehunt_1a.bas",1841
	;[1842] 'crate_loop:
	SRCFILE "whalehunt_1a.bas",1842
	;[1843] '	if map = 1 then print at 160 + crate_map color bg_blue, " "
	SRCFILE "whalehunt_1a.bas",1843
	;[1844] '	wait
	SRCFILE "whalehunt_1a.bas",1844
	;[1845] '	crate_map = rand / 14
	SRCFILE "whalehunt_1a.bas",1845
	;[1846] '	if crate_map = 0 then goto crate_loop
	SRCFILE "whalehunt_1a.bas",1846
	;[1847] '	if crate_map = 19 then goto crate_loop
	SRCFILE "whalehunt_1a.bas",1847
	;[1848] '	crate_x = 4 + (crate_map * 8)
	SRCFILE "whalehunt_1a.bas",1848
	;[1849] '	if crate_x > player_x - 10 then if crate_x < player_x + 10 then goto crate_loop
	SRCFILE "whalehunt_1a.bas",1849
	;[1850] '	if map = 1 then print at 160 + crate_map color bg_blue, "\010"
	SRCFILE "whalehunt_1a.bas",1850
	;[1851] '	end
	SRCFILE "whalehunt_1a.bas",1851
	;[1852] 
	SRCFILE "whalehunt_1a.bas",1852
	;[1853] 'crate_sprites:
	SRCFILE "whalehunt_1a.bas",1853
	;[1854] '	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1854
	;[1855] '	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1855
	;[1856] '	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1856
	;[1857] '	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1857
	;[1858] '	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1858
	;[1859] '	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1859
	;[1860] '	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1860
	;[1861] '	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1861
	;[1862] '	
	SRCFILE "whalehunt_1a.bas",1862
	;[1863] '	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1863
	;[1864] '	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1864
	;[1865] '	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1865
	;[1866] '	bitmap ".#....#."
	SRCFILE "whalehunt_1a.bas",1866
	;[1867] '	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1867
	;[1868] '	bitmap ".#....#."
	SRCFILE "whalehunt_1a.bas",1868
	;[1869] '	bitmap "########"
	SRCFILE "whalehunt_1a.bas",1869
	;[1870] '	bitmap ".#....#."
	SRCFILE "whalehunt_1a.bas",1870
	;[1871] 
	SRCFILE "whalehunt_1a.bas",1871
	;[1872] asm org $2000
	SRCFILE "whalehunt_1a.bas",1872
 org $2000
	;[1873] tally_score:
	SRCFILE "whalehunt_1a.bas",1873
	; TALLY_SCORE
Q26:	;[1874] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1874
	CALL Q20
	;[1875] 	cls
	SRCFILE "whalehunt_1a.bas",1875
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1876] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",1876
	CALL Q173
	;[1877] 	DEFINE 0,16,tally_bitmaps_0
	SRCFILE "whalehunt_1a.bas",1877
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q284,R0
	MVO R0,_gram_bitmap
	;[1878] 	WAIT
	SRCFILE "whalehunt_1a.bas",1878
	CALL _wait
	;[1879] 	DEFINE 16,16,tally_bitmaps_1
	SRCFILE "whalehunt_1a.bas",1879
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q285,R0
	MVO R0,_gram_bitmap
	;[1880] 	WAIT
	SRCFILE "whalehunt_1a.bas",1880
	CALL _wait
	;[1881] 	DEFINE 32,10,tally_bitmaps_2
	SRCFILE "whalehunt_1a.bas",1881
	MVII #32,R0
	MVO R0,_gram_target
	MVII #10,R0
	MVO R0,_gram_total
	MVII #Q286,R0
	MVO R0,_gram_bitmap
	;[1882] 	WAIT
	SRCFILE "whalehunt_1a.bas",1882
	CALL _wait
	;[1883] 	define 43,7,tally_sprites
	SRCFILE "whalehunt_1a.bas",1883
	MVII #43,R0
	MVO R0,_gram_target
	MVII #7,R0
	MVO R0,_gram_total
	MVII #Q265,R0
	MVO R0,_gram_bitmap
	;[1884] 	define alternate 49,1,shadow_3
	SRCFILE "whalehunt_1a.bas",1884
	MVII #49,R0
	MVO R0,_gram2_target
	MVII #1,R0
	MVO R0,_gram2_total
	MVII #Q191,R0
	MVO R0,_gram2_bitmap
	;[1885] 	wait
	SRCFILE "whalehunt_1a.bas",1885
	CALL _wait
	;[1886] 
	SRCFILE "whalehunt_1a.bas",1886
	;[1887] 	y = 0
	SRCFILE "whalehunt_1a.bas",1887
	CLRR R0
	MVO R0,V67
	;[1888] 	#new_score = 0
	SRCFILE "whalehunt_1a.bas",1888
	MVO R0,V5
	;[1889] 	SCREEN tally_cards
	SRCFILE "whalehunt_1a.bas",1889
	MVII #Q287,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1890] 
	SRCFILE "whalehunt_1a.bas",1890
	;[1891] 	REM draw player
	SRCFILE "whalehunt_1a.bas",1891
	;[1892] 	sprite 00, 26 + visible + zoomx2, 73 + zoomy2, spr43 + spr_yellow	'hands
	SRCFILE "whalehunt_1a.bas",1892
	MVII #1562,R0
	MVO R0,_mobs
	MVII #329,R0
	MVO R0,_mobs+8
	MVII #2398,R0
	MVO R0,_mobs+16
	;[1893] 	sprite 01, 23 + visible, 84, spr44 + spr_black	
	SRCFILE "whalehunt_1a.bas",1893
	MVII #535,R0
	MVO R0,_mobs+1
	MVII #84,R0
	MVO R0,_mobs+9
	MVII #2400,R0
	MVO R0,_mobs+17
	;[1894] 	sprite 02, 33 + visible, 84 + flipx, spr44 + spr_black	'boots
	SRCFILE "whalehunt_1a.bas",1894
	MVII #545,R0
	MVO R0,_mobs+2
	MVII #1108,R0
	MVO R0,_mobs+10
	MVII #2400,R0
	MVO R0,_mobs+18
	;[1895] 	sprite 03, 28 + visible, 67, spr45 + spr_orange		'hair
	SRCFILE "whalehunt_1a.bas",1895
	MVII #540,R0
	MVO R0,_mobs+3
	MVII #67,R0
	MVO R0,_mobs+11
	MVII #6506,R0
	MVO R0,_mobs+19
	;[1896] 
	SRCFILE "whalehunt_1a.bas",1896
	;[1897] 	play simple
	SRCFILE "whalehunt_1a.bas",1897
	MVII #1,R3
	MVO R3,_music_mode
	;[1898] 	play score_sound
	SRCFILE "whalehunt_1a.bas",1898
	MVII #Q288,R0
	CALL _play_music
	;[1899] for #new_score = 0 to #score
	SRCFILE "whalehunt_1a.bas",1899
	CLRR R0
	MVO R0,V5
T602:
	;[1900] 	gosub tally_draw
	SRCFILE "whalehunt_1a.bas",1900
	CALL Q289
	;[1901] for x = 1 to 150	
	SRCFILE "whalehunt_1a.bas",1901
	MVII #1,R0
	MVO R0,V60
T603:
	;[1902] 	if #new_score < #score then #new_score = #new_score + 1
	SRCFILE "whalehunt_1a.bas",1902
	MVI V5,R0
	CMP V4,R0
	BGE T604
	INCR R0
	MVO R0,V5
T604:
	;[1903] 	print at 62 color fg_blue, <5>#new_score
	SRCFILE "whalehunt_1a.bas",1903
	MVII #574,R0
	MVO R0,_screen
	MVII #1,R0
	MVO R0,_color
	MVI V5,R0
	MVII #5,R2
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.z
	MVO R4,_screen
	;[1904] 	if y >= 33 then print at 21 color fg_white, "WHALER!" : goto tally_loop
	SRCFILE "whalehunt_1a.bas",1904
	MVI V67,R0
	CMPI #33,R0
	BLT T605
	MVII #533,R0
	MVO R0,_screen
	MVII #7,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #440,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	MVO R4,_screen
	B Q290
T605:
	;[1905] 	if y >= 22 then print at 21 color fg_white, "CAPTAIN" : goto tally_loop
	SRCFILE "whalehunt_1a.bas",1905
	MVI V67,R0
	CMPI #22,R0
	BLT T606
	MVII #533,R0
	MVO R0,_screen
	MVII #7,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #280,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #32,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	MVO R4,_screen
	B Q290
T606:
	;[1906] 	if y >= 11 then print at 21 color fg_white, "MARINER" else print at 21 color fg_white, "SKIPPER"	
	SRCFILE "whalehunt_1a.bas",1906
	MVI V67,R0
	CMPI #11,R0
	BLT T607
	MVII #533,R0
	MVO R0,_screen
	MVII #7,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #360,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO R4,_screen
	B T608
T607:
	MVII #533,R0
	MVO R0,_screen
	MVII #7,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #408,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO R4,_screen
T608:
	;[1907] tally_loop:
	SRCFILE "whalehunt_1a.bas",1907
	; TALLY_LOOP
Q290:	;[1908] next x
	SRCFILE "whalehunt_1a.bas",1908
	MVI V60,R0
	INCR R0
	MVO R0,V60
	CMPI #150,R0
	BLE T603
	;[1909] 'tally_end: 
	SRCFILE "whalehunt_1a.bas",1909
	;[1910] 	if y < 36 then y = y + 1
	SRCFILE "whalehunt_1a.bas",1910
	MVI V67,R0
	CMPI #36,R0
	BGE T609
	INCR R0
	MVO R0,V67
T609:
	;[1911] 	if #new_score >= #score then goto tally_loop_end
	SRCFILE "whalehunt_1a.bas",1911
	MVI V5,R0
	CMP V4,R0
	BGE Q292
	;[1912] next #new_score
	SRCFILE "whalehunt_1a.bas",1912
	MVI V5,R0
	INCR R0
	MVO R0,V5
	CMP V4,R0
	BLE T602
	;[1913] 
	SRCFILE "whalehunt_1a.bas",1913
	;[1914] tally_loop_end:	
	SRCFILE "whalehunt_1a.bas",1914
	; TALLY_LOOP_END
Q292:	;[1915] 
	SRCFILE "whalehunt_1a.bas",1915
	;[1916] play off
	SRCFILE "whalehunt_1a.bas",1916
	CLRR R0
	CALL _play_music
	;[1917] gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",1917
	CALL Q170
	;[1918] if level = 10 then if storm_flag = 0 then if timeout_flag = 0 then goto win_screen
	SRCFILE "whalehunt_1a.bas",1918
	MVI V9,R0
	CMPI #10,R0
	BNE T611
	MVI V57,R0
	TSTR R0
	BNE T612
	MVI V10,R0
	TSTR R0
	BEQ Q260
T612:
T611:
	;[1919] gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",1919
	CALL Q20
	;[1920] cls
	SRCFILE "whalehunt_1a.bas",1920
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1921] gosub transition_in
	SRCFILE "whalehunt_1a.bas",1921
	CALL Q173
	;[1922] goto reset
	SRCFILE "whalehunt_1a.bas",1922
	B Q3
	;[1923] 
	SRCFILE "whalehunt_1a.bas",1923
	;[1924] tally_draw: 	procedure
	SRCFILE "whalehunt_1a.bas",1924
	; TALLY_DRAW
Q289:	PROC
	BEGIN
	;[1925] 	if #score > 4982 then
	SRCFILE "whalehunt_1a.bas",1925
	MVI V4,R0
	CMPI #4982,R0
	BLE T614
	;[1926] 		sprite 04, 96 + visible + zoomx2, y + 11 + flipy, spr49 + spr_black
	SRCFILE "whalehunt_1a.bas",1926
	MVII #1632,R0
	MVO R0,_mobs+4
	MVI V67,R0
	ADDI #2059,R0
	MVO R0,_mobs+12
	MVII #2440,R0
	MVO R0,_mobs+20
	;[1927] 		sprite 07, 106 + visible + zoomx2, y + zoomy8, spr46 + spr_white	'big whale tail
	SRCFILE "whalehunt_1a.bas",1927
	MVII #1642,R0
	MVO R0,_mobs+7
	MVI V67,R0
	ADDI #768,R0
	MVO R0,_mobs+15
	MVII #2423,R0
	MVO R0,_mobs+23
	;[1928] 		sprite 05, 108 + visible + zoomx2, y + 16 + zoomy8, spr47 + spr_white	'big whale body
	SRCFILE "whalehunt_1a.bas",1928
	MVII #1644,R0
	MVO R0,_mobs+5
	MVI V67,R0
	ADDI #784,R0
	MVO R0,_mobs+13
	MVII #2431,R0
	MVO R0,_mobs+21
	;[1929] 		sprite 06, 108 + visible + zoomx2, y + 24 + zoomy8, spr48 + spr_white	'big whale head
	SRCFILE "whalehunt_1a.bas",1929
	MVII #1644,R0
	MVO R0,_mobs+6
	MVI V67,R0
	ADDI #792,R0
	MVO R0,_mobs+14
	MVII #2439,R0
	MVO R0,_mobs+22
	;[1930] 		goto tally_draw_end
	SRCFILE "whalehunt_1a.bas",1930
	B Q295
	;[1931] 	end if
	SRCFILE "whalehunt_1a.bas",1931
T614:
	;[1932] 	if #score > 3321 then
	SRCFILE "whalehunt_1a.bas",1932
	MVI V4,R0
	CMPI #3321,R0
	BLE T615
	;[1933] 		sprite 04, 96 + visible + zoomx2, y + 11 + flipy, spr49 + spr_black
	SRCFILE "whalehunt_1a.bas",1933
	MVII #1632,R0
	MVO R0,_mobs+4
	MVI V67,R0
	ADDI #2059,R0
	MVO R0,_mobs+12
	MVII #2440,R0
	MVO R0,_mobs+20
	;[1934] 		sprite 07, 106 + visible + zoomx2, y + 6 + zoomy4, spr46 + spr_white	'big whale tail
	SRCFILE "whalehunt_1a.bas",1934
	MVII #1642,R0
	MVO R0,_mobs+7
	MVI V67,R0
	ADDI #518,R0
	MVO R0,_mobs+15
	MVII #2423,R0
	MVO R0,_mobs+23
	;[1935] 		sprite 05, 108 + visible + zoomx2, y + 15 + zoomy4, spr47 + spr_white	'big whale body
	SRCFILE "whalehunt_1a.bas",1935
	MVII #1644,R0
	MVO R0,_mobs+5
	MVI V67,R0
	ADDI #527,R0
	MVO R0,_mobs+13
	MVII #2431,R0
	MVO R0,_mobs+21
	;[1936] 		sprite 06, 108 + visible + zoomx2, y + 26 + zoomy4, spr48 + spr_white	'big whale head
	SRCFILE "whalehunt_1a.bas",1936
	MVII #1644,R0
	MVO R0,_mobs+6
	MVI V67,R0
	ADDI #538,R0
	MVO R0,_mobs+14
	MVII #2439,R0
	MVO R0,_mobs+22
	;[1937] 		goto tally_draw_end
	SRCFILE "whalehunt_1a.bas",1937
	B Q295
	;[1938] 	end if
	SRCFILE "whalehunt_1a.bas",1938
T615:
	;[1939] 	if #score > 1660 then
	SRCFILE "whalehunt_1a.bas",1939
	MVI V4,R0
	CMPI #1660,R0
	BLE T616
	;[1940] 		sprite 04, 96 + visible + zoomx2, y + 11 + flipy, spr49 + spr_black
	SRCFILE "whalehunt_1a.bas",1940
	MVII #1632,R0
	MVO R0,_mobs+4
	MVI V67,R0
	ADDI #2059,R0
	MVO R0,_mobs+12
	MVII #2440,R0
	MVO R0,_mobs+20
	;[1941] 		sprite 07, 108 + visible, y + 9 + zoomy2, spr46 + spr_white		'med whale tail
	SRCFILE "whalehunt_1a.bas",1941
	MVII #620,R0
	MVO R0,_mobs+7
	MVI V67,R0
	ADDI #265,R0
	MVO R0,_mobs+15
	MVII #2423,R0
	MVO R0,_mobs+23
	;[1942] 		sprite 05, 110 + visible, y  + 17 + zoomy2, spr47 + spr_white	'med whale body
	SRCFILE "whalehunt_1a.bas",1942
	MVII #622,R0
	MVO R0,_mobs+5
	MVI V67,R0
	ADDI #273,R0
	MVO R0,_mobs+13
	MVII #2431,R0
	MVO R0,_mobs+21
	;[1943] 		sprite 06, 110 + visible, y + 25 + zoomy2, spr48 + spr_white	'med whale head
	SRCFILE "whalehunt_1a.bas",1943
	MVII #622,R0
	MVO R0,_mobs+6
	MVI V67,R0
	ADDI #281,R0
	MVO R0,_mobs+14
	MVII #2439,R0
	MVO R0,_mobs+22
	;[1944] 	else
	SRCFILE "whalehunt_1a.bas",1944
	B T617
T616:
	;[1945] 		sprite 04, 96 + visible + zoomx2, y + 11 + flipy, spr49 + spr_black
	SRCFILE "whalehunt_1a.bas",1945
	MVII #1632,R0
	MVO R0,_mobs+4
	MVI V67,R0
	ADDI #2059,R0
	MVO R0,_mobs+12
	MVII #2440,R0
	MVO R0,_mobs+20
	;[1946] 		sprite 07, 108 + visible, y + 10, spr46 + spr_white		'small whale tail
	SRCFILE "whalehunt_1a.bas",1946
	MVII #620,R0
	MVO R0,_mobs+7
	MVI V67,R0
	ADDI #10,R0
	MVO R0,_mobs+15
	MVII #2423,R0
	MVO R0,_mobs+23
	;[1947] 		sprite 05, 110 + visible, y + 14, spr47 + spr_white		'small whale body
	SRCFILE "whalehunt_1a.bas",1947
	MVII #622,R0
	MVO R0,_mobs+5
	MVI V67,R0
	ADDI #14,R0
	MVO R0,_mobs+13
	MVII #2431,R0
	MVO R0,_mobs+21
	;[1948] 		sprite 06, 110 + visible, y + 18, spr48 + spr_white		'small whale head	
	SRCFILE "whalehunt_1a.bas",1948
	MVII #622,R0
	MVO R0,_mobs+6
	MVI V67,R0
	ADDI #18,R0
	MVO R0,_mobs+14
	MVII #2439,R0
	MVO R0,_mobs+22
	;[1949] 	end if
	SRCFILE "whalehunt_1a.bas",1949
T617:
	;[1950] tally_draw_end:
	SRCFILE "whalehunt_1a.bas",1950
	; TALLY_DRAW_END
Q295:	;[1951] end
	SRCFILE "whalehunt_1a.bas",1951
	RETURN
	ENDP
	;[1952] 
	SRCFILE "whalehunt_1a.bas",1952
	;[1953] 
	SRCFILE "whalehunt_1a.bas",1953
	;[1954] tally_sprites:
	SRCFILE "whalehunt_1a.bas",1954
	; TALLY_SPRITES
Q265:	;[1955] 'hands
	SRCFILE "whalehunt_1a.bas",1955
	;[1956] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1956
	;[1957] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1957
	DECLE 0
	;[1958] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1958
	;[1959] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1959
	DECLE 0
	;[1960] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1960
	;[1961] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1961
	DECLE 0
	;[1962] 	bitmap "#....#.."
	SRCFILE "whalehunt_1a.bas",1962
	;[1963] 	bitmap "#....#.."
	SRCFILE "whalehunt_1a.bas",1963
	DECLE 33924
	;[1964] 'boots	
	SRCFILE "whalehunt_1a.bas",1964
	;[1965] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1965
	;[1966] 	bitmap "....###."
	SRCFILE "whalehunt_1a.bas",1966
	DECLE 3584
	;[1967] 	bitmap "....###."
	SRCFILE "whalehunt_1a.bas",1967
	;[1968] 	bitmap "....###."
	SRCFILE "whalehunt_1a.bas",1968
	DECLE 3598
	;[1969] 	bitmap "...####."
	SRCFILE "whalehunt_1a.bas",1969
	;[1970] 	bitmap "..#####."
	SRCFILE "whalehunt_1a.bas",1970
	DECLE 15902
	;[1971] 	bitmap ".######."
	SRCFILE "whalehunt_1a.bas",1971
	;[1972] 	bitmap ".###.##."
	SRCFILE "whalehunt_1a.bas",1972
	DECLE 30334
	;[1973] 'hair	
	SRCFILE "whalehunt_1a.bas",1973
	;[1974] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",1974
	;[1975] 	bitmap "..#...#."
	SRCFILE "whalehunt_1a.bas",1975
	DECLE 8704
	;[1976] 	bitmap "..##.##."
	SRCFILE "whalehunt_1a.bas",1976
	;[1977] 	bitmap "..#####."
	SRCFILE "whalehunt_1a.bas",1977
	DECLE 15926
	;[1978] 	bitmap "...###.."
	SRCFILE "whalehunt_1a.bas",1978
	;[1979] 	bitmap "...##..."
	SRCFILE "whalehunt_1a.bas",1979
	DECLE 6172
	;[1980] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",1980
	;[1981] 	bitmap ".##....."
	SRCFILE "whalehunt_1a.bas",1981
	DECLE 24624
	;[1982] 'whale tail
	SRCFILE "whalehunt_1a.bas",1982
	;[1983] 	bitmap "#...#..."
	SRCFILE "whalehunt_1a.bas",1983
	;[1984] 	bitmap "##.##..."
	SRCFILE "whalehunt_1a.bas",1984
	DECLE 55432
	;[1985] 	bitmap ".###...."
	SRCFILE "whalehunt_1a.bas",1985
	;[1986] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",1986
	DECLE 12400
	;[1987] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",1987
	;[1988] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",1988
	DECLE 14384
	;[1989] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",1989
	;[1990] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",1990
	DECLE 15416
	;[1991] 'whale body
	SRCFILE "whalehunt_1a.bas",1991
	;[1992] 	bitmap "####...."
	SRCFILE "whalehunt_1a.bas",1992
	;[1993] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",1993
	DECLE 63728
	;[1994] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",1994
	;[1995] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",1995
	DECLE 64760
	;[1996] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",1996
	;[1997] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",1997
	DECLE 65276
	;[1998] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",1998
	;[1999] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",1999
	DECLE 65278
	;[2000] 'whale head
	SRCFILE "whalehunt_1a.bas",2000
	;[2001] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2001
	;[2002] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2002
	DECLE 65278
	;[2003] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2003
	;[2004] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2004
	DECLE 65278
	;[2005] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",2005
	;[2006] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",2006
	DECLE 64764
	;[2007] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",2007
	;[2008] 	bitmap "###....."
	SRCFILE "whalehunt_1a.bas",2008
	DECLE 57592
	;[2009] 
	SRCFILE "whalehunt_1a.bas",2009
	;[2010] 
	SRCFILE "whalehunt_1a.bas",2010
	;[2011] 	' 42 bitmaps
	SRCFILE "whalehunt_1a.bas",2011
	;[2012] tally_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",2012
	; TALLY_BITMAPS_0
Q284:	;[2013] 	DATA $FFFF,$FCFF,$FCFE,$FCFE
	SRCFILE "whalehunt_1a.bas",2013
	DECLE 65535
	DECLE 64767
	DECLE 64766
	DECLE 64766
	;[2014] 	DATA $FFFF,$00FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2014
	DECLE 65535
	DECLE 255
	DECLE 0
	DECLE 0
	;[2015] 	DATA $FFFF,$3FFF,$3F7F,$3F7F
	SRCFILE "whalehunt_1a.bas",2015
	DECLE 65535
	DECLE 16383
	DECLE 16255
	DECLE 16255
	;[2016] 	DATA $C0C0,$C0C0,$C0C0,$C0C0
	SRCFILE "whalehunt_1a.bas",2016
	DECLE 49344
	DECLE 49344
	DECLE 49344
	DECLE 49344
	;[2017] 	DATA $C381,$FFE7,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2017
	DECLE 50049
	DECLE 65511
	DECLE 65535
	DECLE 65535
	;[2018] 	DATA $FCFE,$FCFE,$FCFE,$FCFE
	SRCFILE "whalehunt_1a.bas",2018
	DECLE 64766
	DECLE 64766
	DECLE 64766
	DECLE 64766
	;[2019] 	DATA $3F7F,$3F7F,$3F7F,$3F7F
	SRCFILE "whalehunt_1a.bas",2019
	DECLE 16255
	DECLE 16255
	DECLE 16255
	DECLE 16255
	;[2020] 	DATA $FFFF,$FFFF,$C0C0,$C0C0
	SRCFILE "whalehunt_1a.bas",2020
	DECLE 65535
	DECLE 65535
	DECLE 49344
	DECLE 49344
	;[2021] 	DATA $FFFF,$FFFF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2021
	DECLE 65535
	DECLE 65535
	DECLE 0
	DECLE 0
	;[2022] 	DATA $FFFF,$7EFF,$183C,$0000
	SRCFILE "whalehunt_1a.bas",2022
	DECLE 65535
	DECLE 32511
	DECLE 6204
	DECLE 0
	;[2023] 	DATA $FFFF,$FFFF,$FFFF,$3C7E
	SRCFILE "whalehunt_1a.bas",2023
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 15486
	;[2024] 	DATA $0018,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2024
	DECLE 24
	DECLE 0
	DECLE 0
	DECLE 0
	;[2025] 	DATA $FCFE,$FCFE,$FFFE,$FFFF
	SRCFILE "whalehunt_1a.bas",2025
	DECLE 64766
	DECLE 64766
	DECLE 65534
	DECLE 65535
	;[2026] 	DATA $0000,$0000,$FF00,$FFFF
	SRCFILE "whalehunt_1a.bas",2026
	DECLE 0
	DECLE 0
	DECLE 65280
	DECLE 65535
	;[2027] 	DATA $3F7F,$3F7F,$FF7F,$FFFF
	SRCFILE "whalehunt_1a.bas",2027
	DECLE 16255
	DECLE 16255
	DECLE 65407
	DECLE 65535
	;[2028] 	DATA $8100,$E7C3,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2028
	DECLE 33024
	DECLE 59331
	DECLE 65535
	DECLE 65535
	;[2029] tally_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",2029
	; TALLY_BITMAPS_1
Q285:	;[2030] 	DATA $0303,$0303,$0F0F,$0F0F
	SRCFILE "whalehunt_1a.bas",2030
	DECLE 771
	DECLE 771
	DECLE 3855
	DECLE 3855
	;[2031] 	DATA $F8F8,$F8F8,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2031
	DECLE 63736
	DECLE 63736
	DECLE 65535
	DECLE 65535
	;[2032] 	DATA $0000,$0000,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2032
	DECLE 0
	DECLE 0
	DECLE 65535
	DECLE 65535
	;[2033] 	DATA $0707,$0707,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2033
	DECLE 1799
	DECLE 1799
	DECLE 65535
	DECLE 65535
	;[2034] 	DATA $F0F0,$F0F0,$FCFC,$FCFC
	SRCFILE "whalehunt_1a.bas",2034
	DECLE 61680
	DECLE 61680
	DECLE 64764
	DECLE 64764
	;[2035] 	DATA $FFFF,$3C7E,$0018,$0000
	SRCFILE "whalehunt_1a.bas",2035
	DECLE 65535
	DECLE 15486
	DECLE 24
	DECLE 0
	;[2036] 	DATA $0F0F,$0F0F,$0F0F,$0F0F
	SRCFILE "whalehunt_1a.bas",2036
	DECLE 3855
	DECLE 3855
	DECLE 3855
	DECLE 3855
	;[2037] 	DATA $F8F8,$F8F8,$F8F8,$F8F8
	SRCFILE "whalehunt_1a.bas",2037
	DECLE 63736
	DECLE 63736
	DECLE 63736
	DECLE 63736
	;[2038] 	DATA $0000,$0700,$0707,$0707
	SRCFILE "whalehunt_1a.bas",2038
	DECLE 0
	DECLE 1792
	DECLE 1799
	DECLE 1799
	;[2039] 	DATA $0000,$C000,$C0C0,$C0C0
	SRCFILE "whalehunt_1a.bas",2039
	DECLE 0
	DECLE 49152
	DECLE 49344
	DECLE 49344
	;[2040] 	DATA $0707,$0707,$0707,$0707
	SRCFILE "whalehunt_1a.bas",2040
	DECLE 1799
	DECLE 1799
	DECLE 1799
	DECLE 1799
	;[2041] 	DATA $FCFC,$FCFC,$FCFC,$FCFC
	SRCFILE "whalehunt_1a.bas",2041
	DECLE 64764
	DECLE 64764
	DECLE 64764
	DECLE 64764
	;[2042] 	DATA $0000,$0300,$0303,$0303
	SRCFILE "whalehunt_1a.bas",2042
	DECLE 0
	DECLE 768
	DECLE 771
	DECLE 771
	;[2043] 	DATA $0000,$E000,$E0E0,$E0E0
	SRCFILE "whalehunt_1a.bas",2043
	DECLE 0
	DECLE 57344
	DECLE 57568
	DECLE 57568
	;[2044] 	DATA $0F03,$7F3F,$CFEF,$EFCF
	SRCFILE "whalehunt_1a.bas",2044
	DECLE 3843
	DECLE 32575
	DECLE 53231
	DECLE 61391
	;[2045] 	DATA $F0C0,$FEFC,$F3F7,$F7F3
	SRCFILE "whalehunt_1a.bas",2045
	DECLE 61632
	DECLE 65276
	DECLE 62455
	DECLE 63475
	;[2046] tally_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",2046
	; TALLY_BITMAPS_2
Q286:	;[2047] 	DATA $C0C0,$FFC0,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2047
	DECLE 49344
	DECLE 65472
	DECLE 65535
	DECLE 65535
	;[2048] 	DATA $0F03,$7F3F,$CFEF,$4FEF
	SRCFILE "whalehunt_1a.bas",2048
	DECLE 3843
	DECLE 32575
	DECLE 53231
	DECLE 20463
	;[2049] 	DATA $F0C0,$FEFC,$F3F7,$F2F7
	SRCFILE "whalehunt_1a.bas",2049
	DECLE 61632
	DECLE 65276
	DECLE 62455
	DECLE 62199
	;[2050] 	DATA $0000,$FF00,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2050
	DECLE 0
	DECLE 65280
	DECLE 65535
	DECLE 65535
	;[2051] 	DATA $0000,$0F00,$0F0F,$0F0F
	SRCFILE "whalehunt_1a.bas",2051
	DECLE 0
	DECLE 3840
	DECLE 3855
	DECLE 3855
	;[2052] 	DATA $0000,$F000,$F0F0,$F0F0
	SRCFILE "whalehunt_1a.bas",2052
	DECLE 0
	DECLE 61440
	DECLE 61680
	DECLE 61680
	;[2053] 	DATA $F0F0,$E1F1,$F3E3,$FFF3
	SRCFILE "whalehunt_1a.bas",2053
	DECLE 61680
	DECLE 57841
	DECLE 62435
	DECLE 65523
	;[2054] 	DATA $0F0F,$878F,$CFC7,$FFCF
	SRCFILE "whalehunt_1a.bas",2054
	DECLE 3855
	DECLE 34703
	DECLE 53191
	DECLE 65487
	;[2055] 	DATA $0000,$0000,$C300,$C3C3
	SRCFILE "whalehunt_1a.bas",2055
	DECLE 0
	DECLE 0
	DECLE 49920
	DECLE 50115
	;[2056] 	DATA $C3C3,$FFC3,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2056
	DECLE 50115
	DECLE 65475
	DECLE 65535
	DECLE 65535
	;[2057] 
	SRCFILE "whalehunt_1a.bas",2057
	;[2058] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",2058
	;[2059] tally_cards:
	SRCFILE "whalehunt_1a.bas",2059
	; TALLY_CARDS
Q287:	;[2060] 	DATA $0802,$080A,$080A,$080A,$080A,$080A,$080A,$080A,$0812,$1A1A,$1200,$1A25,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2060
	DECLE 2050
	DECLE 2058
	DECLE 2058
	DECLE 2058
	DECLE 2058
	DECLE 2058
	DECLE 2058
	DECLE 2058
	DECLE 2066
	DECLE 6682
	DECLE 4608
	DECLE 6693
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2061] 	DATA $082A,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0832,$1A3A,$1A42,$2C4D,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2061
	DECLE 2090
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2098
	DECLE 6714
	DECLE 6722
	DECLE 11341
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2062] 	DATA $082A,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0832,$1A1A,$1200,$1C56,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2062
	DECLE 2090
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2098
	DECLE 6682
	DECLE 4608
	DECLE 7254
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2063] 	DATA $082A,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0832,$1A3A,$1A42,$1C5E,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2063
	DECLE 2090
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2098
	DECLE 6714
	DECLE 6722
	DECLE 7262
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2064] 	DATA $0862,$086A,$086A,$086A,$086A,$086A,$086A,$086A,$0872,$1A1A,$1200,$1C7A,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2064
	DECLE 2146
	DECLE 2154
	DECLE 2154
	DECLE 2154
	DECLE 2154
	DECLE 2154
	DECLE 2154
	DECLE 2154
	DECLE 2162
	DECLE 6682
	DECLE 4608
	DECLE 7290
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2065] 	DATA $1A84,$1A8C,$1A94,$1A94,$1A94,$1A94,$1A94,$1A9C,$1AA4,$1200,$1200,$1AAA,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2065
	DECLE 6788
	DECLE 6796
	DECLE 6804
	DECLE 6804
	DECLE 6804
	DECLE 6804
	DECLE 6804
	DECLE 6812
	DECLE 6820
	DECLE 4608
	DECLE 4608
	DECLE 6826
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2066] 	DATA $1AB4,$18BC,$1000,$1000,$18C6,$18CE,$1000,$18D4,$1ADC,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2066
	DECLE 6836
	DECLE 6332
	DECLE 4096
	DECLE 4096
	DECLE 6342
	DECLE 6350
	DECLE 4096
	DECLE 6356
	DECLE 6876
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2067] 	DATA $1AB4,$18BC,$18E6,$18EE,$18F2,$18FA,$1000,$18D4,$1ADC,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2067
	DECLE 6836
	DECLE 6332
	DECLE 6374
	DECLE 6382
	DECLE 6386
	DECLE 6394
	DECLE 4096
	DECLE 6356
	DECLE 6876
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2068] 	DATA $1AB4,$1D04,$1D0A,$1D12,$1D1C,$1D24,$1D2C,$1D1C,$1ADC,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2068
	DECLE 6836
	DECLE 7428
	DECLE 7434
	DECLE 7442
	DECLE 7452
	DECLE 7460
	DECLE 7468
	DECLE 7452
	DECLE 6876
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2069] 	DATA $1AB4,$2000,$2F34,$2F3C,$2000,$2000,$2000,$2000,$1ADC,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2069
	DECLE 6836
	DECLE 8192
	DECLE 12084
	DECLE 12092
	DECLE 8192
	DECLE 8192
	DECLE 8192
	DECLE 8192
	DECLE 6876
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2070] 	DATA $1C69,$1D41,$1C69,$1D41,$1C69,$1D41,$1C69,$1D41,$1C69,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2070
	DECLE 7273
	DECLE 7489
	DECLE 7273
	DECLE 7489
	DECLE 7273
	DECLE 7489
	DECLE 7273
	DECLE 7489
	DECLE 7273
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2071] 	DATA $0200,$1D49,$0200,$1D49,$0200,$1D49,$0200,$1D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2071
	DECLE 512
	DECLE 7497
	DECLE 512
	DECLE 7497
	DECLE 512
	DECLE 7497
	DECLE 512
	DECLE 7497
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2072] 
	SRCFILE "whalehunt_1a.bas",2072
	;[2073] 	
	SRCFILE "whalehunt_1a.bas",2073
	;[2074] REM ====================================UPGRADE SCREEN CODE==========================================
	SRCFILE "whalehunt_1a.bas",2074
	;[2075] 'asm org $c040
	SRCFILE "whalehunt_1a.bas",2075
	;[2076] transition_in:	procedure
	SRCFILE "whalehunt_1a.bas",2076
	; TRANSITION_IN
Q173:	PROC
	BEGIN
	;[2077] 	xmin = 0
	SRCFILE "whalehunt_1a.bas",2077
	CLRR R0
	MVO R0,V72
	;[2078] 	xmax = 19
	SRCFILE "whalehunt_1a.bas",2078
	MVII #19,R0
	MVO R0,V73
	;[2079] 	inc = 19
	SRCFILE "whalehunt_1a.bas",2079
	MVO R0,V74
	;[2080] trans_in_loop:
	SRCFILE "whalehunt_1a.bas",2080
	; TRANS_IN_LOOP
Q303:	;[2081] 	for y = 0 to 11
	SRCFILE "whalehunt_1a.bas",2081
	CLRR R0
	MVO R0,V67
T618:
	;[2082] 	for x = xmin to xmax step inc
	SRCFILE "whalehunt_1a.bas",2082
	MVI V72,R0
	MVO R0,V60
T619:
	;[2083] 		if y < 10 then print at screenpos(x,y) color bg_cyan, "\000" else print at screenpos(x,y) color bg_blue, "\000"
	SRCFILE "whalehunt_1a.bas",2083
	MVI V67,R0
	CMPI #10,R0
	BGE T620
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	B T621
T620:
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #512,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T621:
	;[2084] 	next x
	SRCFILE "whalehunt_1a.bas",2084
	MVI V60,R0
	ADD V74,R0
	MVO R0,V60
	CMP V73,R0
	BLE T619
	;[2085] 	wait
	SRCFILE "whalehunt_1a.bas",2085
	CALL _wait
	;[2086] 	next y	
	SRCFILE "whalehunt_1a.bas",2086
	MVI V67,R0
	INCR R0
	MVO R0,V67
	CMPI #11,R0
	BLE T618
	;[2087] 	xmin = xmin + 1
	SRCFILE "whalehunt_1a.bas",2087
	MVI V72,R0
	INCR R0
	MVO R0,V72
	;[2088] 	xmax = xmax - 1
	SRCFILE "whalehunt_1a.bas",2088
	MVI V73,R0
	DECR R0
	MVO R0,V73
	;[2089] 	inc = inc - 2
	SRCFILE "whalehunt_1a.bas",2089
	MVI V74,R0
	SUBI #2,R0
	MVO R0,V74
	;[2090] 	for y = 11 to 0 step -1
	SRCFILE "whalehunt_1a.bas",2090
	MVII #11,R0
	MVO R0,V67
T622:
	;[2091] 	for x = xmin to xmax step inc
	SRCFILE "whalehunt_1a.bas",2091
	MVI V72,R0
	MVO R0,V60
T623:
	;[2092] 		if y < 10 then print at screenpos(x,y) color bg_cyan, "\000" else print at screenpos(x,y) color bg_blue, "\000"
	SRCFILE "whalehunt_1a.bas",2092
	MVI V67,R0
	CMPI #10,R0
	BGE T624
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	B T625
T624:
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #512,R0
	MVO R0,_color
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T625:
	;[2093] 	next x
	SRCFILE "whalehunt_1a.bas",2093
	MVI V60,R0
	ADD V74,R0
	MVO R0,V60
	CMP V73,R0
	BLE T623
	;[2094] 	wait
	SRCFILE "whalehunt_1a.bas",2094
	CALL _wait
	;[2095] 	next y
	SRCFILE "whalehunt_1a.bas",2095
	MVI V67,R0
	DECR R0
	MVO R0,V67
	CMPI #0,R0
	BGE T622
	;[2096] 	if xmin = 9 then goto trans_in_end else xmin = xmin + 1 : xmax = xmax - 1 : inc = inc - 2
	SRCFILE "whalehunt_1a.bas",2096
	MVI V72,R0
	CMPI #9,R0
	BNE T626
	B Q304
	B T627
T626:
	MVI V72,R0
	INCR R0
	MVO R0,V72
	MVI V73,R0
	DECR R0
	MVO R0,V73
	MVI V74,R0
	SUBI #2,R0
	MVO R0,V74
T627:
	;[2097] 	goto trans_in_loop
	SRCFILE "whalehunt_1a.bas",2097
	B Q303
	;[2098] trans_in_end:
	SRCFILE "whalehunt_1a.bas",2098
	; TRANS_IN_END
Q304:	;[2099] 	end
	SRCFILE "whalehunt_1a.bas",2099
	RETURN
	ENDP
	;[2100] 
	SRCFILE "whalehunt_1a.bas",2100
	;[2101] transition_out:	procedure
	SRCFILE "whalehunt_1a.bas",2101
	; TRANSITION_OUT
Q177:	PROC
	BEGIN
	;[2102] 	xmin = 9
	SRCFILE "whalehunt_1a.bas",2102
	MVII #9,R0
	MVO R0,V72
	;[2103] 	xmax = 10
	SRCFILE "whalehunt_1a.bas",2103
	MVII #10,R0
	MVO R0,V73
	;[2104] 	inc = 1
	SRCFILE "whalehunt_1a.bas",2104
	MVII #1,R0
	MVO R0,V74
	;[2105] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",2105
	CALL Q20
	;[2106] 	cls
	SRCFILE "whalehunt_1a.bas",2106
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[2107] 	if map = 0 then goto trans_out_loop
	SRCFILE "whalehunt_1a.bas",2107
	MVI V11,R0
	TSTR R0
	BEQ Q307
	;[2108] 	DEFINE 0,16,map_bitmaps_0
	SRCFILE "whalehunt_1a.bas",2108
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q143,R0
	MVO R0,_gram_bitmap
	;[2109] 	WAIT
	SRCFILE "whalehunt_1a.bas",2109
	CALL _wait
	;[2110] 	DEFINE 16,4,map_bitmaps_1
	SRCFILE "whalehunt_1a.bas",2110
	MVII #16,R0
	MVO R0,_gram_target
	MVII #4,R0
	MVO R0,_gram_total
	MVII #Q144,R0
	MVO R0,_gram_bitmap
	;[2111] 	define alternate 20,9,buildings
	SRCFILE "whalehunt_1a.bas",2111
	MVII #20,R0
	MVO R0,_gram2_target
	MVII #9,R0
	MVO R0,_gram2_total
	MVII #Q145,R0
	MVO R0,_gram2_bitmap
	;[2112] 	wait
	SRCFILE "whalehunt_1a.bas",2112
	CALL _wait
	;[2113] 	define 36,11,map_sprites
	SRCFILE "whalehunt_1a.bas",2113
	MVII #36,R0
	MVO R0,_gram_target
	MVII #11,R0
	MVO R0,_gram_total
	MVII #Q146,R0
	MVO R0,_gram_bitmap
	;[2114] 	wait
	SRCFILE "whalehunt_1a.bas",2114
	CALL _wait
	;[2115] trans_out_loop:
	SRCFILE "whalehunt_1a.bas",2115
	; TRANS_OUT_LOOP
Q307:	;[2116] 	for y = 11 to 0 step -1
	SRCFILE "whalehunt_1a.bas",2116
	MVII #11,R0
	MVO R0,V67
T629:
	;[2117] 	for x = xmin to xmax step inc
	SRCFILE "whalehunt_1a.bas",2117
	MVI V72,R0
	MVO R0,V60
T630:
	;[2118] 		if map = 0 then PRINT AT y * 20 + x, background_dawn(y * 20 + x) else PRINT AT y * 20 + x, map_cards(y * 20 + x)
	SRCFILE "whalehunt_1a.bas",2118
	MVI V11,R0
	TSTR R0
	BNE T631
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q21,R1
	MVI V67,R2
	MULT R2,R4,20
	ADD V60,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	B T632
T631:
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q147,R1
	MVI V67,R2
	MULT R2,R4,20
	ADD V60,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T632:
	;[2119] 		
	SRCFILE "whalehunt_1a.bas",2119
	;[2120] 	next x
	SRCFILE "whalehunt_1a.bas",2120
	MVI V60,R0
	ADD V74,R0
	MVO R0,V60
	CMP V73,R0
	BLE T630
	;[2121] 	wait
	SRCFILE "whalehunt_1a.bas",2121
	CALL _wait
	;[2122] 	next y	
	SRCFILE "whalehunt_1a.bas",2122
	MVI V67,R0
	DECR R0
	MVO R0,V67
	CMPI #0,R0
	BGE T629
	;[2123] 	xmin = xmin - 1
	SRCFILE "whalehunt_1a.bas",2123
	MVI V72,R0
	DECR R0
	MVO R0,V72
	;[2124] 	xmax = xmax + 1
	SRCFILE "whalehunt_1a.bas",2124
	MVI V73,R0
	INCR R0
	MVO R0,V73
	;[2125] 	inc = inc + 2
	SRCFILE "whalehunt_1a.bas",2125
	MVI V74,R0
	ADDI #2,R0
	MVO R0,V74
	;[2126] 	for y = 0 to 11
	SRCFILE "whalehunt_1a.bas",2126
	CLRR R0
	MVO R0,V67
T633:
	;[2127] 	for x = xmin to xmax step inc
	SRCFILE "whalehunt_1a.bas",2127
	MVI V72,R0
	MVO R0,V60
T634:
	;[2128] 		if map = 0 then PRINT AT y * 20 + x, background_dawn(y * 20 + x) else PRINT AT y * 20 + x, map_cards(y * 20 + x)
	SRCFILE "whalehunt_1a.bas",2128
	MVI V11,R0
	TSTR R0
	BNE T635
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q21,R1
	MVI V67,R2
	MULT R2,R4,20
	ADD V60,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	B T636
T635:
	MVI V67,R0
	MULT R0,R4,20
	ADD V60,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #Q147,R1
	MVI V67,R2
	MULT R2,R4,20
	ADD V60,R2
	ADDR R2,R1
	MVI@ R1,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T636:
	;[2129] 	next x
	SRCFILE "whalehunt_1a.bas",2129
	MVI V60,R0
	ADD V74,R0
	MVO R0,V60
	CMP V73,R0
	BLE T634
	;[2130] 	wait
	SRCFILE "whalehunt_1a.bas",2130
	CALL _wait
	;[2131] 	next y
	SRCFILE "whalehunt_1a.bas",2131
	MVI V67,R0
	INCR R0
	MVO R0,V67
	CMPI #11,R0
	BLE T633
	;[2132] 	if xmin = 0 then goto trans_out_end else xmin = xmin - 1 : xmax = xmax + 1 : inc = inc + 2
	SRCFILE "whalehunt_1a.bas",2132
	MVI V72,R0
	TSTR R0
	BNE T637
	B Q309
	B T638
T637:
	MVI V72,R0
	DECR R0
	MVO R0,V72
	MVI V73,R0
	INCR R0
	MVO R0,V73
	MVI V74,R0
	ADDI #2,R0
	MVO R0,V74
T638:
	;[2133] 	goto trans_out_loop
	SRCFILE "whalehunt_1a.bas",2133
	B Q307
	;[2134] trans_out_end:
	SRCFILE "whalehunt_1a.bas",2134
	; TRANS_OUT_END
Q309:	;[2135] 	if map = 1 then 
	SRCFILE "whalehunt_1a.bas",2135
	MVI V11,R0
	CMPI #1,R0
	BNE T639
	;[2136] 		sprite 05, 24 + hit + visible, 80 + zoomy2, spr41 + spr_orange	'left dock
	SRCFILE "whalehunt_1a.bas",2136
	MVII #792,R0
	MVO R0,_mobs+5
	MVII #336,R0
	MVO R0,_mobs+13
	MVII #6474,R0
	MVO R0,_mobs+21
	;[2137] 		sprite 06, 77 + hit + visible, 80 + zoomy2, spr41 + spr_orange	'middle dock
	SRCFILE "whalehunt_1a.bas",2137
	MVII #845,R0
	MVO R0,_mobs+6
	MVII #336,R0
	MVO R0,_mobs+14
	MVII #6474,R0
	MVO R0,_mobs+22
	;[2138] 		sprite 07, 147 + hit + visible, 79 + zoomy2, spr41 + spr_orange	'right dock
	SRCFILE "whalehunt_1a.bas",2138
	MVII #915,R0
	MVO R0,_mobs+7
	MVII #335,R0
	MVO R0,_mobs+15
	MVII #6474,R0
	MVO R0,_mobs+23
	;[2139] 	end if
	SRCFILE "whalehunt_1a.bas",2139
T639:
	;[2140] 	end
	SRCFILE "whalehunt_1a.bas",2140
	RETURN
	ENDP
	;[2141] 	
	SRCFILE "whalehunt_1a.bas",2141
	;[2142] harpoon_upgrade:	procedure
	SRCFILE "whalehunt_1a.bas",2142
	; HARPOON_UPGRADE
Q164:	PROC
	BEGIN
	;[2143] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",2143
	CALL Q20
	;[2144] 	cls
	SRCFILE "whalehunt_1a.bas",2144
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[2145] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",2145
	CALL Q173
	;[2146] 	DEFINE 0,16,harp_up_bitmaps_0
	SRCFILE "whalehunt_1a.bas",2146
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q312,R0
	MVO R0,_gram_bitmap
	;[2147] 	WAIT
	SRCFILE "whalehunt_1a.bas",2147
	CALL _wait
	;[2148] 	DEFINE 16,16,harp_up_bitmaps_1
	SRCFILE "whalehunt_1a.bas",2148
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q313,R0
	MVO R0,_gram_bitmap
	;[2149] 	WAIT
	SRCFILE "whalehunt_1a.bas",2149
	CALL _wait
	;[2150] 	DEFINE 32,16,harp_up_bitmaps_2
	SRCFILE "whalehunt_1a.bas",2150
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q314,R0
	MVO R0,_gram_bitmap
	;[2151] 	WAIT
	SRCFILE "whalehunt_1a.bas",2151
	CALL _wait
	;[2152] 	DEFINE 48,3,harp_up_bitmaps_3
	SRCFILE "whalehunt_1a.bas",2152
	MVII #48,R0
	MVO R0,_gram_target
	MVII #3,R0
	MVO R0,_gram_total
	MVII #Q315,R0
	MVO R0,_gram_bitmap
	;[2153] 	define alternate 62,2, title_harpoon
	SRCFILE "whalehunt_1a.bas",2153
	MVII #62,R0
	MVO R0,_gram2_target
	MVII #2,R0
	MVO R0,_gram2_total
	MVII #Q10,R0
	MVO R0,_gram2_bitmap
	;[2154] 	WAIT
	SRCFILE "whalehunt_1a.bas",2154
	CALL _wait
	;[2155] 	play simple
	SRCFILE "whalehunt_1a.bas",2155
	MVII #1,R3
	MVO R3,_music_mode
	;[2156] 	play upgrade_song
	SRCFILE "whalehunt_1a.bas",2156
	MVII #Q316,R0
	CALL _play_music
	;[2157] 	screen harp_up_cards
	SRCFILE "whalehunt_1a.bas",2157
	MVII #Q317,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[2158] 	
	SRCFILE "whalehunt_1a.bas",2158
	;[2159] 	sprite 01,		132 + visible, 6 + zoomy2, spr63 + spr_grey
	SRCFILE "whalehunt_1a.bas",2159
	MVII #644,R0
	MVO R0,_mobs+1
	MVII #262,R0
	MVO R0,_mobs+9
	MVII #6648,R0
	MVO R0,_mobs+17
	;[2160] 	SPRITE 02,		137 + VISIBLE + zoomx2, 12 + zoomy8, SPR62 + spr_orange
	SRCFILE "whalehunt_1a.bas",2160
	MVII #1673,R0
	MVO R0,_mobs+2
	MVII #780,R0
	MVO R0,_mobs+10
	MVII #6642,R0
	MVO R0,_mobs+18
	;[2161] 	wait
	SRCFILE "whalehunt_1a.bas",2161
	CALL _wait
	;[2162] 	
	SRCFILE "whalehunt_1a.bas",2162
	;[2163] 	print at screenpos(2,4) color bg_cyan, "YOU GOT"
	SRCFILE "whalehunt_1a.bas",2163
	MVII #594,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #456,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	XORI #312,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[2164] 	if harpoon = 2 then print at screenpos(1,5), "HARPOON 2!"
	SRCFILE "whalehunt_1a.bas",2164
	MVI V33,R0
	CMPI #2,R0
	BNE T640
	MVII #613,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #320,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	MVO R4,_screen
T640:
	;[2165] 	if harpoon = 3 then print at screenpos(1,5), "HARPOON 3!"
	SRCFILE "whalehunt_1a.bas",2165
	MVI V33,R0
	CMPI #3,R0
	BNE T641
	MVII #613,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #320,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #368,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	MVO R4,_screen
T641:
	;[2166] 	gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",2166
	CALL Q170
	;[2167] 	play off
	SRCFILE "whalehunt_1a.bas",2167
	CLRR R0
	CALL _play_music
	;[2168] 	kill_qty = kill_qty + 2
	SRCFILE "whalehunt_1a.bas",2168
	MVI V26,R0
	ADDI #2,R0
	MVO R0,V26
	;[2169] 	wait
	SRCFILE "whalehunt_1a.bas",2169
	CALL _wait
	;[2170] 	end
	SRCFILE "whalehunt_1a.bas",2170
	RETURN
	ENDP
	;[2171] 	
	SRCFILE "whalehunt_1a.bas",2171
	;[2172] 	
	SRCFILE "whalehunt_1a.bas",2172
	;[2173] pad_upgrade:	procedure
	SRCFILE "whalehunt_1a.bas",2173
	; PAD_UPGRADE
Q159:	PROC
	BEGIN
	;[2174] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",2174
	CALL Q20
	;[2175] 	cls
	SRCFILE "whalehunt_1a.bas",2175
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[2176] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",2176
	CALL Q173
	;[2177] 	DEFINE 0,16,pad_up_bitmaps_0
	SRCFILE "whalehunt_1a.bas",2177
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q319,R0
	MVO R0,_gram_bitmap
	;[2178] 	WAIT
	SRCFILE "whalehunt_1a.bas",2178
	CALL _wait
	;[2179] 	DEFINE 16,16,pad_up_bitmaps_1
	SRCFILE "whalehunt_1a.bas",2179
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q320,R0
	MVO R0,_gram_bitmap
	;[2180] 	WAIT
	SRCFILE "whalehunt_1a.bas",2180
	CALL _wait
	;[2181] 	DEFINE 32,16,pad_up_bitmaps_2
	SRCFILE "whalehunt_1a.bas",2181
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q321,R0
	MVO R0,_gram_bitmap
	;[2182] 	WAIT
	SRCFILE "whalehunt_1a.bas",2182
	CALL _wait
	;[2183] 	DEFINE 48,16,pad_up_bitmaps_3
	SRCFILE "whalehunt_1a.bas",2183
	MVII #48,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q322,R0
	MVO R0,_gram_bitmap
	;[2184] 	WAIT
	SRCFILE "whalehunt_1a.bas",2184
	CALL _wait
	;[2185] 	play simple
	SRCFILE "whalehunt_1a.bas",2185
	MVII #1,R3
	MVO R3,_music_mode
	;[2186] 	play upgrade_song
	SRCFILE "whalehunt_1a.bas",2186
	MVII #Q316,R0
	CALL _play_music
	;[2187] 	screen pad_up_cards
	SRCFILE "whalehunt_1a.bas",2187
	MVII #Q323,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[2188] 	
	SRCFILE "whalehunt_1a.bas",2188
	;[2189] 	print at screenpos(1,4) color bg_cyan, "YOU GOT"
	SRCFILE "whalehunt_1a.bas",2189
	MVII #593,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #456,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	XORI #312,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[2190] 	print at screenpos(1,5), "FASTER"
	SRCFILE "whalehunt_1a.bas",2190
	MVII #613,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #304,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[2191] 	print at screenpos(1,6), "PADDLES!"
	SRCFILE "whalehunt_1a.bas",2191
	MVII #633,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #384,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #40,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #400,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[2192] 	gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",2192
	CALL Q170
	;[2193] 	play off
	SRCFILE "whalehunt_1a.bas",2193
	CLRR R0
	CALL _play_music
	;[2194] 	kill_qty = kill_qty + 2
	SRCFILE "whalehunt_1a.bas",2194
	MVI V26,R0
	ADDI #2,R0
	MVO R0,V26
	;[2195] 	wait
	SRCFILE "whalehunt_1a.bas",2195
	CALL _wait
	;[2196] 	end
	SRCFILE "whalehunt_1a.bas",2196
	RETURN
	ENDP
	;[2197] 	
	SRCFILE "whalehunt_1a.bas",2197
	;[2198] 	
	SRCFILE "whalehunt_1a.bas",2198
	;[2199] flute_upgrade:	procedure
	SRCFILE "whalehunt_1a.bas",2199
	; FLUTE_UPGRADE
Q168:	PROC
	BEGIN
	;[2200] 	gosub hide_sprites
	SRCFILE "whalehunt_1a.bas",2200
	CALL Q20
	;[2201] 	cls
	SRCFILE "whalehunt_1a.bas",2201
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[2202] 	gosub transition_in
	SRCFILE "whalehunt_1a.bas",2202
	CALL Q173
	;[2203] 	DEFINE 0,16,flute_up_bitmaps_0
	SRCFILE "whalehunt_1a.bas",2203
	CLRR R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q325,R0
	MVO R0,_gram_bitmap
	;[2204] 	WAIT
	SRCFILE "whalehunt_1a.bas",2204
	CALL _wait
	;[2205] 	DEFINE 16,16,flute_up_bitmaps_1
	SRCFILE "whalehunt_1a.bas",2205
	MVII #16,R0
	MVO R0,_gram_target
	MVO R0,_gram_total
	MVII #Q326,R0
	MVO R0,_gram_bitmap
	;[2206] 	WAIT
	SRCFILE "whalehunt_1a.bas",2206
	CALL _wait
	;[2207] 	DEFINE 32,13,flute_up_bitmaps_2
	SRCFILE "whalehunt_1a.bas",2207
	MVII #32,R0
	MVO R0,_gram_target
	MVII #13,R0
	MVO R0,_gram_total
	MVII #Q327,R0
	MVO R0,_gram_bitmap
	;[2208] 	wait
	SRCFILE "whalehunt_1a.bas",2208
	CALL _wait
	;[2209] 	define 45,5,flute_sprites
	SRCFILE "whalehunt_1a.bas",2209
	MVII #45,R0
	MVO R0,_gram_target
	MVII #5,R0
	MVO R0,_gram_total
	MVII #Q328,R0
	MVO R0,_gram_bitmap
	;[2210] 	wait
	SRCFILE "whalehunt_1a.bas",2210
	CALL _wait
	;[2211] 	play simple
	SRCFILE "whalehunt_1a.bas",2211
	MVII #1,R3
	MVO R3,_music_mode
	;[2212] 	play upgrade_song
	SRCFILE "whalehunt_1a.bas",2212
	MVII #Q316,R0
	CALL _play_music
	;[2213] 	screen flute_up_cards
	SRCFILE "whalehunt_1a.bas",2213
	MVII #Q329,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[2214] 	wait
	SRCFILE "whalehunt_1a.bas",2214
	CALL _wait
	;[2215] 	sprite 00, 100 + visible + zoomx2, 24, spr49 + spr_black	'flute holes
	SRCFILE "whalehunt_1a.bas",2215
	MVII #1636,R0
	MVO R0,_mobs
	MVII #24,R0
	MVO R0,_mobs+8
	MVII #2440,R0
	MVO R0,_mobs+16
	;[2216] 	sprite 01, 104 + visible, 29, spr47 + spr_black 			'hand line
	SRCFILE "whalehunt_1a.bas",2216
	MVII #616,R0
	MVO R0,_mobs+1
	MVII #29,R0
	MVO R0,_mobs+9
	MVII #2424,R0
	MVO R0,_mobs+17
	;[2217] 	sprite 02, 112 + visible, 26, spr46 + spr_black				'shoulder line
	SRCFILE "whalehunt_1a.bas",2217
	MVII #624,R0
	MVO R0,_mobs+2
	MVII #26,R0
	MVO R0,_mobs+10
	MVII #2416,R0
	MVO R0,_mobs+18
	;[2218] 	sprite 03, 104 + visible, 24 + zoomy2, spr45 + spr_red		'shoulder
	SRCFILE "whalehunt_1a.bas",2218
	MVII #616,R0
	MVO R0,_mobs+3
	MVII #280,R0
	MVO R0,_mobs+11
	MVII #2410,R0
	MVO R0,_mobs+19
	;[2219] 	sprite 04, 72 + visible, 23 + zoomy2, spr48 + spr_grey		'flute
	SRCFILE "whalehunt_1a.bas",2219
	MVII #584,R0
	MVO R0,_mobs+4
	MVII #279,R0
	MVO R0,_mobs+12
	MVII #6528,R0
	MVO R0,_mobs+20
	;[2220] 	sprite 05, 88 + visible , 23 + zoomy2, spr48 + spr_grey
	SRCFILE "whalehunt_1a.bas",2220
	MVII #600,R0
	MVO R0,_mobs+5
	MVII #279,R0
	MVO R0,_mobs+13
	MVII #6528,R0
	MVO R0,_mobs+21
	;[2221] 	sprite 06, 92 + visible + zoomx2, 23 + zoomy2, spr48 + spr_grey
	SRCFILE "whalehunt_1a.bas",2221
	MVII #1628,R0
	MVO R0,_mobs+6
	MVII #279,R0
	MVO R0,_mobs+14
	MVII #6528,R0
	MVO R0,_mobs+22
	;[2222] 	sprite 07, 104 + visible + zoomx2, 23 + zoomy2, spr48 + spr_grey
	SRCFILE "whalehunt_1a.bas",2222
	MVII #1640,R0
	MVO R0,_mobs+7
	MVII #279,R0
	MVO R0,_mobs+15
	MVII #6528,R0
	MVO R0,_mobs+23
	;[2223] 	print at screenpos(1,4) color bg_cyan, "YOU GOT"
	SRCFILE "whalehunt_1a.bas",2223
	MVII #593,R0
	MVO R0,_screen
	MVII #4608,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #456,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #424,R0
	MVO@ R0,R4
	XORI #312,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #216,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[2224] 	print at screenpos(2,5), "WIND"
	SRCFILE "whalehunt_1a.bas",2224
	MVII #614,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #440,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[2225] 	print at screenpos(1,6), "FLUTE!"
	SRCFILE "whalehunt_1a.bas",2225
	MVII #633,R0
	MVO R0,_screen
	MOVR R0,R4
	MVII #304,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #136,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[2226] 	gosub upgrade_end
	SRCFILE "whalehunt_1a.bas",2226
	CALL Q170
	;[2227] 	play off
	SRCFILE "whalehunt_1a.bas",2227
	CLRR R0
	CALL _play_music
	;[2228] 	kill_qty = kill_qty + 2
	SRCFILE "whalehunt_1a.bas",2228
	MVI V26,R0
	ADDI #2,R0
	MVO R0,V26
	;[2229] 	wait
	SRCFILE "whalehunt_1a.bas",2229
	CALL _wait
	;[2230] 	end
	SRCFILE "whalehunt_1a.bas",2230
	RETURN
	ENDP
	;[2231] 
	SRCFILE "whalehunt_1a.bas",2231
	;[2232] 	
	SRCFILE "whalehunt_1a.bas",2232
	;[2233] upgrade_end: 	procedure
	SRCFILE "whalehunt_1a.bas",2233
	; UPGRADE_END
Q170:	PROC
	BEGIN
	;[2234] 	gosub cont1wait
	SRCFILE "whalehunt_1a.bas",2234
	CALL Q13
	;[2235] 	gosub cont1pause
	SRCFILE "whalehunt_1a.bas",2235
	CALL Q49
	;[2236] 	end	
	SRCFILE "whalehunt_1a.bas",2236
	RETURN
	ENDP
	;[2237] 	
	SRCFILE "whalehunt_1a.bas",2237
	;[2238] 	
	SRCFILE "whalehunt_1a.bas",2238
	;[2239] 
	SRCFILE "whalehunt_1a.bas",2239
	;[2240] 
	SRCFILE "whalehunt_1a.bas",2240
	;[2241] REM =======================================SPRITE DATA==================================	
	SRCFILE "whalehunt_1a.bas",2241
	;[2242] 
	SRCFILE "whalehunt_1a.bas",2242
	;[2243] asm org $7800
	SRCFILE "whalehunt_1a.bas",2243
 org $7800
	;[2244] small_whale:
	SRCFILE "whalehunt_1a.bas",2244
	; SMALL_WHALE
Q119:	;[2245] 	DATA $0000,$0000,$0000,$1800
	SRCFILE "whalehunt_1a.bas",2245
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 6144
	;[2246] 	DATA $0000,$0000,$0000,$FF7E
	SRCFILE "whalehunt_1a.bas",2246
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65406
	;[2247] med_whale:
	SRCFILE "whalehunt_1a.bas",2247
	; MED_WHALE
Q132:	;[2248] 	DATA $0000,$0000,$6020,$3CF0
	SRCFILE "whalehunt_1a.bas",2248
	DECLE 0
	DECLE 0
	DECLE 24608
	DECLE 15600
	;[2249] 	DATA $0000,$0000,$1F07,$7F3F
	SRCFILE "whalehunt_1a.bas",2249
	DECLE 0
	DECLE 0
	DECLE 7943
	DECLE 32575
	;[2250] big_whale:
	SRCFILE "whalehunt_1a.bas",2250
	; BIG_WHALE
Q181:	;[2251] '	DATA $0000,$0000,$1808,$7f3c
	SRCFILE "whalehunt_1a.bas",2251
	;[2252] '	DATA $0f07,$3F1F,$7f7F,$fFFF
	SRCFILE "whalehunt_1a.bas",2252
	;[2253] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2253
	;[2254] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2254
	DECLE 0
	;[2255] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2255
	;[2256] 	bitmap "...##..."
	SRCFILE "whalehunt_1a.bas",2256
	DECLE 6152
	;[2257] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",2257
	;[2258] 	bitmap ".#####.."
	SRCFILE "whalehunt_1a.bas",2258
	DECLE 31800
	;[2259] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2259
	;[2260] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2260
	DECLE 4095
	;[2261] 
	SRCFILE "whalehunt_1a.bas",2261
	;[2262] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2262
	;[2263] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2263
	DECLE 1792
	;[2264] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2264
	;[2265] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2265
	DECLE 16159
	;[2266] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2266
	;[2267] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2267
	DECLE 65407
	;[2268] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2268
	;[2269] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2269
	DECLE 65535
	;[2270] 	
	SRCFILE "whalehunt_1a.bas",2270
	;[2271] whale_face:
	SRCFILE "whalehunt_1a.bas",2271
	; WHALE_FACE
Q245:	;[2272] '	data $0000,$00c0,$7060,$0000
	SRCFILE "whalehunt_1a.bas",2272
	;[2273] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2273
	;[2274] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2274
	DECLE 0
	;[2275] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2275
	;[2276] 	bitmap "##......"
	SRCFILE "whalehunt_1a.bas",2276
	DECLE 49152
	;[2277] 	bitmap ".###...."
	SRCFILE "whalehunt_1a.bas",2277
	;[2278] 	bitmap ".##....."
	SRCFILE "whalehunt_1a.bas",2278
	DECLE 24688
	;[2279] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2279
	;[2280] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2280
	DECLE 0
	;[2281] 	
	SRCFILE "whalehunt_1a.bas",2281
	;[2282] whale_face_dead:
	SRCFILE "whalehunt_1a.bas",2282
	; WHALE_FACE_DEAD
Q182:	;[2283] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2283
	;[2284] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2284
	DECLE 0
	;[2285] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2285
	;[2286] 	bitmap ".#.#...."
	SRCFILE "whalehunt_1a.bas",2286
	DECLE 20480
	;[2287] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2287
	;[2288] 	bitmap ".#.#...."
	SRCFILE "whalehunt_1a.bas",2288
	DECLE 20512
	;[2289] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2289
	;[2290] 	bitmap "........"	
	SRCFILE "whalehunt_1a.bas",2290
	DECLE 0
	;[2291] 
	SRCFILE "whalehunt_1a.bas",2291
	;[2292] big_serpant:
	SRCFILE "whalehunt_1a.bas",2292
	; BIG_SERPANT
Q248:	;[2293] 	DATA $0000,$0000,$3C00,$E77E
	SRCFILE "whalehunt_1a.bas",2293
	DECLE 0
	DECLE 0
	DECLE 15360
	DECLE 59262
	;[2294] 	DATA $3F1C,$183F,$3818,$E070
	SRCFILE "whalehunt_1a.bas",2294
	DECLE 16156
	DECLE 6207
	DECLE 14360
	DECLE 57456
	;[2295] serpant_eye:
	SRCFILE "whalehunt_1a.bas",2295
	; SERPANT_EYE
Q249:	;[2296] 	DATA $1000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2296
	DECLE 4096
	DECLE 0
	DECLE 0
	DECLE 0
	;[2297] serpant_horn:
	SRCFILE "whalehunt_1a.bas",2297
	; SERPANT_HORN
Q247:	;[2298] 	DATA $4800,$0060,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2298
	DECLE 18432
	DECLE 96
	DECLE 0
	DECLE 0
	;[2299] 
	SRCFILE "whalehunt_1a.bas",2299
	;[2300] med_serpant:
	SRCFILE "whalehunt_1a.bas",2300
	; MED_SERPANT
Q134:	;[2301] 'body
	SRCFILE "whalehunt_1a.bas",2301
	;[2302] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2302
	;[2303] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2303
	DECLE 0
	;[2304] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2304
	;[2305] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2305
	DECLE 0
	;[2306] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2306
	;[2307] 	bitmap "...##..."
	SRCFILE "whalehunt_1a.bas",2307
	DECLE 6144
	;[2308] 	bitmap ".######."
	SRCFILE "whalehunt_1a.bas",2308
	;[2309] 	bitmap "###..###"
	SRCFILE "whalehunt_1a.bas",2309
	DECLE 59262
	;[2310] 'head	
	SRCFILE "whalehunt_1a.bas",2310
	;[2311] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2311
	;[2312] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2312
	DECLE 0
	;[2313] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2313
	;[2314] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",2314
	DECLE 14336
	;[2315] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2315
	;[2316] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2316
	DECLE 12348
	;[2317] 	bitmap ".###...."
	SRCFILE "whalehunt_1a.bas",2317
	;[2318] 	bitmap "###....."
	SRCFILE "whalehunt_1a.bas",2318
	DECLE 57456
	;[2319] 'horns	
	SRCFILE "whalehunt_1a.bas",2319
	;[2320] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2320
	;[2321] 	bitmap ".#.#...."
	SRCFILE "whalehunt_1a.bas",2321
	DECLE 20480
	;[2322] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",2322
	;[2323] 	bitmap ".##....."
	SRCFILE "whalehunt_1a.bas",2323
	DECLE 24640
	;[2324] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2324
	;[2325] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2325
	DECLE 0
	;[2326] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2326
	;[2327] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2327
	DECLE 0
	;[2328] 	
	SRCFILE "whalehunt_1a.bas",2328
	;[2329] small_serpant:
	SRCFILE "whalehunt_1a.bas",2329
	; SMALL_SERPANT
Q121:	;[2330] 'body and head
	SRCFILE "whalehunt_1a.bas",2330
	;[2331] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2331
	;[2332] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2332
	DECLE 0
	;[2333] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2333
	;[2334] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2334
	DECLE 0
	;[2335] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2335
	;[2336] 	bitmap ".....##."
	SRCFILE "whalehunt_1a.bas",2336
	DECLE 1540
	;[2337] 	bitmap ".###.#.."
	SRCFILE "whalehunt_1a.bas",2337
	;[2338] 	bitmap "##.###.."
	SRCFILE "whalehunt_1a.bas",2338
	DECLE 56436
	;[2339] 	
	SRCFILE "whalehunt_1a.bas",2339
	;[2340] big_squid:
	SRCFILE "whalehunt_1a.bas",2340
	; BIG_SQUID
Q252:	;[2341] 	DATA $0800,$3E1C,$7F7F,$1C5D
	SRCFILE "whalehunt_1a.bas",2341
	DECLE 2048
	DECLE 15900
	DECLE 32639
	DECLE 7261
	;[2342] 	DATA $3E1C,$3E3E,$7F3E,$7F7F
	SRCFILE "whalehunt_1a.bas",2342
	DECLE 15900
	DECLE 15934
	DECLE 32574
	DECLE 32639
	;[2343] squid_tentacle:
	SRCFILE "whalehunt_1a.bas",2343
	; SQUID_TENTACLE
Q251:	;[2344] 	DATA $0700,$180C,$6633,$98CC
	SRCFILE "whalehunt_1a.bas",2344
	DECLE 1792
	DECLE 6156
	DECLE 26163
	DECLE 39116
	;[2345] squid_eye:
	SRCFILE "whalehunt_1a.bas",2345
	; SQUID_EYE
Q254:	;[2346] 	DATA $0000,$0000,$0000,$000A
	SRCFILE "whalehunt_1a.bas",2346
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 10
	;[2347] 
	SRCFILE "whalehunt_1a.bas",2347
	;[2348] squid_face_dead:
	SRCFILE "whalehunt_1a.bas",2348
	; SQUID_FACE_DEAD
Q253:	;[2349] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2349
	;[2350] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2350
	DECLE 0
	;[2351] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2351
	;[2352] 	bitmap ".#.#.#.#"
	SRCFILE "whalehunt_1a.bas",2352
	DECLE 21760
	;[2353] 	bitmap "..#...#."
	SRCFILE "whalehunt_1a.bas",2353
	;[2354] 	bitmap ".#.#.#.#"
	SRCFILE "whalehunt_1a.bas",2354
	DECLE 21794
	;[2355] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2355
	;[2356] 	bitmap "........"	
	SRCFILE "whalehunt_1a.bas",2356
	DECLE 0
	;[2357] 	
	SRCFILE "whalehunt_1a.bas",2357
	;[2358] med_squid:
	SRCFILE "whalehunt_1a.bas",2358
	; MED_SQUID
Q136:	;[2359] 	bitmap "...##..."
	SRCFILE "whalehunt_1a.bas",2359
	;[2360] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2360
	DECLE 15384
	;[2361] 	bitmap ".#.##.#."
	SRCFILE "whalehunt_1a.bas",2361
	;[2362] 	bitmap "...##..."
	SRCFILE "whalehunt_1a.bas",2362
	DECLE 6234
	;[2363] 	bitmap "...##..."
	SRCFILE "whalehunt_1a.bas",2363
	;[2364] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2364
	DECLE 15384
	;[2365] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2365
	;[2366] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2366
	DECLE 15420
	;[2367] 	
	SRCFILE "whalehunt_1a.bas",2367
	;[2368] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2368
	;[2369] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2369
	DECLE 0
	;[2370] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2370
	;[2371] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2371
	DECLE 0
	;[2372] 	bitmap "...##..."
	SRCFILE "whalehunt_1a.bas",2372
	;[2373] 	bitmap "....##.."
	SRCFILE "whalehunt_1a.bas",2373
	DECLE 3096
	;[2374] 	bitmap "...#.##."
	SRCFILE "whalehunt_1a.bas",2374
	;[2375] 	bitmap "....#.##"
	SRCFILE "whalehunt_1a.bas",2375
	DECLE 2838
	;[2376] 	
	SRCFILE "whalehunt_1a.bas",2376
	;[2377] big_crab:
	SRCFILE "whalehunt_1a.bas",2377
	; BIG_CRAB
Q258:	;[2378] 	DATA $7F7F,$3F3F,$0F1F,$0307
	SRCFILE "whalehunt_1a.bas",2378
	DECLE 32639
	DECLE 16191
	DECLE 3871
	DECLE 775
	;[2379] 	DATA $C2FC,$0081,$0000,$8000
	SRCFILE "whalehunt_1a.bas",2379
	DECLE 49916
	DECLE 129
	DECLE 0
	DECLE 32768
	;[2380] 	DATA $0000,$8000,$F0C0,$FFFC
	SRCFILE "whalehunt_1a.bas",2380
	DECLE 0
	DECLE 32768
	DECLE 61632
	DECLE 65532
	;[2381] crab_border:
	SRCFILE "whalehunt_1a.bas",2381
	; CRAB_BORDER
Q256:	;[2382] 	DATA $423C,$9281,$8080,$005C
	SRCFILE "whalehunt_1a.bas",2382
	DECLE 16956
	DECLE 37505
	DECLE 32896
	DECLE 92
	;[2383] 'crab_face:
	SRCFILE "whalehunt_1a.bas",2383
	;[2384] 	DATA $FC78,$FEDA,$44FE,$AAAA	
	SRCFILE "whalehunt_1a.bas",2384
	DECLE 64632
	DECLE 65242
	DECLE 17662
	DECLE 43690
	;[2385] 	
	SRCFILE "whalehunt_1a.bas",2385
	;[2386] crab_face_dead:
	SRCFILE "whalehunt_1a.bas",2386
	; CRAB_FACE_DEAD
Q257:	;[2387] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2387
	;[2388] 	bitmap ".#....#."
	SRCFILE "whalehunt_1a.bas",2388
	DECLE 16956
	;[2389] 	bitmap "#.#..#.#"
	SRCFILE "whalehunt_1a.bas",2389
	;[2390] 	bitmap "#..#..#."
	SRCFILE "whalehunt_1a.bas",2390
	DECLE 37541
	;[2391] 	bitmap "#.#..#.."
	SRCFILE "whalehunt_1a.bas",2391
	;[2392] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2392
	DECLE 32932
	;[2393] 	bitmap ".#.###.."
	SRCFILE "whalehunt_1a.bas",2393
	;[2394] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2394
	DECLE 92
	;[2395] med_crab:
	SRCFILE "whalehunt_1a.bas",2395
	; MED_CRAB
Q138:	;[2396] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2396
	;[2397] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",2397
	DECLE 16384
	;[2398] 	bitmap ".###...."
	SRCFILE "whalehunt_1a.bas",2398
	;[2399] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2399
	DECLE 32624
	;[2400] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2400
	;[2401] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2401
	DECLE 7999
	;[2402] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2402
	;[2403] 	bitmap ".......#"
	SRCFILE "whalehunt_1a.bas",2403
	DECLE 263
	;[2404] 	
	SRCFILE "whalehunt_1a.bas",2404
	;[2405] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2405
	;[2406] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2406
	DECLE 0
	;[2407] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2407
	;[2408] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",2408
	DECLE 64512
	;[2409] 	bitmap "###...#."
	SRCFILE "whalehunt_1a.bas",2409
	;[2410] 	bitmap "##......"
	SRCFILE "whalehunt_1a.bas",2410
	DECLE 49378
	;[2411] 	bitmap "##......"
	SRCFILE "whalehunt_1a.bas",2411
	;[2412] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2412
	DECLE 192
	;[2413] 	
	SRCFILE "whalehunt_1a.bas",2413
	;[2414] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2414
	;[2415] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2415
	DECLE 0
	;[2416] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2416
	;[2417] 	bitmap ".#####.."
	SRCFILE "whalehunt_1a.bas",2417
	DECLE 31744
	;[2418] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2418
	;[2419] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2419
	DECLE 65278
	;[2420] 	bitmap ".#...#.."
	SRCFILE "whalehunt_1a.bas",2420
	;[2421] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2421
	DECLE 68
	;[2422] 	
	SRCFILE "whalehunt_1a.bas",2422
	;[2423] small_crab:
	SRCFILE "whalehunt_1a.bas",2423
	; SMALL_CRAB
Q125:	;[2424] 'shell
	SRCFILE "whalehunt_1a.bas",2424
	;[2425] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2425
	;[2426] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2426
	DECLE 32768
	;[2427] 	bitmap "##......"
	SRCFILE "whalehunt_1a.bas",2427
	;[2428] 	bitmap "####...."
	SRCFILE "whalehunt_1a.bas",2428
	DECLE 61632
	;[2429] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2429
	;[2430] 	bitmap ".####..#"
	SRCFILE "whalehunt_1a.bas",2430
	DECLE 31230
	;[2431] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2431
	;[2432] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2432
	DECLE 4144
	;[2433] 'face
	SRCFILE "whalehunt_1a.bas",2433
	;[2434] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2434
	;[2435] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2435
	DECLE 0
	;[2436] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2436
	;[2437] 	bitmap "....###."
	SRCFILE "whalehunt_1a.bas",2437
	DECLE 3584
	;[2438] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2438
	;[2439] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2439
	DECLE 7967
	;[2440] 	bitmap "....#.#."
	SRCFILE "whalehunt_1a.bas",2440
	;[2441] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2441
	DECLE 10
	;[2442] 	
	SRCFILE "whalehunt_1a.bas",2442
	;[2443] REM =====besides harpoon 1, all harpoons are loaded handle first =====
	SRCFILE "whalehunt_1a.bas",2443
	;[2444] 
	SRCFILE "whalehunt_1a.bas",2444
	;[2445] title_harpoon:
	SRCFILE "whalehunt_1a.bas",2445
	; TITLE_HARPOON
Q10:	;[2446] 	REM =====in air
	SRCFILE "whalehunt_1a.bas",2446
	;[2447] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2447
	;[2448] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2448
	DECLE 128
	;[2449] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2449
	;[2450] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2450
	DECLE 8192
	;[2451] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2451
	;[2452] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2452
	DECLE 2064
	;[2453] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2453
	;[2454] 	bitmap "......#."	
	SRCFILE "whalehunt_1a.bas",2454
	DECLE 516
	;[2455] 	
	SRCFILE "whalehunt_1a.bas",2455
	;[2456] harpoon_1:		' =====spear point: sprite 1 of title harpoon \ sprite 0 of harpoon 1
	SRCFILE "whalehunt_1a.bas",2456
	; HARPOON_1
Q70:	;[2457] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2457
	;[2458] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2458
	DECLE 12320
	;[2459] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",2459
	;[2460] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2460
	DECLE 15416
	;[2461] 	bitmap "..#####."
	SRCFILE "whalehunt_1a.bas",2461
	;[2462] 	bitmap "..#####."
	SRCFILE "whalehunt_1a.bas",2462
	DECLE 15934
	;[2463] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2463
	;[2464] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2464
	DECLE 7967
	;[2465] beat_level_harpoon:
	SRCFILE "whalehunt_1a.bas",2465
	; BEAT_LEVEL_HARPOON
Q229:	;[2466] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2466
	;[2467] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",2467
	DECLE 16512
	;[2468] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2468
	;[2469] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2469
	DECLE 4128
	;[2470] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2470
	;[2471] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2471
	DECLE 1032
	;[2472] 	bitmap "......#."
	SRCFILE "whalehunt_1a.bas",2472
	;[2473] 	bitmap ".......#"	
	SRCFILE "whalehunt_1a.bas",2473
	DECLE 258
	;[2474] 
	SRCFILE "whalehunt_1a.bas",2474
	;[2475] harpoon_2:
	SRCFILE "whalehunt_1a.bas",2475
	; HARPOON_2
Q71:	;[2476] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2476
	;[2477] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2477
	DECLE 0
	;[2478] 	bitmap "##......"
	SRCFILE "whalehunt_1a.bas",2478
	;[2479] 	bitmap "####...."
	SRCFILE "whalehunt_1a.bas",2479
	DECLE 61632
	;[2480] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2480
	;[2481] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2481
	DECLE 3900
	;[2482] 	bitmap "......##"
	SRCFILE "whalehunt_1a.bas",2482
	;[2483] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2483
	DECLE 3
	;[2484] shadow_4:	
	SRCFILE "whalehunt_1a.bas",2484
	; SHADOW_4
Q192:	;[2485] 	bitmap ".####..."
	SRCFILE "whalehunt_1a.bas",2485
	;[2486] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2486
	DECLE 16248
	;[2487] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2487
	;[2488] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2488
	DECLE 1823
	;[2489] 	bitmap ".......#"
	SRCFILE "whalehunt_1a.bas",2489
	;[2490] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2490
	DECLE 1
	;[2491] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2491
	;[2492] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2492
	DECLE 0
	;[2493] 	
	SRCFILE "whalehunt_1a.bas",2493
	;[2494] harpoon_3:
	SRCFILE "whalehunt_1a.bas",2494
	; HARPOON_3
Q67:	;[2495] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2495
	;[2496] 	bitmap "......##"
	SRCFILE "whalehunt_1a.bas",2496
	DECLE 768
	;[2497] 	bitmap "....###."
	SRCFILE "whalehunt_1a.bas",2497
	;[2498] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",2498
	DECLE 14350
	;[2499] 	bitmap "###....."
	SRCFILE "whalehunt_1a.bas",2499
	;[2500] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2500
	DECLE 224
	;[2501] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2501
	;[2502] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2502
	DECLE 0
	;[2503] shadow_3:
	SRCFILE "whalehunt_1a.bas",2503
	; SHADOW_3
Q191:	;[2504] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2504
	;[2505] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2505
	DECLE 0
	;[2506] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2506
	;[2507] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2507
	DECLE 0
	;[2508] 	bitmap "......##"
	SRCFILE "whalehunt_1a.bas",2508
	;[2509] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2509
	DECLE 3843
	;[2510] 	bitmap "..#####."
	SRCFILE "whalehunt_1a.bas",2510
	;[2511] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2511
	DECLE 62
	;[2512] 	
	SRCFILE "whalehunt_1a.bas",2512
	;[2513] harpoon_4:
	SRCFILE "whalehunt_1a.bas",2513
	; HARPOON_4
Q72:	;[2514] 	bitmap "......#."
	SRCFILE "whalehunt_1a.bas",2514
	;[2515] 	bitmap "......#."
	SRCFILE "whalehunt_1a.bas",2515
	DECLE 514
	;[2516] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2516
	;[2517] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2517
	DECLE 1028
	;[2518] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2518
	;[2519] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2519
	DECLE 2056
	;[2520] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2520
	;[2521] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2521
	DECLE 4112
	;[2522] shadow_2:	
	SRCFILE "whalehunt_1a.bas",2522
	; SHADOW_2
Q190:	;[2523] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2523
	;[2524] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2524
	DECLE 12336
	;[2525] 	bitmap ".##....."
	SRCFILE "whalehunt_1a.bas",2525
	;[2526] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",2526
	DECLE 16480
	;[2527] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",2527
	;[2528] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2528
	DECLE 64
	;[2529] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2529
	;[2530] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2530
	DECLE 0
	;[2531] harpoon_5:
	SRCFILE "whalehunt_1a.bas",2531
	; HARPOON_5
Q75:	;[2532] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2532
	;[2533] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2533
	DECLE 2056
	;[2534] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2534
	;[2535] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2535
	DECLE 2056
	;[2536] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2536
	;[2537] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2537
	DECLE 4112
	;[2538] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2538
	;[2539] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2539
	DECLE 4112
	;[2540] shadow_1:	
	SRCFILE "whalehunt_1a.bas",2540
	; SHADOW_1
Q189:	;[2541] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2541
	;[2542] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2542
	DECLE 12336
	;[2543] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2543
	;[2544] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2544
	DECLE 8240
	;[2545] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2545
	;[2546] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2546
	DECLE 8224
	;[2547] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2547
	;[2548] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2548
	DECLE 0
	;[2549] 
	SRCFILE "whalehunt_1a.bas",2549
	;[2550] 	
	SRCFILE "whalehunt_1a.bas",2550
	;[2551] blood_1:
	SRCFILE "whalehunt_1a.bas",2551
	; BLOOD_1
Q57:	;[2552] 	DATA $0000,$6308,$0814,$0008
	SRCFILE "whalehunt_1a.bas",2552
	DECLE 0
	DECLE 25352
	DECLE 2068
	DECLE 8
	;[2553] blood_2:
	SRCFILE "whalehunt_1a.bas",2553
	; BLOOD_2
Q228:	;[2554] '	DATA $1400,$6B08,$0814,$0808
	SRCFILE "whalehunt_1a.bas",2554
	;[2555] 	bitmap "...#.#.."
	SRCFILE "whalehunt_1a.bas",2555
	;[2556] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2556
	DECLE 2068
	;[2557] 	bitmap ".##.#.##"
	SRCFILE "whalehunt_1a.bas",2557
	;[2558] 	bitmap "...#.#.."
	SRCFILE "whalehunt_1a.bas",2558
	DECLE 5227
	;[2559] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2559
	;[2560] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2560
	DECLE 2056
	;[2561] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2561
	;[2562] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2562
	DECLE 8
	;[2563] 'blood_3:
	SRCFILE "whalehunt_1a.bas",2563
	;[2564] 	DATA $0000,$0000,$C300,$9924
	SRCFILE "whalehunt_1a.bas",2564
	DECLE 0
	DECLE 0
	DECLE 49920
	DECLE 39204
	;[2565] 	
	SRCFILE "whalehunt_1a.bas",2565
	;[2566] paddle_sprites:
	SRCFILE "whalehunt_1a.bas",2566
	; PADDLE_SPRITES
Q58:	;[2567] 
	SRCFILE "whalehunt_1a.bas",2567
	;[2568] '	DATA $0000,$0300,$0F07,$0F0F
	SRCFILE "whalehunt_1a.bas",2568
	;[2569] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2569
	;[2570] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2570
	DECLE 0
	;[2571] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2571
	;[2572] 	bitmap "......##"
	SRCFILE "whalehunt_1a.bas",2572
	DECLE 768
	;[2573] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2573
	;[2574] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2574
	DECLE 3847
	;[2575] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2575
	;[2576] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2576
	DECLE 3855
	;[2577] 	
	SRCFILE "whalehunt_1a.bas",2577
	;[2578] '	DATA $0F00,$FFFF,$FFFF,$FFFF	
	SRCFILE "whalehunt_1a.bas",2578
	;[2579] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2579
	;[2580] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2580
	DECLE 3840
	;[2581] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2581
	;[2582] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2582
	DECLE 65535
	;[2583] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2583
	;[2584] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2584
	DECLE 65535
	;[2585] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2585
	;[2586] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2586
	DECLE 65535
	;[2587] 
	SRCFILE "whalehunt_1a.bas",2587
	;[2588] '	DATA $FFFF,$FFFF,$FFFF,$FEFF	
	SRCFILE "whalehunt_1a.bas",2588
	;[2589] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2589
	;[2590] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2590
	DECLE 65535
	;[2591] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2591
	;[2592] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2592
	DECLE 65535
	;[2593] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2593
	;[2594] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2594
	DECLE 65535
	;[2595] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2595
	;[2596] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2596
	DECLE 65279
	;[2597] 	
	SRCFILE "whalehunt_1a.bas",2597
	;[2598] '	DATA $FFFF,$FEFF,$E0F8,$0080
	SRCFILE "whalehunt_1a.bas",2598
	;[2599] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2599
	;[2600] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2600
	DECLE 65535
	;[2601] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2601
	;[2602] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2602
	DECLE 65279
	;[2603] 	bitmap "#####..."
	SRCFILE "whalehunt_1a.bas",2603
	;[2604] 	bitmap "###....."
	SRCFILE "whalehunt_1a.bas",2604
	DECLE 57592
	;[2605] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2605
	;[2606] 	bitmap "........"		
	SRCFILE "whalehunt_1a.bas",2606
	DECLE 128
	;[2607] 	
	SRCFILE "whalehunt_1a.bas",2607
	;[2608] map_sprites:
	SRCFILE "whalehunt_1a.bas",2608
	; MAP_SPRITES
Q146:	;[2609] 	data $0000,$0000,$0e00,$ff5f	
	SRCFILE "whalehunt_1a.bas",2609
	DECLE 0
	DECLE 0
	DECLE 3584
	DECLE 65375
	;[2610] 	data $0000,$150a,$0004,$0000
	SRCFILE "whalehunt_1a.bas",2610
	DECLE 0
	DECLE 5386
	DECLE 4
	DECLE 0
	;[2611] 	data $0000,$0000,$2020,$0000
	SRCFILE "whalehunt_1a.bas",2611
	DECLE 0
	DECLE 0
	DECLE 8224
	DECLE 0
	;[2612] 	data $0000,$0604,$0007,$0000
	SRCFILE "whalehunt_1a.bas",2612
	DECLE 0
	DECLE 1540
	DECLE 7
	DECLE 0
	;[2613] 	data $0800,$0808,$0808,$3e7f
	SRCFILE "whalehunt_1a.bas",2613
	DECLE 2048
	DECLE 2056
	DECLE 2056
	DECLE 15999
	;[2614] 	data $0000,$e000,$e0e0,$e0e0
	SRCFILE "whalehunt_1a.bas",2614
	DECLE 0
	DECLE 57344
	DECLE 57568
	DECLE 57568
	;[2615] 'serpant_map:
	SRCFILE "whalehunt_1a.bas",2615
	;[2616] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2616
	;[2617] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2617
	DECLE 0
	;[2618] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2618
	;[2619] 	bitmap ".....##."
	SRCFILE "whalehunt_1a.bas",2619
	DECLE 1536
	;[2620] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2620
	;[2621] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2621
	DECLE 1031
	;[2622] 	bitmap ".##..#.."
	SRCFILE "whalehunt_1a.bas",2622
	;[2623] 	bitmap "#..##..."
	SRCFILE "whalehunt_1a.bas",2623
	DECLE 39012
	;[2624] 'horns
	SRCFILE "whalehunt_1a.bas",2624
	;[2625] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2625
	;[2626] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2626
	DECLE 0
	;[2627] 	bitmap "....#..#"
	SRCFILE "whalehunt_1a.bas",2627
	;[2628] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2628
	DECLE 9
	;[2629] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2629
	;[2630] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2630
	DECLE 0
	;[2631] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2631
	;[2632] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2632
	DECLE 0
	;[2633] 
	SRCFILE "whalehunt_1a.bas",2633
	;[2634] 	
	SRCFILE "whalehunt_1a.bas",2634
	;[2635] squid_map:
	SRCFILE "whalehunt_1a.bas",2635
	; SQUID_MAP
Q123:	;[2636] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2636
	;[2637] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",2637
	DECLE 14352
	;[2638] 	bitmap ".#.#.#.."
	SRCFILE "whalehunt_1a.bas",2638
	;[2639] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2639
	DECLE 4180
	;[2640] 	bitmap "..###..."
	SRCFILE "whalehunt_1a.bas",2640
	;[2641] 	bitmap "#.###.#."
	SRCFILE "whalehunt_1a.bas",2641
	DECLE 47672
	;[2642] 	bitmap "#.###.#."
	SRCFILE "whalehunt_1a.bas",2642
	;[2643] 	bitmap ".#####.."
	SRCFILE "whalehunt_1a.bas",2643
	DECLE 31930
	;[2644] 	
	SRCFILE "whalehunt_1a.bas",2644
	;[2645] 'crab_map:
	SRCFILE "whalehunt_1a.bas",2645
	;[2646] 'shell
	SRCFILE "whalehunt_1a.bas",2646
	;[2647] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2647
	;[2648] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2648
	DECLE 8192
	;[2649] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2649
	;[2650] 	bitmap "..####.."
	SRCFILE "whalehunt_1a.bas",2650
	DECLE 15408
	;[2651] 	bitmap "..#####."
	SRCFILE "whalehunt_1a.bas",2651
	;[2652] 	bitmap "...##..#"
	SRCFILE "whalehunt_1a.bas",2652
	DECLE 6462
	;[2653] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2653
	;[2654] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2654
	DECLE 8
	;[2655] 'face
	SRCFILE "whalehunt_1a.bas",2655
	;[2656] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2656
	;[2657] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2657
	DECLE 0
	;[2658] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2658
	;[2659] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2659
	DECLE 0
	;[2660] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2660
	;[2661] 	bitmap ".....##."
	SRCFILE "whalehunt_1a.bas",2661
	DECLE 1536
	;[2662] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2662
	;[2663] 	bitmap ".....#.#"
	SRCFILE "whalehunt_1a.bas",2663
	DECLE 1287
	;[2664] 	
	SRCFILE "whalehunt_1a.bas",2664
	;[2665] 
	SRCFILE "whalehunt_1a.bas",2665
	;[2666] beat_level_sprites:
	SRCFILE "whalehunt_1a.bas",2666
	; BEAT_LEVEL_SPRITES
Q227:	;[2667] 'boot toe
	SRCFILE "whalehunt_1a.bas",2667
	;[2668] 	bitmap "...###.."
	SRCFILE "whalehunt_1a.bas",2668
	;[2669] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2669
	DECLE 16156
	;[2670] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2670
	;[2671] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2671
	DECLE 7999
	;[2672] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2672
	;[2673] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2673
	DECLE 7967
	;[2674] 	bitmap "....####"	
	SRCFILE "whalehunt_1a.bas",2674
	;[2675] 	bitmap "......##"
	SRCFILE "whalehunt_1a.bas",2675
	DECLE 783
	;[2676] 
	SRCFILE "whalehunt_1a.bas",2676
	;[2677] 	
	SRCFILE "whalehunt_1a.bas",2677
	;[2678] lose_life_sprites:
	SRCFILE "whalehunt_1a.bas",2678
	; LOSE_LIFE_SPRITES
Q219:	;[2679] 'whale fin border
	SRCFILE "whalehunt_1a.bas",2679
	;[2680] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2680
	;[2681] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2681
	DECLE 0
	;[2682] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2682
	;[2683] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2683
	DECLE 8223
	;[2684] 	bitmap ".#......"
	SRCFILE "whalehunt_1a.bas",2684
	;[2685] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2685
	DECLE 32832
	;[2686] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2686
	;[2687] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2687
	DECLE 32640
	;[2688] 'whale fin
	SRCFILE "whalehunt_1a.bas",2688
	;[2689] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2689
	;[2690] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2690
	DECLE 0
	;[2691] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2691
	;[2692] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2692
	DECLE 16159
	;[2693] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2693
	;[2694] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2694
	DECLE 65407
	;[2695] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2695
	;[2696] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2696
	DECLE 32767
	;[2697] 'back boat	
	SRCFILE "whalehunt_1a.bas",2697
	;[2698] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2698
	;[2699] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2699
	DECLE 65535
	;[2700] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2700
	;[2701] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2701
	DECLE 32767
	;[2702] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2702
	;[2703] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2703
	DECLE 63
	;[2704] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2704
	;[2705] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2705
	DECLE 0
	;[2706] 'front boat sky	
	SRCFILE "whalehunt_1a.bas",2706
	;[2707] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2707
	;[2708] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2708
	DECLE 0
	;[2709] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2709
	;[2710] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2710
	DECLE 0
	;[2711] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2711
	;[2712] 	bitmap ".......#"
	SRCFILE "whalehunt_1a.bas",2712
	DECLE 256
	;[2713] 	bitmap "......##"
	SRCFILE "whalehunt_1a.bas",2713
	;[2714] 	bitmap "....####"
	SRCFILE "whalehunt_1a.bas",2714
	DECLE 3843
	;[2715] 'front boat border	
	SRCFILE "whalehunt_1a.bas",2715
	;[2716] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2716
	;[2717] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2717
	DECLE 0
	;[2718] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2718
	;[2719] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2719
	DECLE 0
	;[2720] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2720
	;[2721] 	bitmap "####...."
	SRCFILE "whalehunt_1a.bas",2721
	DECLE 61440
	;[2722] 	bitmap "######.."
	SRCFILE "whalehunt_1a.bas",2722
	;[2723] 	bitmap "#######."
	SRCFILE "whalehunt_1a.bas",2723
	DECLE 65276
	;[2724] 	
	SRCFILE "whalehunt_1a.bas",2724
	;[2725] lightning_images:
	SRCFILE "whalehunt_1a.bas",2725
	; LIGHTNING_IMAGES
Q234:	;[2726] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2726
	;[2727] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2727
	DECLE 2052
	;[2728] 	bitmap "...###.."
	SRCFILE "whalehunt_1a.bas",2728
	;[2729] 	bitmap "..#.#.#."
	SRCFILE "whalehunt_1a.bas",2729
	DECLE 10780
	;[2730] 	bitmap ".#..#..."
	SRCFILE "whalehunt_1a.bas",2730
	;[2731] 	bitmap "...#.#.."
	SRCFILE "whalehunt_1a.bas",2731
	DECLE 5192
	;[2732] 	bitmap "..#..#.."
	SRCFILE "whalehunt_1a.bas",2732
	;[2733] 	bitmap ".#.#..#."
	SRCFILE "whalehunt_1a.bas",2733
	DECLE 21028
	;[2734] 	
	SRCFILE "whalehunt_1a.bas",2734
	;[2735] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2735
	;[2736] 	bitmap "..#....."
	SRCFILE "whalehunt_1a.bas",2736
	DECLE 8208
	;[2737] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2737
	;[2738] 	bitmap "..#.#..."
	SRCFILE "whalehunt_1a.bas",2738
	DECLE 10288
	;[2739] 	bitmap ".#...#.."
	SRCFILE "whalehunt_1a.bas",2739
	;[2740] 	bitmap ".#..#.#."
	SRCFILE "whalehunt_1a.bas",2740
	DECLE 19012
	;[2741] 	bitmap "#.#....#"
	SRCFILE "whalehunt_1a.bas",2741
	;[2742] 	bitmap "...#...."
	SRCFILE "whalehunt_1a.bas",2742
	DECLE 4257
	;[2743] 	
	SRCFILE "whalehunt_1a.bas",2743
	;[2744] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2744
	;[2745] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2745
	DECLE 1028
	;[2746] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2746
	;[2747] 	bitmap "...#.#.."
	SRCFILE "whalehunt_1a.bas",2747
	DECLE 5128
	;[2748] 	bitmap "..#...#."
	SRCFILE "whalehunt_1a.bas",2748
	;[2749] 	bitmap ".#.#.#.#"
	SRCFILE "whalehunt_1a.bas",2749
	DECLE 21794
	;[2750] 	bitmap "#..#...."
	SRCFILE "whalehunt_1a.bas",2750
	;[2751] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2751
	DECLE 2192
	;[2752] 	
	SRCFILE "whalehunt_1a.bas",2752
	;[2753] flute_sprites:
	SRCFILE "whalehunt_1a.bas",2753
	; FLUTE_SPRITES
Q328:	;[2754] 'shoulder in front of hand
	SRCFILE "whalehunt_1a.bas",2754
	;[2755] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2755
	;[2756] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2756
	DECLE 0
	;[2757] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2757
	;[2758] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2758
	DECLE 0
	;[2759] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2759
	;[2760] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2760
	DECLE 0
	;[2761] 	bitmap ".......#"
	SRCFILE "whalehunt_1a.bas",2761
	;[2762] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2762
	DECLE 1793
	;[2763] 'shoulder line	
	SRCFILE "whalehunt_1a.bas",2763
	;[2764] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2764
	;[2765] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2765
	DECLE 0
	;[2766] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2766
	;[2767] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2767
	DECLE 0
	;[2768] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2768
	;[2769] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2769
	DECLE 0
	;[2770] 	bitmap ".#####.."
	SRCFILE "whalehunt_1a.bas",2770
	;[2771] 	bitmap "#......."
	SRCFILE "whalehunt_1a.bas",2771
	DECLE 32892
	;[2772] 'hand line	
	SRCFILE "whalehunt_1a.bas",2772
	;[2773] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2773
	;[2774] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2774
	DECLE 0
	;[2775] 	bitmap ".......#"
	SRCFILE "whalehunt_1a.bas",2775
	;[2776] 	bitmap "......#."
	SRCFILE "whalehunt_1a.bas",2776
	DECLE 513
	;[2777] 	bitmap ".....#.."
	SRCFILE "whalehunt_1a.bas",2777
	;[2778] 	bitmap "....#..."
	SRCFILE "whalehunt_1a.bas",2778
	DECLE 2052
	;[2779] 	bitmap "..##...."
	SRCFILE "whalehunt_1a.bas",2779
	;[2780] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2780
	DECLE 48
	;[2781] 'flute	
	SRCFILE "whalehunt_1a.bas",2781
	;[2782] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2782
	;[2783] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2783
	DECLE 0
	;[2784] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2784
	;[2785] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2785
	DECLE 65280
	;[2786] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2786
	;[2787] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2787
	DECLE 63
	;[2788] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2788
	;[2789] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2789
	DECLE 0
	;[2790] 'flute holes
	SRCFILE "whalehunt_1a.bas",2790
	;[2791] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2791
	;[2792] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2792
	DECLE 0
	;[2793] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2793
	;[2794] 	bitmap "#.#.#.#."
	SRCFILE "whalehunt_1a.bas",2794
	DECLE 43520
	;[2795] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2795
	;[2796] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2796
	DECLE 0
	;[2797] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2797
	;[2798] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2798
	DECLE 0
	;[2799] 	
	SRCFILE "whalehunt_1a.bas",2799
	;[2800] sundial_sprites:
	SRCFILE "whalehunt_1a.bas",2800
	; SUNDIAL_SPRITES
Q188:	;[2801] 	bitmap "........"
	SRCFILE "whalehunt_1a.bas",2801
	;[2802] 	bitmap ".....###"
	SRCFILE "whalehunt_1a.bas",2802
	DECLE 1792
	;[2803] 	bitmap "...#####"
	SRCFILE "whalehunt_1a.bas",2803
	;[2804] 	bitmap "..######"
	SRCFILE "whalehunt_1a.bas",2804
	DECLE 16159
	;[2805] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2805
	;[2806] 	bitmap ".#######"
	SRCFILE "whalehunt_1a.bas",2806
	DECLE 32639
	;[2807] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2807
	;[2808] 	bitmap "########"
	SRCFILE "whalehunt_1a.bas",2808
	DECLE 65535
	;[2809] 	
	SRCFILE "whalehunt_1a.bas",2809
	;[2810] 	' 20 bitmaps
	SRCFILE "whalehunt_1a.bas",2810
	;[2811] map_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",2811
	; MAP_BITMAPS_0
Q143:	;[2812] 	DATA $70BC,$C8E7,$A493,$292A
	SRCFILE "whalehunt_1a.bas",2812
	DECLE 28860
	DECLE 51431
	DECLE 42131
	DECLE 10538
	;[2813] 	DATA $183C,$24C3,$2499,$00C3
	SRCFILE "whalehunt_1a.bas",2813
	DECLE 6204
	DECLE 9411
	DECLE 9369
	DECLE 195
	;[2814] 	DATA $0E3D,$13E7,$25C9,$9454
	SRCFILE "whalehunt_1a.bas",2814
	DECLE 3645
	DECLE 5095
	DECLE 9673
	DECLE 37972
	;[2815] 	DATA $222A,$C894,$94C8,$2A22
	SRCFILE "whalehunt_1a.bas",2815
	DECLE 8746
	DECLE 51348
	DECLE 38088
	DECLE 10786
	;[2816] 	DATA $FFFF,$FFFF,$9BFF,$B3AB
	SRCFILE "whalehunt_1a.bas",2816
	DECLE 65535
	DECLE 65535
	DECLE 39935
	DECLE 45995
	;[2817] 	DATA $4454,$1329,$2913,$5444
	SRCFILE "whalehunt_1a.bas",2817
	DECLE 17492
	DECLE 4905
	DECLE 10515
	DECLE 21572
	;[2818] 	DATA $EFFF,$D7AB,$D739,$EFAB
	SRCFILE "whalehunt_1a.bas",2818
	DECLE 61439
	DECLE 55211
	DECLE 55097
	DECLE 61355
	;[2819] 	DATA $FFFF,$FFFF,$FFFF,$00F8
	SRCFILE "whalehunt_1a.bas",2819
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 248
	;[2820] 	DATA $FFFF,$FFFF,$80FF,$0000
	SRCFILE "whalehunt_1a.bas",2820
	DECLE 65535
	DECLE 65535
	DECLE 33023
	DECLE 0
	;[2821] 	DATA $FFFF,$FFFF,$00FF,$0000
	SRCFILE "whalehunt_1a.bas",2821
	DECLE 65535
	DECLE 65535
	DECLE 255
	DECLE 0
	;[2822] 	DATA $FFFF,$FFFF,$FFFF,$000F
	SRCFILE "whalehunt_1a.bas",2822
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 15
	;[2823] 	DATA $FFFF,$FFFF,$FFFF,$E0FF
	SRCFILE "whalehunt_1a.bas",2823
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 57599
	;[2824] 	DATA $FFFF,$FFFF,$FFFF,$00FF
	SRCFILE "whalehunt_1a.bas",2824
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 255
	;[2825] 	DATA $07FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2825
	DECLE 2047
	DECLE 0
	DECLE 0
	DECLE 0
	;[2826] 	DATA $FFFF,$003F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2826
	DECLE 65535
	DECLE 63
	DECLE 0
	DECLE 0
	;[2827] 	DATA $FFFF,$00FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2827
	DECLE 65535
	DECLE 255
	DECLE 0
	DECLE 0
	;[2828] map_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",2828
	; MAP_BITMAPS_1
Q144:	;[2829] 	DATA $F0FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2829
	DECLE 61695
	DECLE 0
	DECLE 0
	DECLE 0
	;[2830] 	DATA $2A29,$93A4,$E7C8,$BC70
	SRCFILE "whalehunt_1a.bas",2830
	DECLE 10793
	DECLE 37796
	DECLE 59336
	DECLE 48240
	;[2831] 	DATA $C300,$9924,$C324,$3C18
	SRCFILE "whalehunt_1a.bas",2831
	DECLE 49920
	DECLE 39204
	DECLE 49956
	DECLE 15384
	;[2832] 	DATA $5494,$C925,$E713,$3D0E
	SRCFILE "whalehunt_1a.bas",2832
	DECLE 21652
	DECLE 51493
	DECLE 59155
	DECLE 15630
	;[2833] buildings:
	SRCFILE "whalehunt_1a.bas",2833
	; BUILDINGS
Q145:	;[2834] 	DATA $1EFF,$FF82,$FB11,$8A8A
	SRCFILE "whalehunt_1a.bas",2834
	DECLE 7935
	DECLE 65410
	DECLE 64273
	DECLE 35466
	;[2835] 	DATA $54FF,$F455,$9C17,$11F0
	SRCFILE "whalehunt_1a.bas",2835
	DECLE 21759
	DECLE 62549
	DECLE 39959
	DECLE 4592
	;[2836] 	DATA $C99F,$FF09,$2465,$9FB4
	SRCFILE "whalehunt_1a.bas",2836
	DECLE 51615
	DECLE 65289
	DECLE 9317
	DECLE 40884
	;[2837] 	DATA $10FF,$3F10,$BEA2,$E1A3
	SRCFILE "whalehunt_1a.bas",2837
	DECLE 4351
	DECLE 16144
	DECLE 48802
	DECLE 57763
	;[2838] 	DATA $EBFF,$F888,$584F,$7051
	SRCFILE "whalehunt_1a.bas",2838
	DECLE 60415
	DECLE 63624
	DECLE 22607
	DECLE 28753
	;[2839] 	DATA $9FFF,$9093,$73DF,$7FC1
	SRCFILE "whalehunt_1a.bas",2839
	DECLE 40959
	DECLE 37011
	DECLE 29663
	DECLE 32705
	;[2840] 	DATA $F4F4,$FEF4,$87C2,$85FD
	SRCFILE "whalehunt_1a.bas",2840
	DECLE 62708
	DECLE 65268
	DECLE 34754
	DECLE 34301
	;[2841] 	DATA $909C,$92B3,$88FE,$1F08
	SRCFILE "whalehunt_1a.bas",2841
	DECLE 37020
	DECLE 37555
	DECLE 35070
	DECLE 7944
	;[2842] 	DATA $FC24,$9097,$909C,$88FF
	SRCFILE "whalehunt_1a.bas",2842
	DECLE 64548
	DECLE 37015
	DECLE 37020
	DECLE 35071
	;[2843] 
	SRCFILE "whalehunt_1a.bas",2843
	;[2844] map_cards:
	SRCFILE "whalehunt_1a.bas",2844
	; MAP_CARDS
Q147:	;[2845] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2845
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2846] 	DATA $1C05,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C0D,$1C15
	SRCFILE "whalehunt_1a.bas",2846
	DECLE 7173
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7181
	DECLE 7189
	;[2847] 	DATA $1C1D,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0C21,$0200,$1C2D
	SRCFILE "whalehunt_1a.bas",2847
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3105
	DECLE 512
	DECLE 7213
	;[2848] 	DATA $1C1D,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0831,$0200,$1C2D
	SRCFILE "whalehunt_1a.bas",2848
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2097
	DECLE 512
	DECLE 7213
	;[2849] 	DATA $1C1D,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1C2D
	SRCFILE "whalehunt_1a.bas",2849
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7213
	;[2850] 	DATA $1C1D,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1C2D
	SRCFILE "whalehunt_1a.bas",2850
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7213
	;[2851] 	DATA $1C1D,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1C2D
	SRCFILE "whalehunt_1a.bas",2851
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7213
	;[2852] 	DATA $1C1D,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1C2D
	SRCFILE "whalehunt_1a.bas",2852
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7213
	;[2853] 	DATA $1C1D,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1C2D
	SRCFILE "whalehunt_1a.bas",2853
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7213
	;[2854] 	DATA $1C1D,$0200,$0200,$2A39,$2A41,$2A49,$2A49,$2A51,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2A59,$2A61,$2A61,$2A61,$1C2D
	SRCFILE "whalehunt_1a.bas",2854
	DECLE 7197
	DECLE 512
	DECLE 512
	DECLE 10809
	DECLE 10817
	DECLE 10825
	DECLE 10825
	DECLE 10833
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10841
	DECLE 10849
	DECLE 10849
	DECLE 10849
	DECLE 7213
	;[2855] 	DATA $1C1D,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2200,$2A69,$2A71,$2A79,$2A81,$2200,$2200,$2200,$2200,$1C2D
	SRCFILE "whalehunt_1a.bas",2855
	DECLE 7197
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 10857
	DECLE 10865
	DECLE 10873
	DECLE 10881
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 8704
	DECLE 7213
	;[2856] 	DATA $1C8D,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C95,$1C9D
	SRCFILE "whalehunt_1a.bas",2856
	DECLE 7309
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7317
	DECLE 7325
	;[2857] 
	SRCFILE "whalehunt_1a.bas",2857
	;[2858] 	
	SRCFILE "whalehunt_1a.bas",2858
	;[2859] 	
	SRCFILE "whalehunt_1a.bas",2859
	;[2860] background:
	SRCFILE "whalehunt_1a.bas",2860
	; BACKGROUND
Q22:	;[2861] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2861
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2862] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2862
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2863] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2863
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2864] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2864
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2865] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2865
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2866] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2866
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2867] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2867
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2868] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2868
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2869] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2869
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2870] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2870
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2871] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2871
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2872] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2872
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2873] 
	SRCFILE "whalehunt_1a.bas",2873
	;[2874] background_dawn:
	SRCFILE "whalehunt_1a.bas",2874
	; BACKGROUND_DAWN
Q21:	;[2875] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2875
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2876] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2876
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2877] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2877
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2878] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2878
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2879] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2879
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2880] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2880
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2881] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2881
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2882] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2882
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2883] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2883
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2884] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",2884
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[2885] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2885
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2886] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2886
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2887] 
	SRCFILE "whalehunt_1a.bas",2887
	;[2888] 
	SRCFILE "whalehunt_1a.bas",2888
	;[2889] background_dusk:
	SRCFILE "whalehunt_1a.bas",2889
	; BACKGROUND_DUSK
Q23:	;[2890] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2890
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2891] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2891
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2892] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2892
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2893] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2893
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2894] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2894
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2895] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2895
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2896] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2896
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2897] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2897
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2898] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2898
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2899] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",2899
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[2900] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2900
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2901] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2901
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2902] 
	SRCFILE "whalehunt_1a.bas",2902
	;[2903] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",2903
	;[2904] background_storm:
	SRCFILE "whalehunt_1a.bas",2904
	; BACKGROUND_STORM
Q24:	;[2905] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2905
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2906] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2906
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2907] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2907
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2908] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2908
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2909] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2909
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2910] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2910
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2911] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2911
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2912] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2912
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2913] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2913
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2914] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2914
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[2915] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2915
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2916] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",2916
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[2917] 
	SRCFILE "whalehunt_1a.bas",2917
	;[2918] REM ========================TITLE SCREEN==============================	
	SRCFILE "whalehunt_1a.bas",2918
	;[2919] asm org $f800
	SRCFILE "whalehunt_1a.bas",2919
 org $f800
	;[2920] 
	SRCFILE "whalehunt_1a.bas",2920
	;[2921] 	' 62 bitmaps
	SRCFILE "whalehunt_1a.bas",2921
	;[2922] title_screen_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",2922
	; TITLE_SCREEN_BITMAPS_0
Q6:	;[2923] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",2923
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[2924] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",2924
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[2925] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",2925
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[2926] 	DATA $0000,$0000,$0000,$F8F0
	SRCFILE "whalehunt_1a.bas",2926
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 63728
	;[2927] 	DATA $0000,$C000,$F8F0,$FFFC
	SRCFILE "whalehunt_1a.bas",2927
	DECLE 0
	DECLE 49152
	DECLE 63728
	DECLE 65532
	;[2928] 	DATA $0000,$0000,$0000,$0701
	SRCFILE "whalehunt_1a.bas",2928
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1793
	;[2929] 	DATA $0000,$0000,$3F00,$FFFF
	SRCFILE "whalehunt_1a.bas",2929
	DECLE 0
	DECLE 0
	DECLE 16128
	DECLE 65535
	;[2930] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",2930
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[2931] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",2931
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[2932] 	DATA $3F3F,$0F1F,$0307,$FC01
	SRCFILE "whalehunt_1a.bas",2932
	DECLE 16191
	DECLE 3871
	DECLE 775
	DECLE 64513
	;[2933] 	DATA $FCF8,$FFFE,$FFFF,$7FFF
	SRCFILE "whalehunt_1a.bas",2933
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 32767
	;[2934] 	DATA $0000,$0000,$C080,$F0E0
	SRCFILE "whalehunt_1a.bas",2934
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 61664
	;[2935] 	DATA $0301,$0307,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2935
	DECLE 769
	DECLE 775
	DECLE 0
	DECLE 0
	;[2936] 	DATA $FFFF,$FFFF,$0F3F,$0003
	SRCFILE "whalehunt_1a.bas",2936
	DECLE 65535
	DECLE 65535
	DECLE 3903
	DECLE 3
	;[2937] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",2937
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[2938] 	DATA $9F3F,$FFEF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2938
	DECLE 40767
	DECLE 65519
	DECLE 65535
	DECLE 65535
	;[2939] title_screen_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",2939
	; TITLE_SCREEN_BITMAPS_1
Q7:	;[2940] 	DATA $FCF8,$FFFE,$FFFF,$FEFE
	SRCFILE "whalehunt_1a.bas",2940
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 65278
	;[2941] 	DATA $0000,$0000,$0000,$7F1E
	SRCFILE "whalehunt_1a.bas",2941
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 32542
	;[2942] 	DATA $FFFF,$C0FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2942
	DECLE 65535
	DECLE 49407
	DECLE 0
	DECLE 0
	;[2943] 	DATA $F0FC,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2943
	DECLE 61692
	DECLE 0
	DECLE 0
	DECLE 0
	;[2944] 	DATA $0000,$0301,$0F07,$3F1F
	SRCFILE "whalehunt_1a.bas",2944
	DECLE 0
	DECLE 769
	DECLE 3847
	DECLE 16159
	;[2945] 	DATA $7F07,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2945
	DECLE 32519
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[2946] 	DATA $C000,$F0E0,$FCF8,$FFFE
	SRCFILE "whalehunt_1a.bas",2946
	DECLE 49152
	DECLE 61664
	DECLE 64760
	DECLE 65534
	;[2947] 	DATA $0100,$0703,$1F0F,$7F3F
	SRCFILE "whalehunt_1a.bas",2947
	DECLE 256
	DECLE 1795
	DECLE 7951
	DECLE 32575
	;[2948] 	DATA $FEFF,$FEFE,$FEFE,$FCFC
	SRCFILE "whalehunt_1a.bas",2948
	DECLE 65279
	DECLE 65278
	DECLE 65278
	DECLE 64764
	;[2949] 	DATA $7F3F,$7F7F,$FF7F,$FFFF
	SRCFILE "whalehunt_1a.bas",2949
	DECLE 32575
	DECLE 32639
	DECLE 65407
	DECLE 65535
	;[2950] 	DATA $C080,$C1C1,$E3E3,$F7E7
	SRCFILE "whalehunt_1a.bas",2950
	DECLE 49280
	DECLE 49601
	DECLE 58339
	DECLE 63463
	;[2951] 	DATA $FFFF,$EFFF,$CBAF,$F7E7
	SRCFILE "whalehunt_1a.bas",2951
	DECLE 65535
	DECLE 61439
	DECLE 52143
	DECLE 63463
	;[2952] 	DATA $7F7F,$7F7F,$1F3F,$030F
	SRCFILE "whalehunt_1a.bas",2952
	DECLE 32639
	DECLE 32639
	DECLE 7999
	DECLE 783
	;[2953] 	DATA $F8FC,$F8F8,$F0F8,$E0F0
	SRCFILE "whalehunt_1a.bas",2953
	DECLE 63740
	DECLE 63736
	DECLE 61688
	DECLE 57584
	;[2954] 	DATA $FFFF,$8FFF,$C0C3,$E7C3
	SRCFILE "whalehunt_1a.bas",2954
	DECLE 65535
	DECLE 36863
	DECLE 49347
	DECLE 59331
	;[2955] 	DATA $FFFF,$FFFF,$E3FF,$C0C0
	SRCFILE "whalehunt_1a.bas",2955
	DECLE 65535
	DECLE 65535
	DECLE 58367
	DECLE 49344
	;[2956] title_screen_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",2956
	; TITLE_SCREEN_BITMAPS_2
Q8:	;[2957] 	DATA $F0F0,$F0F0,$E0F0,$0040
	SRCFILE "whalehunt_1a.bas",2957
	DECLE 61680
	DECLE 61680
	DECLE 57584
	DECLE 64
	;[2958] 	DATA $7FFF,$000F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2958
	DECLE 32767
	DECLE 15
	DECLE 0
	DECLE 0
	;[2959] 	DATA $C1E3,$8080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2959
	DECLE 49635
	DECLE 32896
	DECLE 0
	DECLE 0
	;[2960] 	DATA $FFFF,$7FFF,$3F7F,$070F
	SRCFILE "whalehunt_1a.bas",2960
	DECLE 65535
	DECLE 32767
	DECLE 16255
	DECLE 1807
	;[2961] 	DATA $0FFF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2961
	DECLE 4095
	DECLE 0
	DECLE 0
	DECLE 0
	;[2962] 	DATA $FFFF,$07FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2962
	DECLE 65535
	DECLE 2047
	DECLE 0
	DECLE 0
	;[2963] 	DATA $C0E0,$80C0,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2963
	DECLE 49376
	DECLE 32960
	DECLE 0
	DECLE 0
	;[2964] 	DATA $7020,$7070,$F979,$7FFB
	SRCFILE "whalehunt_1a.bas",2964
	DECLE 28704
	DECLE 28784
	DECLE 63865
	DECLE 32763
	;[2965] 	DATA $3800,$F078,$E0E0,$C1C0
	SRCFILE "whalehunt_1a.bas",2965
	DECLE 14336
	DECLE 61560
	DECLE 57568
	DECLE 49600
	;[2966] 	DATA $FFFF,$FFFF,$E3F8,$BF8F
	SRCFILE "whalehunt_1a.bas",2966
	DECLE 65535
	DECLE 65535
	DECLE 58360
	DECLE 49039
	;[2967] 	DATA $FFFF,$FFFF,$FF00,$F0FE
	SRCFILE "whalehunt_1a.bas",2967
	DECLE 65535
	DECLE 65535
	DECLE 65280
	DECLE 61694
	;[2968] 	DATA $E0C0,$E0E0,$FC30,$0007
	SRCFILE "whalehunt_1a.bas",2968
	DECLE 57536
	DECLE 57568
	DECLE 64560
	DECLE 7
	;[2969] 	DATA $FFFF,$FFFF,$FFFF,$FBFF
	SRCFILE "whalehunt_1a.bas",2969
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 64511
	;[2970] 	DATA $FEFF,$FEFE,$FCFC,$F8F8
	SRCFILE "whalehunt_1a.bas",2970
	DECLE 65279
	DECLE 65278
	DECLE 64764
	DECLE 63736
	;[2971] 	DATA $73FD,$020F,$FFC7,$FFFF
	SRCFILE "whalehunt_1a.bas",2971
	DECLE 29693
	DECLE 527
	DECLE 65479
	DECLE 65535
	;[2972] 	DATA $7F7F,$3F7F,$1F3F,$070F
	SRCFILE "whalehunt_1a.bas",2972
	DECLE 32639
	DECLE 16255
	DECLE 7999
	DECLE 1807
	;[2973] title_screen_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",2973
	; TITLE_SCREEN_BITMAPS_3
Q9:	;[2974] 	DATA $E3E1,$FFF3,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2974
	DECLE 58337
	DECLE 65523
	DECLE 65535
	DECLE 65535
	;[2975] 	DATA $80C0,$0080,$0000,$C380
	SRCFILE "whalehunt_1a.bas",2975
	DECLE 32960
	DECLE 128
	DECLE 0
	DECLE 50048
	;[2976] 	DATA $FFFF,$FFFF,$BFFF,$030F
	SRCFILE "whalehunt_1a.bas",2976
	DECLE 65535
	DECLE 65535
	DECLE 49151
	DECLE 783
	;[2977] 	DATA $F9C3,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2977
	DECLE 63939
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[2978] 	DATA $F0F8,$F8E0,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",2978
	DECLE 61688
	DECLE 63712
	DECLE 65535
	DECLE 65535
	;[2979] 	DATA $0000,$0000,$F000,$FFFF
	SRCFILE "whalehunt_1a.bas",2979
	DECLE 0
	DECLE 0
	DECLE 61440
	DECLE 65535
	;[2980] 	DATA $0000,$0000,$0000,$F000
	SRCFILE "whalehunt_1a.bas",2980
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 61440
	;[2981] 	DATA $07FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2981
	DECLE 2047
	DECLE 0
	DECLE 0
	DECLE 0
	;[2982] 	DATA $FFFF,$077F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2982
	DECLE 65535
	DECLE 1919
	DECLE 0
	DECLE 0
	;[2983] 	DATA $FFFF,$FFFF,$013F,$0000
	SRCFILE "whalehunt_1a.bas",2983
	DECLE 65535
	DECLE 65535
	DECLE 319
	DECLE 0
	;[2984] 	DATA $FFFF,$FFFF,$FFFF,$0003
	SRCFILE "whalehunt_1a.bas",2984
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 3
	;[2985] 	DATA $FFFF,$FFFF,$FFFF,$03FF
	SRCFILE "whalehunt_1a.bas",2985
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 1023
	;[2986] 	DATA $00FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",2986
	DECLE 255
	DECLE 0
	DECLE 0
	DECLE 0
	;[2987] 	DATA $8080,$C080,$E0C0,$F8F0
	SRCFILE "whalehunt_1a.bas",2987
	DECLE 32896
	DECLE 49280
	DECLE 57536
	DECLE 63728
	;[2988] 
	SRCFILE "whalehunt_1a.bas",2988
	;[2989] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",2989
	;[2990] title_screen_cards:
	SRCFILE "whalehunt_1a.bas",2990
	; TITLE_SCREEN_CARDS
Q12:	;[2991] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2991
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2992] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1C06,$1C0E,$1A16,$1A1A,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2992
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7174
	DECLE 7182
	DECLE 6678
	DECLE 6682
	DECLE 4608
	DECLE 4608
	;[2993] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A16,$1A22,$1200,$1A2A,$1A32,$2C3A,$1C46,$1A4A,$1A52,$1A5A,$1200
	SRCFILE "whalehunt_1a.bas",2993
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6678
	DECLE 6690
	DECLE 4608
	DECLE 6698
	DECLE 6706
	DECLE 11322
	DECLE 7238
	DECLE 6730
	DECLE 6738
	DECLE 6746
	DECLE 4608
	;[2994] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A62,$1A6A,$0400,$0400,$0400,$0400,$1C72,$0400,$1A7A,$1A82,$1200
	SRCFILE "whalehunt_1a.bas",2994
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6754
	DECLE 6762
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7282
	DECLE 1024
	DECLE 6778
	DECLE 6786
	DECLE 4608
	;[2995] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A8F,$0400,$0400,$0400,$0400,$1A92,$1A9A,$1200
	SRCFILE "whalehunt_1a.bas",2995
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6799
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6802
	DECLE 6810
	DECLE 4608
	;[2996] 	DATA $1200,$1200,$1200,$1200,$1200,$1AA7,$1AAF,$2600,$2600,$1AB7,$1200,$1ABF,$2600,$0400,$0400,$0400,$1AC2,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2996
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6823
	DECLE 6831
	DECLE 9728
	DECLE 9728
	DECLE 6839
	DECLE 4608
	DECLE 6847
	DECLE 9728
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6850
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2997] 	DATA $1200,$1200,$1200,$1200,$1200,$1ACF,$2600,$2600,$2600,$2600,$1AD7,$2600,$18DF,$2EE2,$0400,$0400,$1AEA,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2997
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6863
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 6871
	DECLE 9728
	DECLE 6367
	DECLE 12002
	DECLE 1024
	DECLE 1024
	DECLE 6890
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2998] 	DATA $1200,$1200,$1200,$1200,$1200,$2600,$08F7,$2600,$2600,$08FF,$0907,$090F,$1B17,$1B1F,$2F22,$2F2A,$1B32,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2998
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 9728
	DECLE 2295
	DECLE 9728
	DECLE 9728
	DECLE 2303
	DECLE 2311
	DECLE 2319
	DECLE 6935
	DECLE 6943
	DECLE 12066
	DECLE 12074
	DECLE 6962
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[2999] 	DATA $1200,$1200,$1200,$1B3F,$1B47,$2600,$2600,$094F,$0957,$095F,$1B60,$1B68,$1200,$1200,$1977,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",2999
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6975
	DECLE 6983
	DECLE 9728
	DECLE 9728
	DECLE 2383
	DECLE 2391
	DECLE 2399
	DECLE 7008
	DECLE 7016
	DECLE 4608
	DECLE 4608
	DECLE 6519
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3000] 	DATA $1200,$1200,$1200,$1B7F,$1B87,$2600,$2600,$2600,$098F,$1D90,$1B98,$1BA0,$1BA8,$1BB0,$2600,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3000
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7039
	DECLE 7047
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 2447
	DECLE 7568
	DECLE 7064
	DECLE 7072
	DECLE 7080
	DECLE 7088
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3001] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1400,$1DB8,$1DC0,$1DC8,$1DD0,$1DD8,$0000,$09E1,$09E1,$09E1,$09E1
	SRCFILE "whalehunt_1a.bas",3001
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 5120
	DECLE 7608
	DECLE 7616
	DECLE 7624
	DECLE 7632
	DECLE 7640
	DECLE 0
	DECLE 2529
	DECLE 2529
	DECLE 2529
	DECLE 2529
	;[3002] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1DE9,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400
	SRCFILE "whalehunt_1a.bas",3002
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7657
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	;[3003] 
	SRCFILE "whalehunt_1a.bas",3003
	;[3004] 
	SRCFILE "whalehunt_1a.bas",3004
	;[3005] 	' 61 bitmaps
	SRCFILE "whalehunt_1a.bas",3005
	;[3006] beat_level_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",3006
	; BEAT_LEVEL_BITMAPS_0
Q223:	;[3007] 	DATA $0000,$0000,$0000,$0F00
	SRCFILE "whalehunt_1a.bas",3007
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 3840
	;[3008] 	DATA $0000,$0000,$0F00,$F0FF
	SRCFILE "whalehunt_1a.bas",3008
	DECLE 0
	DECLE 0
	DECLE 3840
	DECLE 61695
	;[3009] 	DATA $0000,$0F00,$F0FF,$0000
	SRCFILE "whalehunt_1a.bas",3009
	DECLE 0
	DECLE 3840
	DECLE 61695
	DECLE 0
	;[3010] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",3010
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[3011] 	DATA $0000,$0000,$C080,$F0E0
	SRCFILE "whalehunt_1a.bas",3011
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 61664
	;[3012] 	DATA $0000,$0000,$1F00,$FFFF
	SRCFILE "whalehunt_1a.bas",3012
	DECLE 0
	DECLE 0
	DECLE 7936
	DECLE 65535
	;[3013] 	DATA $0000,$0000,$FF1F,$E0F8
	SRCFILE "whalehunt_1a.bas",3013
	DECLE 0
	DECLE 0
	DECLE 65311
	DECLE 57592
	;[3014] 	DATA $0F00,$F0FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3014
	DECLE 3840
	DECLE 61695
	DECLE 0
	DECLE 0
	;[3015] 	DATA $F0FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3015
	DECLE 61695
	DECLE 0
	DECLE 0
	DECLE 0
	;[3016] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",3016
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[3017] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",3017
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[3018] 	DATA $FCF8,$FFFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3018
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 65535
	;[3019] 	DATA $0000,$0300,$0F07,$0F0F
	SRCFILE "whalehunt_1a.bas",3019
	DECLE 0
	DECLE 768
	DECLE 3847
	DECLE 3855
	;[3020] 	DATA $0F00,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3020
	DECLE 3840
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3021] 	DATA $FFFF,$FFFF,$FFFF,$FEFF
	SRCFILE "whalehunt_1a.bas",3021
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 65279
	;[3022] 	DATA $FFFF,$FEFF,$E0F8,$0080
	SRCFILE "whalehunt_1a.bas",3022
	DECLE 65535
	DECLE 65279
	DECLE 57592
	DECLE 128
	;[3023] beat_level_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",3023
	; BEAT_LEVEL_BITMAPS_1
Q224:	;[3024] 	DATA $80C0,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3024
	DECLE 32960
	DECLE 0
	DECLE 0
	DECLE 0
	;[3025] 	DATA $FFFF,$7F7F,$3F3F,$0F1F
	SRCFILE "whalehunt_1a.bas",3025
	DECLE 65535
	DECLE 32639
	DECLE 16191
	DECLE 3871
	;[3026] 	DATA $E0C0,$F8F0,$FEFC,$FFFF
	SRCFILE "whalehunt_1a.bas",3026
	DECLE 57536
	DECLE 63728
	DECLE 65276
	DECLE 65535
	;[3027] 	DATA $0000,$0000,$0000,$FF01
	SRCFILE "whalehunt_1a.bas",3027
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65281
	;[3028] 	DATA $0000,$0000,$3F00,$FFFF
	SRCFILE "whalehunt_1a.bas",3028
	DECLE 0
	DECLE 0
	DECLE 16128
	DECLE 65535
	;[3029] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",3029
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[3030] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",3030
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[3031] 	DATA $3F7F,$0F1F,$0307,$FF07
	SRCFILE "whalehunt_1a.bas",3031
	DECLE 16255
	DECLE 3871
	DECLE 775
	DECLE 65287
	;[3032] 	DATA $FCF8,$FEFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3032
	DECLE 64760
	DECLE 65278
	DECLE 65535
	DECLE 65535
	;[3033] 	DATA $0F0F,$0107,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3033
	DECLE 3855
	DECLE 263
	DECLE 0
	DECLE 0
	;[3034] 	DATA $FFFF,$FEFF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3034
	DECLE 65535
	DECLE 65279
	DECLE 0
	DECLE 0
	;[3035] 	DATA $E0F8,$0080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3035
	DECLE 57592
	DECLE 128
	DECLE 0
	DECLE 0
	;[3036] 	DATA $0307,$0001,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3036
	DECLE 775
	DECLE 1
	DECLE 0
	DECLE 0
	;[3037] 	DATA $FFFF,$FFFF,$3F7F,$031F
	SRCFILE "whalehunt_1a.bas",3037
	DECLE 65535
	DECLE 65535
	DECLE 16255
	DECLE 799
	;[3038] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",3038
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[3039] 	DATA $FFFF,$FEFF,$F8FE,$C0F0
	SRCFILE "whalehunt_1a.bas",3039
	DECLE 65535
	DECLE 65279
	DECLE 63742
	DECLE 49392
	;[3040] beat_level_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",3040
	; BEAT_LEVEL_BITMAPS_2
Q225:	;[3041] 	DATA $0000,$0000,$0000,$7F1E
	SRCFILE "whalehunt_1a.bas",3041
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 32542
	;[3042] 	DATA $0100,$0703,$1F0F,$7F3F
	SRCFILE "whalehunt_1a.bas",3042
	DECLE 256
	DECLE 1795
	DECLE 7951
	DECLE 32575
	;[3043] 	DATA $FEFF,$FEFE,$FEFE,$FCFC
	SRCFILE "whalehunt_1a.bas",3043
	DECLE 65279
	DECLE 65278
	DECLE 65278
	DECLE 64764
	;[3044] 	DATA $0000,$0101,$0303,$0707
	SRCFILE "whalehunt_1a.bas",3044
	DECLE 0
	DECLE 257
	DECLE 771
	DECLE 1799
	;[3045] 	DATA $FFFF,$EFFF,$CBAF,$F7E7
	SRCFILE "whalehunt_1a.bas",3045
	DECLE 65535
	DECLE 61439
	DECLE 52143
	DECLE 63463
	;[3046] 	DATA $7F7F,$7F7F,$1F3F,$030F
	SRCFILE "whalehunt_1a.bas",3046
	DECLE 32639
	DECLE 32639
	DECLE 7999
	DECLE 783
	;[3047] 	DATA $F8FC,$F8F8,$F0F8,$E0F0
	SRCFILE "whalehunt_1a.bas",3047
	DECLE 63740
	DECLE 63736
	DECLE 61688
	DECLE 57584
	;[3048] 	DATA $0F0F,$0F0F,$1F0F,$FF3F
	SRCFILE "whalehunt_1a.bas",3048
	DECLE 3855
	DECLE 3855
	DECLE 7951
	DECLE 65343
	;[3049] 	DATA $7FFF,$000F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3049
	DECLE 32767
	DECLE 15
	DECLE 0
	DECLE 0
	;[3050] 	DATA $C1E3,$8080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3050
	DECLE 49635
	DECLE 32896
	DECLE 0
	DECLE 0
	;[3051] 	DATA $FFFF,$7FFF,$3F7F,$070F
	SRCFILE "whalehunt_1a.bas",3051
	DECLE 65535
	DECLE 32767
	DECLE 16255
	DECLE 1807
	;[3052] 	DATA $0FFF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3052
	DECLE 4095
	DECLE 0
	DECLE 0
	DECLE 0
	;[3053] 	DATA $FFFF,$07FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3053
	DECLE 65535
	DECLE 2047
	DECLE 0
	DECLE 0
	;[3054] 	DATA $C0E0,$80C0,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3054
	DECLE 49376
	DECLE 32960
	DECLE 0
	DECLE 0
	;[3055] 	DATA $0000,$0000,$0000,$3F0F
	SRCFILE "whalehunt_1a.bas",3055
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 16143
	;[3056] 	DATA $0000,$0000,$0000,$C400
	SRCFILE "whalehunt_1a.bas",3056
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 50176
	;[3057] beat_level_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",3057
	; BEAT_LEVEL_BITMAPS_3
Q226:	;[3058] 	DATA $0100,$0101,$0303,$0707
	SRCFILE "whalehunt_1a.bas",3058
	DECLE 256
	DECLE 257
	DECLE 771
	DECLE 1799
	;[3059] 	DATA $FFF8,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3059
	DECLE 65528
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3060] 	DATA $FF00,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3060
	DECLE 65280
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3061] 	DATA $0FFF,$FFF0,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3061
	DECLE 4095
	DECLE 65520
	DECLE 65535
	DECLE 65535
	;[3062] 	DATA $0000,$C000,$FCF0,$FFFF
	SRCFILE "whalehunt_1a.bas",3062
	DECLE 0
	DECLE 49152
	DECLE 64752
	DECLE 65535
	;[3063] 	DATA $0000,$0000,$0000,$F080
	SRCFILE "whalehunt_1a.bas",3063
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 61568
	;[3064] 	DATA $FEFC,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3064
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3065] 	DATA $0F07,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3065
	DECLE 3847
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3066] 	DATA $FFFE,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3066
	DECLE 65534
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3067] 	DATA $8000,$F8E0,$FFFE,$FFFF
	SRCFILE "whalehunt_1a.bas",3067
	DECLE 32768
	DECLE 63712
	DECLE 65534
	DECLE 65535
	;[3068] 	DATA $0000,$0000,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",3068
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 64736
	;[3069] 	DATA $FEFF,$FCFC,$F8F8,$F0F0
	SRCFILE "whalehunt_1a.bas",3069
	DECLE 65279
	DECLE 64764
	DECLE 63736
	DECLE 61680
	;[3070] 	DATA $E0F0,$E0E0,$C0C0,$C0C0
	SRCFILE "whalehunt_1a.bas",3070
	DECLE 57584
	DECLE 57568
	DECLE 49344
	DECLE 49344
	;[3071] 
	SRCFILE "whalehunt_1a.bas",3071
	;[3072] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3072
	;[3073] beat_level_cards:
	SRCFILE "whalehunt_1a.bas",3073
	; BEAT_LEVEL_CARDS
Q230:	;[3074] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A04,$1A0C,$1A14,$1A1E,$1A22,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3074
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6660
	DECLE 6668
	DECLE 6676
	DECLE 6686
	DECLE 6690
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3075] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A04,$1A2C,$1A34,$1A1E,$1A3C,$1A44,$1200,$1C4E,$1C56,$1A5A,$1A22,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3075
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6660
	DECLE 6700
	DECLE 6708
	DECLE 6686
	DECLE 6716
	DECLE 6724
	DECLE 4608
	DECLE 7246
	DECLE 7254
	DECLE 6746
	DECLE 6690
	DECLE 4608
	DECLE 4608
	;[3076] 	DATA $1200,$1200,$1200,$1200,$1200,$1A64,$1A6C,$1A74,$1A7C,$1A84,$1A8A,$1A92,$1A9A,$1AA2,$2CAA,$1CB6,$1ABA,$1AC2,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3076
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6756
	DECLE 6764
	DECLE 6772
	DECLE 6780
	DECLE 6788
	DECLE 6794
	DECLE 6802
	DECLE 6810
	DECLE 6818
	DECLE 11434
	DECLE 7350
	DECLE 6842
	DECLE 6850
	DECLE 4608
	DECLE 4608
	;[3077] 	DATA $1200,$1200,$1200,$1200,$1200,$1ACC,$1AD4,$1ADC,$1200,$1200,$1AE2,$1AEA,$0400,$0400,$0400,$1CF2,$0400,$1AFA,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3077
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6860
	DECLE 6868
	DECLE 6876
	DECLE 4608
	DECLE 4608
	DECLE 6882
	DECLE 6890
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7410
	DECLE 1024
	DECLE 6906
	DECLE 4608
	DECLE 4608
	;[3078] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B07,$0400,$0400,$0400,$0400,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3078
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6919
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3079] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B0F,$2600,$0400,$0400,$0400,$1B12,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3079
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6927
	DECLE 9728
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6930
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3080] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B1F,$2600,$1927,$2F2A,$0400,$0400,$1B32,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3080
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6943
	DECLE 9728
	DECLE 6439
	DECLE 12074
	DECLE 1024
	DECLE 1024
	DECLE 6962
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3081] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B38,$0947,$1B4F,$1B57,$2F5A,$2F62,$1B6A,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3081
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6968
	DECLE 2375
	DECLE 6991
	DECLE 6999
	DECLE 12122
	DECLE 12130
	DECLE 7018
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3082] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B77,$097F,$0987,$2600,$098F,$0997,$099F,$1BA7,$1BAF,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3082
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7031
	DECLE 2431
	DECLE 2439
	DECLE 9728
	DECLE 2447
	DECLE 2455
	DECLE 2463
	DECLE 7079
	DECLE 7087
	DECLE 4608
	DECLE 4608
	;[3083] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B0F,$2600,$09B7,$09BF,$2600,$2600,$2600,$2600,$2600,$1BC7,$1BCF,$1BD7
	SRCFILE "whalehunt_1a.bas",3083
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6927
	DECLE 9728
	DECLE 2487
	DECLE 2495
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7111
	DECLE 7119
	DECLE 7127
	;[3084] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$2FD9,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600
	SRCFILE "whalehunt_1a.bas",3084
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 12249
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	;[3085] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$2FE1,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600,$2600
	SRCFILE "whalehunt_1a.bas",3085
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 12257
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	;[3086] 
	SRCFILE "whalehunt_1a.bas",3086
	;[3087] 	' 54 bitmaps
	SRCFILE "whalehunt_1a.bas",3087
	;[3088] lose_life_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",3088
	; LOSE_LIFE_BITMAPS_0
Q215:	;[3089] 	DATA $0000,$0000,$0000,$1F07
	SRCFILE "whalehunt_1a.bas",3089
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 7943
	;[3090] 	DATA $0000,$0000,$7F00,$FFFF
	SRCFILE "whalehunt_1a.bas",3090
	DECLE 0
	DECLE 0
	DECLE 32512
	DECLE 65535
	;[3091] 	DATA $0000,$0000,$FF00,$FFFF
	SRCFILE "whalehunt_1a.bas",3091
	DECLE 0
	DECLE 0
	DECLE 65280
	DECLE 65535
	;[3092] 	DATA $0000,$0000,$F000,$FEFC
	SRCFILE "whalehunt_1a.bas",3092
	DECLE 0
	DECLE 0
	DECLE 61440
	DECLE 65276
	;[3093] 	DATA $0000,$0100,$0303,$0707
	SRCFILE "whalehunt_1a.bas",3093
	DECLE 0
	DECLE 256
	DECLE 771
	DECLE 1799
	;[3094] 	DATA $7F3F,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3094
	DECLE 32575
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3095] 	DATA $8000,$E0C0,$F8F0,$FCFC
	SRCFILE "whalehunt_1a.bas",3095
	DECLE 32768
	DECLE 57536
	DECLE 63728
	DECLE 64764
	;[3096] 	DATA $0000,$0000,$0800,$0C0C
	SRCFILE "whalehunt_1a.bas",3096
	DECLE 0
	DECLE 0
	DECLE 2048
	DECLE 3084
	;[3097] 	DATA $0000,$0000,$0000,$1000
	SRCFILE "whalehunt_1a.bas",3097
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 4096
	;[3098] 	DATA $0707,$0F0F,$0F0F,$0F0F
	SRCFILE "whalehunt_1a.bas",3098
	DECLE 1799
	DECLE 3855
	DECLE 3855
	DECLE 3855
	;[3099] 	DATA $FEFC,$FEFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3099
	DECLE 65276
	DECLE 65278
	DECLE 65535
	DECLE 65535
	;[3100] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",3100
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[3101] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",3101
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[3102] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",3102
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[3103] 	DATA $0000,$0000,$0000,$F8F0
	SRCFILE "whalehunt_1a.bas",3103
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 63728
	;[3104] 	DATA $0E0C,$0E0E,$0F0F,$0F0F
	SRCFILE "whalehunt_1a.bas",3104
	DECLE 3596
	DECLE 3598
	DECLE 3855
	DECLE 3855
	;[3105] lose_life_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",3105
	; LOSE_LIFE_BITMAPS_1
Q216:	;[3106] 	DATA $3010,$7030,$F870,$FCFC
	SRCFILE "whalehunt_1a.bas",3106
	DECLE 12304
	DECLE 28720
	DECLE 63600
	DECLE 64764
	;[3107] 	DATA $0F0F,$0F0F,$0F0F,$1F0F
	SRCFILE "whalehunt_1a.bas",3107
	DECLE 3855
	DECLE 3855
	DECLE 3855
	DECLE 7951
	;[3108] 	DATA $FCF8,$FCFC,$FFFE,$FFFF
	SRCFILE "whalehunt_1a.bas",3108
	DECLE 64760
	DECLE 64764
	DECLE 65534
	DECLE 65535
	;[3109] 	DATA $3FFF,$3F0F,$FF7F,$FFFF
	SRCFILE "whalehunt_1a.bas",3109
	DECLE 16383
	DECLE 16143
	DECLE 65407
	DECLE 65535
	;[3110] 	DATA $FFFF,$FFFF,$FFFF,$FEFF
	SRCFILE "whalehunt_1a.bas",3110
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 65279
	;[3111] 	DATA $0000,$C000,$F8F0,$FFFC
	SRCFILE "whalehunt_1a.bas",3111
	DECLE 0
	DECLE 49152
	DECLE 63728
	DECLE 65532
	;[3112] 	DATA $0000,$0000,$0000,$0701
	SRCFILE "whalehunt_1a.bas",3112
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1793
	;[3113] 	DATA $0000,$0000,$3F00,$FFFF
	SRCFILE "whalehunt_1a.bas",3113
	DECLE 0
	DECLE 0
	DECLE 16128
	DECLE 65535
	;[3114] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",3114
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[3115] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",3115
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[3116] 	DATA $3F3F,$0F1F,$0307,$FC01
	SRCFILE "whalehunt_1a.bas",3116
	DECLE 16191
	DECLE 3871
	DECLE 775
	DECLE 64513
	;[3117] 	DATA $FCF8,$FFFE,$FFFF,$7FFF
	SRCFILE "whalehunt_1a.bas",3117
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 32767
	;[3118] 	DATA $0000,$0000,$C080,$F0E0
	SRCFILE "whalehunt_1a.bas",3118
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 61664
	;[3119] 	DATA $0F0F,$0F0F,$070F,$0103
	SRCFILE "whalehunt_1a.bas",3119
	DECLE 3855
	DECLE 3855
	DECLE 1807
	DECLE 259
	;[3120] 	DATA $3F1F,$7F3F,$FF7F,$FFFF
	SRCFILE "whalehunt_1a.bas",3120
	DECLE 16159
	DECLE 32575
	DECLE 65407
	DECLE 65535
	;[3121] 	DATA $FFFF,$F8FE,$FFFB,$FFFF
	SRCFILE "whalehunt_1a.bas",3121
	DECLE 65535
	DECLE 63742
	DECLE 65531
	DECLE 65535
	;[3122] lose_life_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",3122
	; LOSE_LIFE_BITMAPS_2
Q217:	;[3123] 	DATA $80FF,$FF3F,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3123
	DECLE 33023
	DECLE 65343
	DECLE 65535
	DECLE 65535
	;[3124] 	DATA $03FF,$FFFF,$FCFF,$E0F0
	SRCFILE "whalehunt_1a.bas",3124
	DECLE 1023
	DECLE 65535
	DECLE 64767
	DECLE 57584
	;[3125] 	DATA $FEFE,$FCFC,$10F8,$0000
	SRCFILE "whalehunt_1a.bas",3125
	DECLE 65278
	DECLE 64764
	DECLE 4344
	DECLE 0
	;[3126] 	DATA $0301,$0307,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3126
	DECLE 769
	DECLE 775
	DECLE 0
	DECLE 0
	;[3127] 	DATA $FFFF,$FFFF,$0F3F,$0003
	SRCFILE "whalehunt_1a.bas",3127
	DECLE 65535
	DECLE 65535
	DECLE 3903
	DECLE 3
	;[3128] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",3128
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[3129] 	DATA $9F3F,$FFEF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3129
	DECLE 40767
	DECLE 65519
	DECLE 65535
	DECLE 65535
	;[3130] 	DATA $FCF8,$FFFE,$FFFF,$FEFE
	SRCFILE "whalehunt_1a.bas",3130
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 65278
	;[3131] 	DATA $3F1F,$001F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3131
	DECLE 16159
	DECLE 31
	DECLE 0
	DECLE 0
	;[3132] 	DATA $FFFF,$00FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3132
	DECLE 65535
	DECLE 255
	DECLE 0
	DECLE 0
	;[3133] 	DATA $FEFF,$00FC,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3133
	DECLE 65279
	DECLE 252
	DECLE 0
	DECLE 0
	;[3134] 	DATA $1FFF,$000F,$4140,$8F43
	SRCFILE "whalehunt_1a.bas",3134
	DECLE 8191
	DECLE 15
	DECLE 16704
	DECLE 36675
	;[3135] 	DATA $C080,$0080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3135
	DECLE 49280
	DECLE 128
	DECLE 0
	DECLE 0
	;[3136] 	DATA $FFFF,$C0FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3136
	DECLE 65535
	DECLE 49407
	DECLE 0
	DECLE 0
	;[3137] 	DATA $F0FC,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3137
	DECLE 61692
	DECLE 0
	DECLE 0
	DECLE 0
	;[3138] 	DATA $C7E7,$8787,$0707,$0707
	SRCFILE "whalehunt_1a.bas",3138
	DECLE 51175
	DECLE 34695
	DECLE 1799
	DECLE 1799
	;[3139] lose_life_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",3139
	; LOSE_LIFE_BITMAPS_3
Q218:	;[3140] 	DATA $0100,$0101,$0101,$0303
	SRCFILE "whalehunt_1a.bas",3140
	DECLE 256
	DECLE 257
	DECLE 257
	DECLE 771
	;[3141] 	DATA $FF8F,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3141
	DECLE 65423
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3142] 	DATA $9309,$DBB9,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3142
	DECLE 37641
	DECLE 56249
	DECLE 65535
	DECLE 65535
	;[3143] 	DATA $8810,$DBC9,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3143
	DECLE 34832
	DECLE 56265
	DECLE 65535
	DECLE 65535
	;[3144] 	DATA $8949,$BBDC,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3144
	DECLE 35145
	DECLE 48092
	DECLE 65535
	DECLE 65535
	;[3145] 	DATA $8B43,$BFDF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3145
	DECLE 35651
	DECLE 49119
	DECLE 65535
	DECLE 65535
	;[3146] 
	SRCFILE "whalehunt_1a.bas",3146
	;[3147] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3147
	;[3148] lose_life_cards:
	SRCFILE "whalehunt_1a.bas",3148
	; LOSE_LIFE_CARDS
Q221:	;[3149] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3149
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3150] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3150
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3151] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3151
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3152] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3152
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3153] 	DATA $1200,$1200,$1200,$1A07,$1A0F,$1A17,$1A1F,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3153
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6663
	DECLE 6671
	DECLE 6679
	DECLE 6687
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3154] 	DATA $1200,$1200,$1A27,$1A2F,$2600,$2600,$2600,$1A37,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3154
	DECLE 4608
	DECLE 4608
	DECLE 6695
	DECLE 6703
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 6711
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3155] 	DATA $1A3F,$1A47,$1A4F,$2600,$2600,$2600,$2600,$1A57,$1200,$1200,$1200,$1200,$1200,$1200,$1C5E,$1C66,$1A6E,$1A72,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3155
	DECLE 6719
	DECLE 6727
	DECLE 6735
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 6743
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7262
	DECLE 7270
	DECLE 6766
	DECLE 6770
	DECLE 4608
	DECLE 4608
	;[3156] 	DATA $1A7F,$1A87,$1A8F,$0897,$089F,$2600,$2600,$1AA7,$1200,$1A6E,$1AAA,$1200,$1AB2,$1ABA,$2CC2,$1CCE,$1AD2,$1ADA,$1AE2,$1200
	SRCFILE "whalehunt_1a.bas",3156
	DECLE 6783
	DECLE 6791
	DECLE 6799
	DECLE 2199
	DECLE 2207
	DECLE 9728
	DECLE 9728
	DECLE 6823
	DECLE 4608
	DECLE 6766
	DECLE 6826
	DECLE 4608
	DECLE 6834
	DECLE 6842
	DECLE 11458
	DECLE 7374
	DECLE 6866
	DECLE 6874
	DECLE 6882
	DECLE 4608
	;[3157] 	DATA $1AEF,$1A57,$1AF7,$2600,$08FF,$0907,$090F,$1B17,$1200,$1B1A,$1B22,$0400,$0400,$0400,$0400,$1D2A,$0400,$1B32,$1B3A,$1200
	SRCFILE "whalehunt_1a.bas",3157
	DECLE 6895
	DECLE 6743
	DECLE 6903
	DECLE 9728
	DECLE 2303
	DECLE 2311
	DECLE 2319
	DECLE 6935
	DECLE 4608
	DECLE 6938
	DECLE 6946
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7466
	DECLE 1024
	DECLE 6962
	DECLE 6970
	DECLE 4608
	;[3158] 	DATA $1B40,$1D48,$1D48,$1D48,$1D48,$1D48,$1D50,$1D58,$1B60,$1200,$1200,$1200,$1200,$0400,$0400,$0400,$0400,$1B6A,$1B72,$1200
	SRCFILE "whalehunt_1a.bas",3158
	DECLE 6976
	DECLE 7496
	DECLE 7496
	DECLE 7496
	DECLE 7496
	DECLE 7496
	DECLE 7504
	DECLE 7512
	DECLE 7008
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7018
	DECLE 7026
	DECLE 4608
	;[3159] 	DATA $0200,$0200,$2979,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0D81,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3159
	DECLE 512
	DECLE 512
	DECLE 10617
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3457
	DECLE 512
	DECLE 512
	DECLE 512
	;[3160] 	DATA $0200,$0200,$2989,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D91,$0D99,$0DA1,$0DA9,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3160
	DECLE 512
	DECLE 512
	DECLE 10633
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3473
	DECLE 3481
	DECLE 3489
	DECLE 3497
	DECLE 512
	DECLE 512
	DECLE 512
	;[3161] 	
	SRCFILE "whalehunt_1a.bas",3161
	;[3162] REM ===============================BACKGROUND DATA==========================================	
	SRCFILE "whalehunt_1a.bas",3162
	;[3163] asm org $c040
	SRCFILE "whalehunt_1a.bas",3163
 org $c040
	;[3164] dim_check:	procedure
	SRCFILE "whalehunt_1a.bas",3164
	; DIM_CHECK
Q92:	PROC
	BEGIN
	;[3165] 	if player_x < 16 then player_x = 16
	SRCFILE "whalehunt_1a.bas",3165
	MVI V18,R0
	CMPI #16,R0
	BGE T642
	MVII #16,R0
	MVO R0,V18
T642:
	;[3166] 	if player_x > 150 then player_x = 150
	SRCFILE "whalehunt_1a.bas",3166
	MVI V18,R0
	CMPI #150,R0
	BLE T643
	MVII #150,R0
	MVO R0,V18
T643:
	;[3167] 	if player_y < 25 then player_y = 25
	SRCFILE "whalehunt_1a.bas",3167
	MVI V19,R0
	CMPI #25,R0
	BGE T644
	MVII #25,R0
	MVO R0,V19
T644:
	;[3168] 	if player_y > 80 then player_y = 80
	SRCFILE "whalehunt_1a.bas",3168
	MVI V19,R0
	CMPI #80,R0
	BLE T645
	MVII #80,R0
	MVO R0,V19
T645:
	;[3169] 	if whalex_map < 16 then whalex_map = 16
	SRCFILE "whalehunt_1a.bas",3169
	MVI V20,R0
	CMPI #16,R0
	BGE T646
	MVII #16,R0
	MVO R0,V20
T646:
	;[3170] 	if whalex_map > 150 then whalex_map = 150
	SRCFILE "whalehunt_1a.bas",3170
	MVI V20,R0
	CMPI #150,R0
	BLE T647
	MVII #150,R0
	MVO R0,V20
T647:
	;[3171] 	if whaley_map < 25 then whaley_map = 25
	SRCFILE "whalehunt_1a.bas",3171
	MVI V21,R0
	CMPI #25,R0
	BGE T648
	MVII #25,R0
	MVO R0,V21
T648:
	;[3172] 	if whaley_map > 70 then whaley_map = 70
	SRCFILE "whalehunt_1a.bas",3172
	MVI V21,R0
	CMPI #70,R0
	BLE T649
	MVII #70,R0
	MVO R0,V21
T649:
	;[3173] 	end
	SRCFILE "whalehunt_1a.bas",3173
	RETURN
	ENDP
	;[3174] 	' 53 bitmaps
	SRCFILE "whalehunt_1a.bas",3174
	;[3175] row_throw_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",3175
	; ROW_THROW_BITMAPS_0
Q53:	;[3176] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",3176
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[3177] 	DATA $0000,$0000,$C000,$F0E0
	SRCFILE "whalehunt_1a.bas",3177
	DECLE 0
	DECLE 0
	DECLE 49152
	DECLE 61664
	;[3178] 	DATA $0000,$0100,$0301,$0703
	SRCFILE "whalehunt_1a.bas",3178
	DECLE 0
	DECLE 256
	DECLE 769
	DECLE 1795
	;[3179] 	DATA $1F1F,$0F1F,$0307,$0001
	SRCFILE "whalehunt_1a.bas",3179
	DECLE 7967
	DECLE 3871
	DECLE 775
	DECLE 1
	;[3180] 	DATA $FCF8,$FFFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3180
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 65535
	;[3181] 	DATA $0000,$0000,$C080,$F0E0
	SRCFILE "whalehunt_1a.bas",3181
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 61664
	;[3182] 	DATA $0000,$0000,$0000,$0F00
	SRCFILE "whalehunt_1a.bas",3182
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 3840
	;[3183] 	DATA $0000,$0000,$0F00,$F0FF
	SRCFILE "whalehunt_1a.bas",3183
	DECLE 0
	DECLE 0
	DECLE 3840
	DECLE 61695
	;[3184] 	DATA $0000,$0F00,$F0FF,$0000
	SRCFILE "whalehunt_1a.bas",3184
	DECLE 0
	DECLE 3840
	DECLE 61695
	DECLE 0
	;[3185] 	DATA $0E06,$1C0C,$3818,$7030
	SRCFILE "whalehunt_1a.bas",3185
	DECLE 3590
	DECLE 7180
	DECLE 14360
	DECLE 28720
	;[3186] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",3186
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[3187] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",3187
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[3188] 	DATA $0000,$0000,$C080,$E0C0
	SRCFILE "whalehunt_1a.bas",3188
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 57536
	;[3189] 	DATA $0000,$0000,$1F00,$FFFF
	SRCFILE "whalehunt_1a.bas",3189
	DECLE 0
	DECLE 0
	DECLE 7936
	DECLE 65535
	;[3190] 	DATA $0000,$0000,$FF1F,$E0F8
	SRCFILE "whalehunt_1a.bas",3190
	DECLE 0
	DECLE 0
	DECLE 65311
	DECLE 57592
	;[3191] 	DATA $0F00,$F0FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3191
	DECLE 3840
	DECLE 61695
	DECLE 0
	DECLE 0
	;[3192] row_throw_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",3192
	; ROW_THROW_BITMAPS_1
Q54:	;[3193] 	DATA $F0FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3193
	DECLE 61695
	DECLE 0
	DECLE 0
	DECLE 0
	;[3194] 	DATA $E060,$C0C0,$8080,$0000
	SRCFILE "whalehunt_1a.bas",3194
	DECLE 57440
	DECLE 49344
	DECLE 32896
	DECLE 0
	;[3195] 	DATA $0000,$C000,$F8F0,$FFFC
	SRCFILE "whalehunt_1a.bas",3195
	DECLE 0
	DECLE 49152
	DECLE 63728
	DECLE 65532
	;[3196] 	DATA $0000,$0000,$0000,$0701
	SRCFILE "whalehunt_1a.bas",3196
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1793
	;[3197] 	DATA $0000,$0000,$3F00,$FFFF
	SRCFILE "whalehunt_1a.bas",3197
	DECLE 0
	DECLE 0
	DECLE 16128
	DECLE 65535
	;[3198] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",3198
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[3199] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",3199
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[3200] 	DATA $0000,$0000,$0700,$1F0F
	SRCFILE "whalehunt_1a.bas",3200
	DECLE 0
	DECLE 0
	DECLE 1792
	DECLE 7951
	;[3201] 	DATA $E081,$FEF8,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3201
	DECLE 57473
	DECLE 65272
	DECLE 65535
	DECLE 65535
	;[3202] 	DATA $FFFF,$0F3F,$E381,$EFEB
	SRCFILE "whalehunt_1a.bas",3202
	DECLE 65535
	DECLE 3903
	DECLE 58241
	DECLE 61419
	;[3203] 	DATA $F0E0,$F8F0,$FCF8,$FCFC
	SRCFILE "whalehunt_1a.bas",3203
	DECLE 61664
	DECLE 63728
	DECLE 64760
	DECLE 64764
	;[3204] 	DATA $0000,$0300,$0F07,$0F0F
	SRCFILE "whalehunt_1a.bas",3204
	DECLE 0
	DECLE 768
	DECLE 3847
	DECLE 3855
	;[3205] 	DATA $0F00,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3205
	DECLE 3840
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3206] 	DATA $FFFF,$FFFF,$FFFF,$FEFF
	SRCFILE "whalehunt_1a.bas",3206
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 65279
	;[3207] 	DATA $FFFF,$FEFF,$E0F8,$0080
	SRCFILE "whalehunt_1a.bas",3207
	DECLE 65535
	DECLE 65279
	DECLE 57592
	DECLE 128
	;[3208] 	DATA $80C0,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3208
	DECLE 32960
	DECLE 0
	DECLE 0
	DECLE 0
	;[3209] row_throw_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",3209
	; ROW_THROW_BITMAPS_2
Q55:	;[3210] 	DATA $FFFF,$7F7F,$3F3F,$0F1F
	SRCFILE "whalehunt_1a.bas",3210
	DECLE 65535
	DECLE 32639
	DECLE 16191
	DECLE 3871
	;[3211] 	DATA $E0C0,$F8F0,$FEFC,$FFFF
	SRCFILE "whalehunt_1a.bas",3211
	DECLE 57536
	DECLE 63728
	DECLE 65276
	DECLE 65535
	;[3212] 	DATA $0000,$0000,$0000,$FF01
	SRCFILE "whalehunt_1a.bas",3212
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65281
	;[3213] 	DATA $3F7F,$0F1F,$0307,$FF07
	SRCFILE "whalehunt_1a.bas",3213
	DECLE 16255
	DECLE 3871
	DECLE 775
	DECLE 65287
	;[3214] 	DATA $FCF8,$FEFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3214
	DECLE 64760
	DECLE 65278
	DECLE 65535
	DECLE 65535
	;[3215] 	DATA $FCFE,$FCF8,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3215
	DECLE 64766
	DECLE 64760
	DECLE 65535
	DECLE 65535
	;[3216] 	DATA $0000,$0000,$F0C0,$FFFC
	SRCFILE "whalehunt_1a.bas",3216
	DECLE 0
	DECLE 0
	DECLE 61632
	DECLE 65532
	;[3217] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",3217
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[3218] 	DATA $60C0,$0010,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3218
	DECLE 24768
	DECLE 16
	DECLE 0
	DECLE 0
	;[3219] 	DATA $0307,$0001,$0000,$0101
	SRCFILE "whalehunt_1a.bas",3219
	DECLE 775
	DECLE 1
	DECLE 0
	DECLE 257
	;[3220] 	DATA $E0E0,$F0E0,$1830,$0408
	SRCFILE "whalehunt_1a.bas",3220
	DECLE 57568
	DECLE 61664
	DECLE 6192
	DECLE 1032
	;[3221] 	DATA $0103,$0101,$0101,$0000
	SRCFILE "whalehunt_1a.bas",3221
	DECLE 259
	DECLE 257
	DECLE 257
	DECLE 0
	;[3222] 	DATA $F0F0,$FEF8,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3222
	DECLE 61680
	DECLE 65272
	DECLE 65535
	DECLE 65535
	;[3223] 	DATA $0000,$0100,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3223
	DECLE 0
	DECLE 256
	DECLE 65535
	DECLE 65535
	;[3224] 	DATA $1F07,$FF7F,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3224
	DECLE 7943
	DECLE 65407
	DECLE 65535
	DECLE 65535
	;[3225] 	DATA $0000,$0000,$C080,$FCE0
	SRCFILE "whalehunt_1a.bas",3225
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 64736
	;[3226] row_throw_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",3226
	; ROW_THROW_BITMAPS_3
Q56:	;[3227] 	DATA $0000,$0100,$0701,$3F0F
	SRCFILE "whalehunt_1a.bas",3227
	DECLE 0
	DECLE 256
	DECLE 1793
	DECLE 16143
	;[3228] 	DATA $0000,$3F00,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3228
	DECLE 0
	DECLE 16128
	DECLE 65535
	DECLE 65535
	;[3229] 	DATA $0F03,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3229
	DECLE 3843
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3230] 	DATA $C0C0,$E0C0,$F8F0,$FEFC
	SRCFILE "whalehunt_1a.bas",3230
	DECLE 49344
	DECLE 57536
	DECLE 63728
	DECLE 65276
	;[3231] 	DATA $FEFD,$FEFE,$FEFE,$FBFD
	SRCFILE "whalehunt_1a.bas",3231
	DECLE 65277
	DECLE 65278
	DECLE 65278
	DECLE 64509
	;[3232] 
	SRCFILE "whalehunt_1a.bas",3232
	;[3233] 	REM 320x12 cards
	SRCFILE "whalehunt_1a.bas",3233
	;[3234] row_throw_cards:
	SRCFILE "whalehunt_1a.bas",3234
	; ROW_THROW_CARDS
Q96:	;[3235] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3235
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3236] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3236
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3237] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3237
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3238] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3238
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3239] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3239
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3240] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3240
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3241] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A06,$3A0A,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A06,$1A0A,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3806,$380A,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0806,$080A,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A14,$3A06,$3A0A,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A14,$1A06,$1A0A,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3814,$3806,$380A,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0814,$0806,$080A,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3241
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14854
	DECLE 14858
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6662
	DECLE 6666
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14342
	DECLE 14346
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2054
	DECLE 2058
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14868
	DECLE 14854
	DECLE 14858
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6676
	DECLE 6662
	DECLE 6666
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14356
	DECLE 14342
	DECLE 14346
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2068
	DECLE 2054
	DECLE 2058
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3242] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A1A,$3A22,$3A2A,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A1A,$1A22,$1A2A,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$381A,$3822,$382A,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$081A,$0822,$082A,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A34,$3A3C,$3A44,$3A06,$3A2A,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A34,$1A3C,$1A44,$1A06,$1A2A,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3834,$383C,$3844,$3806,$382A,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0834,$083C,$0844,$0806,$082A,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A4C,$3A1A,$3A22,$3A2A,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A4C,$1A1A,$1A22,$1A2A,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$384C,$381A,$3822,$382A,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$084C,$081A,$0822,$082A,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3242
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14874
	DECLE 14882
	DECLE 14890
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6682
	DECLE 6690
	DECLE 6698
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14362
	DECLE 14370
	DECLE 14378
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2074
	DECLE 2082
	DECLE 2090
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14900
	DECLE 14908
	DECLE 14916
	DECLE 14854
	DECLE 14890
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6708
	DECLE 6716
	DECLE 6724
	DECLE 6662
	DECLE 6698
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14388
	DECLE 14396
	DECLE 14404
	DECLE 14342
	DECLE 14378
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2100
	DECLE 2108
	DECLE 2116
	DECLE 2054
	DECLE 2090
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14924
	DECLE 14874
	DECLE 14882
	DECLE 14890
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6732
	DECLE 6682
	DECLE 6690
	DECLE 6698
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14412
	DECLE 14362
	DECLE 14370
	DECLE 14378
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2124
	DECLE 2074
	DECLE 2082
	DECLE 2090
	DECLE 0
	DECLE 0
	DECLE 0
	;[3243] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1C56,$1C5E,$3A06,$3A0A,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1C56,$1C5E,$1A06,$1A0A,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$1C56,$1C5E,$3806,$380A,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$1C56,$1C5E,$0806,$080A,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1C56,$1C5E,$3A22,$3A62,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1C56,$1C5E,$1A22,$1A62,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$1C56,$1C5E,$3822,$3862,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$1C56,$1C5E,$0822,$0862,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A34,$3A6C,$3A74,$3A06,$3A7C,$3A84,$3200,$1C56,$1C5E,$3A22,$3A2A,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A34,$1A6C,$1A74,$1A06,$1A7C,$1A84,$1200,$1C56,$1C5E,$1A22,$1A2A,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3834,$386C,$3874,$3806,$387C,$3884,$3000,$1C56,$1C5E,$3822,$382A,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0834,$086C,$0874,$0806,$087C,$0884,$0000,$1C56,$1C5E,$0822,$082A,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A14,$3A8C,$1C56,$1C5E,$3A22,$3A62,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A14,$1A8C,$1C56,$1C5E,$1A22,$1A62,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3814,$388C,$1C56,$1C5E,$3822,$3862,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0814,$088C,$1C56,$1C5E,$0822,$0862,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3243
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 7254
	DECLE 7262
	DECLE 14854
	DECLE 14858
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7254
	DECLE 7262
	DECLE 6662
	DECLE 6666
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 7254
	DECLE 7262
	DECLE 14342
	DECLE 14346
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 7254
	DECLE 7262
	DECLE 2054
	DECLE 2058
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 7254
	DECLE 7262
	DECLE 14882
	DECLE 14946
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7254
	DECLE 7262
	DECLE 6690
	DECLE 6754
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 7254
	DECLE 7262
	DECLE 14370
	DECLE 14434
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 7254
	DECLE 7262
	DECLE 2082
	DECLE 2146
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14900
	DECLE 14956
	DECLE 14964
	DECLE 14854
	DECLE 14972
	DECLE 14980
	DECLE 12800
	DECLE 7254
	DECLE 7262
	DECLE 14882
	DECLE 14890
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6708
	DECLE 6764
	DECLE 6772
	DECLE 6662
	DECLE 6780
	DECLE 6788
	DECLE 4608
	DECLE 7254
	DECLE 7262
	DECLE 6690
	DECLE 6698
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14388
	DECLE 14444
	DECLE 14452
	DECLE 14342
	DECLE 14460
	DECLE 14468
	DECLE 12288
	DECLE 7254
	DECLE 7262
	DECLE 14370
	DECLE 14378
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2100
	DECLE 2156
	DECLE 2164
	DECLE 2054
	DECLE 2172
	DECLE 2180
	DECLE 0
	DECLE 7254
	DECLE 7262
	DECLE 2082
	DECLE 2090
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14868
	DECLE 14988
	DECLE 7254
	DECLE 7262
	DECLE 14882
	DECLE 14946
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6676
	DECLE 6796
	DECLE 7254
	DECLE 7262
	DECLE 6690
	DECLE 6754
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14356
	DECLE 14476
	DECLE 7254
	DECLE 7262
	DECLE 14370
	DECLE 14434
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2068
	DECLE 2188
	DECLE 7254
	DECLE 7262
	DECLE 2082
	DECLE 2146
	DECLE 0
	DECLE 0
	;[3244] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A06,$3A92,$3200,$3A9A,$3AA2,$2CAA,$1CB6,$3A1A,$3A22,$3A2A,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A06,$1A92,$1200,$1A9A,$1AA2,$2CAA,$1CB6,$1A1A,$1A22,$1A2A,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3806,$3892,$3000,$389A,$38A2,$2CAA,$1CB6,$381A,$3822,$382A,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0806,$0892,$0000,$089A,$08A2,$2CAA,$1CB6,$081A,$0822,$082A,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3ABA,$2CAA,$1CC6,$1CCA,$3AD2,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1ABA,$2CAA,$1CC6,$1CCA,$1AD2,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$38BA,$2CAA,$1CC6,$1CCA,$38D2,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$08BA,$2CAA,$1CC6,$1CCA,$08D2,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3ADC,$3AE4,$3AEC,$3AF4,$3AFC,$3B02,$3B0A,$3B12,$3AA2,$2CAA,$1CB6,$3B1A,$3B22,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1ADC,$1AE4,$1AEC,$1AF4,$1AFC,$1B02,$1B0A,$1B12,$1AA2,$2CAA,$1CB6,$1B1A,$1B22,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$38DC,$38E4,$38EC,$38F4,$38FC,$3902,$390A,$3912,$38A2,$2CAA,$1CB6,$391A,$3922,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$08DC,$08E4,$08EC,$08F4,$08FC,$0902,$090A,$0912,$08A2,$2CAA,$1CB6,$091A,$0922,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A4C,$3ABA,$2CAA,$1CC6,$1CCA,$3AD2,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A4C,$1ABA,$2CAA,$1CC6,$1CCA,$1AD2,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$384C,$38BA,$2CAA,$1CC6,$1CCA,$38D2,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$084C,$08BA,$2CAA,$1CC6,$1CCA,$08D2,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3244
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14854
	DECLE 14994
	DECLE 12800
	DECLE 15002
	DECLE 15010
	DECLE 11434
	DECLE 7350
	DECLE 14874
	DECLE 14882
	DECLE 14890
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6662
	DECLE 6802
	DECLE 4608
	DECLE 6810
	DECLE 6818
	DECLE 11434
	DECLE 7350
	DECLE 6682
	DECLE 6690
	DECLE 6698
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14342
	DECLE 14482
	DECLE 12288
	DECLE 14490
	DECLE 14498
	DECLE 11434
	DECLE 7350
	DECLE 14362
	DECLE 14370
	DECLE 14378
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2054
	DECLE 2194
	DECLE 0
	DECLE 2202
	DECLE 2210
	DECLE 11434
	DECLE 7350
	DECLE 2074
	DECLE 2082
	DECLE 2090
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 15034
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 15058
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6842
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 6866
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14522
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 14546
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2234
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 2258
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 15068
	DECLE 15076
	DECLE 15084
	DECLE 15092
	DECLE 15100
	DECLE 15106
	DECLE 15114
	DECLE 15122
	DECLE 15010
	DECLE 11434
	DECLE 7350
	DECLE 15130
	DECLE 15138
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6876
	DECLE 6884
	DECLE 6892
	DECLE 6900
	DECLE 6908
	DECLE 6914
	DECLE 6922
	DECLE 6930
	DECLE 6818
	DECLE 11434
	DECLE 7350
	DECLE 6938
	DECLE 6946
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14556
	DECLE 14564
	DECLE 14572
	DECLE 14580
	DECLE 14588
	DECLE 14594
	DECLE 14602
	DECLE 14610
	DECLE 14498
	DECLE 11434
	DECLE 7350
	DECLE 14618
	DECLE 14626
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2268
	DECLE 2276
	DECLE 2284
	DECLE 2292
	DECLE 2300
	DECLE 2306
	DECLE 2314
	DECLE 2322
	DECLE 2210
	DECLE 11434
	DECLE 7350
	DECLE 2330
	DECLE 2338
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14924
	DECLE 15034
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 15058
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6732
	DECLE 6842
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 6866
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14412
	DECLE 14522
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 14546
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2124
	DECLE 2234
	DECLE 11434
	DECLE 7366
	DECLE 7370
	DECLE 2258
	DECLE 0
	DECLE 0
	;[3245] '	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2811,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2811,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2811,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2811,$2C01,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3245
	;[3246] '	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2849,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2849,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2849,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2849,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3246
	;[3247] 
	SRCFILE "whalehunt_1a.bas",3247
	;[3248] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D29,$0D31,$0400,$0400,$0400,$0400,$1D3A,$0400,$0D41,$0D49,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2961,$2969,$2971,$0200,$0200,$0C21,$0D79,$0400,$0400,$0400,$1D3A,$0400,$0D81,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a14,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a14,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a14,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a14,$0a06,$0D51,$0400,$0400,$0400,$0D59,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3248
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3369
	DECLE 3377
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3393
	DECLE 3401
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3369
	DECLE 3377
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3393
	DECLE 3401
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3369
	DECLE 3377
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3393
	DECLE 3401
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3369
	DECLE 3377
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3393
	DECLE 3401
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10593
	DECLE 10601
	DECLE 10609
	DECLE 512
	DECLE 512
	DECLE 3105
	DECLE 3449
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10593
	DECLE 10601
	DECLE 10609
	DECLE 512
	DECLE 512
	DECLE 3105
	DECLE 3449
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10593
	DECLE 10601
	DECLE 10609
	DECLE 512
	DECLE 512
	DECLE 3105
	DECLE 3449
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10593
	DECLE 10601
	DECLE 10609
	DECLE 512
	DECLE 512
	DECLE 3105
	DECLE 3449
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7482
	DECLE 1024
	DECLE 3457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2580
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2580
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2580
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2580
	DECLE 2566
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3417
	DECLE 512
	DECLE 512
	;[3249] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D89,$0D91,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a4c,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a4c,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a4c,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0a4c,$0D99,$0400,$09A2,$0400,$0400,$0400,$0200,$0200	
	SRCFILE "whalehunt_1a.bas",3249
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3465
	DECLE 3473
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3465
	DECLE 3473
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3465
	DECLE 3473
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3465
	DECLE 3473
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2636
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2636
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2636
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 2636
	DECLE 3481
	DECLE 1024
	DECLE 2466
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 512
	DECLE 512
	;[3250] 
	SRCFILE "whalehunt_1a.bas",3250
	;[3251] 	' 55 bitmaps
	SRCFILE "whalehunt_1a.bas",3251
	;[3252] sail_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",3252
	; SAIL_BITMAPS_0
Q63:	;[3253] 	DATA $0000,$0101,$0303,$0303
	SRCFILE "whalehunt_1a.bas",3253
	DECLE 0
	DECLE 257
	DECLE 771
	DECLE 771
	;[3254] 	DATA $FFFF,$FFFF,$00FF,$C080
	SRCFILE "whalehunt_1a.bas",3254
	DECLE 65535
	DECLE 65535
	DECLE 255
	DECLE 49280
	;[3255] 	DATA $FFFF,$FFFF,$00FF,$0000
	SRCFILE "whalehunt_1a.bas",3255
	DECLE 65535
	DECLE 65535
	DECLE 255
	DECLE 0
	;[3256] 	DATA $0000,$0000,$0000,$0700
	SRCFILE "whalehunt_1a.bas",3256
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1792
	;[3257] 	DATA $0000,$0000,$0F0F,$F8F8
	SRCFILE "whalehunt_1a.bas",3257
	DECLE 0
	DECLE 0
	DECLE 3855
	DECLE 63736
	;[3258] 	DATA $0707,$0F07,$0F0F,$1F1F
	SRCFILE "whalehunt_1a.bas",3258
	DECLE 1799
	DECLE 3847
	DECLE 3855
	DECLE 7967
	;[3259] 	DATA $871F,$F8E1,$FFFE,$FFFF
	SRCFILE "whalehunt_1a.bas",3259
	DECLE 34591
	DECLE 63713
	DECLE 65534
	DECLE 65535
	;[3260] 	DATA $FFFF,$7FFF,$871F,$F8E1
	SRCFILE "whalehunt_1a.bas",3260
	DECLE 65535
	DECLE 32767
	DECLE 34591
	DECLE 63713
	;[3261] 	DATA $0000,$0000,$0000,$1F1F
	SRCFILE "whalehunt_1a.bas",3261
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 7967
	;[3262] 	DATA $0000,$0000,$7F03,$80FC
	SRCFILE "whalehunt_1a.bas",3262
	DECLE 0
	DECLE 0
	DECLE 32515
	DECLE 33020
	;[3263] 	DATA $0000,$1F00,$E0FF,$0000
	SRCFILE "whalehunt_1a.bas",3263
	DECLE 0
	DECLE 7936
	DECLE 57599
	DECLE 0
	;[3264] 	DATA $0000,$0100,$0F01,$380F
	SRCFILE "whalehunt_1a.bas",3264
	DECLE 0
	DECLE 256
	DECLE 3841
	DECLE 14351
	;[3265] 	DATA $3C07,$E03C,$00E0,$0000
	SRCFILE "whalehunt_1a.bas",3265
	DECLE 15367
	DECLE 57404
	DECLE 224
	DECLE 0
	;[3266] 	DATA $0080,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3266
	DECLE 128
	DECLE 0
	DECLE 0
	DECLE 0
	;[3267] 	DATA $1F1F,$3F3F,$7F3F,$7F7F
	SRCFILE "whalehunt_1a.bas",3267
	DECLE 7967
	DECLE 16191
	DECLE 32575
	DECLE 32639
	;[3268] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",3268
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[3269] sail_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",3269
	; SAIL_BITMAPS_1
Q64:	;[3270] 	DATA $0000,$0000,$C000,$F0E0
	SRCFILE "whalehunt_1a.bas",3270
	DECLE 0
	DECLE 0
	DECLE 49152
	DECLE 61664
	;[3271] 	DATA $0000,$0300,$0E03,$380E
	SRCFILE "whalehunt_1a.bas",3271
	DECLE 0
	DECLE 768
	DECLE 3587
	DECLE 14350
	;[3272] 	DATA $E038,$80E0,$0080,$0000
	SRCFILE "whalehunt_1a.bas",3272
	DECLE 57400
	DECLE 32992
	DECLE 128
	DECLE 0
	;[3273] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",3273
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[3274] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",3274
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[3275] 	DATA $1F1F,$0F1F,$0307,$0001
	SRCFILE "whalehunt_1a.bas",3275
	DECLE 7967
	DECLE 3871
	DECLE 775
	DECLE 1
	;[3276] 	DATA $FCF8,$FFFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3276
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 65535
	;[3277] 	DATA $0000,$0000,$C080,$F0E0
	SRCFILE "whalehunt_1a.bas",3277
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 61664
	;[3278] 	DATA $0000,$C000,$F8F0,$FFFC
	SRCFILE "whalehunt_1a.bas",3278
	DECLE 0
	DECLE 49152
	DECLE 63728
	DECLE 65532
	;[3279] 	DATA $0000,$0000,$0000,$0701
	SRCFILE "whalehunt_1a.bas",3279
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1793
	;[3280] 	DATA $0000,$0000,$0000,$FFFE
	SRCFILE "whalehunt_1a.bas",3280
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65534
	;[3281] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",3281
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[3282] 	DATA $0000,$0000,$0000,$0F01
	SRCFILE "whalehunt_1a.bas",3282
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 3841
	;[3283] 	DATA $0000,$0000,$1F03,$FFFF
	SRCFILE "whalehunt_1a.bas",3283
	DECLE 0
	DECLE 0
	DECLE 7939
	DECLE 65535
	;[3284] 	DATA $FFFF,$7F7F,$3F3F,$0F1F
	SRCFILE "whalehunt_1a.bas",3284
	DECLE 65535
	DECLE 32639
	DECLE 16191
	DECLE 3871
	;[3285] 	DATA $E0C0,$F8F0,$FEFC,$FFFF
	SRCFILE "whalehunt_1a.bas",3285
	DECLE 57536
	DECLE 63728
	DECLE 65276
	DECLE 65535
	;[3286] sail_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",3286
	; SAIL_BITMAPS_2
Q65:	;[3287] 	DATA $0000,$0000,$0000,$FF01
	SRCFILE "whalehunt_1a.bas",3287
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65281
	;[3288] 	DATA $0000,$0000,$0000,$FF07
	SRCFILE "whalehunt_1a.bas",3288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65287
	;[3289] 	DATA $0100,$0703,$1F0F,$FFFF
	SRCFILE "whalehunt_1a.bas",3289
	DECLE 256
	DECLE 1795
	DECLE 7951
	DECLE 65535
	;[3290] 	DATA $FFFF,$FFFF,$FFFF,$FCFE
	SRCFILE "whalehunt_1a.bas",3290
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 64766
	;[3291] 	DATA $3F7F,$0F1F,$0307,$0001
	SRCFILE "whalehunt_1a.bas",3291
	DECLE 16255
	DECLE 3871
	DECLE 775
	DECLE 1
	;[3292] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",3292
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[3293] 	DATA $FCFE,$FCF8,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3293
	DECLE 64766
	DECLE 64760
	DECLE 65535
	DECLE 65535
	;[3294] 	DATA $0000,$0000,$F0C0,$FFFC
	SRCFILE "whalehunt_1a.bas",3294
	DECLE 0
	DECLE 0
	DECLE 61632
	DECLE 65532
	;[3295] 	DATA $BCE3,$F8C0,$FFF3,$FFFF
	SRCFILE "whalehunt_1a.bas",3295
	DECLE 48355
	DECLE 63680
	DECLE 65523
	DECLE 65535
	;[3296] 	DATA $0F0F,$3F1F,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3296
	DECLE 3855
	DECLE 16159
	DECLE 65535
	DECLE 65535
	;[3297] 	DATA $0000,$0000,$C080,$FCE0
	SRCFILE "whalehunt_1a.bas",3297
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 64736
	;[3298] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",3298
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[3299] 	DATA $0F07,$3F1F,$FF7F,$FFFF
	SRCFILE "whalehunt_1a.bas",3299
	DECLE 3847
	DECLE 16159
	DECLE 65407
	DECLE 65535
	;[3300] 	DATA $8080,$8080,$8080,$8080
	SRCFILE "whalehunt_1a.bas",3300
	DECLE 32896
	DECLE 32896
	DECLE 32896
	DECLE 32896
	;[3301] 	DATA $C387,$E0C0,$FFF0,$FFFF
	SRCFILE "whalehunt_1a.bas",3301
	DECLE 50055
	DECLE 57536
	DECLE 65520
	DECLE 65535
	;[3302] 	DATA $1FFF,$0FFF,$3F77,$FFFF
	SRCFILE "whalehunt_1a.bas",3302
	DECLE 8191
	DECLE 4095
	DECLE 16247
	DECLE 65535
	;[3303] sail_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",3303
	; SAIL_BITMAPS_3
Q66:	;[3304] 	DATA $60C0,$0010,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3304
	DECLE 24768
	DECLE 16
	DECLE 0
	DECLE 0
	;[3305] 	DATA $0307,$0001,$0000,$0101
	SRCFILE "whalehunt_1a.bas",3305
	DECLE 775
	DECLE 1
	DECLE 0
	DECLE 257
	;[3306] 	DATA $0700,$FF3F,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3306
	DECLE 1792
	DECLE 65343
	DECLE 65535
	DECLE 65535
	;[3307] 	DATA $FF3F,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3307
	DECLE 65343
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3308] 	DATA $3F0F,$7F7F,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3308
	DECLE 16143
	DECLE 32639
	DECLE 65535
	DECLE 65535
	;[3309] 	DATA $0000,$3F00,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3309
	DECLE 0
	DECLE 16128
	DECLE 65535
	DECLE 65535
	;[3310] 	DATA $0F03,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3310
	DECLE 3843
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3311] 
	SRCFILE "whalehunt_1a.bas",3311
	;[3312] 	REM 240x12 cards
	SRCFILE "whalehunt_1a.bas",3312
	;[3313] sail_cards:
	SRCFILE "whalehunt_1a.bas",3313
	; SAIL_CARDS
Q95:	;[3314] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3314
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3315] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3315
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3316] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3316
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3317] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3317
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3318] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3318
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3319] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A07,$1C0F,$1C17,$1C17,$1C17,$1C17,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A07,$1C0F,$1C17,$1C17,$1C17,$1C17,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3807,$1C0F,$1C17,$1C17,$1C17,$1C17,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0807,$1C0F,$1C17,$1C17,$1C17,$1C17,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A07,$1C0F,$1C17,$1C17,$1C17,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A07,$1C0F,$1C17,$1C17,$1C17,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3807,$1C0F,$1C17,$1C17,$1C17,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0807,$1C0F,$1C17,$1C17,$1C17,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A07,$1C0F,$1C17,$1C17,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A07,$1C0F,$1C17,$1C17,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3807,$1C0F,$1C17,$1C17,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0807,$1C0F,$1C17,$1C17
	SRCFILE "whalehunt_1a.bas",3319
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14855
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6663
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14343
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2055
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14855
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6663
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14343
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2055
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 7191
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14855
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6663
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14343
	DECLE 7183
	DECLE 7191
	DECLE 7191
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2055
	DECLE 7183
	DECLE 7191
	DECLE 7191
	;[3320] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A1C,$3A24,$3A2F,$2600,$2600,$2600,$1C37,$1C3F,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A1C,$1A24,$1A2F,$2600,$2600,$2600,$1C37,$1C3F,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$381C,$3824,$382F,$2600,$2600,$2600,$1C37,$1C3F,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$081C,$0824,$082F,$2600,$2600,$2600,$1C37,$1C3F,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A1C,$3A24,$3200,$3A2F,$2600,$2600,$2600,$1C37,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A1C,$1A24,$1200,$1A2F,$2600,$2600,$2600,$1C37,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$381C,$3824,$3000,$382F,$2600,$2600,$2600,$1C37,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$081C,$0824,$0000,$082F,$2600,$2600,$2600,$1C37,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A44,$3A4C,$3A54,$3200,$3A2F,$2600,$2600,$2600,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A44,$1A4C,$1A54,$1200,$1A2F,$2600,$2600,$2600,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3844,$384C,$3854,$3000,$382F,$2600,$2600,$2600,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0844,$084C,$0854,$0000,$082F,$2600,$2600,$2600
	SRCFILE "whalehunt_1a.bas",3320
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14876
	DECLE 14884
	DECLE 14895
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 7231
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6684
	DECLE 6692
	DECLE 6703
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 7231
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14364
	DECLE 14372
	DECLE 14383
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 7231
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2076
	DECLE 2084
	DECLE 2095
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 7231
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14876
	DECLE 14884
	DECLE 12800
	DECLE 14895
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6684
	DECLE 6692
	DECLE 4608
	DECLE 6703
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14364
	DECLE 14372
	DECLE 12288
	DECLE 14383
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2076
	DECLE 2084
	DECLE 0
	DECLE 2095
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 7223
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14916
	DECLE 14924
	DECLE 14932
	DECLE 12800
	DECLE 14895
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6724
	DECLE 6732
	DECLE 6740
	DECLE 4608
	DECLE 6703
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14404
	DECLE 14412
	DECLE 14420
	DECLE 12288
	DECLE 14383
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2116
	DECLE 2124
	DECLE 2132
	DECLE 0
	DECLE 2095
	DECLE 9728
	DECLE 9728
	DECLE 9728
	;[3321] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A5C,$3A64,$3A6C,$3A77,$2600,$2600,$2600,$2600,$2600,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A5C,$1A64,$1A6C,$1A77,$2600,$2600,$2600,$2600,$2600,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$385C,$3864,$386C,$3877,$2600,$2600,$2600,$2600,$2600,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$085C,$0864,$086C,$0877,$2600,$2600,$2600,$2600,$2600,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A5C,$3A64,$3A6C,$3200,$3A77,$2600,$2600,$2600,$2600,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A5C,$1A64,$1A6C,$1200,$1A77,$2600,$2600,$2600,$2600,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$385C,$3864,$386C,$3000,$3877,$2600,$2600,$2600,$2600,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$085C,$0864,$086C,$0000,$0877,$2600,$2600,$2600,$2600,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A7E,$3A82,$3200,$3200,$3A77,$2600,$2600,$2600,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A7E,$1A82,$1200,$1200,$1A77,$2600,$2600,$2600,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$387E,$3882,$3000,$3000,$3877,$2600,$2600,$2600,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$087E,$0882,$0000,$0000,$0877,$2600,$2600,$2600
	SRCFILE "whalehunt_1a.bas",3321
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14940
	DECLE 14948
	DECLE 14956
	DECLE 14967
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6748
	DECLE 6756
	DECLE 6764
	DECLE 6775
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14428
	DECLE 14436
	DECLE 14444
	DECLE 14455
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2140
	DECLE 2148
	DECLE 2156
	DECLE 2167
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14940
	DECLE 14948
	DECLE 14956
	DECLE 12800
	DECLE 14967
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6748
	DECLE 6756
	DECLE 6764
	DECLE 4608
	DECLE 6775
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14428
	DECLE 14436
	DECLE 14444
	DECLE 12288
	DECLE 14455
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2140
	DECLE 2148
	DECLE 2156
	DECLE 0
	DECLE 2167
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14974
	DECLE 14978
	DECLE 12800
	DECLE 12800
	DECLE 14967
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6782
	DECLE 6786
	DECLE 4608
	DECLE 4608
	DECLE 6775
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14462
	DECLE 14466
	DECLE 12288
	DECLE 12288
	DECLE 14455
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2174
	DECLE 2178
	DECLE 0
	DECLE 0
	DECLE 2167
	DECLE 9728
	DECLE 9728
	DECLE 9728
	;[3322] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A8C,$3A94,$3200,$3200,$2600,$1C9E,$1CA6,$2600,$2600,$2600,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A8C,$1A94,$1200,$1200,$2600,$1C9E,$1CA6,$2600,$2600,$2600,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$388C,$3894,$3000,$3000,$2600,$1C9E,$1CA6,$2600,$2600,$2600,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$088C,$0894,$0000,$0000,$2600,$1C9E,$1CA6,$2600,$2600,$2600,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A7E,$3200,$3200,$3200,$1C9E,$1CA6,$2600,$2600,$2E7E,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A7E,$1200,$1200,$1200,$1C9E,$1CA6,$2600,$2600,$2E7E,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$387E,$3000,$3000,$3000,$1C9E,$1CA6,$2600,$2600,$2E7E,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$087E,$0000,$0000,$0000,$1C9E,$1CA6,$2600,$2600,$2E7E,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3AAA,$3AB2,$3ABA,$1C9E,$1CA6,$2E7E,$2600,$2600,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1AAA,$1AB2,$1ABA,$1C9E,$1CA6,$2E7E,$2600,$2600,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$38AA,$38B2,$38BA,$1C9E,$1CA6,$2E7E,$2600,$2600,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$08AA,$08B2,$08BA,$1C9E,$1CA6,$2E7E,$2600,$2600
	SRCFILE "whalehunt_1a.bas",3322
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14988
	DECLE 14996
	DECLE 12800
	DECLE 12800
	DECLE 9728
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6796
	DECLE 6804
	DECLE 4608
	DECLE 4608
	DECLE 9728
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14476
	DECLE 14484
	DECLE 12288
	DECLE 12288
	DECLE 9728
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2188
	DECLE 2196
	DECLE 0
	DECLE 0
	DECLE 9728
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 9728
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14974
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 11902
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6782
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 11902
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14462
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 11902
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2174
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 7326
	DECLE 7334
	DECLE 9728
	DECLE 9728
	DECLE 11902
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 15018
	DECLE 15026
	DECLE 15034
	DECLE 7326
	DECLE 7334
	DECLE 11902
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6826
	DECLE 6834
	DECLE 6842
	DECLE 7326
	DECLE 7334
	DECLE 11902
	DECLE 9728
	DECLE 9728
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14506
	DECLE 14514
	DECLE 14522
	DECLE 7326
	DECLE 7334
	DECLE 11902
	DECLE 9728
	DECLE 9728
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2218
	DECLE 2226
	DECLE 2234
	DECLE 7326
	DECLE 7334
	DECLE 11902
	DECLE 9728
	DECLE 9728
	;[3323] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3A7E,$3AC2,$3200,$3ACA,$2ED2,$2400,$1CDE,$2600,$2EE2,$2EEA,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A7E,$1AC2,$1200,$1ACA,$2ED2,$2400,$1CDE,$2600,$2EE2,$2EEA,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$387E,$38C2,$3000,$38CA,$2ED2,$2400,$1CDE,$2600,$2EE2,$2EEA,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$087E,$08C2,$0000,$08CA,$2ED2,$2400,$1CDE,$2600,$2EE2,$2EEA,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3AF2,$3AFA,$3B02,$3AD2,$2400,$1CDE,$2F0A,$2F12,$2F1A,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1AF2,$1AFA,$1B02,$1AD2,$2400,$1CDE,$2F0A,$2F12,$2F1A,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$38F2,$38FA,$3902,$38D2,$2400,$1CDE,$2F0A,$2F12,$2F1A,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$08F2,$08FA,$0902,$08D2,$2400,$1CDE,$2F0A,$2F12,$2F1A,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3B22,$3AB2,$2D2A,$1CDE,$2EAA,$2EB2,$2EBA,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B22,$1AB2,$2D2A,$1CDE,$2EAA,$2EB2,$2EBA,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3922,$38B2,$2D2A,$1CDE,$2EAA,$2EB2,$2EBA,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0922,$08B2,$2D2A,$1CDE,$2EAA,$2EB2,$2EBA
	SRCFILE "whalehunt_1a.bas",3323
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 14974
	DECLE 15042
	DECLE 12800
	DECLE 15050
	DECLE 11986
	DECLE 9216
	DECLE 7390
	DECLE 9728
	DECLE 12002
	DECLE 12010
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6782
	DECLE 6850
	DECLE 4608
	DECLE 6858
	DECLE 11986
	DECLE 9216
	DECLE 7390
	DECLE 9728
	DECLE 12002
	DECLE 12010
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14462
	DECLE 14530
	DECLE 12288
	DECLE 14538
	DECLE 11986
	DECLE 9216
	DECLE 7390
	DECLE 9728
	DECLE 12002
	DECLE 12010
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2174
	DECLE 2242
	DECLE 0
	DECLE 2250
	DECLE 11986
	DECLE 9216
	DECLE 7390
	DECLE 9728
	DECLE 12002
	DECLE 12010
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 15090
	DECLE 15098
	DECLE 15106
	DECLE 15058
	DECLE 9216
	DECLE 7390
	DECLE 12042
	DECLE 12050
	DECLE 12058
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6898
	DECLE 6906
	DECLE 6914
	DECLE 6866
	DECLE 9216
	DECLE 7390
	DECLE 12042
	DECLE 12050
	DECLE 12058
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14578
	DECLE 14586
	DECLE 14594
	DECLE 14546
	DECLE 9216
	DECLE 7390
	DECLE 12042
	DECLE 12050
	DECLE 12058
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2290
	DECLE 2298
	DECLE 2306
	DECLE 2258
	DECLE 9216
	DECLE 7390
	DECLE 12042
	DECLE 12050
	DECLE 12058
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 15138
	DECLE 15026
	DECLE 11562
	DECLE 7390
	DECLE 11946
	DECLE 11954
	DECLE 11962
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6946
	DECLE 6834
	DECLE 11562
	DECLE 7390
	DECLE 11946
	DECLE 11954
	DECLE 11962
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 14626
	DECLE 14514
	DECLE 11562
	DECLE 7390
	DECLE 11946
	DECLE 11954
	DECLE 11962
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 2338
	DECLE 2226
	DECLE 11562
	DECLE 7390
	DECLE 11946
	DECLE 11954
	DECLE 11962
	;[3324] '	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0D19,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0D19,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0D19,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0D19,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89
	SRCFILE "whalehunt_1a.bas",3324
	;[3325] '	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1
	SRCFILE "whalehunt_1a.bas",3325
	;[3326] 
	SRCFILE "whalehunt_1a.bas",3326
	;[3327] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D31,$0D39,$0400,$0400,$0400,$1D42,$1D4A,$0400,$0400,$0CE1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0b1a,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0b1a,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0b1a,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0CB1,$0D51,$0400,$0400,$0400,$1D5A,$0400,$0b1a,$0D61,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$1D72,$1D7A,$0D81,$0D89
	SRCFILE "whalehunt_1a.bas",3327
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3377
	DECLE 3385
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7490
	DECLE 7498
	DECLE 1024
	DECLE 1024
	DECLE 3297
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3377
	DECLE 3385
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7490
	DECLE 7498
	DECLE 1024
	DECLE 1024
	DECLE 3297
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3377
	DECLE 3385
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7490
	DECLE 7498
	DECLE 1024
	DECLE 1024
	DECLE 3297
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3377
	DECLE 3385
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7490
	DECLE 7498
	DECLE 1024
	DECLE 1024
	DECLE 3297
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3249
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7514
	DECLE 1024
	DECLE 2842
	DECLE 3425
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3249
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7514
	DECLE 1024
	DECLE 2842
	DECLE 3425
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3249
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7514
	DECLE 1024
	DECLE 2842
	DECLE 3425
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3249
	DECLE 3409
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7514
	DECLE 1024
	DECLE 2842
	DECLE 3425
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 7538
	DECLE 7546
	DECLE 3457
	DECLE 3465
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 7538
	DECLE 7546
	DECLE 3457
	DECLE 3465
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 7538
	DECLE 7546
	DECLE 3457
	DECLE 3465
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 7538
	DECLE 7546
	DECLE 3457
	DECLE 3465
	;[3328] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0D91,$0D99,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0400,$0400,$0400,$0400,$0DA1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0D69,$0400,$0400,$0400,$0DA9,$0DB1
	SRCFILE "whalehunt_1a.bas",3328
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3473
	DECLE 3481
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3473
	DECLE 3481
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3473
	DECLE 3481
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3473
	DECLE 3481
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3489
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3489
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3489
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3489
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3497
	DECLE 3505
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3497
	DECLE 3505
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3497
	DECLE 3505
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 3433
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 3497
	DECLE 3505
	;[3329] 	
	SRCFILE "whalehunt_1a.bas",3329
	;[3330] 
	SRCFILE "whalehunt_1a.bas",3330
	;[3331] 
	SRCFILE "whalehunt_1a.bas",3331
	;[3332] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3332
	;[3333] harp_up_cards:
	SRCFILE "whalehunt_1a.bas",3333
	; HARP_UP_CARDS
Q317:	;[3334] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3334
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3335] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1C06,$1C0E,$1A16,$1A1A,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3335
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7174
	DECLE 7182
	DECLE 6678
	DECLE 6682
	DECLE 4608
	DECLE 4608
	;[3336] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A16,$1A22,$1200,$1A2A,$1A32,$2C3A,$1C46,$1A4A,$1A52,$1A5A,$1200
	SRCFILE "whalehunt_1a.bas",3336
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6678
	DECLE 6690
	DECLE 4608
	DECLE 6698
	DECLE 6706
	DECLE 11322
	DECLE 7238
	DECLE 6730
	DECLE 6738
	DECLE 6746
	DECLE 4608
	;[3337] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A62,$1A6A,$0400,$0400,$0400,$0400,$1C72,$0400,$1A7A,$1A82,$1200
	SRCFILE "whalehunt_1a.bas",3337
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6754
	DECLE 6762
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7282
	DECLE 1024
	DECLE 6778
	DECLE 6786
	DECLE 4608
	;[3338] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A8F,$0400,$0400,$0400,$0400,$1A92,$1A9A,$1200
	SRCFILE "whalehunt_1a.bas",3338
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6799
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6802
	DECLE 6810
	DECLE 4608
	;[3339] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1AA7,$2600,$0400,$0400,$0400,$1AAA,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3339
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6823
	DECLE 9728
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6826
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3340] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1AB7,$2600,$18BF,$2EC2,$0400,$0400,$1ACA,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3340
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6839
	DECLE 9728
	DECLE 6335
	DECLE 11970
	DECLE 1024
	DECLE 1024
	DECLE 6858
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3341] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1AD0,$1AD8,$08E7,$1AEF,$1AF7,$2EFA,$2F02,$1B0A,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3341
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6864
	DECLE 6872
	DECLE 2279
	DECLE 6895
	DECLE 6903
	DECLE 12026
	DECLE 12034
	DECLE 6922
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3342] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B10,$1B18,$1B20,$1B28,$1200,$1200,$1937,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3342
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6928
	DECLE 6936
	DECLE 6944
	DECLE 6952
	DECLE 4608
	DECLE 4608
	DECLE 6455
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3343] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B38,$1D40,$1B48,$1B50,$1B58,$1B60,$2600,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3343
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6968
	DECLE 7488
	DECLE 6984
	DECLE 6992
	DECLE 7000
	DECLE 7008
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3344] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1400,$1D68,$1D70,$1D78,$1D80,$1D88,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3344
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 5120
	DECLE 7528
	DECLE 7536
	DECLE 7544
	DECLE 7552
	DECLE 7560
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3345] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1D91,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400
	SRCFILE "whalehunt_1a.bas",3345
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7569
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	;[3346] 
	SRCFILE "whalehunt_1a.bas",3346
	;[3347] 
	SRCFILE "whalehunt_1a.bas",3347
	;[3348] 
	SRCFILE "whalehunt_1a.bas",3348
	;[3349] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3349
	;[3350] pad_up_cards:
	SRCFILE "whalehunt_1a.bas",3350
	; PAD_UP_CARDS
Q323:	;[3351] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A04,$1A0C,$1A14,$1A1E,$1A22,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3351
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6660
	DECLE 6668
	DECLE 6676
	DECLE 6686
	DECLE 6690
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3352] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A04,$1A2C,$1A34,$1A1E,$1A3C,$1A44,$1200,$1C4E,$1C56,$1A5A,$1A22,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3352
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6660
	DECLE 6700
	DECLE 6708
	DECLE 6686
	DECLE 6716
	DECLE 6724
	DECLE 4608
	DECLE 7246
	DECLE 7254
	DECLE 6746
	DECLE 6690
	DECLE 4608
	DECLE 4608
	;[3353] 	DATA $1200,$1200,$1200,$1200,$1200,$1A64,$1A6C,$1A74,$1A7C,$1A84,$1A8A,$1A92,$1A9A,$1AA2,$2CAA,$1CB6,$1ABA,$1AC2,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3353
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6756
	DECLE 6764
	DECLE 6772
	DECLE 6780
	DECLE 6788
	DECLE 6794
	DECLE 6802
	DECLE 6810
	DECLE 6818
	DECLE 11434
	DECLE 7350
	DECLE 6842
	DECLE 6850
	DECLE 4608
	DECLE 4608
	;[3354] 	DATA $1200,$1200,$1200,$1200,$1200,$1ACC,$1AD4,$1ADC,$1200,$1200,$1AE2,$1AEA,$0400,$0400,$0400,$1CF2,$0400,$1AFA,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3354
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6860
	DECLE 6868
	DECLE 6876
	DECLE 4608
	DECLE 4608
	DECLE 6882
	DECLE 6890
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7410
	DECLE 1024
	DECLE 6906
	DECLE 4608
	DECLE 4608
	;[3355] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B07,$0400,$0400,$0400,$0400,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3355
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6919
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3356] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B0F,$2600,$0400,$0400,$0400,$1B12,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3356
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6927
	DECLE 9728
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6930
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3357] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B1F,$2600,$1927,$2F2A,$0400,$0400,$1B32,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3357
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6943
	DECLE 9728
	DECLE 6439
	DECLE 12074
	DECLE 1024
	DECLE 1024
	DECLE 6962
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3358] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B38,$1B40,$094F,$1B57,$1B5F,$2F62,$2F6A,$1B72,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3358
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6968
	DECLE 6976
	DECLE 2383
	DECLE 6999
	DECLE 7007
	DECLE 12130
	DECLE 12138
	DECLE 7026
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3359] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B78,$1B80,$1B88,$1B90,$1200,$1200,$199F,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3359
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7032
	DECLE 7040
	DECLE 7048
	DECLE 7056
	DECLE 4608
	DECLE 4608
	DECLE 6559
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3360] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1BA0,$1DA8,$1BB0,$1BB8,$1BC0,$1BC8,$2600,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3360
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7072
	DECLE 7592
	DECLE 7088
	DECLE 7096
	DECLE 7104
	DECLE 7112
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3361] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1400,$1DD0,$1DD8,$1DE0,$1DE8,$1DF0,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3361
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 5120
	DECLE 7632
	DECLE 7640
	DECLE 7648
	DECLE 7656
	DECLE 7664
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3362] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1DF9,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400
	SRCFILE "whalehunt_1a.bas",3362
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7673
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	;[3363] 	
	SRCFILE "whalehunt_1a.bas",3363
	;[3364] 
	SRCFILE "whalehunt_1a.bas",3364
	;[3365] 
	SRCFILE "whalehunt_1a.bas",3365
	;[3366] 	
	SRCFILE "whalehunt_1a.bas",3366
	;[3367] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3367
	;[3368] flute_up_cards:
	SRCFILE "whalehunt_1a.bas",3368
	; FLUTE_UP_CARDS
Q329:	;[3369] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3369
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3370] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1C06,$1C0E,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3370
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 7174
	DECLE 7182
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3371] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A16,$1A1A,$1200,$1A16,$1A22,$2C2A,$1C36,$1A3A,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3371
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6678
	DECLE 6682
	DECLE 4608
	DECLE 6678
	DECLE 6690
	DECLE 11306
	DECLE 7222
	DECLE 6714
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3372] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A42,$1A4A,$0400,$0400,$0400,$0400,$1C52,$0400,$1A5A,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3372
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6722
	DECLE 6730
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 7250
	DECLE 1024
	DECLE 6746
	DECLE 4608
	DECLE 4608
	;[3373] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A67,$0400,$0400,$0400,$0400,$1A6A,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3373
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6759
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6762
	DECLE 4608
	DECLE 4608
	;[3374] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A77,$2600,$0400,$0400,$0400,$1A7A,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3374
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6775
	DECLE 9728
	DECLE 1024
	DECLE 1024
	DECLE 1024
	DECLE 6778
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3375] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1A87,$2600,$188F,$2E92,$0400,$0400,$1A9A,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3375
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6791
	DECLE 9728
	DECLE 6287
	DECLE 11922
	DECLE 1024
	DECLE 1024
	DECLE 6810
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3376] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1AA0,$1AA8,$08B7,$1ABF,$1AC7,$2ECA,$2ED2,$1ADA,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3376
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6816
	DECLE 6824
	DECLE 2231
	DECLE 6847
	DECLE 6855
	DECLE 11978
	DECLE 11986
	DECLE 6874
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3377] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1AE0,$1AE8,$1AF0,$1AF8,$1200,$1200,$1907,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3377
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6880
	DECLE 6888
	DECLE 6896
	DECLE 6904
	DECLE 4608
	DECLE 4608
	DECLE 6407
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3378] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1B08,$1D10,$1B18,$1B20,$1B28,$1B30,$2600,$2600,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3378
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 6920
	DECLE 7440
	DECLE 6936
	DECLE 6944
	DECLE 6952
	DECLE 6960
	DECLE 9728
	DECLE 9728
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3379] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1400,$1D38,$1D40,$1D48,$1D50,$1D58,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3379
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 5120
	DECLE 7480
	DECLE 7488
	DECLE 7496
	DECLE 7504
	DECLE 7512
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3380] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1D61,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400,$1400
	SRCFILE "whalehunt_1a.bas",3380
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 7521
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	DECLE 5120
	;[3381] 	
	SRCFILE "whalehunt_1a.bas",3381
	;[3382] 	' 52 bitmaps
	SRCFILE "whalehunt_1a.bas",3382
	;[3383] sundial_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",3383
	; SUNDIAL_BITMAPS_0
Q184:	;[3384] 	DATA $FFFF,$FFFF,$FFFF,$F0FE
	SRCFILE "whalehunt_1a.bas",3384
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 61694
	;[3385] 	DATA $FFFF,$FFFF,$C0FC,$0000
	SRCFILE "whalehunt_1a.bas",3385
	DECLE 65535
	DECLE 65535
	DECLE 49404
	DECLE 0
	;[3386] 	DATA $FFFF,$FFFF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3386
	DECLE 65535
	DECLE 65535
	DECLE 0
	DECLE 0
	;[3387] 	DATA $FFFF,$FFFF,$033F,$0000
	SRCFILE "whalehunt_1a.bas",3387
	DECLE 65535
	DECLE 65535
	DECLE 831
	DECLE 0
	;[3388] 	DATA $FFFF,$FFFF,$FFFF,$0F7F
	SRCFILE "whalehunt_1a.bas",3388
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 3967
	;[3389] 	DATA $FFFF,$FCFE,$F0F8,$C0E0
	SRCFILE "whalehunt_1a.bas",3389
	DECLE 65535
	DECLE 64766
	DECLE 61688
	DECLE 49376
	;[3390] 	DATA $80E0,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3390
	DECLE 32992
	DECLE 0
	DECLE 0
	DECLE 0
	;[3391] 	DATA $0107,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3391
	DECLE 263
	DECLE 0
	DECLE 0
	DECLE 0
	;[3392] 	DATA $FFFF,$3F7F,$0F1F,$0307
	SRCFILE "whalehunt_1a.bas",3392
	DECLE 65535
	DECLE 16255
	DECLE 3871
	DECLE 775
	;[3393] 	DATA $FFFF,$FCFE,$F8FC,$F0F8
	SRCFILE "whalehunt_1a.bas",3393
	DECLE 65535
	DECLE 64766
	DECLE 63740
	DECLE 61688
	;[3394] 	DATA $0080,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3394
	DECLE 128
	DECLE 0
	DECLE 0
	DECLE 0
	;[3395] 	DATA $0001,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3395
	DECLE 1
	DECLE 0
	DECLE 0
	DECLE 0
	;[3396] 	DATA $FFFF,$3F7F,$1F3F,$0F1F
	SRCFILE "whalehunt_1a.bas",3396
	DECLE 65535
	DECLE 16255
	DECLE 7999
	DECLE 3871
	;[3397] 	DATA $E0F0,$C0E0,$C0C0,$8080
	SRCFILE "whalehunt_1a.bas",3397
	DECLE 57584
	DECLE 49376
	DECLE 49344
	DECLE 32896
	;[3398] 	DATA $0000,$3800,$8244,$8282
	SRCFILE "whalehunt_1a.bas",3398
	DECLE 0
	DECLE 14336
	DECLE 33348
	DECLE 33410
	;[3399] 	DATA $0707,$0303,$0103,$0001
	SRCFILE "whalehunt_1a.bas",3399
	DECLE 1799
	DECLE 771
	DECLE 259
	DECLE 1
	;[3400] sundial_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",3400
	; SUNDIAL_BITMAPS_1
Q185:	;[3401] 	DATA $0000,$0000,$0505,$0002
	SRCFILE "whalehunt_1a.bas",3401
	DECLE 0
	DECLE 0
	DECLE 1285
	DECLE 2
	;[3402] 	DATA $0000,$0000,$5050,$0050
	SRCFILE "whalehunt_1a.bas",3402
	DECLE 0
	DECLE 0
	DECLE 20560
	DECLE 80
	;[3403] 	DATA $8282,$8282,$4444,$4444
	SRCFILE "whalehunt_1a.bas",3403
	DECLE 33410
	DECLE 33410
	DECLE 17476
	DECLE 17476
	;[3404] 	DATA $0000,$0000,$0A0A,$0004
	SRCFILE "whalehunt_1a.bas",3404
	DECLE 0
	DECLE 0
	DECLE 2570
	DECLE 4
	;[3405] 	DATA $A800,$48A8,$0000,$0A0A
	SRCFILE "whalehunt_1a.bas",3405
	DECLE 43008
	DECLE 18600
	DECLE 0
	DECLE 2570
	;[3406] 	DATA $4444,$4444,$4444,$2828
	SRCFILE "whalehunt_1a.bas",3406
	DECLE 17476
	DECLE 17476
	DECLE 17476
	DECLE 10280
	;[3407] 	DATA $0000,$0000,$0000,$0101
	SRCFILE "whalehunt_1a.bas",3407
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 257
	;[3408] 	DATA $2A00,$122A,$0000,$5454
	SRCFILE "whalehunt_1a.bas",3408
	DECLE 10752
	DECLE 4650
	DECLE 0
	DECLE 21588
	;[3409] 	DATA $8080,$C0C0,$E0C0,$F0E0
	SRCFILE "whalehunt_1a.bas",3409
	DECLE 32896
	DECLE 49344
	DECLE 57536
	DECLE 61664
	;[3410] 	DATA $0004,$0500,$0405,$0000
	SRCFILE "whalehunt_1a.bas",3410
	DECLE 4
	DECLE 1280
	DECLE 1029
	DECLE 0
	;[3411] 	DATA $0000,$4000,$8040,$0000
	SRCFILE "whalehunt_1a.bas",3411
	DECLE 0
	DECLE 16384
	DECLE 32832
	DECLE 0
	;[3412] 	DATA $2828,$2828,$2828,$1010
	SRCFILE "whalehunt_1a.bas",3412
	DECLE 10280
	DECLE 10280
	DECLE 10280
	DECLE 4112
	;[3413] 	DATA $0000,$0A00,$040A,$0000
	SRCFILE "whalehunt_1a.bas",3413
	DECLE 0
	DECLE 2560
	DECLE 1034
	DECLE 0
	;[3414] 	DATA $0094,$A800,$A8A8,$0000
	SRCFILE "whalehunt_1a.bas",3414
	DECLE 148
	DECLE 43008
	DECLE 43176
	DECLE 0
	;[3415] 	DATA $0101,$0303,$0703,$0F07
	SRCFILE "whalehunt_1a.bas",3415
	DECLE 257
	DECLE 771
	DECLE 1795
	DECLE 3847
	;[3416] 	DATA $F8F0,$FCF8,$FEFC,$FFFF
	SRCFILE "whalehunt_1a.bas",3416
	DECLE 63728
	DECLE 64760
	DECLE 65276
	DECLE 65535
	;[3417] sundial_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",3417
	; SUNDIAL_BITMAPS_2
Q186:	;[3418] 	DATA $0000,$0000,$0000,$8000
	SRCFILE "whalehunt_1a.bas",3418
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 32768
	;[3419] 	DATA $5454,$0054,$0101,$0001
	SRCFILE "whalehunt_1a.bas",3419
	DECLE 21588
	DECLE 84
	DECLE 257
	DECLE 1
	;[3420] 	DATA $0000,$0000,$4040,$0840
	SRCFILE "whalehunt_1a.bas",3420
	DECLE 0
	DECLE 0
	DECLE 16448
	DECLE 2112
	;[3421] 	DATA $0010,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3421
	DECLE 16
	DECLE 0
	DECLE 0
	DECLE 0
	;[3422] 	DATA $0000,$0000,$0102,$A802
	SRCFILE "whalehunt_1a.bas",3422
	DECLE 0
	DECLE 0
	DECLE 258
	DECLE 43010
	;[3423] 	DATA $242A,$002A,$0080,$0080
	SRCFILE "whalehunt_1a.bas",3423
	DECLE 9258
	DECLE 42
	DECLE 128
	DECLE 128
	;[3424] 	DATA $0000,$0000,$0000,$0100
	SRCFILE "whalehunt_1a.bas",3424
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 256
	;[3425] 	DATA $1F0F,$3F1F,$7F3F,$FFFF
	SRCFILE "whalehunt_1a.bas",3425
	DECLE 7951
	DECLE 16159
	DECLE 32575
	DECLE 65535
	;[3426] 	DATA $E0C0,$F8F0,$FEFC,$FFFF
	SRCFILE "whalehunt_1a.bas",3426
	DECLE 57536
	DECLE 63728
	DECLE 65276
	DECLE 65535
	;[3427] 	DATA $0000,$0000,$0000,$C080
	SRCFILE "whalehunt_1a.bas",3427
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 49280
	;[3428] 	DATA $0908,$0100,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3428
	DECLE 2312
	DECLE 256
	DECLE 0
	DECLE 0
	;[3429] 	DATA $5400,$5494,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3429
	DECLE 21504
	DECLE 21652
	DECLE 0
	DECLE 0
	;[3430] 	DATA $A848,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3430
	DECLE 43080
	DECLE 0
	DECLE 0
	DECLE 0
	;[3431] 	DATA $0000,$0000,$0000,$0301
	SRCFILE "whalehunt_1a.bas",3431
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 769
	;[3432] 	DATA $0703,$1F0F,$7F3F,$FFFF
	SRCFILE "whalehunt_1a.bas",3432
	DECLE 1795
	DECLE 7951
	DECLE 32575
	DECLE 65535
	;[3433] 	DATA $FEF0,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3433
	DECLE 65264
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3434] sundial_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",3434
	; SUNDIAL_BITMAPS_3
Q187:	;[3435] 	DATA $0000,$FCC0,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3435
	DECLE 0
	DECLE 64704
	DECLE 65535
	DECLE 65535
	;[3436] 	DATA $0000,$0000,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3436
	DECLE 0
	DECLE 0
	DECLE 65535
	DECLE 65535
	;[3437] 	DATA $0000,$3F03,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",3437
	DECLE 0
	DECLE 16131
	DECLE 65535
	DECLE 65535
	;[3438] 	DATA $7F0F,$FFFF,$FFFF,$FFFF	
	SRCFILE "whalehunt_1a.bas",3438
	DECLE 32527
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[3439] 
	SRCFILE "whalehunt_1a.bas",3439
	;[3440] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3440
	;[3441] sundial_cards:
	SRCFILE "whalehunt_1a.bas",3441
	; SUNDIAL_CARDS
Q194:	;[3442] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3442
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3443] 	DATA $1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200,$1200
	SRCFILE "whalehunt_1a.bas",3443
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	DECLE 4608
	;[3444] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1801,$1809,$1811,$1819,$1821,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3444
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6145
	DECLE 6153
	DECLE 6161
	DECLE 6169
	DECLE 6177
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3445] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1829,$1831,$1000,$1000,$1000,$1839,$1841,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3445
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6185
	DECLE 6193
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6201
	DECLE 6209
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3446] 	DATA $0200,$0200,$0200,$0200,$0200,$1849,$1851,$1000,$1000,$1000,$1000,$1000,$1859,$1861,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3446
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6217
	DECLE 6225
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6233
	DECLE 6241
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3447] 	DATA $0200,$0200,$0200,$0200,$0200,$1869,$1000,$1000,$1000,$1870,$1000,$1000,$1000,$1879,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3447
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6249
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6256
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6265
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3448] 	DATA $0200,$0200,$0200,$0200,$0200,$1880,$1888,$1000,$1000,$1890,$1000,$1000,$1898,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3448
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6272
	DECLE 6280
	DECLE 4096
	DECLE 4096
	DECLE 6288
	DECLE 4096
	DECLE 4096
	DECLE 6296
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3449] 	DATA $0200,$0200,$0200,$0200,$0200,$1000,$18A0,$1000,$1000,$18A8,$1000,$18B0,$18B8,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3449
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 4096
	DECLE 6304
	DECLE 4096
	DECLE 4096
	DECLE 6312
	DECLE 4096
	DECLE 6320
	DECLE 6328
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3450] 	DATA $0200,$0200,$0200,$0200,$0200,$18C1,$18C8,$18D0,$1000,$18D8,$1000,$18E0,$18E8,$18F1,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3450
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6337
	DECLE 6344
	DECLE 6352
	DECLE 4096
	DECLE 6360
	DECLE 4096
	DECLE 6368
	DECLE 6376
	DECLE 6385
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3451] 	DATA $0200,$0200,$0200,$0200,$0200,$18F9,$1901,$1908,$1910,$1918,$1920,$1928,$1931,$1939,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3451
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6393
	DECLE 6401
	DECLE 6408
	DECLE 6416
	DECLE 6424
	DECLE 6432
	DECLE 6440
	DECLE 6449
	DECLE 6457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3452] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1941,$1949,$1950,$1958,$1960,$1969,$1971,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3452
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6465
	DECLE 6473
	DECLE 6480
	DECLE 6488
	DECLE 6496
	DECLE 6505
	DECLE 6513
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3453] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1979,$1981,$1989,$1991,$1999,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3453
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6521
	DECLE 6529
	DECLE 6537
	DECLE 6545
	DECLE 6553
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3454] 	
	SRCFILE "whalehunt_1a.bas",3454
	;[3455] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3455
	;[3456] sundial_dawn_cards:
	SRCFILE "whalehunt_1a.bas",3456
	; SUNDIAL_DAWN_CARDS
Q193:	;[3457] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",3457
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[3458] 	DATA $3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200,$3200
	SRCFILE "whalehunt_1a.bas",3458
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	DECLE 12800
	;[3459] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1801,$1809,$1811,$1819,$1821,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3459
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6145
	DECLE 6153
	DECLE 6161
	DECLE 6169
	DECLE 6177
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3460] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1829,$1831,$1000,$1000,$1000,$1839,$1841,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3460
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6185
	DECLE 6193
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6201
	DECLE 6209
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3461] 	DATA $0200,$0200,$0200,$0200,$0200,$1849,$1851,$1000,$1000,$1000,$1000,$1000,$1859,$1861,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3461
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6217
	DECLE 6225
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6233
	DECLE 6241
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3462] 	DATA $0200,$0200,$0200,$0200,$0200,$1869,$1000,$1000,$1000,$1870,$1000,$1000,$1000,$1879,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3462
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6249
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6256
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6265
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3463] 	DATA $0200,$0200,$0200,$0200,$0200,$1880,$1888,$1000,$1000,$1890,$1000,$1000,$1898,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3463
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6272
	DECLE 6280
	DECLE 4096
	DECLE 4096
	DECLE 6288
	DECLE 4096
	DECLE 4096
	DECLE 6296
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3464] 	DATA $0200,$0200,$0200,$0200,$0200,$1000,$18A0,$1000,$1000,$18A8,$1000,$18B0,$18B8,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3464
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 4096
	DECLE 6304
	DECLE 4096
	DECLE 4096
	DECLE 6312
	DECLE 4096
	DECLE 6320
	DECLE 6328
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3465] 	DATA $0200,$0200,$0200,$0200,$0200,$18C1,$18C8,$18D0,$1000,$18D8,$1000,$18E0,$18E8,$18F1,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3465
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6337
	DECLE 6344
	DECLE 6352
	DECLE 4096
	DECLE 6360
	DECLE 4096
	DECLE 6368
	DECLE 6376
	DECLE 6385
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3466] 	DATA $0200,$0200,$0200,$0200,$0200,$18F9,$1901,$1908,$1910,$1918,$1920,$1928,$1931,$1939,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3466
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6393
	DECLE 6401
	DECLE 6408
	DECLE 6416
	DECLE 6424
	DECLE 6432
	DECLE 6440
	DECLE 6449
	DECLE 6457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3467] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1941,$1949,$1950,$1958,$1960,$1969,$1971,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3467
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6465
	DECLE 6473
	DECLE 6480
	DECLE 6488
	DECLE 6496
	DECLE 6505
	DECLE 6513
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3468] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1979,$1981,$1989,$1991,$1999,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3468
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6521
	DECLE 6529
	DECLE 6537
	DECLE 6545
	DECLE 6553
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3469] 
	SRCFILE "whalehunt_1a.bas",3469
	;[3470] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3470
	;[3471] sundial_dusk_cards:
	SRCFILE "whalehunt_1a.bas",3471
	; SUNDIAL_DUSK_CARDS
Q195:	;[3472] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",3472
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[3473] 	DATA $3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000,$3000
	SRCFILE "whalehunt_1a.bas",3473
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	DECLE 12288
	;[3474] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1801,$1809,$1811,$1819,$1821,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3474
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6145
	DECLE 6153
	DECLE 6161
	DECLE 6169
	DECLE 6177
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3475] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1829,$1831,$1000,$1000,$1000,$1839,$1841,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3475
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6185
	DECLE 6193
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6201
	DECLE 6209
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3476] 	DATA $0200,$0200,$0200,$0200,$0200,$1849,$1851,$1000,$1000,$1000,$1000,$1000,$1859,$1861,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3476
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6217
	DECLE 6225
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6233
	DECLE 6241
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3477] 	DATA $0200,$0200,$0200,$0200,$0200,$1869,$1000,$1000,$1000,$1870,$1000,$1000,$1000,$1879,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3477
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6249
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6256
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6265
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3478] 	DATA $0200,$0200,$0200,$0200,$0200,$1880,$1888,$1000,$1000,$1890,$1000,$1000,$1898,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3478
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6272
	DECLE 6280
	DECLE 4096
	DECLE 4096
	DECLE 6288
	DECLE 4096
	DECLE 4096
	DECLE 6296
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3479] 	DATA $0200,$0200,$0200,$0200,$0200,$1000,$18A0,$1000,$1000,$18A8,$1000,$18B0,$18B8,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3479
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 4096
	DECLE 6304
	DECLE 4096
	DECLE 4096
	DECLE 6312
	DECLE 4096
	DECLE 6320
	DECLE 6328
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3480] 	DATA $0200,$0200,$0200,$0200,$0200,$18C1,$18C8,$18D0,$1000,$18D8,$1000,$18E0,$18E8,$18F1,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3480
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6337
	DECLE 6344
	DECLE 6352
	DECLE 4096
	DECLE 6360
	DECLE 4096
	DECLE 6368
	DECLE 6376
	DECLE 6385
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3481] 	DATA $0200,$0200,$0200,$0200,$0200,$18F9,$1901,$1908,$1910,$1918,$1920,$1928,$1931,$1939,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3481
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6393
	DECLE 6401
	DECLE 6408
	DECLE 6416
	DECLE 6424
	DECLE 6432
	DECLE 6440
	DECLE 6449
	DECLE 6457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3482] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1941,$1949,$1950,$1958,$1960,$1969,$1971,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3482
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6465
	DECLE 6473
	DECLE 6480
	DECLE 6488
	DECLE 6496
	DECLE 6505
	DECLE 6513
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3483] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1979,$1981,$1989,$1991,$1999,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3483
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6521
	DECLE 6529
	DECLE 6537
	DECLE 6545
	DECLE 6553
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3484] 	
	SRCFILE "whalehunt_1a.bas",3484
	;[3485] 	REM 20x12 cards
	SRCFILE "whalehunt_1a.bas",3485
	;[3486] sundial_storm_cards:
	SRCFILE "whalehunt_1a.bas",3486
	; SUNDIAL_STORM_CARDS
Q196:	;[3487] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3487
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3488] 	DATA $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",3488
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 0
	;[3489] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1801,$1809,$1811,$1819,$1821,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3489
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6145
	DECLE 6153
	DECLE 6161
	DECLE 6169
	DECLE 6177
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3490] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1829,$1831,$1000,$1000,$1000,$1839,$1841,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3490
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6185
	DECLE 6193
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6201
	DECLE 6209
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3491] 	DATA $0200,$0200,$0200,$0200,$0200,$1849,$1851,$1000,$1000,$1000,$1000,$1000,$1859,$1861,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3491
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6217
	DECLE 6225
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6233
	DECLE 6241
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3492] 	DATA $0200,$0200,$0200,$0200,$0200,$1869,$1000,$1000,$1000,$1870,$1000,$1000,$1000,$1879,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3492
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6249
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6256
	DECLE 4096
	DECLE 4096
	DECLE 4096
	DECLE 6265
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3493] 	DATA $0200,$0200,$0200,$0200,$0200,$1880,$1888,$1000,$1000,$1890,$1000,$1000,$1898,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3493
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6272
	DECLE 6280
	DECLE 4096
	DECLE 4096
	DECLE 6288
	DECLE 4096
	DECLE 4096
	DECLE 6296
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3494] 	DATA $0200,$0200,$0200,$0200,$0200,$1000,$18A0,$1000,$1000,$18A8,$1000,$18B0,$18B8,$1000,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3494
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 4096
	DECLE 6304
	DECLE 4096
	DECLE 4096
	DECLE 6312
	DECLE 4096
	DECLE 6320
	DECLE 6328
	DECLE 4096
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3495] 	DATA $0200,$0200,$0200,$0200,$0200,$18C1,$18C8,$18D0,$1000,$18D8,$1000,$18E0,$18E8,$18F1,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3495
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6337
	DECLE 6344
	DECLE 6352
	DECLE 4096
	DECLE 6360
	DECLE 4096
	DECLE 6368
	DECLE 6376
	DECLE 6385
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3496] 	DATA $0200,$0200,$0200,$0200,$0200,$18F9,$1901,$1908,$1910,$1918,$1920,$1928,$1931,$1939,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3496
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6393
	DECLE 6401
	DECLE 6408
	DECLE 6416
	DECLE 6424
	DECLE 6432
	DECLE 6440
	DECLE 6449
	DECLE 6457
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3497] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$1941,$1949,$1950,$1958,$1960,$1969,$1971,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3497
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6465
	DECLE 6473
	DECLE 6480
	DECLE 6488
	DECLE 6496
	DECLE 6505
	DECLE 6513
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3498] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$1979,$1981,$1989,$1991,$1999,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "whalehunt_1a.bas",3498
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6521
	DECLE 6529
	DECLE 6537
	DECLE 6545
	DECLE 6553
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[3499] 
	SRCFILE "whalehunt_1a.bas",3499
	;[3500] 	
	SRCFILE "whalehunt_1a.bas",3500
	;[3501] beat_level_music:		data 8
	SRCFILE "whalehunt_1a.bas",3501
	; BEAT_LEVEL_MUSIC
Q11:		DECLE 8
	;[3502] 
	SRCFILE "whalehunt_1a.bas",3502
	;[3503] music c4w,c3y,c5w,m1
	SRCFILE "whalehunt_1a.bas",3503
	DECLE 36121,293
	;[3504] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3504
	DECLE 28,40
	;[3505] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3505
	DECLE 28,40
	;[3506] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3506
	DECLE 28,40
	;[3507] music d4,-,d5,-
	SRCFILE "whalehunt_1a.bas",3507
	DECLE 27,39
	;[3508] music c4#,-,c5#,-
	SRCFILE "whalehunt_1a.bas",3508
	DECLE 26,38
	;[3509] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3509
	DECLE 25,37
	;[3510] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3510
	DECLE 25,37
	;[3511] music b3,-,b4,-
	SRCFILE "whalehunt_1a.bas",3511
	DECLE 24,36
	;[3512] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3512
	DECLE 25,37
	;[3513] music s,-,s,-
	SRCFILE "whalehunt_1a.bas",3513
	DECLE 63,63
	;[3514] music s,-,s,-
	SRCFILE "whalehunt_1a.bas",3514
	DECLE 63,63
	;[3515] 
	SRCFILE "whalehunt_1a.bas",3515
	;[3516] music c4,c3,c5,m1
	SRCFILE "whalehunt_1a.bas",3516
	DECLE 36121,293
	;[3517] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3517
	DECLE 28,40
	;[3518] music d4#,c3,d5#,m1
	SRCFILE "whalehunt_1a.bas",3518
	DECLE 36124,296
	;[3519] music d4#,s,d5#,-
	SRCFILE "whalehunt_1a.bas",3519
	DECLE 16156,40
	;[3520] music d4,s,d5,-
	SRCFILE "whalehunt_1a.bas",3520
	DECLE 16155,39
	;[3521] music d4#,s,d5#,-
	SRCFILE "whalehunt_1a.bas",3521
	DECLE 16156,40
	;[3522] music e4,s,e5,-
	SRCFILE "whalehunt_1a.bas",3522
	DECLE 16157,41
	;[3523] music e4,s,e5,-
	SRCFILE "whalehunt_1a.bas",3523
	DECLE 16157,41
	;[3524] music d4,-,d5,-
	SRCFILE "whalehunt_1a.bas",3524
	DECLE 27,39
	;[3525] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3525
	DECLE 28,40
	;[3526] music s,-,s,-
	SRCFILE "whalehunt_1a.bas",3526
	DECLE 63,63
	;[3527] music s,c3,s,m1
	SRCFILE "whalehunt_1a.bas",3527
	DECLE 36159,319
	;[3528] 
	SRCFILE "whalehunt_1a.bas",3528
	;[3529] music c4,c3,c5,m1
	SRCFILE "whalehunt_1a.bas",3529
	DECLE 36121,293
	;[3530] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3530
	DECLE 28,40
	;[3531] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3531
	DECLE 28,40
	;[3532] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3532
	DECLE 28,40
	;[3533] music d4,-,d5,-
	SRCFILE "whalehunt_1a.bas",3533
	DECLE 27,39
	;[3534] music c4#,-,c5#,-
	SRCFILE "whalehunt_1a.bas",3534
	DECLE 26,38
	;[3535] music d4,-,d5,-
	SRCFILE "whalehunt_1a.bas",3535
	DECLE 27,39
	;[3536] music c4#,-,c5#,-
	SRCFILE "whalehunt_1a.bas",3536
	DECLE 26,38
	;[3537] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3537
	DECLE 25,37
	;[3538] music c4#,-,c5#,-
	SRCFILE "whalehunt_1a.bas",3538
	DECLE 26,38
	;[3539] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3539
	DECLE 25,37
	;[3540] music b3,-,b4,-
	SRCFILE "whalehunt_1a.bas",3540
	DECLE 24,36
	;[3541] 
	SRCFILE "whalehunt_1a.bas",3541
	;[3542] music a3,-,a4,-
	SRCFILE "whalehunt_1a.bas",3542
	DECLE 22,34
	;[3543] music b3,-,b4,-
	SRCFILE "whalehunt_1a.bas",3543
	DECLE 24,36
	;[3544] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3544
	DECLE 25,37
	;[3545] music d4#,-,d5#,-
	SRCFILE "whalehunt_1a.bas",3545
	DECLE 28,40
	;[3546] music d4,-,d5,-
	SRCFILE "whalehunt_1a.bas",3546
	DECLE 27,39
	;[3547] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3547
	DECLE 25,37
	;[3548] music a3#,-,a4#,-
	SRCFILE "whalehunt_1a.bas",3548
	DECLE 23,35
	;[3549] music a3#,-,a4#,-
	SRCFILE "whalehunt_1a.bas",3549
	DECLE 23,35
	;[3550] music a3#,-,a4#,-
	SRCFILE "whalehunt_1a.bas",3550
	DECLE 23,35
	;[3551] music c4,-,c5,-
	SRCFILE "whalehunt_1a.bas",3551
	DECLE 25,37
	;[3552] music s,-,s,-
	SRCFILE "whalehunt_1a.bas",3552
	DECLE 63,63
	;[3553] music s,-,s,-
	SRCFILE "whalehunt_1a.bas",3553
	DECLE 63,63
	;[3554] 
	SRCFILE "whalehunt_1a.bas",3554
	;[3555] music repeat
	SRCFILE "whalehunt_1a.bas",3555
	DECLE 253,0
	;[3556] 
	SRCFILE "whalehunt_1a.bas",3556
	;[3557] spear_miss:	data 1
	SRCFILE "whalehunt_1a.bas",3557
	; SPEAR_MISS
Q77:		DECLE 1
	;[3558] 	music c6z,-,-,-
	SRCFILE "whalehunt_1a.bas",3558
	DECLE 241,0
	;[3559] 	music b5,-,-,-
	SRCFILE "whalehunt_1a.bas",3559
	DECLE 240,0
	;[3560] 	music a5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3560
	DECLE 239,0
	;[3561] 	music a5,-,-,-
	SRCFILE "whalehunt_1a.bas",3561
	DECLE 238,0
	;[3562] 	music g5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3562
	DECLE 237,0
	;[3563] 	music g5,-,-,-
	SRCFILE "whalehunt_1a.bas",3563
	DECLE 236,0
	;[3564] 	music f5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3564
	DECLE 235,0
	;[3565] 	music f5,-,-,-
	SRCFILE "whalehunt_1a.bas",3565
	DECLE 234,0
	;[3566] 	music e5,-,-,-
	SRCFILE "whalehunt_1a.bas",3566
	DECLE 233,0
	;[3567] 	music d5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3567
	DECLE 232,0
	;[3568] 	music d5,-,-,-
	SRCFILE "whalehunt_1a.bas",3568
	DECLE 231,0
	;[3569] 	music c5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3569
	DECLE 230,0
	;[3570] 	music c5,-,-,-
	SRCFILE "whalehunt_1a.bas",3570
	DECLE 229,0
	;[3571] 	music b4,-,-,-
	SRCFILE "whalehunt_1a.bas",3571
	DECLE 228,0
	;[3572] 	music a4#,-,-,-
	SRCFILE "whalehunt_1a.bas",3572
	DECLE 227,0
	;[3573] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",3573
	DECLE 226,0
	;[3574] 	music stop
	SRCFILE "whalehunt_1a.bas",3574
	DECLE 254,0
	;[3575] 	
	SRCFILE "whalehunt_1a.bas",3575
	;[3576] spear_hit:	data 1
	SRCFILE "whalehunt_1a.bas",3576
	; SPEAR_HIT
Q80:		DECLE 1
	;[3577] 	music c4y,c4w,-,-
	SRCFILE "whalehunt_1a.bas",3577
	DECLE 6553,0
	;[3578] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3578
	DECLE 16191,0
	;[3579] 	music d4,s,-,-
	SRCFILE "whalehunt_1a.bas",3579
	DECLE 16283,0
	;[3580] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3580
	DECLE 16191,0
	;[3581] 	music s,f4,-,-
	SRCFILE "whalehunt_1a.bas",3581
	DECLE 7743,0
	;[3582] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3582
	DECLE 16191,0
	;[3583] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3583
	DECLE 16191,0
	;[3584] 	music g4#,s,-,-
	SRCFILE "whalehunt_1a.bas",3584
	DECLE 16289,0
	;[3585] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3585
	DECLE 16191,0
	;[3586] 	music s,e4#,-,-
	SRCFILE "whalehunt_1a.bas",3586
	DECLE 7743,0
	;[3587] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3587
	DECLE 16191,0
	;[3588] 	music d4,s,-,-
	SRCFILE "whalehunt_1a.bas",3588
	DECLE 16283,0
	;[3589] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3589
	DECLE 16191,0
	;[3590] 	music s,c4#,-,-
	SRCFILE "whalehunt_1a.bas",3590
	DECLE 6719,0
	;[3591] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3591
	DECLE 16191,0
	;[3592] 	music b3,s,-,-
	SRCFILE "whalehunt_1a.bas",3592
	DECLE 16280,0
	;[3593] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3593
	DECLE 16191,0
	;[3594] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3594
	DECLE 16191,0
	;[3595] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3595
	DECLE 16191,0
	;[3596] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3596
	DECLE 16191,0
	;[3597] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3597
	DECLE 16191,0
	;[3598] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3598
	DECLE 16191,0
	;[3599] 	music stop
	SRCFILE "whalehunt_1a.bas",3599
	DECLE 254,0
	;[3600] 	
	SRCFILE "whalehunt_1a.bas",3600
	;[3601] 
	SRCFILE "whalehunt_1a.bas",3601
	;[3602] enemy_splash:	data 1
	SRCFILE "whalehunt_1a.bas",3602
	; ENEMY_SPLASH
Q277:		DECLE 1
	;[3603] 	music -,-,-,m3
	SRCFILE "whalehunt_1a.bas",3603
	DECLE 0,768
	;[3604] 	music repeat
	SRCFILE "whalehunt_1a.bas",3604
	DECLE 253,0
	;[3605] 	
	SRCFILE "whalehunt_1a.bas",3605
	;[3606] enemy_hit:		data 1
	SRCFILE "whalehunt_1a.bas",3606
	; ENEMY_HIT
Q278:		DECLE 1
	;[3607] 	music c5y,c5w,-,-
	SRCFILE "whalehunt_1a.bas",3607
	DECLE 9637,0
	;[3608] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3608
	DECLE 16191,0
	;[3609] 	music d5,s,-,-
	SRCFILE "whalehunt_1a.bas",3609
	DECLE 16295,0
	;[3610] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3610
	DECLE 16191,0
	;[3611] 	music s,f5,-,-
	SRCFILE "whalehunt_1a.bas",3611
	DECLE 10815,0
	;[3612] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3612
	DECLE 16191,0
	;[3613] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3613
	DECLE 16191,0
	;[3614] 	music g5#,s,-,-
	SRCFILE "whalehunt_1a.bas",3614
	DECLE 16301,0
	;[3615] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3615
	DECLE 16191,0
	;[3616] 	music s,e5#,-,-
	SRCFILE "whalehunt_1a.bas",3616
	DECLE 10815,0
	;[3617] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3617
	DECLE 16191,0
	;[3618] 	music d5,s,-,-
	SRCFILE "whalehunt_1a.bas",3618
	DECLE 16295,0
	;[3619] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3619
	DECLE 16191,0
	;[3620] 	music s,c5#,-,-
	SRCFILE "whalehunt_1a.bas",3620
	DECLE 9791,0
	;[3621] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3621
	DECLE 16191,0
	;[3622] 	music b4,s,-,-
	SRCFILE "whalehunt_1a.bas",3622
	DECLE 16292,0
	;[3623] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3623
	DECLE 16191,0
	;[3624] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3624
	DECLE 16191,0
	;[3625] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3625
	DECLE 16191,0
	;[3626] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3626
	DECLE 16191,0
	;[3627] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3627
	DECLE 16191,0
	;[3628] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3628
	DECLE 16191,0
	;[3629] 	music stop
	SRCFILE "whalehunt_1a.bas",3629
	DECLE 254,0
	;[3630] 	
	SRCFILE "whalehunt_1a.bas",3630
	;[3631] enemy_miss:		data 1
	SRCFILE "whalehunt_1a.bas",3631
	; ENEMY_MISS
Q280:		DECLE 1
	;[3632] 	music c6y,-,-,-
	SRCFILE "whalehunt_1a.bas",3632
	DECLE 177,0
	;[3633] 	music b5,-,-,-
	SRCFILE "whalehunt_1a.bas",3633
	DECLE 176,0
	;[3634] 	music a5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3634
	DECLE 175,0
	;[3635] 	music a5,-,-,-
	SRCFILE "whalehunt_1a.bas",3635
	DECLE 174,0
	;[3636] 	music g5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3636
	DECLE 173,0
	;[3637] 	music g5,-,-,-
	SRCFILE "whalehunt_1a.bas",3637
	DECLE 172,0
	;[3638] 	music f5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3638
	DECLE 171,0
	;[3639] 	music f5,-,-,-
	SRCFILE "whalehunt_1a.bas",3639
	DECLE 170,0
	;[3640] 	music e5,-,-,-
	SRCFILE "whalehunt_1a.bas",3640
	DECLE 169,0
	;[3641] 	music d5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3641
	DECLE 168,0
	;[3642] 	music d5,-,-,-
	SRCFILE "whalehunt_1a.bas",3642
	DECLE 167,0
	;[3643] 	music c5#,-,-,-
	SRCFILE "whalehunt_1a.bas",3643
	DECLE 166,0
	;[3644] 	music c5,-,-,-
	SRCFILE "whalehunt_1a.bas",3644
	DECLE 165,0
	;[3645] 	music b4,-,-,-
	SRCFILE "whalehunt_1a.bas",3645
	DECLE 164,0
	;[3646] 	music a4#,-,-,-
	SRCFILE "whalehunt_1a.bas",3646
	DECLE 163,0
	;[3647] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",3647
	DECLE 162,0
	;[3648] 	music stop
	SRCFILE "whalehunt_1a.bas",3648
	DECLE 254,0
	;[3649] 	
	SRCFILE "whalehunt_1a.bas",3649
	;[3650] 	
	SRCFILE "whalehunt_1a.bas",3650
	;[3651] score_sound:	data 4
	SRCFILE "whalehunt_1a.bas",3651
	; SCORE_SOUND
Q288:		DECLE 4
	;[3652] 	music -,-,-,m2
	SRCFILE "whalehunt_1a.bas",3652
	DECLE 0,512
	;[3653] 	music repeat
	SRCFILE "whalehunt_1a.bas",3653
	DECLE 253,0
	;[3654] 
	SRCFILE "whalehunt_1a.bas",3654
	;[3655] upgrade_song:		data 4
	SRCFILE "whalehunt_1a.bas",3655
	; UPGRADE_SONG
Q316:		DECLE 4
	;[3656] 	music b4,-,-,-
	SRCFILE "whalehunt_1a.bas",3656
	DECLE 164,0
	;[3657] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3657
	DECLE 63,0
	;[3658] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3658
	DECLE 63,0
	;[3659] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3659
	DECLE 63,0
	;[3660] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3660
	DECLE 0,0
	;[3661] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3661
	DECLE 0,0
	;[3662] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3662
	DECLE 0,0
	;[3663] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3663
	DECLE 0,0
	;[3664] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",3664
	DECLE 162,0
	;[3665] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3665
	DECLE 63,0
	;[3666] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3666
	DECLE 63,0
	;[3667] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3667
	DECLE 63,0
	;[3668] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3668
	DECLE 0,0
	;[3669] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3669
	DECLE 0,0
	;[3670] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3670
	DECLE 160,0
	;[3671] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3671
	DECLE 63,0
	;[3672] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3672
	DECLE 0,0
	;[3673] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3673
	DECLE 0,0
	;[3674] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3674
	DECLE 160,0
	;[3675] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3675
	DECLE 0,0
	;[3676] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",3676
	DECLE 162,0
	;[3677] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3677
	DECLE 63,0
	;[3678] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3678
	DECLE 0,0
	;[3679] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3679
	DECLE 0,0
	;[3680] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3680
	DECLE 160,0
	;[3681] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3681
	DECLE 63,0
	;[3682] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3682
	DECLE 0,0
	;[3683] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3683
	DECLE 0,0
	;[3684] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3684
	DECLE 160,0
	;[3685] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3685
	DECLE 63,0
	;[3686] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3686
	DECLE 0,0
	;[3687] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3687
	DECLE 0,0
	;[3688] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",3688
	DECLE 157,0
	;[3689] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3689
	DECLE 63,0
	;[3690] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3690
	DECLE 63,0
	;[3691] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3691
	DECLE 63,0
	;[3692] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3692
	DECLE 0,0
	;[3693] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3693
	DECLE 0,0
	;[3694] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",3694
	DECLE 157,0
	;[3695] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3695
	DECLE 63,0
	;[3696] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3696
	DECLE 0,0
	;[3697] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3697
	DECLE 0,0
	;[3698] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",3698
	DECLE 157,0
	;[3699] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3699
	DECLE 0,0
	;[3700] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3700
	DECLE 160,0
	;[3701] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3701
	DECLE 63,0
	;[3702] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3702
	DECLE 0,0
	;[3703] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3703
	DECLE 0,0
	;[3704] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",3704
	DECLE 155,0
	;[3705] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3705
	DECLE 63,0
	;[3706] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3706
	DECLE 63,0
	;[3707] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3707
	DECLE 0,0
	;[3708] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",3708
	DECLE 157,0
	;[3709] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3709
	DECLE 63,0
	;[3710] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3710
	DECLE 63,0
	;[3711] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3711
	DECLE 0,0
	;[3712] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3712
	DECLE 152,0
	;[3713] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3713
	DECLE 63,0
	;[3714] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3714
	DECLE 63,0
	;[3715] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3715
	DECLE 0,0
	;[3716] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3716
	DECLE 0,0
	;[3717] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3717
	DECLE 0,0
	;[3718] 	music -,-,-,-	
	SRCFILE "whalehunt_1a.bas",3718
	DECLE 0,0
	;[3719] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3719
	DECLE 0,0
	;[3720] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3720
	DECLE 0,0
	;[3721] 	music repeat
	SRCFILE "whalehunt_1a.bas",3721
	DECLE 253,0
	;[3722] 	
	SRCFILE "whalehunt_1a.bas",3722
	;[3723] storm_sound:	data 6
	SRCFILE "whalehunt_1a.bas",3723
	; STORM_SOUND
Q235:		DECLE 6
	;[3724] 	music -,-,-,m3
	SRCFILE "whalehunt_1a.bas",3724
	DECLE 0,768
	;[3725] 	music -,-,-,m3
	SRCFILE "whalehunt_1a.bas",3725
	DECLE 0,768
	;[3726] 	music -,-,-,m1
	SRCFILE "whalehunt_1a.bas",3726
	DECLE 0,256
	;[3727] 	music -,-,-,m1
	SRCFILE "whalehunt_1a.bas",3727
	DECLE 0,256
	;[3728] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3728
	DECLE 0,0
	;[3729] 	music -,-,-,m3
	SRCFILE "whalehunt_1a.bas",3729
	DECLE 0,768
	;[3730] 	music -,-,-,m3
	SRCFILE "whalehunt_1a.bas",3730
	DECLE 0,768
	;[3731] 	music -,-,-,m1
	SRCFILE "whalehunt_1a.bas",3731
	DECLE 0,256
	;[3732] 	music -,-,-,m1
	SRCFILE "whalehunt_1a.bas",3732
	DECLE 0,256
	;[3733] 	music stop
	SRCFILE "whalehunt_1a.bas",3733
	DECLE 254,0
	;[3734] 	
	SRCFILE "whalehunt_1a.bas",3734
	;[3735] flute_song:		data 3
	SRCFILE "whalehunt_1a.bas",3735
	; FLUTE_SONG
Q37:		DECLE 3
	;[3736] 	music f4y,-,-,-
	SRCFILE "whalehunt_1a.bas",3736
	DECLE 158,0
	;[3737] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3737
	DECLE 63,0
	;[3738] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3738
	DECLE 63,0
	;[3739] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3739
	DECLE 160,0
	;[3740] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3740
	DECLE 63,0
	;[3741] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3741
	DECLE 63,0
	;[3742] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",3742
	DECLE 162,0
	;[3743] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3743
	DECLE 63,0
	;[3744] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3744
	DECLE 63,0
	;[3745] 	music b4#,-,-,-
	SRCFILE "whalehunt_1a.bas",3745
	DECLE 165,0
	;[3746] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3746
	DECLE 63,0
	;[3747] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3747
	DECLE 63,0
	;[3748] 	music a4#,-,-,-
	SRCFILE "whalehunt_1a.bas",3748
	DECLE 163,0
	;[3749] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3749
	DECLE 63,0
	;[3750] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3750
	DECLE 63,0
	;[3751] 	music b4#,-,-,-
	SRCFILE "whalehunt_1a.bas",3751
	DECLE 165,0
	;[3752] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3752
	DECLE 63,0
	;[3753] 	music stop
	SRCFILE "whalehunt_1a.bas",3753
	DECLE 254,0
	;[3754] 	
	SRCFILE "whalehunt_1a.bas",3754
	;[3755] game_over_song:		data 3
	SRCFILE "whalehunt_1a.bas",3755
	; GAME_OVER_SONG
Q220:		DECLE 3
	;[3756] 	music d3y,d3x,-,-
	SRCFILE "whalehunt_1a.bas",3756
	DECLE 20367,0
	;[3757] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3757
	DECLE 0,0
	;[3758] 	music d3,d3,-,-
	SRCFILE "whalehunt_1a.bas",3758
	DECLE 20367,0
	;[3759] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3759
	DECLE 0,0
	;[3760] 	music d3,d3,-,-
	SRCFILE "whalehunt_1a.bas",3760
	DECLE 20367,0
	;[3761] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3761
	DECLE 16191,0
	;[3762] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3762
	DECLE 16191,0
	;[3763] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3763
	DECLE 16191,0
	;[3764] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3764
	DECLE 0,0
	;[3765] 	music e3,e3,-,-
	SRCFILE "whalehunt_1a.bas",3765
	DECLE 20881,0
	;[3766] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3766
	DECLE 16191,0
	;[3767] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3767
	DECLE 16191,0
	;[3768] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3768
	DECLE 0,0
	;[3769] 	music e3,e3,-,-
	SRCFILE "whalehunt_1a.bas",3769
	DECLE 20881,0
	;[3770] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3770
	DECLE 16191,0
	;[3771] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3771
	DECLE 16191,0
	;[3772] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3772
	DECLE 16191,0
	;[3773] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3773
	DECLE 0,0
	;[3774] 	music f3,f3,-,-
	SRCFILE "whalehunt_1a.bas",3774
	DECLE 21138,0
	;[3775] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3775
	DECLE 0,0
	;[3776] 	music f3,f3,-,-
	SRCFILE "whalehunt_1a.bas",3776
	DECLE 21138,0
	;[3777] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3777
	DECLE 0,0
	;[3778] 	music f3,f3,-,-
	SRCFILE "whalehunt_1a.bas",3778
	DECLE 21138,0
	;[3779] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3779
	DECLE 16191,0
	;[3780] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3780
	DECLE 16191,0
	;[3781] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3781
	DECLE 16191,0
	;[3782] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3782
	DECLE 0,0
	;[3783] 	music e3,e3,-,-
	SRCFILE "whalehunt_1a.bas",3783
	DECLE 20881,0
	;[3784] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3784
	DECLE 16191,0
	;[3785] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3785
	DECLE 16191,0
	;[3786] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3786
	DECLE 0,0
	;[3787] 	music e3,e3,-,-
	SRCFILE "whalehunt_1a.bas",3787
	DECLE 20881,0
	;[3788] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3788
	DECLE 16191,0
	;[3789] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3789
	DECLE 16191,0
	;[3790] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3790
	DECLE 16191,0
	;[3791] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3791
	DECLE 0,0
	;[3792] 	music d3,d3,-,-
	SRCFILE "whalehunt_1a.bas",3792
	DECLE 20367,0
	;[3793] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3793
	DECLE 0,0
	;[3794] 	music d3,d3,-,-
	SRCFILE "whalehunt_1a.bas",3794
	DECLE 20367,0
	;[3795] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3795
	DECLE 0,0
	;[3796] 	music d3,d3,-,-
	SRCFILE "whalehunt_1a.bas",3796
	DECLE 20367,0
	;[3797] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3797
	DECLE 16191,0
	;[3798] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3798
	DECLE 16191,0
	;[3799] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3799
	DECLE 16191,0
	;[3800] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3800
	DECLE 0,0
	;[3801] 	music c3,c3,-,-
	SRCFILE "whalehunt_1a.bas",3801
	DECLE 19853,0
	;[3802] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3802
	DECLE 16191,0
	;[3803] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3803
	DECLE 16191,0
	;[3804] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3804
	DECLE 0,0
	;[3805] 	music c3,c3,-,-
	SRCFILE "whalehunt_1a.bas",3805
	DECLE 19853,0
	;[3806] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3806
	DECLE 16191,0
	;[3807] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3807
	DECLE 16191,0
	;[3808] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3808
	DECLE 16191,0
	;[3809] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3809
	DECLE 0,0
	;[3810] 	music b2,b2,-,-
	SRCFILE "whalehunt_1a.bas",3810
	DECLE 19596,0
	;[3811] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3811
	DECLE 16191,0
	;[3812] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3812
	DECLE 16191,0
	;[3813] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3813
	DECLE 0,0
	;[3814] 	music b2,b2,-,-
	SRCFILE "whalehunt_1a.bas",3814
	DECLE 19596,0
	;[3815] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3815
	DECLE 16191,0
	;[3816] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3816
	DECLE 16191,0
	;[3817] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3817
	DECLE 16191,0
	;[3818] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3818
	DECLE 0,0
	;[3819] 	music c3,c3,-,-
	SRCFILE "whalehunt_1a.bas",3819
	DECLE 19853,0
	;[3820] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3820
	DECLE 16191,0
	;[3821] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3821
	DECLE 16191,0
	;[3822] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3822
	DECLE 16191,0
	;[3823] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3823
	DECLE 16191,0
	;[3824] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3824
	DECLE 16191,0
	;[3825] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3825
	DECLE 16191,0
	;[3826] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3826
	DECLE 16191,0
	;[3827] 	music s,s,-,-
	SRCFILE "whalehunt_1a.bas",3827
	DECLE 16191,0
	;[3828] 	music stop
	SRCFILE "whalehunt_1a.bas",3828
	DECLE 254,0
	;[3829] 	
	SRCFILE "whalehunt_1a.bas",3829
	;[3830] win_song:	data 4
	SRCFILE "whalehunt_1a.bas",3830
	; WIN_SONG
Q267:		DECLE 4
	;[3831] 	music a3x,-,-,-
	SRCFILE "whalehunt_1a.bas",3831
	DECLE 86,0
	;[3832] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3832
	DECLE 0,0
	;[3833] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3833
	DECLE 88,0
	;[3834] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3834
	DECLE 63,0
	;[3835] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3835
	DECLE 0,0
	;[3836] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3836
	DECLE 0,0
	;[3837] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3837
	DECLE 88,0
	;[3838] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3838
	DECLE 0,0
	;[3839] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3839
	DECLE 88,0
	;[3840] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3840
	DECLE 0,0
	;[3841] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3841
	DECLE 88,0
	;[3842] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3842
	DECLE 63,0
	;[3843] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3843
	DECLE 0,0
	;[3844] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3844
	DECLE 0,0
	;[3845] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3845
	DECLE 86,0
	;[3846] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3846
	DECLE 0,0
	;[3847] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",3847
	DECLE 84,0
	;[3848] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3848
	DECLE 63,0
	;[3849] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3849
	DECLE 0,0
	;[3850] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3850
	DECLE 0,0
	;[3851] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3851
	DECLE 88,0
	;[3852] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3852
	DECLE 63,0
	;[3853] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3853
	DECLE 0,0
	;[3854] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3854
	DECLE 0,0
	;[3855] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",3855
	DECLE 91,0
	;[3856] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3856
	DECLE 63,0
	;[3857] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3857
	DECLE 63,0
	;[3858] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3858
	DECLE 63,0
	;[3859] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3859
	DECLE 0,0
	;[3860] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3860
	DECLE 0,0
	;[3861] 	
	SRCFILE "whalehunt_1a.bas",3861
	;[3862] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3862
	DECLE 88,0
	;[3863] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3863
	DECLE 0,0
	;[3864] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3864
	DECLE 86,0
	;[3865] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3865
	DECLE 0,0
	;[3866] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3866
	DECLE 86,0
	;[3867] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3867
	DECLE 63,0
	;[3868] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3868
	DECLE 0,0
	;[3869] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3869
	DECLE 0,0
	;[3870] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3870
	DECLE 86,0
	;[3871] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3871
	DECLE 0,0
	;[3872] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3872
	DECLE 86,0
	;[3873] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3873
	DECLE 0,0
	;[3874] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3874
	DECLE 86,0
	;[3875] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3875
	DECLE 63,0
	;[3876] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3876
	DECLE 0,0
	;[3877] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3877
	DECLE 0,0
	;[3878] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",3878
	DECLE 84,0
	;[3879] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3879
	DECLE 0,0
	;[3880] 	music f3,-,-,-
	SRCFILE "whalehunt_1a.bas",3880
	DECLE 82,0
	;[3881] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3881
	DECLE 63,0
	;[3882] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3882
	DECLE 0,0
	;[3883] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3883
	DECLE 0,0
	;[3884] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",3884
	DECLE 84,0
	;[3885] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3885
	DECLE 63,0
	;[3886] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3886
	DECLE 0,0
	;[3887] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3887
	DECLE 0,0
	;[3888] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3888
	DECLE 86,0
	;[3889] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3889
	DECLE 63,0
	;[3890] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3890
	DECLE 63,0
	;[3891] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3891
	DECLE 63,0
	;[3892] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3892
	DECLE 0,0
	;[3893] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3893
	DECLE 0,0
	;[3894] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3894
	DECLE 0,0
	;[3895] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3895
	DECLE 0,0
	;[3896] 	
	SRCFILE "whalehunt_1a.bas",3896
	;[3897] 	music a3x,-,-,-
	SRCFILE "whalehunt_1a.bas",3897
	DECLE 86,0
	;[3898] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3898
	DECLE 0,0
	;[3899] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3899
	DECLE 88,0
	;[3900] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3900
	DECLE 63,0
	;[3901] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3901
	DECLE 0,0
	;[3902] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3902
	DECLE 0,0
	;[3903] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3903
	DECLE 88,0
	;[3904] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3904
	DECLE 0,0
	;[3905] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3905
	DECLE 88,0
	;[3906] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3906
	DECLE 0,0
	;[3907] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3907
	DECLE 88,0
	;[3908] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3908
	DECLE 63,0
	;[3909] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3909
	DECLE 0,0
	;[3910] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3910
	DECLE 0,0
	;[3911] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3911
	DECLE 86,0
	;[3912] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3912
	DECLE 0,0
	;[3913] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",3913
	DECLE 84,0
	;[3914] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3914
	DECLE 63,0
	;[3915] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3915
	DECLE 0,0
	;[3916] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3916
	DECLE 0,0
	;[3917] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3917
	DECLE 88,0
	;[3918] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3918
	DECLE 63,0
	;[3919] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3919
	DECLE 0,0
	;[3920] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3920
	DECLE 0,0
	;[3921] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",3921
	DECLE 91,0
	;[3922] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3922
	DECLE 63,0
	;[3923] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3923
	DECLE 63,0
	;[3924] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3924
	DECLE 63,0
	;[3925] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3925
	DECLE 0,0
	;[3926] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3926
	DECLE 0,0
	;[3927] 	
	SRCFILE "whalehunt_1a.bas",3927
	;[3928] 	
	SRCFILE "whalehunt_1a.bas",3928
	;[3929] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3929
	DECLE 88,0
	;[3930] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3930
	DECLE 0,0
	;[3931] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3931
	DECLE 86,0
	;[3932] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3932
	DECLE 0,0
	;[3933] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3933
	DECLE 86,0
	;[3934] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3934
	DECLE 63,0
	;[3935] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3935
	DECLE 0,0
	;[3936] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3936
	DECLE 0,0
	;[3937] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3937
	DECLE 86,0
	;[3938] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3938
	DECLE 0,0
	;[3939] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3939
	DECLE 86,0
	;[3940] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3940
	DECLE 0,0
	;[3941] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3941
	DECLE 86,0
	;[3942] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3942
	DECLE 63,0
	;[3943] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3943
	DECLE 0,0
	;[3944] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3944
	DECLE 0,0
	;[3945] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",3945
	DECLE 86,0
	;[3946] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3946
	DECLE 0,0
	;[3947] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",3947
	DECLE 84,0
	;[3948] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3948
	DECLE 63,0
	;[3949] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3949
	DECLE 0,0
	;[3950] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3950
	DECLE 0,0
	;[3951] 	music c4,-,-,-
	SRCFILE "whalehunt_1a.bas",3951
	DECLE 89,0
	;[3952] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3952
	DECLE 63,0
	;[3953] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3953
	DECLE 0,0
	;[3954] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3954
	DECLE 0,0
	;[3955] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",3955
	DECLE 88,0
	;[3956] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3956
	DECLE 63,0
	;[3957] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3957
	DECLE 63,0
	;[3958] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3958
	DECLE 63,0
	;[3959] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3959
	DECLE 0,0
	;[3960] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3960
	DECLE 0,0
	;[3961] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3961
	DECLE 0,0
	;[3962] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3962
	DECLE 0,0
	;[3963] 
	SRCFILE "whalehunt_1a.bas",3963
	;[3964] 	music b4,-,-,-
	SRCFILE "whalehunt_1a.bas",3964
	DECLE 100,0
	;[3965] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3965
	DECLE 63,0
	;[3966] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3966
	DECLE 63,0
	;[3967] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3967
	DECLE 63,0
	;[3968] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3968
	DECLE 0,0
	;[3969] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3969
	DECLE 0,0
	;[3970] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3970
	DECLE 0,0
	;[3971] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3971
	DECLE 0,0
	;[3972] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",3972
	DECLE 98,0
	;[3973] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3973
	DECLE 63,0
	;[3974] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3974
	DECLE 63,0
	;[3975] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3975
	DECLE 63,0
	;[3976] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3976
	DECLE 0,0
	;[3977] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3977
	DECLE 0,0
	;[3978] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3978
	DECLE 96,0
	;[3979] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3979
	DECLE 63,0
	;[3980] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3980
	DECLE 0,0
	;[3981] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3981
	DECLE 0,0
	;[3982] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3982
	DECLE 96,0
	;[3983] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3983
	DECLE 0,0
	;[3984] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",3984
	DECLE 98,0
	;[3985] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3985
	DECLE 63,0
	;[3986] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3986
	DECLE 0,0
	;[3987] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3987
	DECLE 0,0
	;[3988] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3988
	DECLE 96,0
	;[3989] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3989
	DECLE 63,0
	;[3990] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3990
	DECLE 0,0
	;[3991] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3991
	DECLE 0,0
	;[3992] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",3992
	DECLE 96,0
	;[3993] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3993
	DECLE 63,0
	;[3994] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3994
	DECLE 0,0
	;[3995] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",3995
	DECLE 0,0
	;[3996] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",3996
	DECLE 93,0
	;[3997] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3997
	DECLE 63,0
	;[3998] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3998
	DECLE 63,0
	;[3999] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",3999
	DECLE 63,0
	;[4000] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4000
	DECLE 0,0
	;[4001] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4001
	DECLE 0,0
	;[4002] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4002
	DECLE 93,0
	;[4003] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4003
	DECLE 63,0
	;[4004] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4004
	DECLE 0,0
	;[4005] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4005
	DECLE 0,0
	;[4006] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4006
	DECLE 93,0
	;[4007] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4007
	DECLE 0,0
	;[4008] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4008
	DECLE 96,0
	;[4009] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4009
	DECLE 63,0
	;[4010] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4010
	DECLE 0,0
	;[4011] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4011
	DECLE 0,0
	;[4012] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",4012
	DECLE 91,0
	;[4013] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4013
	DECLE 63,0
	;[4014] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4014
	DECLE 63,0
	;[4015] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4015
	DECLE 0,0
	;[4016] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4016
	DECLE 93,0
	;[4017] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4017
	DECLE 63,0
	;[4018] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4018
	DECLE 63,0
	;[4019] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4019
	DECLE 0,0
	;[4020] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4020
	DECLE 88,0
	;[4021] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4021
	DECLE 63,0
	;[4022] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4022
	DECLE 63,0
	;[4023] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4023
	DECLE 63,0
	;[4024] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4024
	DECLE 0,0
	;[4025] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4025
	DECLE 0,0
	;[4026] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4026
	DECLE 0,0
	;[4027] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4027
	DECLE 0,0
	;[4028] 
	SRCFILE "whalehunt_1a.bas",4028
	;[4029] 	music b4,-,-,-
	SRCFILE "whalehunt_1a.bas",4029
	DECLE 100,0
	;[4030] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4030
	DECLE 63,0
	;[4031] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4031
	DECLE 63,0
	;[4032] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4032
	DECLE 63,0
	;[4033] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4033
	DECLE 0,0
	;[4034] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4034
	DECLE 0,0
	;[4035] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4035
	DECLE 0,0
	;[4036] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4036
	DECLE 0,0
	;[4037] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",4037
	DECLE 98,0
	;[4038] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4038
	DECLE 63,0
	;[4039] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4039
	DECLE 63,0
	;[4040] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4040
	DECLE 63,0
	;[4041] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4041
	DECLE 0,0
	;[4042] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4042
	DECLE 0,0
	;[4043] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4043
	DECLE 96,0
	;[4044] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4044
	DECLE 63,0
	;[4045] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4045
	DECLE 0,0
	;[4046] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4046
	DECLE 0,0
	;[4047] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4047
	DECLE 96,0
	;[4048] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4048
	DECLE 0,0
	;[4049] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",4049
	DECLE 98,0
	;[4050] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4050
	DECLE 63,0
	;[4051] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4051
	DECLE 0,0
	;[4052] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4052
	DECLE 0,0
	;[4053] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4053
	DECLE 96,0
	;[4054] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4054
	DECLE 63,0
	;[4055] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4055
	DECLE 0,0
	;[4056] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4056
	DECLE 0,0
	;[4057] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4057
	DECLE 96,0
	;[4058] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4058
	DECLE 63,0
	;[4059] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4059
	DECLE 0,0
	;[4060] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4060
	DECLE 0,0
	;[4061] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4061
	DECLE 93,0
	;[4062] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4062
	DECLE 63,0
	;[4063] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4063
	DECLE 63,0
	;[4064] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4064
	DECLE 63,0
	;[4065] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4065
	DECLE 0,0
	;[4066] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4066
	DECLE 0,0
	;[4067] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4067
	DECLE 93,0
	;[4068] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4068
	DECLE 63,0
	;[4069] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4069
	DECLE 0,0
	;[4070] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4070
	DECLE 0,0
	;[4071] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4071
	DECLE 93,0
	;[4072] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4072
	DECLE 0,0
	;[4073] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4073
	DECLE 96,0
	;[4074] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4074
	DECLE 63,0
	;[4075] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4075
	DECLE 0,0
	;[4076] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4076
	DECLE 0,0
	;[4077] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",4077
	DECLE 91,0
	;[4078] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4078
	DECLE 63,0
	;[4079] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4079
	DECLE 63,0
	;[4080] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4080
	DECLE 0,0
	;[4081] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4081
	DECLE 93,0
	;[4082] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4082
	DECLE 63,0
	;[4083] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4083
	DECLE 63,0
	;[4084] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4084
	DECLE 0,0
	;[4085] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4085
	DECLE 88,0
	;[4086] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4086
	DECLE 63,0
	;[4087] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4087
	DECLE 63,0
	;[4088] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4088
	DECLE 0,0
	;[4089] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4089
	DECLE 0,0
	;[4090] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4090
	DECLE 0,0
	;[4091] 	music -,-,-,-		
	SRCFILE "whalehunt_1a.bas",4091
	DECLE 0,0
	;[4092] 	
	SRCFILE "whalehunt_1a.bas",4092
	;[4093] 
	SRCFILE "whalehunt_1a.bas",4093
	;[4094] 	music a3x,-,-,-
	SRCFILE "whalehunt_1a.bas",4094
	DECLE 86,0
	;[4095] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4095
	DECLE 0,0
	;[4096] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4096
	DECLE 88,0
	;[4097] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4097
	DECLE 63,0
	;[4098] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4098
	DECLE 0,0
	;[4099] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4099
	DECLE 0,0
	;[4100] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4100
	DECLE 88,0
	;[4101] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4101
	DECLE 0,0
	;[4102] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4102
	DECLE 88,0
	;[4103] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4103
	DECLE 0,0
	;[4104] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4104
	DECLE 88,0
	;[4105] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4105
	DECLE 63,0
	;[4106] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4106
	DECLE 0,0
	;[4107] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4107
	DECLE 0,0
	;[4108] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4108
	DECLE 86,0
	;[4109] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4109
	DECLE 0,0
	;[4110] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",4110
	DECLE 84,0
	;[4111] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4111
	DECLE 63,0
	;[4112] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4112
	DECLE 0,0
	;[4113] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4113
	DECLE 0,0
	;[4114] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4114
	DECLE 88,0
	;[4115] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4115
	DECLE 63,0
	;[4116] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4116
	DECLE 0,0
	;[4117] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4117
	DECLE 0,0
	;[4118] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",4118
	DECLE 91,0
	;[4119] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4119
	DECLE 63,0
	;[4120] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4120
	DECLE 63,0
	;[4121] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4121
	DECLE 63,0
	;[4122] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4122
	DECLE 0,0
	;[4123] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4123
	DECLE 0,0
	;[4124] 	
	SRCFILE "whalehunt_1a.bas",4124
	;[4125] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4125
	DECLE 88,0
	;[4126] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4126
	DECLE 0,0
	;[4127] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4127
	DECLE 86,0
	;[4128] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4128
	DECLE 0,0
	;[4129] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4129
	DECLE 86,0
	;[4130] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4130
	DECLE 63,0
	;[4131] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4131
	DECLE 0,0
	;[4132] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4132
	DECLE 0,0
	;[4133] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4133
	DECLE 86,0
	;[4134] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4134
	DECLE 0,0
	;[4135] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4135
	DECLE 86,0
	;[4136] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4136
	DECLE 0,0
	;[4137] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4137
	DECLE 86,0
	;[4138] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4138
	DECLE 63,0
	;[4139] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4139
	DECLE 0,0
	;[4140] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4140
	DECLE 0,0
	;[4141] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",4141
	DECLE 84,0
	;[4142] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4142
	DECLE 0,0
	;[4143] 	music f3,-,-,-
	SRCFILE "whalehunt_1a.bas",4143
	DECLE 82,0
	;[4144] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4144
	DECLE 63,0
	;[4145] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4145
	DECLE 0,0
	;[4146] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4146
	DECLE 0,0
	;[4147] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",4147
	DECLE 84,0
	;[4148] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4148
	DECLE 63,0
	;[4149] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4149
	DECLE 0,0
	;[4150] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4150
	DECLE 0,0
	;[4151] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4151
	DECLE 86,0
	;[4152] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4152
	DECLE 63,0
	;[4153] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4153
	DECLE 63,0
	;[4154] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4154
	DECLE 63,0
	;[4155] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4155
	DECLE 0,0
	;[4156] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4156
	DECLE 0,0
	;[4157] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4157
	DECLE 0,0
	;[4158] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4158
	DECLE 0,0
	;[4159] 	
	SRCFILE "whalehunt_1a.bas",4159
	;[4160] 	music a3x,-,-,-
	SRCFILE "whalehunt_1a.bas",4160
	DECLE 86,0
	;[4161] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4161
	DECLE 0,0
	;[4162] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4162
	DECLE 88,0
	;[4163] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4163
	DECLE 63,0
	;[4164] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4164
	DECLE 0,0
	;[4165] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4165
	DECLE 0,0
	;[4166] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4166
	DECLE 88,0
	;[4167] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4167
	DECLE 0,0
	;[4168] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4168
	DECLE 88,0
	;[4169] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4169
	DECLE 0,0
	;[4170] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4170
	DECLE 88,0
	;[4171] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4171
	DECLE 63,0
	;[4172] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4172
	DECLE 0,0
	;[4173] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4173
	DECLE 0,0
	;[4174] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4174
	DECLE 86,0
	;[4175] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4175
	DECLE 0,0
	;[4176] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",4176
	DECLE 84,0
	;[4177] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4177
	DECLE 63,0
	;[4178] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4178
	DECLE 0,0
	;[4179] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4179
	DECLE 0,0
	;[4180] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4180
	DECLE 88,0
	;[4181] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4181
	DECLE 63,0
	;[4182] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4182
	DECLE 0,0
	;[4183] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4183
	DECLE 0,0
	;[4184] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",4184
	DECLE 91,0
	;[4185] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4185
	DECLE 63,0
	;[4186] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4186
	DECLE 63,0
	;[4187] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4187
	DECLE 63,0
	;[4188] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4188
	DECLE 0,0
	;[4189] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4189
	DECLE 0,0
	;[4190] 	
	SRCFILE "whalehunt_1a.bas",4190
	;[4191] 	
	SRCFILE "whalehunt_1a.bas",4191
	;[4192] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4192
	DECLE 88,0
	;[4193] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4193
	DECLE 0,0
	;[4194] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4194
	DECLE 86,0
	;[4195] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4195
	DECLE 0,0
	;[4196] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4196
	DECLE 86,0
	;[4197] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4197
	DECLE 63,0
	;[4198] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4198
	DECLE 0,0
	;[4199] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4199
	DECLE 0,0
	;[4200] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4200
	DECLE 86,0
	;[4201] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4201
	DECLE 0,0
	;[4202] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4202
	DECLE 86,0
	;[4203] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4203
	DECLE 0,0
	;[4204] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4204
	DECLE 86,0
	;[4205] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4205
	DECLE 63,0
	;[4206] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4206
	DECLE 0,0
	;[4207] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4207
	DECLE 0,0
	;[4208] 	music a3,-,-,-
	SRCFILE "whalehunt_1a.bas",4208
	DECLE 86,0
	;[4209] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4209
	DECLE 0,0
	;[4210] 	music g3,-,-,-
	SRCFILE "whalehunt_1a.bas",4210
	DECLE 84,0
	;[4211] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4211
	DECLE 63,0
	;[4212] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4212
	DECLE 0,0
	;[4213] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4213
	DECLE 0,0
	;[4214] 	music c4,-,-,-
	SRCFILE "whalehunt_1a.bas",4214
	DECLE 89,0
	;[4215] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4215
	DECLE 63,0
	;[4216] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4216
	DECLE 0,0
	;[4217] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4217
	DECLE 0,0
	;[4218] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4218
	DECLE 88,0
	;[4219] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4219
	DECLE 63,0
	;[4220] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4220
	DECLE 63,0
	;[4221] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4221
	DECLE 63,0
	;[4222] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4222
	DECLE 0,0
	;[4223] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4223
	DECLE 0,0
	;[4224] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4224
	DECLE 0,0
	;[4225] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4225
	DECLE 0,0
	;[4226] 
	SRCFILE "whalehunt_1a.bas",4226
	;[4227] 	music b4,-,-,-
	SRCFILE "whalehunt_1a.bas",4227
	DECLE 100,0
	;[4228] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4228
	DECLE 63,0
	;[4229] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4229
	DECLE 63,0
	;[4230] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4230
	DECLE 63,0
	;[4231] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4231
	DECLE 0,0
	;[4232] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4232
	DECLE 0,0
	;[4233] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4233
	DECLE 0,0
	;[4234] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4234
	DECLE 0,0
	;[4235] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",4235
	DECLE 98,0
	;[4236] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4236
	DECLE 63,0
	;[4237] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4237
	DECLE 63,0
	;[4238] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4238
	DECLE 63,0
	;[4239] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4239
	DECLE 0,0
	;[4240] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4240
	DECLE 0,0
	;[4241] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4241
	DECLE 96,0
	;[4242] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4242
	DECLE 63,0
	;[4243] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4243
	DECLE 0,0
	;[4244] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4244
	DECLE 0,0
	;[4245] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4245
	DECLE 96,0
	;[4246] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4246
	DECLE 0,0
	;[4247] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",4247
	DECLE 98,0
	;[4248] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4248
	DECLE 63,0
	;[4249] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4249
	DECLE 0,0
	;[4250] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4250
	DECLE 0,0
	;[4251] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4251
	DECLE 96,0
	;[4252] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4252
	DECLE 63,0
	;[4253] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4253
	DECLE 0,0
	;[4254] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4254
	DECLE 0,0
	;[4255] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4255
	DECLE 96,0
	;[4256] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4256
	DECLE 63,0
	;[4257] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4257
	DECLE 0,0
	;[4258] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4258
	DECLE 0,0
	;[4259] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4259
	DECLE 93,0
	;[4260] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4260
	DECLE 63,0
	;[4261] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4261
	DECLE 63,0
	;[4262] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4262
	DECLE 63,0
	;[4263] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4263
	DECLE 0,0
	;[4264] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4264
	DECLE 0,0
	;[4265] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4265
	DECLE 93,0
	;[4266] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4266
	DECLE 63,0
	;[4267] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4267
	DECLE 0,0
	;[4268] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4268
	DECLE 0,0
	;[4269] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4269
	DECLE 93,0
	;[4270] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4270
	DECLE 0,0
	;[4271] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4271
	DECLE 96,0
	;[4272] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4272
	DECLE 63,0
	;[4273] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4273
	DECLE 0,0
	;[4274] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4274
	DECLE 0,0
	;[4275] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",4275
	DECLE 91,0
	;[4276] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4276
	DECLE 63,0
	;[4277] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4277
	DECLE 63,0
	;[4278] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4278
	DECLE 0,0
	;[4279] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4279
	DECLE 93,0
	;[4280] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4280
	DECLE 63,0
	;[4281] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4281
	DECLE 63,0
	;[4282] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4282
	DECLE 0,0
	;[4283] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4283
	DECLE 88,0
	;[4284] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4284
	DECLE 63,0
	;[4285] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4285
	DECLE 63,0
	;[4286] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4286
	DECLE 63,0
	;[4287] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4287
	DECLE 0,0
	;[4288] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4288
	DECLE 0,0
	;[4289] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4289
	DECLE 0,0
	;[4290] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4290
	DECLE 0,0
	;[4291] 
	SRCFILE "whalehunt_1a.bas",4291
	;[4292] 	music b4,-,-,-
	SRCFILE "whalehunt_1a.bas",4292
	DECLE 100,0
	;[4293] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4293
	DECLE 63,0
	;[4294] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4294
	DECLE 63,0
	;[4295] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4295
	DECLE 63,0
	;[4296] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4296
	DECLE 0,0
	;[4297] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4297
	DECLE 0,0
	;[4298] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4298
	DECLE 0,0
	;[4299] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4299
	DECLE 0,0
	;[4300] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",4300
	DECLE 98,0
	;[4301] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4301
	DECLE 63,0
	;[4302] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4302
	DECLE 63,0
	;[4303] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4303
	DECLE 63,0
	;[4304] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4304
	DECLE 0,0
	;[4305] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4305
	DECLE 0,0
	;[4306] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4306
	DECLE 96,0
	;[4307] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4307
	DECLE 63,0
	;[4308] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4308
	DECLE 0,0
	;[4309] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4309
	DECLE 0,0
	;[4310] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4310
	DECLE 96,0
	;[4311] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4311
	DECLE 0,0
	;[4312] 	music a4,-,-,-
	SRCFILE "whalehunt_1a.bas",4312
	DECLE 98,0
	;[4313] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4313
	DECLE 63,0
	;[4314] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4314
	DECLE 0,0
	;[4315] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4315
	DECLE 0,0
	;[4316] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4316
	DECLE 96,0
	;[4317] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4317
	DECLE 63,0
	;[4318] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4318
	DECLE 0,0
	;[4319] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4319
	DECLE 0,0
	;[4320] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4320
	DECLE 96,0
	;[4321] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4321
	DECLE 63,0
	;[4322] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4322
	DECLE 0,0
	;[4323] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4323
	DECLE 0,0
	;[4324] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4324
	DECLE 93,0
	;[4325] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4325
	DECLE 63,0
	;[4326] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4326
	DECLE 63,0
	;[4327] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4327
	DECLE 63,0
	;[4328] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4328
	DECLE 0,0
	;[4329] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4329
	DECLE 0,0
	;[4330] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4330
	DECLE 93,0
	;[4331] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4331
	DECLE 63,0
	;[4332] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4332
	DECLE 0,0
	;[4333] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4333
	DECLE 0,0
	;[4334] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4334
	DECLE 93,0
	;[4335] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4335
	DECLE 0,0
	;[4336] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4336
	DECLE 96,0
	;[4337] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4337
	DECLE 63,0
	;[4338] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4338
	DECLE 0,0
	;[4339] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4339
	DECLE 0,0
	;[4340] 	music d4,-,-,-
	SRCFILE "whalehunt_1a.bas",4340
	DECLE 91,0
	;[4341] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4341
	DECLE 63,0
	;[4342] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4342
	DECLE 63,0
	;[4343] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4343
	DECLE 0,0
	;[4344] 	music e4,-,-,-
	SRCFILE "whalehunt_1a.bas",4344
	DECLE 93,0
	;[4345] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4345
	DECLE 63,0
	;[4346] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4346
	DECLE 63,0
	;[4347] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4347
	DECLE 0,0
	;[4348] 	music b3,-,-,-
	SRCFILE "whalehunt_1a.bas",4348
	DECLE 88,0
	;[4349] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4349
	DECLE 63,0
	;[4350] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4350
	DECLE 63,0
	;[4351] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4351
	DECLE 0,0
	;[4352] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4352
	DECLE 0,0
	;[4353] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4353
	DECLE 0,0
	;[4354] 	music -,-,-,-	
	SRCFILE "whalehunt_1a.bas",4354
	DECLE 0,0
	;[4355] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4355
	DECLE 0,0
	;[4356] 	music -,-,-,-
	SRCFILE "whalehunt_1a.bas",4356
	DECLE 0,0
	;[4357] 
	SRCFILE "whalehunt_1a.bas",4357
	;[4358] 	music g4,-,-,-
	SRCFILE "whalehunt_1a.bas",4358
	DECLE 96,0
	;[4359] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4359
	DECLE 63,0
	;[4360] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4360
	DECLE 63,0
	;[4361] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4361
	DECLE 63,0
	;[4362] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4362
	DECLE 63,0
	;[4363] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4363
	DECLE 63,0
	;[4364] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4364
	DECLE 63,0
	;[4365] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4365
	DECLE 63,0
	;[4366] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4366
	DECLE 63,0
	;[4367] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4367
	DECLE 63,0
	;[4368] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4368
	DECLE 63,0
	;[4369] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4369
	DECLE 63,0
	;[4370] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4370
	DECLE 63,0
	;[4371] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4371
	DECLE 63,0
	;[4372] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4372
	DECLE 63,0
	;[4373] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4373
	DECLE 63,0
	;[4374] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4374
	DECLE 63,0
	;[4375] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4375
	DECLE 63,0
	;[4376] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4376
	DECLE 63,0
	;[4377] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4377
	DECLE 63,0
	;[4378] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4378
	DECLE 63,0
	;[4379] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4379
	DECLE 63,0
	;[4380] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4380
	DECLE 63,0
	;[4381] 	music s,-,-,-
	SRCFILE "whalehunt_1a.bas",4381
	DECLE 63,0
	;[4382] 	music s,-,-,-	
	SRCFILE "whalehunt_1a.bas",4382
	DECLE 63,0
	;[4383] 	music stop
	SRCFILE "whalehunt_1a.bas",4383
	DECLE 254,0
	;[4384] 	
	SRCFILE "whalehunt_1a.bas",4384
	;[4385] 	
	SRCFILE "whalehunt_1a.bas",4385
	;[4386] REM ========================================MUSIC & SOUNDS================================================
	SRCFILE "whalehunt_1a.bas",4386
	;[4387] 
	SRCFILE "whalehunt_1a.bas",4387
	;[4388] asm org $b800
	SRCFILE "whalehunt_1a.bas",4388
 org $b800
	;[4389] 	' 51 bitmaps
	SRCFILE "whalehunt_1a.bas",4389
	;[4390] harp_up_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",4390
	; HARP_UP_BITMAPS_0
Q312:	;[4391] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",4391
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[4392] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",4392
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[4393] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",4393
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[4394] 	DATA $0000,$0000,$0000,$F8F0
	SRCFILE "whalehunt_1a.bas",4394
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 63728
	;[4395] 	DATA $0000,$C000,$F8F0,$FFFC
	SRCFILE "whalehunt_1a.bas",4395
	DECLE 0
	DECLE 49152
	DECLE 63728
	DECLE 65532
	;[4396] 	DATA $0000,$0000,$0000,$0701
	SRCFILE "whalehunt_1a.bas",4396
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 1793
	;[4397] 	DATA $0000,$0000,$3F00,$FFFF
	SRCFILE "whalehunt_1a.bas",4397
	DECLE 0
	DECLE 0
	DECLE 16128
	DECLE 65535
	;[4398] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",4398
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[4399] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",4399
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[4400] 	DATA $3F3F,$0F1F,$0307,$FC01
	SRCFILE "whalehunt_1a.bas",4400
	DECLE 16191
	DECLE 3871
	DECLE 775
	DECLE 64513
	;[4401] 	DATA $FCF8,$FFFE,$FFFF,$7FFF
	SRCFILE "whalehunt_1a.bas",4401
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 32767
	;[4402] 	DATA $0000,$0000,$C080,$F0E0
	SRCFILE "whalehunt_1a.bas",4402
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 61664
	;[4403] 	DATA $0301,$0307,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4403
	DECLE 769
	DECLE 775
	DECLE 0
	DECLE 0
	;[4404] 	DATA $FFFF,$FFFF,$0F3F,$0003
	SRCFILE "whalehunt_1a.bas",4404
	DECLE 65535
	DECLE 65535
	DECLE 3903
	DECLE 3
	;[4405] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",4405
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[4406] 	DATA $9F3F,$FFEF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4406
	DECLE 40767
	DECLE 65519
	DECLE 65535
	DECLE 65535
	;[4407] harp_up_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",4407
	; HARP_UP_BITMAPS_1
Q313:	;[4408] 	DATA $FCF8,$FFFE,$FFFF,$FEFE
	SRCFILE "whalehunt_1a.bas",4408
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 65278
	;[4409] 	DATA $0000,$0000,$0000,$7F1E
	SRCFILE "whalehunt_1a.bas",4409
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 32542
	;[4410] 	DATA $FFFF,$C0FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4410
	DECLE 65535
	DECLE 49407
	DECLE 0
	DECLE 0
	;[4411] 	DATA $F0FC,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4411
	DECLE 61692
	DECLE 0
	DECLE 0
	DECLE 0
	;[4412] 	DATA $0100,$0703,$1F0F,$7F3F
	SRCFILE "whalehunt_1a.bas",4412
	DECLE 256
	DECLE 1795
	DECLE 7951
	DECLE 32575
	;[4413] 	DATA $FEFF,$FEFE,$FEFE,$FCFC
	SRCFILE "whalehunt_1a.bas",4413
	DECLE 65279
	DECLE 65278
	DECLE 65278
	DECLE 64764
	;[4414] 	DATA $0000,$0101,$0303,$0707
	SRCFILE "whalehunt_1a.bas",4414
	DECLE 0
	DECLE 257
	DECLE 771
	DECLE 1799
	;[4415] 	DATA $FFFF,$EFFF,$CBAF,$F7E7
	SRCFILE "whalehunt_1a.bas",4415
	DECLE 65535
	DECLE 61439
	DECLE 52143
	DECLE 63463
	;[4416] 	DATA $7F7F,$7F7F,$1F3F,$030F
	SRCFILE "whalehunt_1a.bas",4416
	DECLE 32639
	DECLE 32639
	DECLE 7999
	DECLE 783
	;[4417] 	DATA $F8FC,$F8F8,$F0F8,$E0F0
	SRCFILE "whalehunt_1a.bas",4417
	DECLE 63740
	DECLE 63736
	DECLE 61688
	DECLE 57584
	;[4418] 	DATA $0000,$0000,$1C00,$3F3F
	SRCFILE "whalehunt_1a.bas",4418
	DECLE 0
	DECLE 0
	DECLE 7168
	DECLE 16191
	;[4419] 	DATA $0F0F,$0F0F,$1F0F,$FFBF
	SRCFILE "whalehunt_1a.bas",4419
	DECLE 3855
	DECLE 3855
	DECLE 7951
	DECLE 65471
	;[4420] 	DATA $7FFF,$000F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4420
	DECLE 32767
	DECLE 15
	DECLE 0
	DECLE 0
	;[4421] 	DATA $C1E3,$8080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4421
	DECLE 49635
	DECLE 32896
	DECLE 0
	DECLE 0
	;[4422] 	DATA $FFFF,$7FFF,$3F7F,$070F
	SRCFILE "whalehunt_1a.bas",4422
	DECLE 65535
	DECLE 32767
	DECLE 16255
	DECLE 1807
	;[4423] 	DATA $0FFF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4423
	DECLE 4095
	DECLE 0
	DECLE 0
	DECLE 0
	;[4424] harp_up_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",4424
	; HARP_UP_BITMAPS_2
Q314:	;[4425] 	DATA $FFFF,$07FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4425
	DECLE 65535
	DECLE 2047
	DECLE 0
	DECLE 0
	;[4426] 	DATA $C0E0,$80C0,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4426
	DECLE 49376
	DECLE 32960
	DECLE 0
	DECLE 0
	;[4427] 	DATA $0000,$0000,$0000,$0F01
	SRCFILE "whalehunt_1a.bas",4427
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 3841
	;[4428] 	DATA $1F3F,$1F1F,$030F,$FFF8
	SRCFILE "whalehunt_1a.bas",4428
	DECLE 7999
	DECLE 7967
	DECLE 783
	DECLE 65528
	;[4429] 	DATA $FFFF,$FFFF,$FFFF,$FBFF
	SRCFILE "whalehunt_1a.bas",4429
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 64511
	;[4430] 	DATA $FEFF,$FEFE,$FCFC,$F8F8
	SRCFILE "whalehunt_1a.bas",4430
	DECLE 65279
	DECLE 65278
	DECLE 64764
	DECLE 63736
	;[4431] 	DATA $73FD,$020F,$FFC7,$FFFF
	SRCFILE "whalehunt_1a.bas",4431
	DECLE 29693
	DECLE 527
	DECLE 65479
	DECLE 65535
	;[4432] 	DATA $7F3F,$FF7F,$FFFF,$3C7F
	SRCFILE "whalehunt_1a.bas",4432
	DECLE 32575
	DECLE 65407
	DECLE 65535
	DECLE 15487
	;[4433] 	DATA $FFFF,$FFFF,$BFFF,$030F
	SRCFILE "whalehunt_1a.bas",4433
	DECLE 65535
	DECLE 65535
	DECLE 49151
	DECLE 783
	;[4434] 	DATA $F9C3,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4434
	DECLE 63939
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[4435] 	DATA $F0F8,$F8E0,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4435
	DECLE 61688
	DECLE 63712
	DECLE 65535
	DECLE 65535
	;[4436] 	DATA $0000,$0000,$F000,$FFFF
	SRCFILE "whalehunt_1a.bas",4436
	DECLE 0
	DECLE 0
	DECLE 61440
	DECLE 65535
	;[4437] 	DATA $0000,$0000,$0000,$F000
	SRCFILE "whalehunt_1a.bas",4437
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 61440
	;[4438] 	DATA $07FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4438
	DECLE 2047
	DECLE 0
	DECLE 0
	DECLE 0
	;[4439] 	DATA $FFFF,$077F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4439
	DECLE 65535
	DECLE 1919
	DECLE 0
	DECLE 0
	;[4440] 	DATA $FFFF,$FFFF,$013F,$0000
	SRCFILE "whalehunt_1a.bas",4440
	DECLE 65535
	DECLE 65535
	DECLE 319
	DECLE 0
	;[4441] harp_up_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",4441
	; HARP_UP_BITMAPS_3
Q315:	;[4442] 	DATA $FFFF,$FFFF,$FFFF,$0003
	SRCFILE "whalehunt_1a.bas",4442
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 3
	;[4443] 	DATA $FFFF,$FFFF,$FFFF,$03FF
	SRCFILE "whalehunt_1a.bas",4443
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 1023
	;[4444] 	DATA $8080,$C080,$E0C0,$F8F0
	SRCFILE "whalehunt_1a.bas",4444
	DECLE 32896
	DECLE 49280
	DECLE 57536
	DECLE 63728
	;[4445] 	
	SRCFILE "whalehunt_1a.bas",4445
	;[4446] 	' 64 bitmaps
	SRCFILE "whalehunt_1a.bas",4446
	;[4447] pad_up_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",4447
	; PAD_UP_BITMAPS_0
Q319:	;[4448] 	DATA $0000,$0000,$0000,$0F00
	SRCFILE "whalehunt_1a.bas",4448
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 3840
	;[4449] 	DATA $0000,$0000,$0F00,$F0FF
	SRCFILE "whalehunt_1a.bas",4449
	DECLE 0
	DECLE 0
	DECLE 3840
	DECLE 61695
	;[4450] 	DATA $0000,$0F00,$F0FF,$0000
	SRCFILE "whalehunt_1a.bas",4450
	DECLE 0
	DECLE 3840
	DECLE 61695
	DECLE 0
	;[4451] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",4451
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[4452] 	DATA $0000,$0000,$C080,$F0E0
	SRCFILE "whalehunt_1a.bas",4452
	DECLE 0
	DECLE 0
	DECLE 49280
	DECLE 61664
	;[4453] 	DATA $0000,$0000,$1F00,$FFFF
	SRCFILE "whalehunt_1a.bas",4453
	DECLE 0
	DECLE 0
	DECLE 7936
	DECLE 65535
	;[4454] 	DATA $0000,$0000,$FF1F,$E0F8
	SRCFILE "whalehunt_1a.bas",4454
	DECLE 0
	DECLE 0
	DECLE 65311
	DECLE 57592
	;[4455] 	DATA $0F00,$F0FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4455
	DECLE 3840
	DECLE 61695
	DECLE 0
	DECLE 0
	;[4456] 	DATA $F0FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4456
	DECLE 61695
	DECLE 0
	DECLE 0
	DECLE 0
	;[4457] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",4457
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[4458] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",4458
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[4459] 	DATA $FCF8,$FFFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4459
	DECLE 64760
	DECLE 65534
	DECLE 65535
	DECLE 65535
	;[4460] 	DATA $0000,$0300,$0F07,$0F0F
	SRCFILE "whalehunt_1a.bas",4460
	DECLE 0
	DECLE 768
	DECLE 3847
	DECLE 3855
	;[4461] 	DATA $0F00,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4461
	DECLE 3840
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[4462] 	DATA $FFFF,$FFFF,$FFFF,$FEFF
	SRCFILE "whalehunt_1a.bas",4462
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 65279
	;[4463] 	DATA $FFFF,$FEFF,$E0F8,$0080
	SRCFILE "whalehunt_1a.bas",4463
	DECLE 65535
	DECLE 65279
	DECLE 57592
	DECLE 128
	;[4464] pad_up_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",4464
	; PAD_UP_BITMAPS_1
Q320:	;[4465] 	DATA $80C0,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4465
	DECLE 32960
	DECLE 0
	DECLE 0
	DECLE 0
	;[4466] 	DATA $FFFF,$7F7F,$3F3F,$0F1F
	SRCFILE "whalehunt_1a.bas",4466
	DECLE 65535
	DECLE 32639
	DECLE 16191
	DECLE 3871
	;[4467] 	DATA $E0C0,$F8F0,$FEFC,$FFFF
	SRCFILE "whalehunt_1a.bas",4467
	DECLE 57536
	DECLE 63728
	DECLE 65276
	DECLE 65535
	;[4468] 	DATA $0000,$0000,$0000,$FF01
	SRCFILE "whalehunt_1a.bas",4468
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 65281
	;[4469] 	DATA $0000,$0000,$3F00,$FFFF
	SRCFILE "whalehunt_1a.bas",4469
	DECLE 0
	DECLE 0
	DECLE 16128
	DECLE 65535
	;[4470] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",4470
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[4471] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",4471
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[4472] 	DATA $3F7F,$0F1F,$0307,$FF07
	SRCFILE "whalehunt_1a.bas",4472
	DECLE 16255
	DECLE 3871
	DECLE 775
	DECLE 65287
	;[4473] 	DATA $FCF8,$FEFE,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4473
	DECLE 64760
	DECLE 65278
	DECLE 65535
	DECLE 65535
	;[4474] 	DATA $0F0F,$0107,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4474
	DECLE 3855
	DECLE 263
	DECLE 0
	DECLE 0
	;[4475] 	DATA $FFFF,$FEFF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4475
	DECLE 65535
	DECLE 65279
	DECLE 0
	DECLE 0
	;[4476] 	DATA $E0F8,$0080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4476
	DECLE 57592
	DECLE 128
	DECLE 0
	DECLE 0
	;[4477] 	DATA $0307,$0001,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4477
	DECLE 775
	DECLE 1
	DECLE 0
	DECLE 0
	;[4478] 	DATA $FFFF,$FFFF,$3F7F,$031F
	SRCFILE "whalehunt_1a.bas",4478
	DECLE 65535
	DECLE 65535
	DECLE 16255
	DECLE 799
	;[4479] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",4479
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[4480] 	DATA $FFFF,$FEFF,$F8FE,$C0F0
	SRCFILE "whalehunt_1a.bas",4480
	DECLE 65535
	DECLE 65279
	DECLE 63742
	DECLE 49392
	;[4481] pad_up_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",4481
	; PAD_UP_BITMAPS_2
Q321:	;[4482] 	DATA $0000,$0000,$0000,$7F1E
	SRCFILE "whalehunt_1a.bas",4482
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 32542
	;[4483] 	DATA $0100,$0703,$1F0F,$7F3F
	SRCFILE "whalehunt_1a.bas",4483
	DECLE 256
	DECLE 1795
	DECLE 7951
	DECLE 32575
	;[4484] 	DATA $FEFF,$FEFE,$FEFE,$FCFC
	SRCFILE "whalehunt_1a.bas",4484
	DECLE 65279
	DECLE 65278
	DECLE 65278
	DECLE 64764
	;[4485] 	DATA $0000,$0101,$0303,$0707
	SRCFILE "whalehunt_1a.bas",4485
	DECLE 0
	DECLE 257
	DECLE 771
	DECLE 1799
	;[4486] 	DATA $FFFF,$EFFF,$CBAF,$F7E7
	SRCFILE "whalehunt_1a.bas",4486
	DECLE 65535
	DECLE 61439
	DECLE 52143
	DECLE 63463
	;[4487] 	DATA $7F7F,$7F7F,$1F3F,$030F
	SRCFILE "whalehunt_1a.bas",4487
	DECLE 32639
	DECLE 32639
	DECLE 7999
	DECLE 783
	;[4488] 	DATA $F8FC,$F8F8,$F0F8,$E0F0
	SRCFILE "whalehunt_1a.bas",4488
	DECLE 63740
	DECLE 63736
	DECLE 61688
	DECLE 57584
	;[4489] 	DATA $0000,$0000,$1C00,$3F3F
	SRCFILE "whalehunt_1a.bas",4489
	DECLE 0
	DECLE 0
	DECLE 7168
	DECLE 16191
	;[4490] 	DATA $0F0F,$0F0F,$1F0F,$FFBF
	SRCFILE "whalehunt_1a.bas",4490
	DECLE 3855
	DECLE 3855
	DECLE 7951
	DECLE 65471
	;[4491] 	DATA $7FFF,$000F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4491
	DECLE 32767
	DECLE 15
	DECLE 0
	DECLE 0
	;[4492] 	DATA $C1E3,$8080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4492
	DECLE 49635
	DECLE 32896
	DECLE 0
	DECLE 0
	;[4493] 	DATA $FFFF,$7FFF,$3F7F,$070F
	SRCFILE "whalehunt_1a.bas",4493
	DECLE 65535
	DECLE 32767
	DECLE 16255
	DECLE 1807
	;[4494] 	DATA $0FFF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4494
	DECLE 4095
	DECLE 0
	DECLE 0
	DECLE 0
	;[4495] 	DATA $FFFF,$07FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4495
	DECLE 65535
	DECLE 2047
	DECLE 0
	DECLE 0
	;[4496] 	DATA $C0E0,$80C0,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4496
	DECLE 49376
	DECLE 32960
	DECLE 0
	DECLE 0
	;[4497] 	DATA $0000,$0000,$0000,$0F01
	SRCFILE "whalehunt_1a.bas",4497
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 3841
	;[4498] pad_up_bitmaps_3:
	SRCFILE "whalehunt_1a.bas",4498
	; PAD_UP_BITMAPS_3
Q322:	;[4499] 	DATA $1F3F,$1F1F,$030F,$FFF8
	SRCFILE "whalehunt_1a.bas",4499
	DECLE 7999
	DECLE 7967
	DECLE 783
	DECLE 65528
	;[4500] 	DATA $FFFF,$FFFF,$FFFF,$FBFF
	SRCFILE "whalehunt_1a.bas",4500
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 64511
	;[4501] 	DATA $FEFF,$FEFE,$FCFC,$F8F8
	SRCFILE "whalehunt_1a.bas",4501
	DECLE 65279
	DECLE 65278
	DECLE 64764
	DECLE 63736
	;[4502] 	DATA $73FD,$020F,$FFC7,$FFFF
	SRCFILE "whalehunt_1a.bas",4502
	DECLE 29693
	DECLE 527
	DECLE 65479
	DECLE 65535
	;[4503] 	DATA $7F3F,$FF7F,$FFFF,$3C7F
	SRCFILE "whalehunt_1a.bas",4503
	DECLE 32575
	DECLE 65407
	DECLE 65535
	DECLE 15487
	;[4504] 	DATA $FFFF,$FFFF,$BFFF,$030F
	SRCFILE "whalehunt_1a.bas",4504
	DECLE 65535
	DECLE 65535
	DECLE 49151
	DECLE 783
	;[4505] 	DATA $F9C3,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4505
	DECLE 63939
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[4506] 	DATA $F0F8,$F8E0,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4506
	DECLE 61688
	DECLE 63712
	DECLE 65535
	DECLE 65535
	;[4507] 	DATA $0000,$0000,$F000,$FFFF
	SRCFILE "whalehunt_1a.bas",4507
	DECLE 0
	DECLE 0
	DECLE 61440
	DECLE 65535
	;[4508] 	DATA $0000,$0000,$0000,$F000
	SRCFILE "whalehunt_1a.bas",4508
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 61440
	;[4509] 	DATA $07FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4509
	DECLE 2047
	DECLE 0
	DECLE 0
	DECLE 0
	;[4510] 	DATA $FFFF,$077F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4510
	DECLE 65535
	DECLE 1919
	DECLE 0
	DECLE 0
	;[4511] 	DATA $FFFF,$FFFF,$013F,$0000
	SRCFILE "whalehunt_1a.bas",4511
	DECLE 65535
	DECLE 65535
	DECLE 319
	DECLE 0
	;[4512] 	DATA $FFFF,$FFFF,$FFFF,$0003
	SRCFILE "whalehunt_1a.bas",4512
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 3
	;[4513] 	DATA $FFFF,$FFFF,$FFFF,$03FF
	SRCFILE "whalehunt_1a.bas",4513
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 1023
	;[4514] 	DATA $8080,$C080,$E0C0,$F8F0
	SRCFILE "whalehunt_1a.bas",4514
	DECLE 32896
	DECLE 49280
	DECLE 57536
	DECLE 63728
	;[4515] 	
	SRCFILE "whalehunt_1a.bas",4515
	;[4516] 
	SRCFILE "whalehunt_1a.bas",4516
	;[4517] 	' 45 bitmaps
	SRCFILE "whalehunt_1a.bas",4517
	;[4518] flute_up_bitmaps_0:
	SRCFILE "whalehunt_1a.bas",4518
	; FLUTE_UP_BITMAPS_0
Q325:	;[4519] 	DATA $7FFF,$0F3F,$8000,$FCE0
	SRCFILE "whalehunt_1a.bas",4519
	DECLE 32767
	DECLE 3903
	DECLE 32768
	DECLE 64736
	;[4520] 	DATA $FEFF,$F8FC,$0000,$0301
	SRCFILE "whalehunt_1a.bas",4520
	DECLE 65279
	DECLE 63740
	DECLE 0
	DECLE 769
	;[4521] 	DATA $FEFC,$FFFF,$FFFF,$3F7F
	SRCFILE "whalehunt_1a.bas",4521
	DECLE 65276
	DECLE 65535
	DECLE 65535
	DECLE 16255
	;[4522] 	DATA $0000,$C000,$F8F0,$FFFC
	SRCFILE "whalehunt_1a.bas",4522
	DECLE 0
	DECLE 49152
	DECLE 63728
	DECLE 65532
	;[4523] 	DATA $0000,$C000,$FFFC,$FFFF
	SRCFILE "whalehunt_1a.bas",4523
	DECLE 0
	DECLE 49152
	DECLE 65532
	DECLE 65535
	;[4524] 	DATA $0000,$0000,$8000,$F8C0
	SRCFILE "whalehunt_1a.bas",4524
	DECLE 0
	DECLE 0
	DECLE 32768
	DECLE 63680
	;[4525] 	DATA $8703,$CFC7,$CFCF,$8FCF
	SRCFILE "whalehunt_1a.bas",4525
	DECLE 34563
	DECLE 53191
	DECLE 53199
	DECLE 36815
	;[4526] 	DATA $0000,$0000,$0000,$FC00
	SRCFILE "whalehunt_1a.bas",4526
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 64512
	;[4527] 	DATA $0301,$0307,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4527
	DECLE 769
	DECLE 775
	DECLE 0
	DECLE 0
	;[4528] 	DATA $FFFF,$FFFF,$0F3F,$0003
	SRCFILE "whalehunt_1a.bas",4528
	DECLE 65535
	DECLE 65535
	DECLE 3903
	DECLE 3
	;[4529] 	DATA $8F8F,$8787,$A787,$EFAB
	SRCFILE "whalehunt_1a.bas",4529
	DECLE 36751
	DECLE 34695
	DECLE 42887
	DECLE 61355
	;[4530] 	DATA $8000,$C0C0,$C0C0,$C0C0
	SRCFILE "whalehunt_1a.bas",4530
	DECLE 32768
	DECLE 49344
	DECLE 49344
	DECLE 49344
	;[4531] 	DATA $0000,$0000,$0000,$7F1E
	SRCFILE "whalehunt_1a.bas",4531
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 32542
	;[4532] 	DATA $80C0,$8080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4532
	DECLE 32960
	DECLE 32896
	DECLE 0
	DECLE 0
	;[4533] 	DATA $0100,$0703,$1F0F,$7F3F
	SRCFILE "whalehunt_1a.bas",4533
	DECLE 256
	DECLE 1795
	DECLE 7951
	DECLE 32575
	;[4534] 	DATA $FEFF,$FEFE,$FEFE,$FCFC
	SRCFILE "whalehunt_1a.bas",4534
	DECLE 65279
	DECLE 65278
	DECLE 65278
	DECLE 64764
	;[4535] flute_up_bitmaps_1:
	SRCFILE "whalehunt_1a.bas",4535
	; FLUTE_UP_BITMAPS_1
Q326:	;[4536] 	DATA $0000,$0101,$0303,$0707
	SRCFILE "whalehunt_1a.bas",4536
	DECLE 0
	DECLE 257
	DECLE 771
	DECLE 1799
	;[4537] 	DATA $FFFF,$EFFF,$CBAF,$F7E7
	SRCFILE "whalehunt_1a.bas",4537
	DECLE 65535
	DECLE 61439
	DECLE 52143
	DECLE 63463
	;[4538] 	DATA $7F7F,$7F7F,$1F3F,$030F
	SRCFILE "whalehunt_1a.bas",4538
	DECLE 32639
	DECLE 32639
	DECLE 7999
	DECLE 783
	;[4539] 	DATA $F8FC,$F8F8,$F0F8,$E0F0
	SRCFILE "whalehunt_1a.bas",4539
	DECLE 63740
	DECLE 63736
	DECLE 61688
	DECLE 57584
	;[4540] 	DATA $0000,$0000,$1C00,$3F3F
	SRCFILE "whalehunt_1a.bas",4540
	DECLE 0
	DECLE 0
	DECLE 7168
	DECLE 16191
	;[4541] 	DATA $0F0F,$0F0F,$1F0F,$FFBF
	SRCFILE "whalehunt_1a.bas",4541
	DECLE 3855
	DECLE 3855
	DECLE 7951
	DECLE 65471
	;[4542] 	DATA $7FFF,$000F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4542
	DECLE 32767
	DECLE 15
	DECLE 0
	DECLE 0
	;[4543] 	DATA $C1E3,$8080,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4543
	DECLE 49635
	DECLE 32896
	DECLE 0
	DECLE 0
	;[4544] 	DATA $FFFF,$7FFF,$3F7F,$070F
	SRCFILE "whalehunt_1a.bas",4544
	DECLE 65535
	DECLE 32767
	DECLE 16255
	DECLE 1807
	;[4545] 	DATA $0FFF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4545
	DECLE 4095
	DECLE 0
	DECLE 0
	DECLE 0
	;[4546] 	DATA $FFFF,$07FF,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4546
	DECLE 65535
	DECLE 2047
	DECLE 0
	DECLE 0
	;[4547] 	DATA $C0E0,$80C0,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4547
	DECLE 49376
	DECLE 32960
	DECLE 0
	DECLE 0
	;[4548] 	DATA $0000,$0000,$0000,$0F01
	SRCFILE "whalehunt_1a.bas",4548
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 3841
	;[4549] 	DATA $1F3F,$1F1F,$030F,$FFF8
	SRCFILE "whalehunt_1a.bas",4549
	DECLE 7999
	DECLE 7967
	DECLE 783
	DECLE 65528
	;[4550] 	DATA $FFFF,$FFFF,$FFFF,$FBFF
	SRCFILE "whalehunt_1a.bas",4550
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 64511
	;[4551] 	DATA $FEFF,$FEFE,$FCFC,$F8F8
	SRCFILE "whalehunt_1a.bas",4551
	DECLE 65279
	DECLE 65278
	DECLE 64764
	DECLE 63736
	;[4552] flute_up_bitmaps_2:
	SRCFILE "whalehunt_1a.bas",4552
	; FLUTE_UP_BITMAPS_2
Q327:	;[4553] 	DATA $73FD,$020F,$FFC7,$FFFF
	SRCFILE "whalehunt_1a.bas",4553
	DECLE 29693
	DECLE 527
	DECLE 65479
	DECLE 65535
	;[4554] 	DATA $7F3F,$FF7F,$FFFF,$3C7F
	SRCFILE "whalehunt_1a.bas",4554
	DECLE 32575
	DECLE 65407
	DECLE 65535
	DECLE 15487
	;[4555] 	DATA $FFFF,$FFFF,$BFFF,$030F
	SRCFILE "whalehunt_1a.bas",4555
	DECLE 65535
	DECLE 65535
	DECLE 49151
	DECLE 783
	;[4556] 	DATA $F9C3,$FFFF,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4556
	DECLE 63939
	DECLE 65535
	DECLE 65535
	DECLE 65535
	;[4557] 	DATA $F0F8,$F8E0,$FFFF,$FFFF
	SRCFILE "whalehunt_1a.bas",4557
	DECLE 61688
	DECLE 63712
	DECLE 65535
	DECLE 65535
	;[4558] 	DATA $0000,$0000,$F000,$FFFF
	SRCFILE "whalehunt_1a.bas",4558
	DECLE 0
	DECLE 0
	DECLE 61440
	DECLE 65535
	;[4559] 	DATA $0000,$0000,$0000,$F000
	SRCFILE "whalehunt_1a.bas",4559
	DECLE 0
	DECLE 0
	DECLE 0
	DECLE 61440
	;[4560] 	DATA $07FF,$0000,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4560
	DECLE 2047
	DECLE 0
	DECLE 0
	DECLE 0
	;[4561] 	DATA $FFFF,$077F,$0000,$0000
	SRCFILE "whalehunt_1a.bas",4561
	DECLE 65535
	DECLE 1919
	DECLE 0
	DECLE 0
	;[4562] 	DATA $FFFF,$FFFF,$013F,$0000
	SRCFILE "whalehunt_1a.bas",4562
	DECLE 65535
	DECLE 65535
	DECLE 319
	DECLE 0
	;[4563] 	DATA $FFFF,$FFFF,$FFFF,$0003
	SRCFILE "whalehunt_1a.bas",4563
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 3
	;[4564] 	DATA $FFFF,$FFFF,$FFFF,$03FF
	SRCFILE "whalehunt_1a.bas",4564
	DECLE 65535
	DECLE 65535
	DECLE 65535
	DECLE 1023
	;[4565] 	DATA $8080,$C080,$E0C0,$F8F0
	SRCFILE "whalehunt_1a.bas",4565
	DECLE 32896
	DECLE 49280
	DECLE 57536
	DECLE 63728
	;[4566] 	
	SRCFILE "whalehunt_1a.bas",4566
	;ENDFILE
	SRCFILE "",0
intybasic_keypad:	equ 1	; Forces to include keypad library
intybasic_music:	equ 1	; Forces to include music library
intybasic_numbers:	equ 1	; Forces to include numbers library
intybasic_ecs:	equ 1	; Forces to include ECS startup
        ;
        ; Epilogue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Moved GRAM code below MOB updates.
        ;                        Added comments.
        ; Revision: Feb/26/2014. Optimized access to collision registers
        ;                        per DZ-Jay suggestion. Added scrolling
        ;                        routines with optimization per intvnut
        ;                        suggestion. Added border/mask support.
        ; Revision: Apr/02/2014. Added support to set MODE (color stack
        ;                        or foreground/background), added support
        ;                        for SCREEN statement.
        ; Revision: Aug/19/2014. Solved bug in bottom scroll, moved an
        ;                        extra unneeded line.
        ; Revision: Aug/26/2014. Integrated music player and NTSC/PAL
        ;                        detection.
        ; Revision: Oct/24/2014. Adjust in some comments.
        ; Revision: Nov/13/2014. Integrated Joseph Zbiciak's routines
        ;                        for printing numbers.
        ; Revision: Nov/17/2014. Redesigned MODE support to use a single
        ;                        variable.
        ; Revision: Nov/21/2014. Added Intellivoice support routines made
        ;                        by Joseph Zbiciak.
	; Revision: Dec/11/2014. Optimized keypad decode routines.
	; Revision: Jan/25/2015. Added marker for insertion of ON FRAME GOSUB
	; Revision: Feb/17/2015. Allows to deactivate music player (PLAY NONE)
	; Revision: Apr/21/2015. Accelerates common case of keypad not pressed.
	;                        Added ECS ROM disable code.
	; Revision: Apr/22/2015. Added Joseph Zbiciak accelerated multiplication
	;                        routines.
	; Revision: Jun/04/2015. Optimized play_music (per GroovyBee suggestion)
	; Revision: Jul/25/2015. Added infinite loop at start to avoid crashing
	;                        with empty programs. Solved bug where _color
	;                        didn't started with white.

	;
	; Avoids empty programs to crash
	; 
stuck:	B stuck

        ;
        ; Copy screen helper for SCREEN statement
        ;
CPYBLK: PROC
        PSHR R5
        MOVR R3,R4
        MOVR R2,R5

@@1:    MOVR R1,R3              ; Init line copy
@@2:    MVI@ R4,R2              ; Copy line
        MVO@ R2,R5
        DECR R3
        BNE @@2
        MVII #20,R3             ; Add offset to start in next line
        SUBR R1,R3
        ADDR R3,R4
        ADDR R3,R5
        DECR R0                 ; Count lines
        BNE @@1

        PULR R5
        JR R5
        ENDP

        ;
        ; Wait for interruption
        ;
_wait:  PROC

    IF DEFINED intybasic_keypad
        MVI $01FF,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt1_p0,R0
        BNE @@2
        CMP _cnt1_p1,R0
        BNE @@2
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@4
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@4
	CMP@ R4,R0
        BEQ @@4
    ENDR
	INCR R4
@@4:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt1_key

@@2:    MVI _cnt1_p1,R1
        MVO R1,_cnt1_p0
        MVO R0,_cnt1_p1

        MVI $01FE,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt2_p0,R0
        BNE @@5
        CMP _cnt2_p1,R0
        BNE @@5
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@7
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@7
	CMP@ R4,R0
	BEQ @@7
    ENDR

	INCR R4
@@7:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt2_key

@@5:    MVI _cnt2_p1,R1
        MVO R1,_cnt2_p0
        MVO R0,_cnt2_p1
    ENDI

        CLRR    R0
        MVO     R0,_int         ; Clears waiting flag
@@1:    CMP     _int,  R0       ; Waits for change
        BEQ     @@1
        JR      R5              ; Returns
        ENDP

        ;
        ; Keypad table
        ;
_keypad_table:          PROC
        DECLE $48,$81,$41,$21,$82,$42,$22,$84,$44,$24,$88,$28
        ENDP

_pal1_vector:    PROC
        MVII #_pal2_vector,R0
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #3,R0
        MVO R0,_ntsc
        JR R5
        ENDP

_pal2_vector:    PROC
        MVII #_int_vector,R0     ; Point to "real" interruption handler
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #4,R0
        MVO R0,_ntsc
	CLRR R0
	CLRR R4
	MVII #$18,R1
@@1:	MVO@ R0,R4
	DECR R1
	BNE @@1
        JR R5
        ENDP

        ;
        ; Interruption routine
        ;
_int_vector:     PROC
        BEGIN

        MVO     R0,     $20     ; Activates display

    IF DEFINED intybasic_stack
	CMPI #$308,R6
	BNC @@vs
	MVI $21,R0	; Activates Color Stack mode
	CLRR R0
	MVO R0,$28
	MVO R0,$29
	MVO R0,$2A
	MVO R0,$2B
	MVII #@@vs1,R4
	MVII #$200,R5
	MVII #20,R1
@@vs2:	MVI@ R4,R0
	MVO@ R0,R5
	DECR R1
	BNE @@vs2
	RETURN

	; Stack Overflow message
@@vs1:	DECLE 0,0,0,$33*8+7,$54*8+7,$41*8+7,$43*8+7,$4B*8+7,$00*8+7
	DECLE $4F*8+7,$56*8+7,$45*8+7,$52*8+7,$46*8+7,$4C*8+7
	DECLE $4F*8+7,$57*8+7,0,0,0

@@vs:
    ENDI
        MVII    #1,     R0
        MVO     R0,     _int    ; Indicates interrupt happened

        MVI _mode_select,R0
        TSTR R0
        BEQ @@vi0
        CLRR R1
        MVO R1,_mode_select
        DECR R0
        BEQ @@vi14
        MVO R0,$21  ; Activates Foreground/Background mode
        B @@vi15

@@vi14: MVI $21,R0  ; Activates Color Stack mode
        MVI _color,R0
        MVO R0,$28
        SWAP R0
        MVO R0,$29
        SLR R0,2
        SLR R0,2
        MVO R0,$2A
        SWAP R0
        MVO R0,$2B
@@vi15: MVII #7,R0
        MVO R0,_color           ; Default color for PRINT "string"
@@vi0:
        MVI _border_color,R0
        MVO     R0,     $2C     ; Border color
        MVI _border_mask,R0
        MVO     R0,     $32     ; Border mask
        ;
        ; Save collision registers for further use and clear them
        ;
        MVII #$18,R4
        MVII #_col0,R5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col0
        MVI@ R4,R0
        MVO@ R0,R5  ; _col1
        MVI@ R4,R0
        MVO@ R0,R5  ; _col2
        MVI@ R4,R0
        MVO@ R0,R5  ; _col3
        MVI@ R4,R0
        MVO@ R0,R5  ; _col4
        MVI@ R4,R0
        MVO@ R0,R5  ; _col5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col6
        MVI@ R4,R0
        MVO@ R0,R5  ; _col7
        MVII #$18,R5
        CLRR R0
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        
    IF DEFINED intybasic_scroll

        ;
        ; Scrolling things
        ;
        MVI _scroll_x,R0
        MVO R0,$30
        MVI _scroll_y,R0
        MVO R0,$31
    ENDI

        ;
        ; Updates sprites (MOBs)
        ;
        MVII #_mobs,R4
        MVII #$0,R5     ; X-coordinates
        MVII #8,R1
@@vi2:  MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        DECR R1
        BNE @@vi2

    IF DEFINED intybasic_music
     	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo97      ; Yes, always emit sound
	MVI _music_frame,R0
	INCR R0
	CMPI #6,R0
	BNE @@vo14
	CLRR R0
@@vo14:	MVO R0,_music_frame
	BEQ @@vo15
@@vo97:	CALL _emit_sound
@@vo15:
    ENDI

        ;
        ; Detect GRAM definition
        ;
        MVI _gram_bitmap,R4
        TSTR R4
        BEQ @@vi1
        MVI _gram_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram_total,R0
@@vi3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vi3
        MVO R0,_gram_bitmap
@@vi1:
        MVI _gram2_bitmap,R4
        TSTR R4
        BEQ @@vii1
        MVI _gram2_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram2_total,R0
@@vii3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vii3
        MVO R0,_gram2_bitmap
@@vii1:

    IF DEFINED intybasic_scroll
        ;
        ; Frame scroll support
        ;
        MVI _scroll_d,R0
        TSTR R0
        BEQ @@vi4
        CLRR R1
        MVO R1,_scroll_d
        DECR R0     ; Left
        BEQ @@vi5
        DECR R0     ; Right
        BEQ @@vi6
        DECR R0     ; Top
        BEQ @@vi7
        DECR R0     ; Bottom
        BEQ @@vi8
        B @@vi4

@@vi5:  MVII #$0200,R4
        MOVR R4,R5
        INCR R5
        MVII #12,R1
@@vi12: MVI@ R4,R2
        MVI@ R4,R3
        REPEAT 8
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVI@ R4,R3
        ENDR
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVO@ R2,R5
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi12
        B @@vi4

@@vi6:  MVII #$0201,R4
        MVII #$0200,R5
        MVII #12,R1
@@vi11:
        REPEAT 19
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi11
        B @@vi4
    
        ;
        ; Complex routine to be ahead of STIC display
        ; Moves first the top 6 lines, saves intermediate line
        ; Then moves the bottom 6 lines and restores intermediate line
        ;
@@vi7:  MVII #$0264,R4
        MVII #5,R1
        MVII #_scroll_buffer,R5
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        MOVR R4,R5
        ADDI #20,R5
@@vi10:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi10
        MVII #$02C8,R4
        MVII #$02DC,R5
        MVII #5,R1
@@vi13:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi13
        MVII #_scroll_buffer,R4
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        B @@vi4

@@vi8:  MVII #$0214,R4
        MVII #$0200,R5
        MVII #$DC/4,R1
@@vi9:  
        REPEAT 4
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        DECR R1
        BNE @@vi9
        B @@vi4

@@vi4:
    ENDI

    IF DEFINED intybasic_voice
        ;
        ; Intellivoice support
        ;
        CALL IV_ISR
    ENDI

        ;
        ; Random number generator
        ;
	CALL _next_random

    IF DEFINED intybasic_music
	; Generate sound for next frame
       	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo98      ; Yes, always generate sound
	MVI _music_frame,R0
	TSTR R0
	BEQ @@vo16
@@vo98: CALL _generate_music
@@vo16:
    ENDI

        ; Increase frame number
        MVI _frame,R0
        INCR R0
        MVO R0,_frame

	; This mark is for ON FRAME GOSUB support

        RETURN
        ENDP

	;
	; Generates the next random number
	;
_next_random:	PROC

MACRO _ROR
	RRC R0,1
	MOVR R0,R2
	SLR R2,2
	SLR R2,2
	ANDI #$0800,R2
	SLR R2,2
	SLR R2,2
	ANDI #$007F,R0
	XORR R2,R0
ENDM
        MVI _rand,R0
        SETC
        _ROR
        XOR _frame,R0
        _ROR
        XOR _rand,R0
        _ROR
        XORI #9,R0
        MVO R0,_rand
	JR R5
	ENDP

    IF DEFINED intybasic_music

        ;
        ; Music player, comes from my game Princess Quest for Intellivision
        ; so it's a practical tracker used in a real game ;) and with enough
        ; features.
        ;

        ; NTSC frequency for notes (based on 3.579545 mhz)
ntsc_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octave 2 - 1
        DECLE 1721,1621,1532,1434,1364,1286,1216,1141,1076,1017,956,909
        ; Octave 3 - 13
        DECLE 854,805,761,717,678,639,605,571,538,508,480,453
        ; Octave 4 - 25
        DECLE 427,404,380,360,339,321,302,285,270,254,240,226
        ; Octave 5 - 37
        DECLE 214,202,191,180,170,160,151,143,135,127,120,113
        ; Octave 6 - 49
        DECLE 107,101,95,90,85,80,76,71,67,64,60,57
        ; Octave 7 - 61
        ; Space for two notes more
	ENDP

        ; PAL frequency for notes (based on 4 mhz)
pal_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octava 2 - 1
        DECLE 1923,1812,1712,1603,1524,1437,1359,1276,1202,1136,1068,1016
        ; Octava 3 - 13
        DECLE 954,899,850,801,758,714,676,638,601,568,536,506
        ; Octava 4 - 25
        DECLE 477,451,425,402,379,358,338,319,301,284,268,253
        ; Octava 5 - 37
        DECLE 239,226,213,201,190,179,169,159,150,142,134,127
        ; Octava 6 - 49
        DECLE 120,113,106,100,95,89,84,80,75,71,67,63
        ; Octava 7 - 61
        ; Space for two notes more
	ENDP
    ENDI

        ;
        ; Music tracker init
        ;
_init_music:	PROC
    IF DEFINED intybasic_music
        MVI _ntsc,R0
        CMPI #1,R0
        MVII #ntsc_note_table,R0
        BEQ @@0
        MVII #pal_note_table,R0
@@0:    MVO R0,_music_table
        MVII #$38,R0	; $B8 blocks controllers o.O!
	MVO R0,_music_mix
        CLRR R0
    ELSE
	JR R5
    ENDI
	ENDP

    IF DEFINED intybasic_music
        ;
        ; Start music
        ; R0 = Pointer to music
        ;
_play_music:	PROC
	MOVR R0,R2
        MVII #1,R0
	MOVR R0,R3
	TSTR R2
	BEQ @@1
	MVI@ R2,R3
	INCR R2
@@1:	MVO R2,_music_start
	MVO R2,_music_p
	MVO R3,_music_t
	MVO R0,_music_tc
        JR R5

	ENDP

        ;
        ; Generate music
        ;
_generate_music:	PROC
	BEGIN
	MVI _music_mix,R0
	ANDI #$C0,R0
	XORI #$38,R0
	MVO R0,_music_mix
	CLRR R1			; Turn off volume for the three sound channels
	MVO R1,_music_vol1
	MVO R1,_music_vol2
	NOP
	MVO R1,_music_vol3
	MVI _music_tc,R3
	DECR R3
	MVO R3,_music_tc
	BNE @@6
	; R3 is zero from here up to @@6
	MVI _music_p,R4
@@15:	TSTR R4		; Silence?
	BEQ @@000	; Keep quiet
	MVI@ R4,R0
	MVI@ R4,R1
	MVI _music_t,R2
        CMPI #$FE,R0	; The end?
	BEQ @@000       ; Keep quiet
	CMPI #$FD,R0	; Repeat?
	BNE @@00
	MVI _music_start,R4
	B @@15

@@000:  MVII #1,R0
        MVO R0,_music_tc
        B @@0
        
@@00: 	MVO R2,_music_tc    ; Restart note time
     	MVO R4,_music_p
     	
	MOVR R0,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@1
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n1	; Note
	MVO R3,_music_s1	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i1	; Instrument
	
@@1:	MOVR R0,R2
	SWAP R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@2
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n2	; Note
	MVO R3,_music_s2	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i2	; Instrument
	
@@2:	MOVR R1,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@3
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n3	; Note
	MVO R3,_music_s3	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i3	; Instrument
	
@@3:	MOVR R1,R2
	SWAP R2
	MVO R2,_music_n4
	MVO R3,_music_s4
	
        ;
        ; Construct main voice
        ;
@@6:	MVI _music_n1,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@7		; No, jump
	MVI _music_s1,R1
	MVI _music_i1,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq10	; Note in voice A
	SWAP R3
	MVO R3,_music_freq11
	MVO R1,_music_vol1
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@20
	SUBI #$08,R0
@@20:	MVO R0,_music_s1

@@7:	MVI _music_n2,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@8		; No, jump
	MVI _music_s2,R1
	MVI _music_i2,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq20	; Note in voice B
	SWAP R3
	MVO R3,_music_freq21
	MVO R1,_music_vol2
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@21
	SUBI #$08,R0
@@21:	MVO R0,_music_s2

@@8:	MVI _music_n3,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@9		; No, jump
	MVI _music_s3,R1
	MVI _music_i3,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq30	; Note in voice C
	SWAP R3
	MVO R3,_music_freq31
	MVO R1,_music_vol3
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@22
	SUBI #$08,R0
@@22:	MVO R0,_music_s3

@@9:	MVI _music_n4,R0	; Read drum
	DECR R0		; There is drum?
	BMI @@4		; No, jump
	MVI _music_s4,R1
	       		; 1 - Strong
	BNE @@5
	CMPI #3,R1
	BGE @@12
@@10:	MVII #5,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@5:	DECR R0		;2 - Short
	BNE @@11
	TSTR R1
	BNE @@12
	MVII #8,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@11:	;DECR R0	; 3 - Rolling
	;BNE @@12
	CMPI #2,R1
	BLT @@10
	MVI _music_t,R0
	SLR R0,1
	CMPR R0,R1
	BLT @@12
        ADDI #2,R0
	CMPR R0,R1
	BLT @@10
        ; Increase time for drum waveform
@@12:   INCR R1
	MVO R1,_music_s4
@@4:
@@0:	RETURN
	ENDP

        ;
	; Translates note number to frequency
        ; R3 = Note
        ; R1 = Position in waveform for instrument
        ; R2 = Instrument
        ;
_note2freq:	PROC
        ADD _music_table,R3
	MVI@ R3,R3
        SWAP R2
	BEQ _piano_instrument
	RLC R2,1
	BNC _clarinet_instrument
	BPL _flute_instrument
;	BMI _bass_instrument
	ENDP

        ;
        ; Generates a bass
        ;
_bass_instrument:	PROC
	SLL R3,2	; Lower 2 octaves
	ADDI #_bass_volume,R1
	MVI@ R1,R1	; Bass effect
	JR R5
	ENDP

_bass_volume:	PROC
        DECLE 12,13,14,14,13,12,12,12
        DECLE 11,11,12,12,11,11,12,12
	DECLE 11,11,12,12,11,11,12,12
	ENDP

        ;
        ; Generates a piano
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency.
        ; R1 = Volume.
        ;
_piano_instrument:	PROC
	ADDI #_piano_volume,R1
	MVI@ R1,R1
	JR R5
	ENDP

_piano_volume:	PROC
        DECLE 14,13,13,12,12,11,11,10
        DECLE 10,9,9,8,8,7,7,6
        DECLE 6,6,7,7,6,6,5,5
	ENDP

        ;
        ; Generate a clarinet
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_clarinet_instrument:	PROC
	ADDI #_clarinet_vibrato,R1
	ADD@ R1,R3
	CLRC
	RRC R3,1	; Duplicates frequency
	ADCR R3
        ADDI #_clarinet_volume-_clarinet_vibrato,R1
	MVI@ R1,R1
	JR R5
	ENDP

_clarinet_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
	ENDP

_clarinet_volume:	PROC
        DECLE 13,14,14,13,13,12,12,12
        DECLE 11,11,11,11,12,12,12,12
        DECLE 11,11,11,11,12,12,12,12
	ENDP

        ;
        ; Generates a flute
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_flute_instrument:	PROC
	ADDI #_flute_vibrato,R1
	ADD@ R1,R3
	ADDI #_flute_volume-_flute_vibrato,R1
	MVI@ R1,R1
	JR R5
	ENDP

_flute_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
	ENDP
                 
_flute_volume:	PROC
        DECLE 10,12,13,13,12,12,12,12
        DECLE 11,11,11,11,10,10,10,10
        DECLE 11,11,11,11,10,10,10,10
	ENDP

        ;
        ; Emits sound
        ;
_emit_sound:	PROC
        MOVR R5,R1
	MVI _music_mode,R2
	TSTR R2
	BEQ @@2
	MVII #_music_freq10,R4
	MVII #$01F0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	CMPI #1,R2
	BEQ @@1
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        JR R1

@@1:	INCR R4
	ADDI #2,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R4
	ADDI #2,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
@@2:    JR R1
	ENDP

        ;
        ; Activates drum
        ;
_activate_drum:	PROC
	MVI _music_vol1,R0
	TSTR R0
	BNE @@1
        MVII #11,R0
	MVO R0,_music_vol1
	MVI _music_mix,R0
	ANDI #$F6,R0
	XORI #$01,R0
	MVO R0,_music_mix
	JR R5

@@1:    MVI _music_vol2,R0
	TSTR R0
	BNE @@2
        MVII #11,R0
	MVO R0,_music_vol2
	MVI _music_mix,R0
	ANDI #$ED,R0
	XORI #$02,R0
	MVO R0,_music_mix
	JR R5

@@2:    MVI _music_mode,R0
        CMPI #2,R0
        BNE @@3
        MVI _music_vol3,R0
	TSTR R0
	BNE @@3
        MVII #11,R0
	MVO R0,_music_vol3
	MVI _music_mix,R0
	ANDI #$DB,R0
	XORI #$04,R0
	MVO R0,_music_mix
	JR R5

@@3:    MVI _music_mix,R0
        ANDI #$EF,R0
	MVO R0,_music_mix
	JR R5

	ENDP

    ENDI
    
    IF DEFINED intybasic_numbers

	;
	; Following code from as1600 libraries, prnum16.asm
        ; Public domain by Joseph Zbiciak
	;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  _PW10                                                                   ;;
;;      Lookup table holding the first 5 powers of 10 (1 thru 10000) as     ;;
;;      16-bit numbers.                                                     ;;
;; ======================================================================== ;;
_PW10   PROC    ; 0 thru 10000
        DECLE   10000, 1000, 100, 10, 1, 0
        ENDP

;; ======================================================================== ;;
;;  PRNUM16.l     -- Print an unsigned 16-bit number left-justified.        ;;
;;  PRNUM16.b     -- Print an unsigned 16-bit number with leading blanks.   ;;
;;  PRNUM16.z     -- Print an unsigned 16-bit number with leading zeros.    ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak  <im14u2c AT globalcrossing DOT net>                 ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      30-Mar-2003 Initial complete revision                               ;;
;;                                                                          ;;
;;  INPUTS for all variants                                                 ;;
;;      R0  Number to print.                                                ;;
;;      R2  Width of field.  Ignored by PRNUM16.l.                          ;;
;;      R3  Format word, added to digits to set the color.                  ;;
;;          Note:  Bit 15 MUST be cleared when building with PRNUM32.       ;;
;;      R4  Pointer to location on screen to print number                   ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0  Zeroed                                                          ;;
;;      R1  Unmodified                                                      ;;
;;      R2  Unmodified                                                      ;;
;;      R3  Unmodified                                                      ;;
;;      R4  Points to first character after field.                          ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      These routines print unsigned 16-bit numbers in a field up to 5     ;;
;;      positions wide.  The number is printed either in left-justified     ;;
;;      or right-justified format.  Right-justified numbers are padded      ;;
;;      with leading blanks or leading zeros.  Left-justified numbers       ;;
;;      are not padded on the right.                                        ;;
;;                                                                          ;;
;;      This code handles fields wider than 5 characters, padding with      ;;
;;      zeros or blanks as necessary.                                       ;;
;;                                                                          ;;
;;              Routine      Value(hex)     Field        Output             ;;
;;              ----------   ----------   ----------   ----------           ;;
;;              PRNUM16.l      $0045         n/a        "69"                ;;
;;              PRNUM16.b      $0045          4         "  69"              ;;
;;              PRNUM16.b      $0045          6         "    69"            ;;
;;              PRNUM16.z      $0045          4         "0069"              ;;
;;              PRNUM16.z      $0045          6         "000069"            ;;
;;                                                                          ;;
;;  TECHNIQUES                                                              ;;
;;      This routine uses repeated subtraction to divide the number         ;;
;;      to display by various powers of 10.  This is cheaper than a         ;;
;;      full divide, at least when the input number is large.  It's         ;;
;;      also easier to get right.  :-)                                      ;;
;;                                                                          ;;
;;      The printing routine first pads out fields wider than 5 spaces      ;;
;;      with zeros or blanks as requested.  It then scans the power-of-10   ;;
;;      table looking for the first power of 10 that is <= the number to    ;;
;;      display.  While scanning for this power of 10, it outputs leading   ;;
;;      blanks or zeros, if requested.  This eliminates "leading digit"     ;;
;;      logic from the main digit loop.                                     ;;
;;                                                                          ;;
;;      Once in the main digit loop, we discover the value of each digit    ;;
;;      by repeated subtraction.  We build up our digit value while         ;;
;;      subtracting the power-of-10 repeatedly.  We iterate until we go     ;;
;;      a step too far, and then we add back on power-of-10 to restore      ;;
;;      the remainder.                                                      ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      The left-justified variant ignores field width.                     ;;
;;                                                                          ;;
;;      The code is fully reentrant.                                        ;;
;;                                                                          ;;
;;      This code does not handle numbers which are too large to be         ;;
;;      displayed in the provided field.  If the number is too large,       ;;
;;      non-digit characters will be displayed in the initial digit         ;;
;;      position.  Also, the run time of this routine may get excessively   ;;
;;      large, depending on the magnitude of the overflow.                  ;;
;;                                                                          ;;
;;      When using with PRNUM32, one must either include PRNUM32 before     ;;
;;      this function, or define the symbol _WITH_PRNUM32.  PRNUM32         ;;
;;      needs a tiny bit of support from PRNUM16 to handle numbers in       ;;
;;      the range 65536...99999 correctly.                                  ;;
;;                                                                          ;;
;;  CODESIZE                                                                ;;
;;      73 words, including power-of-10 table                               ;;
;;      80 words, if compiled with PRNUM32.                                 ;;
;;                                                                          ;;
;;      To save code size, you can define the following symbols to omit     ;;
;;      some variants:                                                      ;;
;;                                                                          ;;
;;          _NO_PRNUM16.l:   Disables PRNUM16.l.  Saves 10 words            ;;
;;          _NO_PRNUM16.b:   Disables PRNUM16.b.  Saves 3 words.            ;;
;;                                                                          ;;
;;      Defining both symbols saves 17 words total, because it omits        ;;
;;      some code shared by both routines.                                  ;;
;;                                                                          ;;
;;  STACK USAGE                                                             ;;
;;      This function uses up to 4 words of stack space.                    ;;
;; ======================================================================== ;;

PRNUM16 PROC

    
        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.l:  Print unsigned, left-justified.                     ;;
        ;; ---------------------------------------------------------------- ;;
@@l:    PSHR    R5              ; save return address
@@l1:   MVII    #$1,    R5      ; set R5 to 1 to counteract screen ptr update
                                ; in the 'find initial power of 10' loop
        PSHR    R2
        MVII    #5,     R2      ; force effective field width to 5.
        B       @@z2

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.b:  Print unsigned with leading blanks.                 ;;
        ;; ---------------------------------------------------------------- ;;
@@b:    PSHR    R5
@@b1:   CLRR    R5              ; let the blank loop do its thing
        INCR    PC              ; skip the PSHR R5

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.z:  Print unsigned with leading zeros.                  ;;
        ;; ---------------------------------------------------------------- ;;
@@z:    PSHR    R5
@@z1:   PSHR    R2
@@z2:   PSHR    R1

        ;; ---------------------------------------------------------------- ;;
        ;;  Find the initial power of 10 to use for display.                ;;
        ;;  Note:  For fields wider than 5, fill the extra spots above 5    ;;
        ;;  with blanks or zeros as needed.                                 ;;
        ;; ---------------------------------------------------------------- ;;
        MVII    #_PW10+5,R1     ; Point to end of power-of-10 table
        SUBR    R2,     R1      ; Subtract the field width to get right power
        PSHR    R3              ; save format word

        CMPI    #2,     R5      ; are we leading with zeros?
        BNC     @@lblnk         ; no:  then do the loop w/ blanks

        CLRR    R5              ; force R5==0
        ADDI    #$80,   R3      ; yes: do the loop with zeros
        B       @@lblnk
    

@@llp   MVO@    R3,     R4      ; print a blank/zero

        SUBR    R5,     R4      ; rewind pointer if needed.

        INCR    R1              ; get next power of 10
@@lblnk DECR    R2              ; decrement available digits
        BEQ     @@ldone
        CMPI    #5,     R2      ; field too wide?
        BGE     @@llp           ; just force blanks/zeros 'till we're narrower.
        CMP@    R1,     R0      ; Is this power of 10 too big?
        BNC     @@llp           ; Yes:  Put a blank and go to next

@@ldone PULR    R3              ; restore format word

        ;; ---------------------------------------------------------------- ;;
        ;;  The digit loop prints at least one digit.  It discovers digits  ;;
        ;;  by repeated subtraction.                                        ;;
        ;; ---------------------------------------------------------------- ;;
@@digit TSTR    R0              ; If the number is zero, print zero and leave
        BNEQ    @@dig1          ; no: print the number

        MOVR    R3,     R5      ;\    
        ADDI    #$80,   R5      ; |-- print a 0 there.
        MVO@    R5,     R4      ;/    
        B       @@done

@@dig1:
    
@@nxdig MOVR    R3,     R5      ; save display format word
@@cont: ADDI    #$80-8, R5      ; start our digit as one just before '0'
@@spcl:
 
        ;; ---------------------------------------------------------------- ;;
        ;;  Divide by repeated subtraction.  This divide is constructed     ;;
        ;;  to go "one step too far" and then back up.                      ;;
        ;; ---------------------------------------------------------------- ;;
@@div:  ADDI    #8,     R5      ; increment our digit
        SUB@    R1,     R0      ; subtract power of 10
        BC      @@div           ; loop until we go too far
        ADD@    R1,     R0      ; add back the extra power of 10.

        MVO@    R5,     R4      ; display the digit.

        INCR    R1              ; point to next power of 10
        DECR    R2              ; any room left in field?
        BPL     @@nxdig         ; keep going until R2 < 0.

@@done: PULR    R1              ; restore R1
        PULR    R2              ; restore R2
        PULR    PC              ; return

        ENDP
        
    ENDI

    IF DEFINED intybasic_voice
;;==========================================================================;;
;;  SP0256-AL2 Allophones                                                   ;;
;;                                                                          ;;
;;  This file contains the allophone set that was obtained from an          ;;
;;  SP0256-AL2.  It is being provided for your convenience.                 ;;
;;                                                                          ;;
;;  The directory "al2" contains a series of assembly files, each one       ;;
;;  containing a single allophone.  This series of files may be useful in   ;;
;;  situations where space is at a premium.                                 ;;
;;                                                                          ;;
;;  Consult the Archer SP0256-AL2 documentation (under doc/programming)     ;;
;;  for more information about SP0256-AL2's allophone library.              ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The allophone data below was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;; ------------------------------------------------------------------------ ;;
_AA:
    DECLE   _AA.end - _AA - 1
    DECLE   $0318, $014C, $016F, $02CE, $03AF, $015F, $01B1, $008E
    DECLE   $0088, $0392, $01EA, $024B, $03AA, $039B, $000F, $0000
_AA.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_AE1:
    DECLE   _AE1.end - _AE1 - 1
    DECLE   $0118, $038E, $016E, $01FC, $0149, $0043, $026F, $036E
    DECLE   $01CC, $0005, $0000
_AE1.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AO:
    DECLE   _AO.end - _AO - 1
    DECLE   $0018, $010E, $016F, $0225, $00C6, $02C4, $030F, $0160
    DECLE   $024B, $0005, $0000
_AO.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AR:
    DECLE   _AR.end - _AR - 1
    DECLE   $0218, $010C, $016E, $001E, $000B, $0091, $032F, $00DE
    DECLE   $018B, $0095, $0003, $0238, $0027, $01E0, $03E8, $0090
    DECLE   $0003, $01C7, $0020, $03DE, $0100, $0190, $01CA, $02AB
    DECLE   $00B7, $004A, $0386, $0100, $0144, $02B6, $0024, $0320
    DECLE   $0011, $0041, $01DF, $0316, $014C, $016E, $001E, $00C4
    DECLE   $02B2, $031E, $0264, $02AA, $019D, $01BE, $000B, $00F0
    DECLE   $006A, $01CE, $00D6, $015B, $03B5, $03E4, $0000, $0380
    DECLE   $0007, $0312, $03E8, $030C, $016D, $02EE, $0085, $03C2
    DECLE   $03EC, $0283, $024A, $0005, $0000
_AR.end:  ; 69 decles
;; ------------------------------------------------------------------------ ;;
_AW:
    DECLE   _AW.end - _AW - 1
    DECLE   $0010, $01CE, $016E, $02BE, $0375, $034F, $0220, $0290
    DECLE   $008A, $026D, $013F, $01D5, $0316, $029F, $02E2, $018A
    DECLE   $0170, $0035, $00BD, $0000, $0000
_AW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_AX:
    DECLE   _AX.end - _AX - 1
    DECLE   $0218, $02CD, $016F, $02F5, $0386, $00C2, $00CD, $0094
    DECLE   $010C, $0005, $0000
_AX.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AY:
    DECLE   _AY.end - _AY - 1
    DECLE   $0110, $038C, $016E, $03B7, $03B3, $02AF, $0221, $009E
    DECLE   $01AA, $01B3, $00BF, $02E7, $025B, $0354, $00DA, $017F
    DECLE   $018A, $03F3, $00AF, $02D5, $0356, $027F, $017A, $01FB
    DECLE   $011E, $01B9, $03E5, $029F, $025A, $0076, $0148, $0124
    DECLE   $003D, $0000
_AY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_BB1:
    DECLE   _BB1.end - _BB1 - 1
    DECLE   $0318, $004C, $016C, $00FB, $00C7, $0144, $002E, $030C
    DECLE   $010E, $018C, $01DC, $00AB, $00C9, $0268, $01F7, $021D
    DECLE   $01B3, $0098, $0000
_BB1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_BB2:
    DECLE   _BB2.end - _BB2 - 1
    DECLE   $00F4, $0046, $0062, $0200, $0221, $03E4, $0087, $016F
    DECLE   $02A6, $02B7, $0212, $0326, $0368, $01BF, $0338, $0196
    DECLE   $0002
_BB2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_CH:
    DECLE   _CH.end - _CH - 1
    DECLE   $00F5, $0146, $0052, $0000, $032A, $0049, $0032, $02F2
    DECLE   $02A5, $0000, $026D, $0119, $0124, $00F6, $0000
_CH.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_DD1:
    DECLE   _DD1.end - _DD1 - 1
    DECLE   $0318, $034C, $016E, $0397, $01B9, $0020, $02B1, $008E
    DECLE   $0349, $0291, $01D8, $0072, $0000
_DD1.end:  ; 13 decles
;; ------------------------------------------------------------------------ ;;
_DD2:
    DECLE   _DD2.end - _DD2 - 1
    DECLE   $00F4, $00C6, $00F2, $0000, $0129, $00A6, $0246, $01F3
    DECLE   $02C6, $02B7, $028E, $0064, $0362, $01CF, $0379, $01D5
    DECLE   $0002
_DD2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_DH1:
    DECLE   _DH1.end - _DH1 - 1
    DECLE   $0018, $034F, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_DH2:
    DECLE   _DH2.end - _DH2 - 1
    DECLE   $0119, $034C, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_EH:
    DECLE   _EH.end - _EH - 1
    DECLE   $0218, $02CD, $016F, $0105, $014B, $0224, $02CF, $0274
    DECLE   $014C, $0005, $0000
_EH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_EL:
    DECLE   _EL.end - _EL - 1
    DECLE   $0118, $038D, $016E, $011C, $008B, $03D2, $030F, $0262
    DECLE   $006C, $019D, $01CC, $022B, $0170, $0078, $03FE, $0018
    DECLE   $0183, $03A3, $010D, $016E, $012E, $00C6, $00C3, $0300
    DECLE   $0060, $000D, $0005, $0000
_EL.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_ER1:
    DECLE   _ER1.end - _ER1 - 1
    DECLE   $0118, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0188
    DECLE   $01DA, $00CB, $00E7, $0048, $03A6, $0244, $016C, $01A8
    DECLE   $03E4, $0000, $0002, $0001, $00FC, $01DA, $02E4, $0000
    DECLE   $0002, $0008, $0200, $0217, $0164, $0000, $000E, $0038
    DECLE   $0014, $01EA, $0264, $0000, $0002, $0048, $01EC, $02F1
    DECLE   $03CC, $016D, $021E, $0048, $00C2, $034E, $036A, $000D
    DECLE   $008D, $000B, $0200, $0047, $0022, $03A8, $0000, $0000
_ER1.end:  ; 64 decles
;; ------------------------------------------------------------------------ ;;
_ER2:
    DECLE   _ER2.end - _ER2 - 1
    DECLE   $0218, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0190
    DECLE   $01D8, $00CB, $00E7, $0058, $01A6, $0244, $0164, $02A9
    DECLE   $0024, $0000, $0000, $0007, $0201, $02F8, $02E4, $0000
    DECLE   $0002, $0001, $00FC, $02DA, $0024, $0000, $0002, $0008
    DECLE   $0200, $0217, $0024, $0000, $000E, $0038, $0014, $03EA
    DECLE   $03A4, $0000, $0002, $0048, $01EC, $03F1, $038C, $016D
    DECLE   $021E, $0048, $00C2, $034E, $036A, $000D, $009D, $0003
    DECLE   $0200, $0047, $0022, $03A8, $0000, $0000
_ER2.end:  ; 70 decles
;; ------------------------------------------------------------------------ ;;
_EY:
    DECLE   _EY.end - _EY - 1
    DECLE   $0310, $038C, $016E, $02A7, $00BB, $0160, $0290, $0094
    DECLE   $01CA, $03A9, $00C1, $02D7, $015B, $01D4, $03CE, $02FF
    DECLE   $00EA, $03E7, $0041, $0277, $025B, $0355, $03C9, $0103
    DECLE   $02EA, $03E4, $003F, $0000
_EY.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_FF:
    DECLE   _FF.end - _FF - 1
    DECLE   $0119, $03C8, $0000, $00A7, $0094, $0138, $01C6, $0000
_FF.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_GG1:
    DECLE   _GG1.end - _GG1 - 1
    DECLE   $00F4, $00C6, $00C2, $0200, $0015, $03FE, $0283, $01FD
    DECLE   $01E6, $00B7, $030A, $0364, $0331, $017F, $033D, $0215
    DECLE   $0002
_GG1.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG2:
    DECLE   _GG2.end - _GG2 - 1
    DECLE   $00F4, $0106, $0072, $0300, $0021, $0308, $0039, $0173
    DECLE   $00C6, $00B7, $037E, $03A3, $0319, $0177, $0036, $0217
    DECLE   $0002
_GG2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG3:
    DECLE   _GG3.end - _GG3 - 1
    DECLE   $00F8, $0146, $00F2, $0100, $0132, $03A8, $0055, $01F5
    DECLE   $00A6, $02B7, $0291, $0326, $0368, $0167, $023A, $01C6
    DECLE   $0002
_GG3.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_HH1:
    DECLE   _HH1.end - _HH1 - 1
    DECLE   $0218, $01C9, $0000, $0095, $0127, $0060, $01D6, $0213
    DECLE   $0002, $01AE, $033E, $01A0, $03C4, $0122, $0001, $0218
    DECLE   $01E4, $03FD, $0019, $0000
_HH1.end:  ; 20 decles
;; ------------------------------------------------------------------------ ;;
_HH2:
    DECLE   _HH2.end - _HH2 - 1
    DECLE   $0218, $00CB, $0000, $0086, $000F, $0240, $0182, $031A
    DECLE   $02DB, $0008, $0293, $0067, $00BD, $01E0, $0092, $000C
    DECLE   $0000
_HH2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_IH:
    DECLE   _IH.end - _IH - 1
    DECLE   $0118, $02CD, $016F, $0205, $0144, $02C3, $00FE, $031A
    DECLE   $000D, $0005, $0000
_IH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_IY:
    DECLE   _IY.end - _IY - 1
    DECLE   $0318, $02CC, $016F, $0008, $030B, $01C3, $0330, $0178
    DECLE   $002B, $019D, $01F6, $018B, $01E1, $0010, $020D, $0358
    DECLE   $015F, $02A4, $02CC, $016F, $0109, $030B, $0193, $0320
    DECLE   $017A, $034C, $009C, $0017, $0001, $0200, $03C1, $0020
    DECLE   $00A7, $001D, $0001, $0104, $003D, $0040, $01A7, $01CA
    DECLE   $018B, $0160, $0078, $01F6, $0343, $01C7, $0090, $0000
_IY.end:  ; 48 decles
;; ------------------------------------------------------------------------ ;;
_JH:
    DECLE   _JH.end - _JH - 1
    DECLE   $0018, $0149, $0001, $00A4, $0321, $0180, $01F4, $039A
    DECLE   $02DC, $023C, $011A, $0047, $0200, $0001, $018E, $034E
    DECLE   $0394, $0356, $02C1, $010C, $03FD, $0129, $00B7, $01BA
    DECLE   $0000
_JH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_KK1:
    DECLE   _KK1.end - _KK1 - 1
    DECLE   $00F4, $00C6, $00D2, $0000, $023A, $03E0, $02D1, $02E5
    DECLE   $0184, $0200, $0041, $0210, $0188, $00C5, $0000
_KK1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_KK2:
    DECLE   _KK2.end - _KK2 - 1
    DECLE   $021D, $023C, $0211, $003C, $0180, $024D, $0008, $032B
    DECLE   $025B, $002D, $01DC, $01E3, $007A, $0000
_KK2.end:  ; 14 decles
;; ------------------------------------------------------------------------ ;;
_KK3:
    DECLE   _KK3.end - _KK3 - 1
    DECLE   $00F7, $0046, $01D2, $0300, $0131, $006C, $006E, $00F1
    DECLE   $00E4, $0000, $025A, $010D, $0110, $01F9, $014A, $0001
    DECLE   $00B5, $01A2, $00D8, $01CE, $0000
_KK3.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_LL:
    DECLE   _LL.end - _LL - 1
    DECLE   $0318, $038C, $016D, $029E, $0333, $0260, $0221, $0294
    DECLE   $01C4, $0299, $025A, $00E6, $014C, $012C, $0031, $0000
_LL.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_MM:
    DECLE   _MM.end - _MM - 1
    DECLE   $0210, $034D, $016D, $03F5, $00B0, $002E, $0220, $0290
    DECLE   $03CE, $02B6, $03AA, $00F3, $00CF, $015D, $016E, $0000
_MM.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_NG1:
    DECLE   _NG1.end - _NG1 - 1
    DECLE   $0118, $03CD, $016E, $00DC, $032F, $01BF, $01E0, $0116
    DECLE   $02AB, $029A, $0358, $01DB, $015B, $01A7, $02FD, $02B1
    DECLE   $03D2, $0356, $0000
_NG1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_NN1:
    DECLE   _NN1.end - _NN1 - 1
    DECLE   $0318, $03CD, $016C, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $009D, $000D, $0248, $01B4, $0120, $01E1, $00C8
    DECLE   $0003, $0040, $0000, $0080, $015F, $0006, $0000
_NN1.end:  ; 23 decles
;; ------------------------------------------------------------------------ ;;
_NN2:
    DECLE   _NN2.end - _NN2 - 1
    DECLE   $0018, $034D, $016D, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $0095, $0003, $0248, $01B4, $0120, $01E1, $0090
    DECLE   $000B, $0040, $0000, $0080, $015F, $019E, $01F6, $028B
    DECLE   $00E0, $0266, $03F6, $01D8, $0143, $01A8, $0024, $00C0
    DECLE   $0080, $0000, $01E6, $0321, $0024, $0260, $000A, $0008
    DECLE   $03FE, $0000, $0000
_NN2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_OR2:
    DECLE   _OR2.end - _OR2 - 1
    DECLE   $0218, $018C, $016D, $02A6, $03AB, $004F, $0301, $0390
    DECLE   $02EA, $0289, $0228, $0356, $01CF, $02D5, $0135, $007D
    DECLE   $02B5, $02AF, $024A, $02E2, $0153, $0167, $0333, $02A9
    DECLE   $02B3, $039A, $0351, $0147, $03CD, $0339, $02DA, $0000
_OR2.end:  ; 32 decles
;; ------------------------------------------------------------------------ ;;
_OW:
    DECLE   _OW.end - _OW - 1
    DECLE   $0310, $034C, $016E, $02AE, $03B1, $00CF, $0304, $0192
    DECLE   $018A, $022B, $0041, $0277, $015B, $0395, $03D1, $0082
    DECLE   $03CE, $00B6, $03BB, $02DA, $0000
_OW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_OY:
    DECLE   _OY.end - _OY - 1
    DECLE   $0310, $014C, $016E, $02A6, $03AF, $00CF, $0304, $0192
    DECLE   $03CA, $01A8, $007F, $0155, $02B4, $027F, $00E2, $036A
    DECLE   $031F, $035D, $0116, $01D5, $02F4, $025F, $033A, $038A
    DECLE   $014F, $01B5, $03D5, $0297, $02DA, $03F2, $0167, $0124
    DECLE   $03FB, $0001
_OY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_PA1:
    DECLE   _PA1.end - _PA1 - 1
    DECLE   $00F1, $0000
_PA1.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA2:
    DECLE   _PA2.end - _PA2 - 1
    DECLE   $00F4, $0000
_PA2.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA3:
    DECLE   _PA3.end - _PA3 - 1
    DECLE   $00F7, $0000
_PA3.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA4:
    DECLE   _PA4.end - _PA4 - 1
    DECLE   $00FF, $0000
_PA4.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA5:
    DECLE   _PA5.end - _PA5 - 1
    DECLE   $031D, $003F, $0000
_PA5.end:  ; 3 decles
;; ------------------------------------------------------------------------ ;;
_PP:
    DECLE   _PP.end - _PP - 1
    DECLE   $00FD, $0106, $0052, $0000, $022A, $03A5, $0277, $035F
    DECLE   $0184, $0000, $0055, $0391, $00EB, $00CF, $0000
_PP.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_RR1:
    DECLE   _RR1.end - _RR1 - 1
    DECLE   $0118, $01CD, $016C, $029E, $0171, $038E, $01E0, $0190
    DECLE   $0245, $0299, $01AA, $02E2, $01C7, $02DE, $0125, $00B5
    DECLE   $02C5, $028F, $024E, $035E, $01CB, $02EC, $0005, $0000
_RR1.end:  ; 24 decles
;; ------------------------------------------------------------------------ ;;
_RR2:
    DECLE   _RR2.end - _RR2 - 1
    DECLE   $0218, $03CC, $016C, $030C, $02C8, $0393, $02CD, $025E
    DECLE   $008A, $019D, $01AC, $02CB, $00BE, $0046, $017E, $01C2
    DECLE   $0174, $00A1, $01E5, $00E0, $010E, $0007, $0313, $0017
    DECLE   $0000
_RR2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SH:
    DECLE   _SH.end - _SH - 1
    DECLE   $0218, $0109, $0000, $007A, $0187, $02E0, $03F6, $0311
    DECLE   $0002, $0126, $0242, $0161, $03E9, $0219, $016C, $0300
    DECLE   $0013, $0045, $0124, $0005, $024C, $005C, $0182, $03C2
    DECLE   $0001
_SH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SS:
    DECLE   _SS.end - _SS - 1
    DECLE   $0218, $01CA, $0001, $0128, $001C, $0149, $01C6, $0000
_SS.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TH:
    DECLE   _TH.end - _TH - 1
    DECLE   $0019, $0349, $0000, $00C6, $0212, $01D8, $01CA, $0000
_TH.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TT1:
    DECLE   _TT1.end - _TT1 - 1
    DECLE   $00F6, $0046, $0142, $0100, $0042, $0088, $027E, $02EF
    DECLE   $01A4, $0200, $0049, $0290, $00FC, $00E8, $0000
_TT1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_TT2:
    DECLE   _TT2.end - _TT2 - 1
    DECLE   $00F5, $00C6, $01D2, $0100, $0335, $00E9, $0042, $027A
    DECLE   $02A4, $0000, $0062, $01D1, $014C, $03EA, $02EC, $01E0
    DECLE   $0007, $03A7, $0000
_TT2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_UH:
    DECLE   _UH.end - _UH - 1
    DECLE   $0018, $034E, $016E, $01FF, $0349, $00D2, $003C, $030C
    DECLE   $008B, $0005, $0000
_UH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_UW1:
    DECLE   _UW1.end - _UW1 - 1
    DECLE   $0318, $014C, $016F, $029E, $03BD, $03BD, $0271, $0212
    DECLE   $0325, $0291, $016A, $027B, $014A, $03B4, $0133, $0001
_UW1.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_UW2:
    DECLE   _UW2.end - _UW2 - 1
    DECLE   $0018, $034E, $016E, $02F6, $0107, $02C2, $006D, $0090
    DECLE   $03AC, $01A4, $01DC, $03AB, $0128, $0076, $03E6, $0119
    DECLE   $014F, $03A6, $03A5, $0020, $0090, $0001, $02EE, $00BB
    DECLE   $0000
_UW2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_VV:
    DECLE   _VV.end - _VV - 1
    DECLE   $0218, $030D, $016C, $010B, $010B, $0095, $034F, $03E4
    DECLE   $0108, $01B5, $01BE, $028B, $0160, $00AA, $03E4, $0106
    DECLE   $00EB, $02DE, $014C, $016E, $00F6, $0107, $00D2, $00CD
    DECLE   $0296, $00E4, $0006, $0000
_VV.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_WH:
    DECLE   _WH.end - _WH - 1
    DECLE   $0218, $00C9, $0000, $0084, $038E, $0147, $03A4, $0195
    DECLE   $0000, $012E, $0118, $0150, $02D1, $0232, $01B7, $03F1
    DECLE   $0237, $01C8, $03B1, $0227, $01AE, $0254, $0329, $032D
    DECLE   $01BF, $0169, $019A, $0307, $0181, $028D, $0000
_WH.end:  ; 31 decles
;; ------------------------------------------------------------------------ ;;
_WW:
    DECLE   _WW.end - _WW - 1
    DECLE   $0118, $034D, $016C, $00FA, $02C7, $0072, $03CC, $0109
    DECLE   $000B, $01AD, $019E, $016B, $0130, $0278, $01F8, $0314
    DECLE   $017E, $029E, $014D, $016D, $0205, $0147, $02E2, $001A
    DECLE   $010A, $026E, $0004, $0000
_WW.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_XR2:
    DECLE   _XR2.end - _XR2 - 1
    DECLE   $0318, $034C, $016E, $02A6, $03BB, $002F, $0290, $008E
    DECLE   $004B, $0392, $01DA, $024B, $013A, $01DA, $012F, $00B5
    DECLE   $02E5, $0297, $02DC, $0372, $014B, $016D, $0377, $00E7
    DECLE   $0376, $038A, $01CE, $026B, $02FA, $01AA, $011E, $0071
    DECLE   $00D5, $0297, $02BC, $02EA, $01C7, $02D7, $0135, $0155
    DECLE   $01DD, $0007, $0000
_XR2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_YR:
    DECLE   _YR.end - _YR - 1
    DECLE   $0318, $03CC, $016E, $0197, $00FD, $0130, $0270, $0094
    DECLE   $0328, $0291, $0168, $007E, $01CC, $02F5, $0125, $02B5
    DECLE   $00F4, $0298, $01DA, $03F6, $0153, $0126, $03B9, $00AB
    DECLE   $0293, $03DB, $0175, $01B9, $0001
_YR.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY1:
    DECLE   _YY1.end - _YY1 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0001, $0000
_YY1.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY2:
    DECLE   _YY2.end - _YY2 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0199, $01EE, $008B, $0161, $0232
    DECLE   $0004, $0318, $01A7, $0198, $0124, $03E0, $0001, $0001
    DECLE   $030F, $0027, $0000
_YY2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_ZH:
    DECLE   _ZH.end - _ZH - 1
    DECLE   $0310, $014D, $016E, $00C3, $03B9, $01BF, $0241, $0012
    DECLE   $0163, $00E1, $0000, $0080, $0084, $023F, $003F, $0000
_ZH.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_ZZ:
    DECLE   _ZZ.end - _ZZ - 1
    DECLE   $0218, $010D, $016F, $0225, $0351, $00B5, $02A0, $02EE
    DECLE   $00E9, $014D, $002C, $0360, $0008, $00EC, $004C, $0342
    DECLE   $03D4, $0156, $0052, $0131, $0008, $03B0, $01BE, $0172
    DECLE   $0000
_ZZ.end:  ; 25 decles

;;==========================================================================;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The above allophone data was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  INTELLIVOICE DRIVER ROUTINES                                            ;;
;;  Written in 2002 by Joe Zbiciak <intvnut AT gmail.com>                   ;;
;;  http://spatula-city.org/~im14u2c/intv/                                  ;;
;; ======================================================================== ;;

;; ======================================================================== ;;
;;  GLOBAL VARIABLES USED BY THESE ROUTINES                                 ;;
;;                                                                          ;;
;;  Note that some of these routines may use one or more global variables.  ;;
;;  If you use these routines, you will need to allocate the appropriate    ;;
;;  space in either 16-bit or 8-bit memory as appropriate.  Each global     ;;
;;  variable is listed with the routines which use it and the required      ;;
;;  memory width.                                                           ;;
;;                                                                          ;;
;;  Example declarations for these routines are shown below, commented out. ;;
;;  You should uncomment these and add them to your program to make use of  ;;
;;  the routine that needs them.  Make sure to assign these variables to    ;;
;;  locations that aren't used for anything else.                           ;;
;; ======================================================================== ;;

                        ; Used by       Req'd Width     Description
                        ;-----------------------------------------------------
;IV.QH      EQU $110    ; IV_xxx        8-bit           Voice queue head
;IV.QT      EQU $111    ; IV_xxx        8-bit           Voice queue tail
;IV.Q       EQU $112    ; IV_xxx        8-bit           Voice queue  (8 bytes)
;IV.FLEN    EQU $11A    ; IV_xxx        8-bit           Length of FIFO data
;IV.FPTR    EQU $320    ; IV_xxx        16-bit          Current FIFO ptr.
;IV.PPTR    EQU $321    ; IV_xxx        16-bit          Current Phrase ptr.

;; ======================================================================== ;;
;;  MEMORY USAGE                                                            ;;
;;                                                                          ;;
;;  These routines implement a queue of "pending phrases" that will be      ;;
;;  played by the Intellivoice.  The user calls IV_PLAY to enqueue a        ;;
;;  phrase number.  Phrase numbers indicate either a RESROM sample or       ;;
;;  a compiled in phrase to be spoken.                                      ;;
;;                                                                          ;;
;;  The user must compose an "IV_PHRASE_TBL", which is composed of          ;;
;;  pointers to phrases to be spoken.  Phrases are strings of pointers      ;;
;;  and RESROM triggers, terminated by a NUL.                               ;;
;;                                                                          ;;
;;  Phrase numbers 1 through 42 are RESROM samples.  Phrase numbers         ;;
;;  43 through 255 index into the IV_PHRASE_TBL.                            ;;
;;                                                                          ;;
;;  SPECIAL NOTES                                                           ;;
;;                                                                          ;;
;;  Bit 7 of IV.QH and IV.QT is used to denote whether the Intellivoice     ;;
;;  is present.  If Intellivoice is present, this bit is clear.             ;;
;;                                                                          ;;
;;  Bit 6 of IV.QT is used to denote that we still need to do an ALD $00    ;;
;;  for FIFO'd voice data.                                                  ;;
;; ======================================================================== ;;
            

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_INIT     Initialize the Intellivoice                             ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      0 if Intellivoice found, -1 if not.                         ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      Resets Intellivoice, determines if it is actually there, and        ;;
;;      then initializes the IV structure.                                  ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;

IV_INIT     PROC
            MVII    #$0400, R0          ;
            MVO     R0,     $0081       ; Reset the Intellivoice

            MVI     $0081,  R0          ; \
            RLC     R0,     2           ;  |-- See if we detect Intellivoice
            BOV     @@no_ivoice         ; /    once we've reset it.

            CLRR    R0                  ; 
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            MVO     R0,     IV.QH       ; Clear our queue
            MVO     R0,     IV.QT       ; Clear our queue
            JR      R5                  ; Done!

@@no_ivoice:
            CLRR    R0
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            DECR    R0
            MVO     R0,     IV.QH       ; Set queue to -1 ("No Intellivoice")
            MVO     R0,     IV.QT       ; Set queue to -1 ("No Intellivoice")
            JR      R5                  ; Done!
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_ISR      Interrupt service routine to feed Intellivoice          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_ISR                                                       ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1, R4 trashed.                                                 ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      Call this from your main interrupt service routine.                 ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_ISR      PROC
            ;; ------------------------------------------------------------ ;;
            ;;  Check for Intellivoice.  Leave if none present.             ;;
            ;; ------------------------------------------------------------ ;;
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2
            BPL     @@ok                ; Bit 7 set? If yes: No Intellivoice
@@ald_busy:
@@leave     JR      R5                  ; Exit if no Intellivoice.

     
            ;; ------------------------------------------------------------ ;;
            ;;  Check to see if we pump samples into the FIFO.
            ;; ------------------------------------------------------------ ;;
@@ok:       MVI     IV.FPTR, R4         ; Get FIFO data pointer
            TSTR    R4                  ; is it zero?
            BEQ     @@no_fifodata       ; Yes:  No data for FIFO.
@@fifo_fill:
            MVI     $0081,  R0          ; Read speech FIFO ready bit
            SLLC    R0,     1           ; 
            BC      @@fifo_busy     

            MVI@    R4,     R0          ; Get next word
            MVO     R0,     $0081       ; write it to the FIFO

            MVI     IV.FLEN, R0         ;\
            DECR    R0                  ; |-- Decrement our FIFO'd data length
            MVO     R0,     IV.FLEN     ;/
            BEQ     @@last_fifo         ; If zero, we're done w/ FIFO
            MVO     R4,     IV.FPTR     ; Otherwise, save new pointer
            B       @@fifo_fill         ; ...and keep trying to load FIFO

@@last_fifo MVO     R0,     IV.FPTR     ; done with FIFO loading.
                                        ; fall into ALD processing.


            ;; ------------------------------------------------------------ ;;
            ;;  Try to do an Address Load.  We do this in two settings:     ;;
            ;;   -- We have no FIFO data to load.                           ;;
            ;;   -- We've loaded as much FIFO data as we can, but we        ;;
            ;;      might have an address load command to send for it.      ;;
            ;; ------------------------------------------------------------ ;;
@@fifo_busy:
@@no_fifodata:
            MVI     $0080,  R0          ; Read LRQ bit from ALD register
            SLLC    R0,     1
            BNC     @@ald_busy          ; LRQ is low, meaning we can't ALD.
                                        ; So, leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We can do an address load (ALD) on the SP0256.  Give FIFO   ;;
            ;;  driven ALDs priority, since we already started the FIFO     ;;
            ;;  load.  The "need ALD" bit is stored in bit 6 of IV.QT.      ;;
            ;; ------------------------------------------------------------ ;;
            ANDI    #$40,   R1          ; Is "Need FIFO ALD" bit set?
            BEQ     @@no_fifo_ald
            XOR     IV.QT,  R1          ;\__ Clear the "Need FIFO ALD" bit.
            MVO     R1,     IV.QT       ;/
            CLRR    R1
            MVO     R1,     $80         ; Load a 0 into ALD (trigger FIFO rd.)
            JR      R5                  ; done!

            ;; ------------------------------------------------------------ ;;
            ;;  We don't need to ALD on behalf of the FIFO.  So, we grab    ;;
            ;;  the next thing off our phrase list.                         ;;
            ;; ------------------------------------------------------------ ;;
@@no_fifo_ald:
            MVI     IV.PPTR, R4         ; Get phrase pointer.
            TSTR    R4                  ; Is it zero?
            BEQ     @@next_phrase       ; Yes:  Get next phrase from queue.

            MVI@    R4,     R0
            TSTR    R0                  ; Is it end of phrase?
            BNEQ    @@process_phrase    ; !=0:  Go do it.

            MVO     R0,     IV.PPTR     ; 
@@next_phrase:
            MVI     IV.QT,  R1          ; reload queue tail (was trashed above)
            MOVR    R1,     R0          ; copy QT to R0 so we can increment it
            ANDI    #$7,    R1          ; Mask away flags in queue head
            CMP     IV.QH,  R1          ; Is it same as queue tail?
            BEQ     @@leave             ; Yes:  No more speech for now.

            INCR    R0
            ANDI    #$F7,   R0          ; mask away the possible 'carry'
            MVO     R0,     IV.QT       ; save updated queue tail

            ADDI    #IV.Q,  R1          ; Index into queue
            MVI@    R1,     R4          ; get next value from queue
            CMPI    #43,    R4          ; Is it a RESROM or Phrase?
            BNC     @@play_resrom_r4
@@new_phrase:
;            ADDI    #IV_PHRASE_TBL - 43, R4 ; Index into phrase table
;            MVI@    R4,     R4          ; Read from phrase table
            MVO     R4,     IV.PPTR
            JR      R5                  ; we'll get to this phrase next time.

@@play_resrom_r4:
            MVO     R4,     $0080       ; Just ALD it
            JR      R5                  ; and leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We're in the middle of a phrase, so continue interpreting.  ;;
            ;; ------------------------------------------------------------ ;;
@@process_phrase:
            
            MVO     R4,     IV.PPTR     ; save new phrase pointer
            CMPI    #43,    R0          ; Is it a RESROM cue?
            BC      @@play_fifo         ; Just ALD it and leave.
@@play_resrom_r0
            MVO     R0,     $0080       ; Just ALD it
            JR      R5                  ; and leave.
@@play_fifo:
            MVI     IV.FPTR,R1          ; Make sure not to stomp existing FIFO
            TSTR    R1                  ; data.
            BEQ     @@new_fifo_ok
            DECR    R4                  ; Oops, FIFO data still playing,
            MVO     R4,     IV.PPTR     ; so rewind.
            JR      R5                  ; and leave.

@@new_fifo_ok:
            MOVR    R0,     R4          ;
            MVI@    R4,     R0          ; Get chunk length
            MVO     R0,     IV.FLEN     ; Init FIFO chunk length
            MVO     R4,     IV.FPTR     ; Init FIFO pointer
            MVI     IV.QT,  R0          ;\
            XORI    #$40,   R0          ; |- Set "Need ALD" bit in QT
            MVO     R0,     IV.QT       ;/

  IF 1      ; debug code                ;\
            ANDI    #$40,   R0          ; |   Debug code:  We should only
            BNEQ    @@qtok              ; |-- be here if "Need FIFO ALD" 
            HLT     ;BUG!!              ; |   was already clear.         
@@qtok                                  ;/    
  ENDI
            JR      R5                  ; leave.

            ENDP


;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAY     Play a voice sample sequence.                           ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;      Z==0    if item not successfully queued.                            ;;
;;      Z==1    if successfully queued.                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will drop phrases if the queue is full.                   ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAY     PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     @@leave             ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@leave             ; Leave if we're full

@@2:        MVI     IV.QH,  R1          ; Get our queue head pointer
            PSHR    R1                  ;\
            INCR    R1                  ; |
            ANDI    #$F7,   R1          ; |-- Increment it, removing
            MVO     R1,     IV.QH       ; |   carry but preserving flags.
            PULR    R1                  ;/

            ADDI    #IV.Q,  R1          ;\__ Store phrase to queue
            MVO@    R0,     R1          ;/

@@leave:    JR      R5                  ; Leave.
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAYW    Play a voice sample sequence.  Wait for queue room.     ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will wait for a queue slot to open if queue is full.      ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAYW    PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     IV_PLAY.leave       ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@1                 ; wait for room
            B       IV_PLAY.2

            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_WAIT     Wait for voice queue to empty.                          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_WAIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      trashed.                                                    ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This waits until the Intellivoice is nearly completely quiescent.   ;;
;;      Some voice data may still be spoken from the last triggered         ;;
;;      phrase.  To truly wait for *that* to be spoken, speak a 'pause'     ;;
;;      (eg. RESROM.pa1) and then call IV_WAIT.                             ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_WAIT     PROC
            MVI     IV.QH,  R0
            SWAP    R0                  ;\___ test bit 7, leave if set.
            SWAP    R0                  ;/    (SWAP2 corrupts upper byte.)
            BMI     @@leave

            ; Wait for queue to drain.
@@q_loop:   CMP     IV.QT,  R0
            BNEQ    @@q_loop

            ; Wait for FIFO and LRQ to say ready.
@@s_loop:   MVI     $81,    R0          ; Read FIFO status.  0 == ready.
            COMR    R0
            AND     $80,    R0          ; Merge w/ ALD status.  1 == ready
            TSTR    R0
            BPL     @@s_loop            ; if bit 15 == 0, not ready.
            
@@leave:    JR      R5
            ENDP

;; ======================================================================== ;;
;;  End of File:  ivoice.asm                                                ;;
;; ======================================================================== ;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_SAYNUM16 Say a 16-bit unsigned number using RESROM digits        ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      16-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R0      Number to "speak"                                           ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      "Says" a 16-bit number using IV_PLAYW to queue up the phrase.       ;;
;;      Because the number may be built from several segments, it could     ;;
;;      easily eat up the queue.  I believe the longest number will take    ;;
;;      7 queue entries -- that is, fill the queue.  Thus, this code        ;;
;;      could block, waiting for slots in the queue.                        ;;
;; ======================================================================== ;;

IV_SAYNUM16 PROC
            PSHR    R5

            TSTR    R0
            BEQ     @@zero          ; Special case:  Just say "zero"

            ;; ------------------------------------------------------------ ;;
            ;;  First, try to pull off 'thousands'.  We call ourselves      ;;
            ;;  recursively to play the the number of thousands.            ;;
            ;; ------------------------------------------------------------ ;;
            CLRR    R1
@@thloop:   INCR    R1
            SUBI    #1000,  R0
            BC      @@thloop

            ADDI    #1000,  R0
            PSHR    R0
            DECR    R1
            BEQ     @@no_thousand

            CALL    IV_SAYNUM16.recurse

            CALL    IV_PLAYW
            DECLE   36  ; THOUSAND
            
@@no_thousand
            PULR    R1

            ;; ------------------------------------------------------------ ;;
            ;;  Now try to play hundreds.                                   ;;
            ;; ------------------------------------------------------------ ;;
            MVII    #7-1, R0    ; ZERO
            CMPI    #100,   R1
            BNC     @@no_hundred

@@hloop:    INCR    R0
            SUBI    #100,   R1
            BC      @@hloop
            ADDI    #100,   R1

            PSHR    R1

            CALL    IV_PLAYW.1

            CALL    IV_PLAYW
            DECLE   35  ; HUNDRED

            PULR    R1
            B       @@notrecurse    ; skip "PSHR R5"
@@recurse:  PSHR    R5              ; recursive entry point for 'thousand'

@@no_hundred:
@@notrecurse:
            MOVR    R1,     R0
            BEQ     @@leave

            SUBI    #20,    R1
            BNC     @@teens

            MVII    #27-1, R0   ; TWENTY
@@tyloop    INCR    R0
            SUBI    #10,    R1
            BC      @@tyloop
            ADDI    #10,    R1

            PSHR    R1
            CALL    IV_PLAYW.1

            PULR    R0
            TSTR    R0
            BEQ     @@leave

@@teens:
@@zero:     ADDI    #7, R0  ; ZERO

            CALL    IV_PLAYW.1

@@leave     PULR    PC
            ENDP

;; ======================================================================== ;;
;;  End of File:  saynum16.asm                                              ;;
;; ======================================================================== ;;

    ENDI

	IF DEFINED intybasic_ecs
	ORG $4800	; Available up to $4FFF

        ; Disable ECS ROMs so that they don't conflict with us
        MVII    #$2A5F, R0
        MVO     R0,     $2FFF
        MVII    #$7A5F, R0
        MVO     R0,     $7FFF
        MVII    #$EA5F, R0
        MVO     R0,     $EFFF

        B       $1041       ; resume boot

	ENDI

	IF DEFINED intybasic_fastmult

; Quarter Square Multiplication
; Assembly code by Joe Zbiciak, 2015
; Released to public domain.

QSQR8_TBL:  PROC
            DECLE   $3F80, $3F01, $3E82, $3E04, $3D86, $3D09, $3C8C, $3C10
            DECLE   $3B94, $3B19, $3A9E, $3A24, $39AA, $3931, $38B8, $3840
            DECLE   $37C8, $3751, $36DA, $3664, $35EE, $3579, $3504, $3490
            DECLE   $341C, $33A9, $3336, $32C4, $3252, $31E1, $3170, $3100
            DECLE   $3090, $3021, $2FB2, $2F44, $2ED6, $2E69, $2DFC, $2D90
            DECLE   $2D24, $2CB9, $2C4E, $2BE4, $2B7A, $2B11, $2AA8, $2A40
            DECLE   $29D8, $2971, $290A, $28A4, $283E, $27D9, $2774, $2710
            DECLE   $26AC, $2649, $25E6, $2584, $2522, $24C1, $2460, $2400
            DECLE   $23A0, $2341, $22E2, $2284, $2226, $21C9, $216C, $2110
            DECLE   $20B4, $2059, $1FFE, $1FA4, $1F4A, $1EF1, $1E98, $1E40
            DECLE   $1DE8, $1D91, $1D3A, $1CE4, $1C8E, $1C39, $1BE4, $1B90
            DECLE   $1B3C, $1AE9, $1A96, $1A44, $19F2, $19A1, $1950, $1900
            DECLE   $18B0, $1861, $1812, $17C4, $1776, $1729, $16DC, $1690
            DECLE   $1644, $15F9, $15AE, $1564, $151A, $14D1, $1488, $1440
            DECLE   $13F8, $13B1, $136A, $1324, $12DE, $1299, $1254, $1210
            DECLE   $11CC, $1189, $1146, $1104, $10C2, $1081, $1040, $1000
            DECLE   $0FC0, $0F81, $0F42, $0F04, $0EC6, $0E89, $0E4C, $0E10
            DECLE   $0DD4, $0D99, $0D5E, $0D24, $0CEA, $0CB1, $0C78, $0C40
            DECLE   $0C08, $0BD1, $0B9A, $0B64, $0B2E, $0AF9, $0AC4, $0A90
            DECLE   $0A5C, $0A29, $09F6, $09C4, $0992, $0961, $0930, $0900
            DECLE   $08D0, $08A1, $0872, $0844, $0816, $07E9, $07BC, $0790
            DECLE   $0764, $0739, $070E, $06E4, $06BA, $0691, $0668, $0640
            DECLE   $0618, $05F1, $05CA, $05A4, $057E, $0559, $0534, $0510
            DECLE   $04EC, $04C9, $04A6, $0484, $0462, $0441, $0420, $0400
            DECLE   $03E0, $03C1, $03A2, $0384, $0366, $0349, $032C, $0310
            DECLE   $02F4, $02D9, $02BE, $02A4, $028A, $0271, $0258, $0240
            DECLE   $0228, $0211, $01FA, $01E4, $01CE, $01B9, $01A4, $0190
            DECLE   $017C, $0169, $0156, $0144, $0132, $0121, $0110, $0100
            DECLE   $00F0, $00E1, $00D2, $00C4, $00B6, $00A9, $009C, $0090
            DECLE   $0084, $0079, $006E, $0064, $005A, $0051, $0048, $0040
            DECLE   $0038, $0031, $002A, $0024, $001E, $0019, $0014, $0010
            DECLE   $000C, $0009, $0006, $0004, $0002, $0001, $0000
@@mid:
            DECLE   $0000, $0000, $0001, $0002, $0004, $0006, $0009, $000C
            DECLE   $0010, $0014, $0019, $001E, $0024, $002A, $0031, $0038
            DECLE   $0040, $0048, $0051, $005A, $0064, $006E, $0079, $0084
            DECLE   $0090, $009C, $00A9, $00B6, $00C4, $00D2, $00E1, $00F0
            DECLE   $0100, $0110, $0121, $0132, $0144, $0156, $0169, $017C
            DECLE   $0190, $01A4, $01B9, $01CE, $01E4, $01FA, $0211, $0228
            DECLE   $0240, $0258, $0271, $028A, $02A4, $02BE, $02D9, $02F4
            DECLE   $0310, $032C, $0349, $0366, $0384, $03A2, $03C1, $03E0
            DECLE   $0400, $0420, $0441, $0462, $0484, $04A6, $04C9, $04EC
            DECLE   $0510, $0534, $0559, $057E, $05A4, $05CA, $05F1, $0618
            DECLE   $0640, $0668, $0691, $06BA, $06E4, $070E, $0739, $0764
            DECLE   $0790, $07BC, $07E9, $0816, $0844, $0872, $08A1, $08D0
            DECLE   $0900, $0930, $0961, $0992, $09C4, $09F6, $0A29, $0A5C
            DECLE   $0A90, $0AC4, $0AF9, $0B2E, $0B64, $0B9A, $0BD1, $0C08
            DECLE   $0C40, $0C78, $0CB1, $0CEA, $0D24, $0D5E, $0D99, $0DD4
            DECLE   $0E10, $0E4C, $0E89, $0EC6, $0F04, $0F42, $0F81, $0FC0
            DECLE   $1000, $1040, $1081, $10C2, $1104, $1146, $1189, $11CC
            DECLE   $1210, $1254, $1299, $12DE, $1324, $136A, $13B1, $13F8
            DECLE   $1440, $1488, $14D1, $151A, $1564, $15AE, $15F9, $1644
            DECLE   $1690, $16DC, $1729, $1776, $17C4, $1812, $1861, $18B0
            DECLE   $1900, $1950, $19A1, $19F2, $1A44, $1A96, $1AE9, $1B3C
            DECLE   $1B90, $1BE4, $1C39, $1C8E, $1CE4, $1D3A, $1D91, $1DE8
            DECLE   $1E40, $1E98, $1EF1, $1F4A, $1FA4, $1FFE, $2059, $20B4
            DECLE   $2110, $216C, $21C9, $2226, $2284, $22E2, $2341, $23A0
            DECLE   $2400, $2460, $24C1, $2522, $2584, $25E6, $2649, $26AC
            DECLE   $2710, $2774, $27D9, $283E, $28A4, $290A, $2971, $29D8
            DECLE   $2A40, $2AA8, $2B11, $2B7A, $2BE4, $2C4E, $2CB9, $2D24
            DECLE   $2D90, $2DFC, $2E69, $2ED6, $2F44, $2FB2, $3021, $3090
            DECLE   $3100, $3170, $31E1, $3252, $32C4, $3336, $33A9, $341C
            DECLE   $3490, $3504, $3579, $35EE, $3664, $36DA, $3751, $37C8
            DECLE   $3840, $38B8, $3931, $39AA, $3A24, $3A9E, $3B19, $3B94
            DECLE   $3C10, $3C8C, $3D09, $3D86, $3E04, $3E82, $3F01, $3F80
            DECLE   $4000, $4080, $4101, $4182, $4204, $4286, $4309, $438C
            DECLE   $4410, $4494, $4519, $459E, $4624, $46AA, $4731, $47B8
            DECLE   $4840, $48C8, $4951, $49DA, $4A64, $4AEE, $4B79, $4C04
            DECLE   $4C90, $4D1C, $4DA9, $4E36, $4EC4, $4F52, $4FE1, $5070
            DECLE   $5100, $5190, $5221, $52B2, $5344, $53D6, $5469, $54FC
            DECLE   $5590, $5624, $56B9, $574E, $57E4, $587A, $5911, $59A8
            DECLE   $5A40, $5AD8, $5B71, $5C0A, $5CA4, $5D3E, $5DD9, $5E74
            DECLE   $5F10, $5FAC, $6049, $60E6, $6184, $6222, $62C1, $6360
            DECLE   $6400, $64A0, $6541, $65E2, $6684, $6726, $67C9, $686C
            DECLE   $6910, $69B4, $6A59, $6AFE, $6BA4, $6C4A, $6CF1, $6D98
            DECLE   $6E40, $6EE8, $6F91, $703A, $70E4, $718E, $7239, $72E4
            DECLE   $7390, $743C, $74E9, $7596, $7644, $76F2, $77A1, $7850
            DECLE   $7900, $79B0, $7A61, $7B12, $7BC4, $7C76, $7D29, $7DDC
            DECLE   $7E90, $7F44, $7FF9, $80AE, $8164, $821A, $82D1, $8388
            DECLE   $8440, $84F8, $85B1, $866A, $8724, $87DE, $8899, $8954
            DECLE   $8A10, $8ACC, $8B89, $8C46, $8D04, $8DC2, $8E81, $8F40
            DECLE   $9000, $90C0, $9181, $9242, $9304, $93C6, $9489, $954C
            DECLE   $9610, $96D4, $9799, $985E, $9924, $99EA, $9AB1, $9B78
            DECLE   $9C40, $9D08, $9DD1, $9E9A, $9F64, $A02E, $A0F9, $A1C4
            DECLE   $A290, $A35C, $A429, $A4F6, $A5C4, $A692, $A761, $A830
            DECLE   $A900, $A9D0, $AAA1, $AB72, $AC44, $AD16, $ADE9, $AEBC
            DECLE   $AF90, $B064, $B139, $B20E, $B2E4, $B3BA, $B491, $B568
            DECLE   $B640, $B718, $B7F1, $B8CA, $B9A4, $BA7E, $BB59, $BC34
            DECLE   $BD10, $BDEC, $BEC9, $BFA6, $C084, $C162, $C241, $C320
            DECLE   $C400, $C4E0, $C5C1, $C6A2, $C784, $C866, $C949, $CA2C
            DECLE   $CB10, $CBF4, $CCD9, $CDBE, $CEA4, $CF8A, $D071, $D158
            DECLE   $D240, $D328, $D411, $D4FA, $D5E4, $D6CE, $D7B9, $D8A4
            DECLE   $D990, $DA7C, $DB69, $DC56, $DD44, $DE32, $DF21, $E010
            DECLE   $E100, $E1F0, $E2E1, $E3D2, $E4C4, $E5B6, $E6A9, $E79C
            DECLE   $E890, $E984, $EA79, $EB6E, $EC64, $ED5A, $EE51, $EF48
            DECLE   $F040, $F138, $F231, $F32A, $F424, $F51E, $F619, $F714
            DECLE   $F810, $F90C, $FA09, $FB06, $FC04, $FD02, $FE01
            ENDP

; R0 = R0 * R1, where R0 and R1 are unsigned 8-bit values
; Destroys R1, R4
qs_mpy8:    PROC
            MOVR    R0,             R4      ;   6
            ADDI    #QSQR8_TBL.mid, R1      ;   8
            ADDR    R1,             R4      ;   6   a + b
            SUBR    R0,             R1      ;   6   a - b
@@ok:       MVI@    R4,             R0      ;   8
            SUB@    R1,             R0      ;   8
            JR      R5                      ;   7
                                            ;----
                                            ;  49
            ENDP
            

; R1 = R0 * R1, where R0 and R1 are 16-bit values
; destroys R0, R2, R3, R4, R5
qs_mpy16:   PROC
            PSHR    R5                  ;   9
                                   
            ; Unpack lo/hi
            MOVR    R0,         R2      ;   6   
            ANDI    #$FF,       R0      ;   8   R0 is lo(a)
            XORR    R0,         R2      ;   6   
            SWAP    R2                  ;   6   R2 is hi(a)

            MOVR    R1,         R3      ;   6   R3 is orig 16-bit b
            ANDI    #$FF,       R1      ;   8   R1 is lo(b)
            MOVR    R1,         R5      ;   6   R5 is lo(b)
            XORR    R1,         R3      ;   6   
            SWAP    R3                  ;   6   R3 is hi(b)
                                        ;----
                                        ;  67
                                        
            ; lo * lo                   
            MOVR    R0,         R4      ;   6   R4 is lo(a)
            ADDI    #QSQR8_TBL.mid, R1  ;   8
            ADDR    R1,         R4      ;   6   R4 = lo(a) + lo(b)
            SUBR    R0,         R1      ;   6   R1 = lo(a) - lo(b)
                                        
@@pos_ll:   MVI@    R4,         R4      ;   8   R4 = qstbl[lo(a)+lo(b)]
            SUB@    R1,         R4      ;   8   R4 = lo(a)*lo(b)
                                        ;----
                                        ;  42
                                        ;  67 (carried forward)
                                        ;----
                                        ; 109
                                       
            ; lo * hi                  
            MOVR    R0,         R1      ;   6   R0 = R1 = lo(a)
            ADDI    #QSQR8_TBL.mid, R3  ;   8
            ADDR    R3,         R1      ;   6   R1 = hi(b) + lo(a)
            SUBR    R0,         R3      ;   6   R3 = hi(b) - lo(a)
                                       
@@pos_lh:   MVI@    R1,         R1      ;   8   R1 = qstbl[hi(b)-lo(a)]
            SUB@    R3,         R1      ;   8   R1 = lo(a)*hi(b)
                                        ;----
                                        ;  42
                                        ; 109 (carried forward)
                                        ;----
                                        ; 151
                                       
            ; hi * lo                  
            MOVR    R5,         R0      ;   6   R5 = R0 = lo(b)
            ADDI    #QSQR8_TBL.mid, R2  ;   8
            ADDR    R2,         R5      ;   6   R3 = hi(a) + lo(b)
            SUBR    R0,         R2      ;   6   R2 = hi(a) - lo(b)
                                       
@@pos_hl:   ADD@    R5,         R1      ;   8   \_ R1 = lo(a)*hi(b)+hi(a)*lo(b)
            SUB@    R2,         R1      ;   8   /
                                        ;----
                                        ;  42
                                        ; 151 (carried forward)
                                        ;----
                                        ; 193
                                       
            SWAP    R1                  ;   6   \_ shift upper product left 8
            ANDI    #$FF00,     R1      ;   8   /
            ADDR    R4,         R1      ;   6   final product
            PULR    PC                  ;  12
                                        ;----
                                        ;  32
                                        ; 193 (carried forward)
                                        ;----
                                        ; 225
            ENDP

	ENDI

	IF DEFINED intybasic_fastdiv

; Fast unsigned division/remainder
; Assembly code by Oscar Toledo G. Jul/10/2015
; Released to public domain.

	; Ultrafast unsigned division/remainder operation
	; Entry: R0 = Dividend
	;        R1 = Divisor
	; Output: R0 = Quotient
	;         R2 = Remainder
	; Worst case: 6 + 6 + 9 + 496 = 517 cycles
	; Best case: 6 + (6 + 7) * 16 = 214 cycles

uf_udiv16:	PROC
	CLRR R2		; 6
	SLLC R0,1	; 6
	BC @@1		; 7/9
	SLLC R0,1	; 6
	BC @@2		; 7/9
	SLLC R0,1	; 6
	BC @@3		; 7/9
	SLLC R0,1	; 6
	BC @@4		; 7/9
	SLLC R0,1	; 6
	BC @@5		; 7/9
	SLLC R0,1	; 6
	BC @@6		; 7/9
	SLLC R0,1	; 6
	BC @@7		; 7/9
	SLLC R0,1	; 6
	BC @@8		; 7/9
	SLLC R0,1	; 6
	BC @@9		; 7/9
	SLLC R0,1	; 6
	BC @@10		; 7/9
	SLLC R0,1	; 6
	BC @@11		; 7/9
	SLLC R0,1	; 6
	BC @@12		; 7/9
	SLLC R0,1	; 6
	BC @@13		; 7/9
	SLLC R0,1	; 6
	BC @@14		; 7/9
	SLLC R0,1	; 6
	BC @@15		; 7/9
	SLLC R0,1	; 6
	BC @@16		; 7/9
	JR R5

@@1:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@2:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@3:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@4:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@5:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@6:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@7:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@8:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@9:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@10:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@11:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@12:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@13:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@14:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@15:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@16:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
	JR R5
	
	ENDP

	ENDI

        ORG $319,$319,"-RWB"
        ;
        ; 16-bits variables
	; Note IntyBASIC variables grow up starting in $308.
        ;
        IF DEFINED intybasic_voice
IV.Q:      RMB 8    ; IV_xxx        16-bit          Voice queue  (8 words)
IV.FPTR:   RMB 1    ; IV_xxx        16-bit          Current FIFO ptr.
IV.PPTR:   RMB 1    ; IV_xxx        16-bit          Current Phrase ptr.
        ENDI

        ORG $323,$323,"-RWB"

_scroll_buffer: RMB 20  ; Sometimes this is unused
_music_table:	RMB 1	; Note table
_music_start:	RMB 1	; Start of music
_music_p:	RMB 1	; Pointer to music
_frame:         RMB 1   ; Current frame
_read:          RMB 1   ; Pointer to DATA
_gram_bitmap:   RMB 1   ; Bitmap for definition
_gram2_bitmap:  RMB 1   ; Secondary bitmap for definition
_screen:    RMB 1       ; Pointer to current screen position
_color:     RMB 1       ; Current color
_mobs:      RMB 3*8     ; MOB buffer
_col0:      RMB 1       ; Collision status for MOB0
_col1:      RMB 1       ; Collision status for MOB1
_col2:      RMB 1       ; Collision status for MOB2
_col3:      RMB 1       ; Collision status for MOB3
_col4:      RMB 1       ; Collision status for MOB4
_col5:      RMB 1       ; Collision status for MOB5
_col6:      RMB 1       ; Collision status for MOB6
_col7:      RMB 1       ; Collision status for MOB7

SCRATCH:    ORG $100,$100,"-RWBN"
        ;
        ; 8-bits variables
        ;
ISRVEC:     RMB 2       ; Pointer to ISR vector (required by Intellivision ROM)
_int:       RMB 1       ; Signals interrupt received
_ntsc:      RMB 1       ; Signals NTSC Intellivision
_rand:      RMB 1       ; Pseudo-random value
_gram_target:   RMB 1   ; Contains GRAM card number
_gram_total:    RMB 1   ; Contains total GRAM cards for definition
_gram2_target:  RMB 1   ; Contains GRAM card number
_gram2_total:   RMB 1   ; Contains total GRAM cards for definition
_mode_select:   RMB 1   ; Graphics mode selection
_border_color:  RMB 1   ; Border color
_border_mask:   RMB 1   ; Border mask
    IF DEFINED intybasic_keypad
_cnt1_p0:   RMB 1       ; Debouncing 1
_cnt1_p1:   RMB 1       ; Debouncing 2
_cnt1_key:  RMB 1       ; Currently pressed key
_cnt2_p0:   RMB 1       ; Debouncing 1
_cnt2_p1:   RMB 1       ; Debouncing 2
_cnt2_key:  RMB 1       ; Currently pressed key
    ENDI
    IF DEFINED intybasic_scroll
_scroll_x:  RMB 1       ; Scroll X offset
_scroll_y:  RMB 1       ; Scroll Y offset
_scroll_d:  RMB 1       ; Scroll direction
    ENDI
    IF DEFINED intybasic_music
_music_mode: RMB 1      ; Music mode (0= Not using PSG, 1= Simple, 2= Full)
_music_frame: RMB 1     ; Music frame (for 50 hz fixed)
_music_tc:  RMB 1       ; Time counter
_music_t:   RMB 1       ; Time base
_music_i1:  RMB 1       ; Instrument 1 
_music_s1:  RMB 1       ; Sample pointer 1
_music_n1:  RMB 1       ; Note 1
_music_i2:  RMB 1       ; Instrument 2
_music_s2:  RMB 1       ; Sample pointer 2
_music_n2:  RMB 1       ; Note 2
_music_i3:  RMB 1       ; Instrument 3
_music_s3:  RMB 1       ; Sample pointer 3
_music_n3:  RMB 1       ; Note 3
_music_s4:  RMB 1       ; Sample pointer 4
_music_n4:  RMB 1       ; Note 4 (really it's drum)

_music_freq10:	RMB 1   ; Low byte frequency A
_music_freq20:	RMB 1   ; Low byte frequency B
_music_freq30:	RMB 1   ; Low byte frequency C
_music_freq11:	RMB 1   ; High byte frequency A
_music_freq21:	RMB 1   ; High byte frequency B
_music_freq31:	RMB 1   ; High byte frequency C
_music_mix:	RMB 1   ; Mixer
_music_noise:	RMB 1   ; Noise
_music_vol1:	RMB 1   ; Volume A
_music_vol2:	RMB 1   ; Volume B
_music_vol3:	RMB 1   ; Volume C
    ENDI
    IF DEFINED intybasic_voice
IV.QH:     RMB 1    ; IV_xxx        8-bit           Voice queue head
IV.QT:     RMB 1    ; IV_xxx        8-bit           Voice queue tail
IV.FLEN:   RMB 1    ; IV_xxx        8-bit           Length of FIFO data
    ENDI


V59:	RMB 1	; ARCH
V54:	RMB 1	; CNT
V47:	RMB 1	; DAYTIME
V48:	RMB 1	; DAYTIME_CNT
V15:	RMB 1	; DIRECTION
V14:	RMB 1	; DIR_CNT
V43:	RMB 1	; DRAW_X
V44:	RMB 1	; DRAW_Y
V41:	RMB 1	; ENEMY
V42:	RMB 1	; ENEMY_ATK
V16:	RMB 1	; HANDS
V30:	RMB 1	; HARP1
V31:	RMB 1	; HARP2
V32:	RMB 1	; HARP3
V33:	RMB 1	; HARPOON
V8:	RMB 1	; HEALTH
V28:	RMB 1	; HIT_CNT
V29:	RMB 1	; HIT_TOTAL
V74:	RMB 1	; INC
V27:	RMB 1	; KILL_CNT
V26:	RMB 1	; KILL_QTY
V9:	RMB 1	; LEVEL
V7:	RMB 1	; LIVES
V11:	RMB 1	; MAP
V70:	RMB 1	; MOVE_DIR
V17:	RMB 1	; OFFSET
V35:	RMB 1	; PADDLE
V18:	RMB 1	; PLAYER_X
V19:	RMB 1	; PLAYER_Y
V25:	RMB 1	; ROW
V24:	RMB 1	; ROW_CNT
V23:	RMB 1	; ROW_SPEED
V22:	RMB 1	; ROW_TOTAL
V58:	RMB 1	; SAIL_DIR
V61:	RMB 1	; SCORE_CNT
V50:	RMB 1	; STORM_CNT
V51:	RMB 1	; STORM_CNT_TOTAL
V57:	RMB 1	; STORM_FLAG
V52:	RMB 1	; STORM_QTY
V53:	RMB 1	; STORM_ROLL
V49:	RMB 1	; SUN_X
V63:	RMB 1	; THROW_X
V10:	RMB 1	; TIMEOUT_FLAG
V38:	RMB 1	; TOWN1_CNT
V39:	RMB 1	; TOWN2_CNT
V40:	RMB 1	; TOWN3_CNT
V37:	RMB 1	; TOWN_CHECK
V45:	RMB 1	; WAVE_X
V46:	RMB 1	; WAVE_Y
V12:	RMB 1	; WHALEX
V20:	RMB 1	; WHALEX_MAP
V13:	RMB 1	; WHALEY
V21:	RMB 1	; WHALEY_MAP
V56:	RMB 1	; WHALE_CNT
V71:	RMB 1	; WHALE_DIR
V66:	RMB 1	; WHALE_DOWN
V64:	RMB 1	; WHALE_POSITION
V65:	RMB 1	; WHALE_UP
V68:	RMB 1	; WIND_BONUS
V36:	RMB 1	; WIND_CNT
V55:	RMB 1	; WIND_DIRECTION
V34:	RMB 1	; WIND_FLUTE
V69:	RMB 1	; WIND_OFFSET
V62:	RMB 1	; WIND_ROLL
V60:	RMB 1	; X
V73:	RMB 1	; XMAX
V72:	RMB 1	; XMIN
V67:	RMB 1	; Y
Q4:	RMB 12	; STORMX_MAP
Q5:	RMB 12	; STORMY_MAP
_SCRATCH:	EQU $

SYSTEM:	ORG $2F0, $2F0, "-RWBN"
STACK:	RMB 24
V2:	RMB 1	; #CHAR_DIR
V1:	RMB 1	; #DAY_CNT
V3:	RMB 1	; #ENEMY_DIR
V5:	RMB 1	; #NEW_SCORE
V6:	RMB 1	; #NEXT_SCORE
V4:	RMB 1	; #SCORE
Q2:	EQU $0200
Q1:	EQU _mobs
_SYSTEM:	EQU $
